@@ -28,7 +28,7 @@
 
 #include "fdb5/LibFdb5.h"
 #include "fdb5/api/FDB.h"
-#include "fdb5/grib/GribArchiver.h"
+#include "fdb5/message/MessageArchiver.h"
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -262,7 +262,7 @@ static err fdb5_write(void* data, request* r, void* buffer, long* length) {
 
         fdb5::Key check;
 
-        fdb5::GribArchiver archiver(check);
+        fdb5::MessageArchiver archiver(check);
 
         eckit::MemoryHandle mh(buffer, size_t(*length));
 
