@@ -712,6 +712,14 @@ static option mars_opts[] = {
      sizeof(boolean),
      OFFSET(globals, auto_split_by_dates)},
 
+    {NULL,
+     "MARS_AUTO_SPLIT_BY_DAY",
+     NULL,
+     "0",
+     t_boolean,
+     sizeof(boolean),
+     OFFSET(globals, auto_split_by_day)},
+
     {NULL,
      "WEBMARS_KEEP_DATABASE",
      NULL,
