@@ -155,7 +155,7 @@ boolean bias(const request* r);
 boolean track(const request* r);
 boolean is_bufr(const request* r);
 boolean is_odb(const request* r);
-boolean is_ocean(const request* r);
+boolean is_ocean_netcdf(const request* r);
 boolean is_grib(const request* r);
 boolean wave2d(const request* r);
 parameter* find_parameter(const request* r, const char* parname);
