@@ -56,7 +56,7 @@ typedef struct retrieve_err_list {
 
 static const request* multi_choices(const request* t, const request* req, const char* name, err* error) {
     const request* choices = get_subrequest(t, "choices", 0);
-    *error = -2;
+    *error                 = -2;
     if (choices) {
         const char* verb        = strcache(lowcase(req->name));
         const request* choice   = choices;
@@ -651,48 +651,44 @@ err handle_retrieve(request* r, void* data) {
 
     if (e == EOF || e == TOO_SHORT_ERR) {
 
-        if (is_odb(r)) {
-
-            /* For ODB data, we don't know how much we are expecting, and it may
-             * come from multiple sources
-             *
-             * --> If there is no data available, this could have been for there
-             *     being no data, or because of an error on a previous database
-             * --> Check that... */
-
-            if (cnt == 0 && visited > 0) {
-                e = NOERR;
-                for (retrieve_err_list_t* err = db_errs.next; err != NULL; err = err->next) {
-                    if (err->e != NOERR && err->e != EOF && err->e != TOO_SHORT_ERR) {
-                        e = err->e;
-                    }
+        if (cnt == 0 && visited > 0) {
+            e = NOERR;
+            for (retrieve_err_list_t* err = db_errs.next; err != NULL; err = err->next) {
+                if (err->e != NOERR && err->e != EOF && err->e != TOO_SHORT_ERR) {
+                    e = err->e;
                 }
             }
         }
-        else {
-            /* TODO: This is just the old behaviour */
 
-            if (!enough(r, cnt) && is_bufr(r) && visited > 0) {
-                e = NOERR;
-            }
-            else if (!enough(r, cnt)) {
-                const char* expect = get_value(r, "EXPECT", 0);
-                if (expect == NULL || atol(expect) != 0) {
-                    if (all_is_used(r))
-                        marslog(LOG_EROR, "MARS considers %d fields retrieved are not enough", cnt);
-                    else
-                        marslog(LOG_EROR, "Expected %d, got %d.", need, cnt);
+        if(e) {
+            marslog(LOG_EROR, "Last error is %d", e);
+        }
+
+        if (!enough(r, cnt) && is_bufr(r) && visited > 0) {
+            e = NOERR;
+        }
+        else if (!enough(r, cnt)) {
+            const char* expect = get_value(r, "EXPECT", 0);
+            if (expect == NULL || atol(expect) != 0) {
+                if (all_is_used(r)) {
+                    marslog(LOG_EROR, "MARS considers %d fields retrieved are not enough", cnt);
                     e = -1;
                 }
                 else {
-                    if (e == TOO_SHORT_ERR) {
-                        long length = 0;
-                        marslog(LOG_WARN, "No data, but EXPECT was provided");
-                        database_write(target, 0, 0, &length);
-                        e = 0;
+                    if(need != cnt){
+                        marslog(LOG_EROR, "Expected %d, got %d.", need, cnt);
+                        e = -1;
                     }
                 }
             }
+            else {
+                if (e == TOO_SHORT_ERR || e == NOERR) {
+                    long length = 0;
+                    marslog(LOG_WARN, "No data, but EXPECT was provided");
+                    database_write(target, 0, 0, &length);
+                    e = 0;
+                }
+            }
         }
     }
 
