@@ -13,42 +13,37 @@
 #ifndef Endowned_H
 #define Endowned_H
 
-#include <string>
 #include <map>
+#include <string>
 
 class Attribute;
 
-class Endowed
-{
+class Endowed {
 public:
     Endowed();
     virtual ~Endowed();
 
     // -- Methods
-    void add(Attribute *);
+    void add(Attribute*);
 
     void getAttributes(int nc, int i, int nattr);
-    void copyAttributes(const Endowed &other);
-    void mergeAttributes(const Endowed &other);
+    void copyAttributes(const Endowed& other);
+    void mergeAttributes(const Endowed& other);
 
-    virtual const std::string &path() const = 0;
-    virtual int varid() const = 0;
-    virtual const std::string &name() const = 0;
+    virtual const std::string& path() const = 0;
+    virtual int varid() const               = 0;
+    virtual const std::string& name() const = 0;
 
-    const std::map<std::string, Attribute *> &attributes() const ;
+    const std::map<std::string, Attribute*>& attributes() const;
 
 protected:
-
     // -- Members
 
-    std::map<std::string, Attribute *> attributes_;
+    std::map<std::string, Attribute*> attributes_;
 
 private:
-
-    Endowed(const Endowed &);
-    Endowed &operator=(const Endowed &);
-
-
+    Endowed(const Endowed&);
+    Endowed& operator=(const Endowed&);
 };
 
 #endif
