@@ -15,14 +15,12 @@
 #include <netcdf.h>
 
 
-NCError::NCError(int e, const std::string& call, const std::string &path):
-    msg_(std::string("NCError: ") + nc_strerror(e) +  + " " + call +  " (" + path + ")") {}
+NCError::NCError(int e, const std::string& call, const std::string& path) :
+    msg_(std::string("NCError: ") + nc_strerror(e) + +" " + call + " (" + path + ")") {}
 
-const char *NCError::what() const noexcept
-{
+const char* NCError::what() const noexcept {
     return msg_.c_str();
 }
 
-NCError::~NCError() noexcept
-{
+NCError::~NCError() noexcept {
 }
