@@ -14,23 +14,20 @@
 #include "NCFile.h"
 
 NCFileCache::NCFileCache() {
-
 }
 
 NCFileCache::~NCFileCache() {
-    for (std::map<std::string, NCFile *>::iterator j = files_.begin(); j != files_.end(); ++j)
-    {
+    for (std::map<std::string, NCFile*>::iterator j = files_.begin(); j != files_.end(); ++j) {
         delete (*j).second;
     }
 }
 
-NCFile &NCFileCache::lookUp(const std::string &path) {
-    std::map<std::string, NCFile *>::iterator j = files_.find(path);
+NCFile& NCFileCache::lookUp(const std::string& path) {
+    std::map<std::string, NCFile*>::iterator j = files_.find(path);
     if (j == files_.end()) {
-        NCFile *f = new NCFile(path);
+        NCFile* f    = new NCFile(path);
         files_[path] = f;
         return *f;
     }
     return *((*j).second);
 }
-
