@@ -10,14 +10,15 @@
 #include <unistd.h>
 #include <pwd.h>
 
+#include <fstream>
 #include <iostream>
 #include <sstream>
+#include "fstream_mars_fix.h"
+
 #include "Metview.h"
 #include "MvService.h"
 
-string ftmp;
-
-using namespace std;
+std::string ftmp;
 
 // Globals
 int ac;
@@ -27,23 +28,23 @@ class Base : public MvService
 {
 protected:
     Base(const char* a) :
-        MvService(a){};
+        MvService(a) {}
 };
 
 class MvCompress : public Base
 {
 public:
     MvCompress() :
-        Base("COMPRESS"){};
+        Base("COMPRESS") {}
     void serve(MvRequest&, MvRequest&);
 };
 
 void MvCompress::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "--------------MvCompress::serve()--------------" << endl;
+    std::cout << "--------------MvCompress::serve()--------------" << std::endl;
     in.print();
 
-    vector<string> vals;
+    std::vector<std::string> vals;
     if (!in.getValue("ITEMS", vals))
         return;
 
@@ -52,8 +53,8 @@ void MvCompress::serve(MvRequest& in, MvRequest& out)
         return;
 
     //Dump file name + tar file name
-    string fLog(marstmp());
-    string method;
+    std::string fLog(marstmp());
+    std::string method;
 
     if (strcmp(id, "tar") == 0) {
         method = "tar";
@@ -75,26 +76,26 @@ void MvCompress::serve(MvRequest& in, MvRequest& out)
     }
 
     //Compress command
-    string cmd = string(getenv("METVIEW_BIN")) + "/mv_compress ";
+    std::string cmd = std::string(getenv("METVIEW_BIN")) + "/mv_compress ";
 
     cmd += " -m \"" + method + "\" -l \"" + fLog + "\" ";
-    for (vector<string>::iterator it = vals.begin(); it != vals.end(); it++) {
-        cmd += "\"" + (*it) + "\" ";
+    for (auto& val : vals) {
+        cmd += "\"" + val + "\" ";
     }
     cmd += " 2>&1";
 
-    //COUT << "command " << cmd << endl;
+    //COUT << "command " << cmd << std::endl;
 
     int ret = system(cmd.c_str());
 
     //If the script failed read log file and
     //write it into LOG_EROR
     if (ret == -1 || WEXITSTATUS(ret) != 0) {
-        ifstream inLog(fLog.c_str());
-        string line;
-        string msg;
-        string detailed;
-        string st;
+        std::ifstream inLog(fLog.c_str());
+        std::string line;
+        std::string msg;
+        std::string detailed;
+        std::string st;
 
         if (WEXITSTATUS(ret) == 255) {
             msg = "MvCompress-> Some of the icons could not be archived!";
@@ -113,7 +114,7 @@ void MvCompress::serve(MvRequest& in, MvRequest& out)
                 msg = "MvCompress-> Failed to archive the selected icons!";
             }
             else {
-                stringstream ss;
+                std::stringstream ss;
                 ss << "MvCompress-> Icon archiving failed with exit code: " << WEXITSTATUS(ret) << "!";
                 msg = ss.str();
             }
