@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef SAVEPOOLGUI_H
-#define SAVEPOOLGUI_H
+#pragma once
 
 #include <QObject>
 #include <QString>
@@ -32,5 +31,3 @@ protected:
     MvQFileDialog* fDialog_;
     QString selectedFile_;
 };
-
-#endif // SAVEPOOLGUI_H
