@@ -26,12 +26,12 @@
 
 static int gac;
 static char** gav;
-static svc* gs = NULL;
+static svc* gs = nullptr;
 
-static svcid* s_id          = NULL;
-static const char* path     = NULL;
-static const char* iconName = NULL;
-static char* cptr           = NULL;
+static svcid* s_id          = nullptr;
+static const char* path     = nullptr;
+static const char* iconName = nullptr;
+static char* cptr           = nullptr;
 
 void cleanup(const char* file);
 void save(svcid* id, request* r, void*);
@@ -49,7 +49,7 @@ void cleanup(const char* file)
                 request* r = empty_request("WRITE");
                 set_value(r, "TARGET", "%s", file);
                 set_value(r, "FIELDSET", "%s", iconName);
-                handle_write(r, NULL);
+                handle_write(r, nullptr);
                 free_all_requests(r);
             }
             else {
@@ -62,11 +62,11 @@ void cleanup(const char* file)
             set_svc_msg(s_id, "Data from %s not saved", iconName);
         }
 
-        send_reply(s_id, NULL);
+        send_reply(s_id, nullptr);
 
-        s_id     = NULL;
-        path     = NULL;
-        iconName = NULL;
+        s_id     = nullptr;
+        path     = nullptr;
+        iconName = nullptr;
     }
 }
 
@@ -140,7 +140,7 @@ void save(svcid* id, request* r, void*)
     // Start the application
     std::string cmd;
     cmd += "$metview_command $METVIEW_BIN/SavePoolApp " +
-            reqFile.path() + " $METVIEW_QT_APPLICATION_FLAGS ";
+           reqFile.path() + " $METVIEW_QT_APPLICATION_FLAGS ";
 
     marslog(LOG_INFO, "Start appliction with command: %s", cmd.c_str());
 
@@ -150,30 +150,25 @@ void save(svcid* id, request* r, void*)
     out.read(outFile.path().c_str(), false, true);
 
     std::string targetFile;
-    if (const char* ch=out("PATH")) {
+    if (const char* ch = out("PATH")) {
         targetFile = std::string(ch);
     }
 
     //The real save operation
-    if (!targetFile.empty()) {
-        cleanup(targetFile.c_str());
-    }
-    else {
-        cleanup(0);
-    }
+    cleanup(targetFile.empty() ? nullptr : targetFile.c_str());
 
     exit(0);
 }
 
 int main(int argc, char** argv)
 {
-    marsinit(&argc, argv, 0, 0, 0);
+    marsinit(&argc, argv, nullptr, 0, nullptr);
 
     gac = argc;
     gav = argv;
 
     gs = create_service(progname());
-    add_service_callback(gs, NULL, save, NULL);
+    add_service_callback(gs, nullptr, save, nullptr);
 
     service_run(gs);
 }
