@@ -95,7 +95,7 @@ int BufrDataKeyModel::rowCount(const QModelIndex& parent) const
     return 0;
 }
 
-int BufrDataKeyModel::columnCount(const QModelIndex& parent) const
+int BufrDataKeyModel::columnCount(const QModelIndex& /*parent*/) const
 {
     return 1;
 }
@@ -135,17 +135,17 @@ bool BufrDataKeyModel::setData(const QModelIndex& idx, const QVariant& value, in
 }
 
 
-QVariant BufrDataKeyModel::headerData(int section, Qt::Orientation orientation, int role) const
+QVariant BufrDataKeyModel::headerData(int /*section*/, Qt::Orientation /*orientation*/, int /*role*/) const
 {
-    return QVariant();
+    return {};
 }
 
-QModelIndex BufrDataKeyModel::index(int row, int column, const QModelIndex& parent) const
+QModelIndex BufrDataKeyModel::index(int row, int column, const QModelIndex& /*parent*/) const
 {
     return createIndex(row, column, static_cast<void*>(0));
 }
 
-QModelIndex BufrDataKeyModel::parent(const QModelIndex& index) const
+QModelIndex BufrDataKeyModel::parent(const QModelIndex& /*index*/) const
 {
     return QModelIndex();
 }
@@ -280,7 +280,7 @@ void BufrCompDataWidget::clearData()
 void BufrCompDataWidget::loadData(int msgNum, int subsetNum)
 {
     Q_ASSERT(data_);
-    MvKeyProfile* prof = new MvKeyProfile("comp");
+    auto* prof = new MvKeyProfile("comp");
     data_->readCompressedData(prof, msgNum, subsetNum);
 
     //The model will take ownership of the profile
