@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef BUFRCOMPDATAWIDGET_H
-#define BUFRCOMPDATAWIDGET_H
+#pragma once
 
 #include "ui_BufrCompDataWidget.h"
 
@@ -95,5 +94,3 @@ protected:
     BufrDataKeyModel* colModel_;
     BufrDataKeyFilterModel* colFilterModel_;
 };
-
-#endif  // BUFRCOMPDATAWIDGET_H
