@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef BUFREXAMINER_H
-#define BUFREXAMINER_H
+#pragma once
 
 #include "MvQAbstractMessageExaminer.h"
 #include "MvObsSet.h"
@@ -51,7 +50,7 @@ class BufrExpandDataModel;
 
 class BufrJsonDumpWidget : public QWidget
 {
-  Q_OBJECT
+    Q_OBJECT
 public:
     BufrJsonDumpWidget(MvQBufrDumpPanel* context, QWidget* parent = nullptr);
     ~BufrJsonDumpWidget();
@@ -93,7 +92,7 @@ protected:
 
 class BufrExpandDumpWidget : public QWidget
 {
-  Q_OBJECT
+    Q_OBJECT
 public:
     BufrExpandDumpWidget(QWidget* parent = nullptr);
     ~BufrExpandDumpWidget();
@@ -133,9 +132,9 @@ public:
     void clear();
     void setHasFilterResult(bool);
     void selectFilterResultTab();
-    int currentSubset() const {return currentSubset_;}
+    int currentSubset() const { return currentSubset_; }
     int currentMessage() const { return currentMsg_; }
-    BufrMetaData* data() const {return data_;}
+    BufrMetaData* data() const { return data_; }
 
     QList<QAction*> actionsToControl() const;
 
@@ -190,8 +189,8 @@ private:
     BufrMetaData* data_;
     QTabWidget* dumpTab_;
 
-    BufrJsonDumpWidget *jsonDumpWidget_;
-    BufrExpandDumpWidget *expandDumpWidget_;
+    BufrJsonDumpWidget* jsonDumpWidget_;
+    BufrExpandDumpWidget* expandDumpWidget_;
 
     QTextEdit* tableTe_;
     PlainTextWidget* debugTe_;
@@ -254,7 +253,7 @@ signals:
     void keyProfileChanged();
     void messageNumDetermined();
 
-private:  
+private:
     BufrMetaData* data_;
     MvQMessagePanel* messagePanel_;
     MvQBufrDumpPanel* dumpPanel_;
@@ -329,5 +328,3 @@ private:
     QAction* actionSave_;
     BufrFilterDialog* filterDialog_;
 };
-
-#endif  // BUFREXAMINER_H
