@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef BUFRFLATDATAMODE_H
-#define BUFRFLATDATAMODE_H
+#pragma once
 
 #include <QAbstractItemModel>
 
@@ -22,7 +21,7 @@ public:
     bool loadDumpData(const std::string&, QString& err);
     void clear();
 
-    int columnCount(const QModelIndex& parent=QModelIndex()) const;
+    int columnCount(const QModelIndex& parent = QModelIndex()) const;
     int rowCount(const QModelIndex& index) const;
     QVariant data(const QModelIndex& index, int role) const;
     QVariant headerData(const int section, const Qt::Orientation orient, const int role) const;
@@ -30,8 +29,6 @@ public:
     QModelIndex parent(const QModelIndex& index) const;
 
 protected:
-    MvKeyProfile *templateProf_;
-    MvKeyProfile *prof_;
+    MvKeyProfile* templateProf_;
+    MvKeyProfile* prof_;
 };
-
-#endif // BUFRFLATDATAMODE_H
