@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef BUFRFILTERDIALOG_H
-#define BUFRFILTERDIALOG_H
+#pragma once
 
 #include "ui_BufrFilterDialog.h"
 
@@ -51,5 +50,3 @@ protected:
     QString settingsName_;
     std::string lastFileLoaded_;
 };
-
-#endif  // BUFRFILTERDIALOG_H
