@@ -28,7 +28,7 @@
 
 #include "BufrMetaData.h"
 #include "MvEccBufr.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "PropertyLineEditor.h"
 #include "MvQMethods.h"
 #include "MvQProperty.h"
@@ -39,10 +39,10 @@ BufrFilterEditor::BufrFilterEditor(QWidget* parent) :
 {
     loadInit();
 
-    linePen_ = QPen(MvQTheme::colour("iconeditor", "line_item_pen"));
+    linePen_  = QPen(MvQTheme::colour("iconeditor", "line_item_pen"));
     framePen_ = QPen(MvQTheme::colour("iconeditor", "frame_pen"));
 
-    QVBoxLayout* vb = new QVBoxLayout(this);
+    auto* vb = new QVBoxLayout(this);
 
     grid_ = new QGridLayout();
     grid_->setHorizontalSpacing(4);
@@ -158,7 +158,7 @@ void BufrFilterEditor::initHelpers(BufrMetaData* decoder, int msgIdx)
         updateHelpers(decoder, msgIdx);
 }
 
-void BufrFilterEditor::slotOutputLeChanged(EditLine*, QString mode)
+void BufrFilterEditor::slotOutputLeChanged(EditLine*, QString /*mode*/)
 {
     adjustExtractOptions();
     adjustCoordOptions();
@@ -174,7 +174,7 @@ void BufrFilterEditor::slotCoordModeLeChanged(EditLine*, QString)
     adjustCoordOptions();
 }
 
-void BufrFilterEditor::slotCoordKeyCountLeChanged(EditLine*, QString mode)
+void BufrFilterEditor::slotCoordKeyCountLeChanged(EditLine*, QString /*mode*/)
 {
     adjustCoordOptions();
 }
@@ -184,7 +184,7 @@ void BufrFilterEditor::slotCustomModeLeChanged(EditLine*, QString)
     adjustCustomOptions();
 }
 
-void BufrFilterEditor::slotCustomKeyCountLeChanged(EditLine*, QString mode)
+void BufrFilterEditor::slotCustomKeyCountLeChanged(EditLine*, QString /*mode*/)
 {
     adjustCustomOptions();
 }
@@ -558,7 +558,7 @@ QString BufrFilterEditor::lineValue(QString id)
     return QString();
 }
 
-void BufrFilterEditor::paintEvent(QPaintEvent* event)
+void BufrFilterEditor::paintEvent(QPaintEvent* /*event*/)
 {
     QPainter painter(this);
 
@@ -606,7 +606,7 @@ void BufrFilterEditor::paintEvent(QPaintEvent* event)
                 int y    = r.y() - spacingV / 2;
 
                 //horizontal line at the top of the row
-                MvQ::safeDrawLine(QPoint(0, y),QPoint(this->width(), y), &painter);
+                MvQ::safeDrawLine(QPoint(0, y), QPoint(this->width(), y), &painter);
                 lastY = y + h;
             }
         }
@@ -615,7 +615,7 @@ void BufrFilterEditor::paintEvent(QPaintEvent* event)
 
     //The last Horizontal line
     if (!prevIsHeader) {
-        MvQ::safeDrawLine(QPoint(0, lastY - 1),QPoint(this->width(), lastY - 1), &painter);
+        MvQ::safeDrawLine(QPoint(0, lastY - 1), QPoint(this->width(), lastY - 1), &painter);
     }
 
     //Vertical lines
@@ -651,8 +651,8 @@ void BufrFilterEditor::loadInit()
         //We process one group
         QJsonObject grObj = doc.array()[i].toObject();
         Q_ASSERT(!grObj.isEmpty());
-        QString groupName   = grObj.value("name").toString();
-        MvQProperty* grProp = new MvQProperty(groupName.toStdString());
+        QString groupName = grObj.value("name").toString();
+        auto* grProp      = new MvQProperty(groupName.toStdString());
         groups_ << grProp;
 
         //Iterat through th ojects in a group
@@ -666,8 +666,8 @@ void BufrFilterEditor::loadInit()
                 for (int j = 0; j < chArr.count(); j++) {
                     QJsonObject chObj = chArr[j].toObject();
                     Q_ASSERT(!chObj.isEmpty());
-                    QString chName      = chObj.value("name").toString();
-                    MvQProperty* chProp = new MvQProperty(chName.toStdString());
+                    QString chName = chObj.value("name").toString();
+                    auto* chProp   = new MvQProperty(chName.toStdString());
                     grProp->addChild(chProp);
                     loadProperty(chArr[j], chProp);
                     chProp->adjustAfterLoad();
