@@ -139,11 +139,11 @@ void BufrKeyWidget::setData(MvQBufrDataItem* item, int subset, MvEccBufrMessage*
             eccType = "long";
 
         if (eccType == "long" || eccType == "double") {
-            float scale = item->data("scale").toFloat();
-            float ref = item->data("reference").toFloat();
-            float width = item->data("width").toFloat();
-            float minv   = ref / std::pow(10., scale);
-            float maxv   = (std::pow(2.,width) - 2 + ref) / pow(10, scale);
+            float scale     = item->data("scale").toFloat();
+            float ref       = item->data("reference").toFloat();
+            float width     = item->data("width").toFloat();
+            float minv      = ref / std::pow(10., scale);
+            float maxv      = (std::pow(2., width) - 2 + ref) / pow(10, scale);
             float precision = pow(10., -scale);
             tp += formatRow("Min", QString::number(minv));
             tp += formatRow("Max", QString::number(maxv));
@@ -161,14 +161,14 @@ void BufrKeyWidget::setData(MvQBufrDataItem* item, int subset, MvEccBufrMessage*
         (key == "unexpandedDescriptors" && item->valueArray().count() > 1)) {
         int n = item->valueArray().count();
         if (n > 0) {
-            MvKeyProfile* prof     = new MvKeyProfile("tmp");
+            auto* prof             = new MvKeyProfile("tmp");
             std::string firstName  = (key == "unexpandedDescriptors") ? "pos" : "subset";
             std::string secondName = (key == "unexpandedDescriptors") ? "descriptor" : "value";
-            MvKey* firstKey        = new MvKey(firstName, firstName);
+            auto* firstKey         = new MvKey(firstName, firstName);
             firstKey->setValueType(MvKey::IntType);
             firstKey->setIntRange(1, n);
             prof->addKey(firstKey);
-            MvKey* secondKey = new MvKey(secondName, secondName);
+            auto* secondKey = new MvKey(secondName, secondName);
             secondKey->setValueType(MvKey::StringType);
             prof->addKey(secondKey);
 
@@ -189,15 +189,16 @@ void BufrKeyWidget::setData(MvQBufrDataItem* item, int subset, MvEccBufrMessage*
     }
     if (key != "unexpandedDescriptors") {
         broadcast_ = true;
-    } else {
+    }
+    else {
         broadcast_ = false;
     }
 }
 
 QString BufrKeyWidget::formatKey(QString key)
-{   
-//    auto subCol = MvQTheme::subText();
-//    return MvQ::formatText(key, subCol);
+{
+    //    auto subCol = MvQTheme::subText();
+    //    return MvQ::formatText(key, subCol);
     return key;
 }
 
@@ -228,9 +229,9 @@ QString BufrKeyWidget::formatElementBlock(QString val)
                 break;
         }
 
-        QString typeStr =  MvQ::formatText(type, MvQTheme::colour("bufrelement", "type")); //"<b><font color=\'" + typeCol.name() + "\'>" + type + "</font></b>";
-        QString catStr  = MvQ::formatText(cat, MvQTheme::colour("bufrelement", "category")); //"<b><font color=\'" + catCol.name() + "\'>" + cat + "</font></b>";
-        QString codeStr =  MvQ::formatText(code, MvQTheme::colour("bufrelement", "code")); //"<b><font color=\'" + codeCol.name() + "\'>" + code + "</font></b>";
+        QString typeStr = MvQ::formatText(type, MvQTheme::colour("bufrelement", "type"));     //"<b><font color=\'" + typeCol.name() + "\'>" + type + "</font></b>";
+        QString catStr  = MvQ::formatText(cat, MvQTheme::colour("bufrelement", "category"));  //"<b><font color=\'" + catCol.name() + "\'>" + cat + "</font></b>";
+        QString codeStr = MvQ::formatText(code, MvQTheme::colour("bufrelement", "code"));     //"<b><font color=\'" + codeCol.name() + "\'>" + code + "</font></b>";
 
         s += formatRow(key, typeStr + catStr + codeStr);
         s += formatRow("Category", catStr);
@@ -249,7 +250,7 @@ void BufrKeyWidget::slotValueItemSelected(const QModelIndex& idx)
         auto srcIdx = sortModel_->mapToSource(idx);
         if (srcIdx.isValid()) {
             // subset indexing starts at 1
-            emit subsetSelected(srcIdx.row()+1);
+            emit subsetSelected(srcIdx.row() + 1);
         }
     }
 }
