@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef BUFRKEYWIDGET_H
-#define BUFRKEYWIDGET_H
+#pragma once
 
 #include "ui_BufrKeyWidget.h"
 
@@ -21,7 +20,7 @@ class MvQKeyProfileSortFilterModel;
 
 class BufrKeyWidget : public QWidget, protected Ui::BufrKeyWidget
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
     explicit BufrKeyWidget(QWidget* parent = 0);
@@ -43,5 +42,3 @@ protected:
     MvQKeyProfileSortFilterModel* sortModel_;
     bool broadcast_{true};
 };
-
-#endif  // BUFRKEYWIDGET_H
