@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef BUFRVALUEMODEL_HPP
-#define BUFRVALUEMODEL_HPP
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QPixmap>
@@ -37,5 +36,3 @@ private:
     //int subsetNumber_;
     //QPixmap arrayPix_;
 };
-
-#endif  // BUFRVALUEMODEL_HPP
