@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQBUFRDATAITEM_H_
-#define MVQBUFRDATAITEM_H_
+#pragma once
 
 #include <QStringList>
 #include <QHash>
@@ -30,8 +29,8 @@ public:
     virtual QString title(int) const { return QString(); }
     QString data(QString key) const;
     QString key() const;
-    QString value(int subset = -1) const {return getValue(subset, true);}
-    QString rawValue(int subset = -1) const {return getValue(subset, false);}
+    QString value(int subset = -1) const { return getValue(subset, true); }
+    QString rawValue(int subset = -1) const { return getValue(subset, false); }
     QString getValue(int subset, bool includeCount) const;
     QStringList valueArray() const { return valueArray_; }
     bool valueIsArray() const { return !valueArray_.isEmpty(); }
@@ -47,6 +46,7 @@ protected:
     void addChild(MvQBufrDataItem* item);
     static QString beautify(QString val);
     static QString beautify(QStringList arrayVal);
+    static QString toString(const QString& key, QJsonValue v);
 
     QString key_;
     QString value_;
@@ -71,6 +71,3 @@ public:
 protected:
     QString title_;
 };
-
-
-#endif
