@@ -13,18 +13,18 @@
 
 void CptecAccess::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "CPTEC Access::serve in..." << endl;
+    std::cout << "CPTEC Access::serve in..." << std::endl;
     in.print();
 
     int i;
 
     // Build the path
-    string spath;
+    std::string spath;
     if (!buildPath(in, spath))
         return;
 
     // Build the filename(s)
-    vector<string> vfiles;
+    std::vector<std::string> vfiles;
     if (!buildFilenames(in, vfiles))
         return;
 
@@ -32,10 +32,10 @@ void CptecAccess::serve(MvRequest& in, MvRequest& out)
     const char* type = in("TYPE");
     if (strcmp(type, "OBSERVATION") == 0) {
         // Check if file exists
-        string ffile = spath + vfiles[0];
-        FILE* f      = fopen(ffile.c_str(), "r");
+        std::string ffile = spath + vfiles[0];
+        FILE* f           = fopen(ffile.c_str(), "r");
         if (!f) {
-            string error = "CptecAccess-> FILE NOT FOUND: ";
+            std::string error = "CptecAccess-> FILE NOT FOUND: ";
             error += ffile.c_str();
             setError(1, error.c_str());
             return;
@@ -52,8 +52,8 @@ void CptecAccess::serve(MvRequest& in, MvRequest& out)
     // Get the requested PARAMs
     const char* caux;
     int nparams = in.iterInit("PARAMETER");
-    map<string, int> params;
-    string param;
+    std::map<std::string, int> params;
+    std::string param;
     for (i = 0; i < nparams; ++i) {
         in.iterGetNextValue(caux);
         param         = caux;
@@ -62,7 +62,7 @@ void CptecAccess::serve(MvRequest& in, MvRequest& out)
 
     // Get the requested LEVELs
     int nlevels = in.iterInit("LEVEL_LIST");
-    map<long, int> levels;
+    std::map<long, int> levels;
     double dlevel;
     for (i = 0; i < nlevels; ++i) {
         in.iterGetNextValue(dlevel);
@@ -77,19 +77,19 @@ void CptecAccess::serve(MvRequest& in, MvRequest& out)
     char shortName[20];
     size_t len;
     int error       = 0;
-    grib_handle* h  = NULL;
+    grib_handle* h  = nullptr;
     grib_context* c = grib_context_get_default();
 
     // Create the output file name
-    string outname(marstmp());
+    std::string outname(marstmp());
     for (i = 0; i < (signed)vfiles.size(); ++i) {
         // Full filename
-        string ffile = spath + vfiles[i];
+        std::string ffile = spath + vfiles[i];
 
         // Open the input file
         FILE* f = fopen(ffile.c_str(), "r");
         if (!f) {
-            string error = "CptecAccess-> FILE NOT FOUND: ";
+            std::string error = "CptecAccess-> FILE NOT FOUND: ";
             error += ffile.c_str();
             setError(1, error.c_str());
             return;
@@ -97,10 +97,10 @@ void CptecAccess::serve(MvRequest& in, MvRequest& out)
 
         // Loop on all GRIB messages in file
         long level;
-        while ((h = grib_handle_new_from_file(c, f, &error)) != NULL) {
+        while ((h = grib_handle_new_from_file(c, f, &error)) != nullptr) {
             len = 20;
             grib_get_string(h, "shortName", shortName, &len);
-            param = string(shortName);
+            param = std::string(shortName);
             grib_get_long(h, "level", &level);
             if (params.find(param) != params.end()) {
                 if (levels.find(level) != levels.end()) {
@@ -118,7 +118,7 @@ void CptecAccess::serve(MvRequest& in, MvRequest& out)
         fclose(f);
     }
 
-    cout << "CPTEC Access::serve out..." << endl;
+    std::cout << "CPTEC Access::serve out..." << std::endl;
     out.print();
 
     return;
@@ -130,10 +130,10 @@ bool CptecAccess::buildPath(MvRequest& in, string& spath)
     // 1. Date/time related string
     const char* date = in("DATE");
     const char* time = in("TIME");
-    string yyyymm(date, 6);
-    string dd(date, 6, 2);
-    string hh(time, 2);
-    string sdate = yyyymm + '/' + dd + hh;
+    std::string yyyymm(date, 6);
+    std::string dd(date, 6, 2);
+    std::string hh(time, 2);
+    std::string sdate = yyyymm + '/' + dd + hh;
 
     //eta 20
     // /rede/eva01/modoper/tempo/regional/etap_20km/grbctl/2012/Jan/11
@@ -204,7 +204,7 @@ bool CptecAccess::buildPath(MvRequest& in, string& spath)
             spath = "/rede/tupa_tempo/externos/Download/NCEP/" + sdate + "/";
     }
     else {
-        string error = "CptecAccess-> ERROR: MODEL not recognized ";
+        std::string error = "CptecAccess-> ERROR: MODEL not recognized ";
         setError(1, error.c_str());
         return false;
     }
@@ -212,7 +212,7 @@ bool CptecAccess::buildPath(MvRequest& in, string& spath)
     return true;
 }
 
-bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
+bool CptecAccess::buildFilenames(MvRequest& in, std::vector<std::string>& vfn)
 {
     int i, j, k;
 
@@ -224,7 +224,7 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
     // Get all values related to parameters DATE/TIME/STEP
     double xx;
     int ndates = in.iterInit("DATE");
-    vector<double> dates;
+    std::vector<double> dates;
     dates.reserve(ndates);
     for (i = 0; i < ndates; ++i) {
         in.iterGetNextValue(xx);
@@ -232,7 +232,7 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
     }
 
     int ntimes = in.iterInit("TIME");
-    vector<double> times;
+    std::vector<double> times;
     times.reserve(ntimes);
     for (i = 0; i < ntimes; ++i) {
         in.iterGetNextValue(xx);
@@ -240,7 +240,7 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
     }
 
     int nsteps = in.iterInit("STEP");
-    vector<double> steps;
+    std::vector<double> steps;
     steps.reserve(nsteps);
     for (i = 0; i < nsteps; ++i) {
         in.iterGetNextValue(xx);
@@ -258,8 +258,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     // Analise time stamp string
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmddHH", buf);
-                    string cs = "eta_15km_";
-                    cs        = cs + buf + '+';
+                    std::string cs = "eta_15km_";
+                    cs             = cs + buf + '+';
 
                     // Forecast time stamp string
                     for (k = 0; k < nsteps; k++) {
@@ -278,8 +278,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     // Analise time stamp string
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmddHH", buf);
-                    string cs = "eta_10km_";
-                    cs        = cs + buf + '+';
+                    std::string cs = "eta_10km_";
+                    cs             = cs + buf + '+';
 
                     // Forecast time stamp string
                     for (k = 0; k < nsteps; k++) {
@@ -298,8 +298,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     // Analise time stamp string
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmddHH", buf);
-                    string cs = "eta_05km_";
-                    cs        = cs + buf + '+';
+                    std::string cs = "eta_05km_";
+                    cs             = cs + buf + '+';
 
                     // Forecast time stamp string
                     for (k = 0; k < nsteps; k++) {
@@ -318,8 +318,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     // Analise time stamp string
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmddHH", buf);
-                    string cs = "GPOSNMC";
-                    cs        = cs + buf;
+                    std::string cs = "GPOSNMC";
+                    cs             = cs + buf;
 
                     // Forecast time stamp string
                     for (k = 0; k < nsteps; k++) {
@@ -338,8 +338,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     // Analise time stamp string
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmddHH", buf);
-                    string cs = "GPOSNMC";
-                    cs        = cs + buf;
+                    std::string cs = "GPOSNMC";
+                    cs             = cs + buf;
 
                     // Forecast time stamp string
                     for (k = 0; k < nsteps; k++) {
@@ -358,8 +358,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     // Analise time stamp string
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmddHH", buf);
-                    string cs = "GPOSCPT";
-                    cs        = cs + buf;
+                    std::string cs = "GPOSCPT";
+                    cs             = cs + buf;
 
                     // Forecast time stamp string
                     for (k = 0; k < nsteps; k++) {
@@ -378,8 +378,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     // Analise time stamp string
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmddHH", buf);
-                    string cs = "JULES_BRAMS05km_";
-                    cs        = cs + buf + "_";
+                    std::string cs = "JULES_BRAMS05km_";
+                    cs             = cs + buf + "_";
 
                     // Forecast time stamp string
                     for (k = 0; k < nsteps; k++) {
@@ -400,8 +400,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmdd", buf);
                     danal.Format("HH", buf2);
-                    string rodada    = buf2;
-                    string anomesdia = buf;
+                    std::string rodada    = buf2;
+                    std::string anomesdia = buf;
                     //gdas1.t00z.1bamua.tm00.bufr_d.20121129   vfn.push_back("gdas1.T" + rodada + "Z.prepbufr.nr." + anomesdia + rodada);
                     vfn.push_back("gdas1.t" + rodada + "z.prepbufr.nr." + anomesdia);
                 }
@@ -414,8 +414,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmdd", buf);
                     danal.Format("HH", buf2);
-                    string rodada    = buf2;
-                    string anomesdia = buf;
+                    std::string rodada    = buf2;
+                    std::string anomesdia = buf;
                     //vfn.push_back("gdas1.T" + rodada + "Z.prepbufr.nr." + anomesdia + rodada);
                     vfn.push_back("gdas1.t" + rodada + "z.1bamua.tm" + rodada + ".bufr_d." + anomesdia);
                 }
@@ -428,8 +428,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmdd", buf);
                     danal.Format("HH", buf2);
-                    string rodada    = buf2;
-                    string anomesdia = buf;
+                    std::string rodada    = buf2;
+                    std::string anomesdia = buf;
                     //vfn.push_back("gdas1.T" + rodada + "Z.prepbufr.nr." + anomesdia + rodada);
                     vfn.push_back("gdas1.t" + rodada + "z.1bamub.tm" + rodada + ".bufr_d." + anomesdia);
                 }
@@ -442,8 +442,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmdd", buf);
                     danal.Format("HH", buf2);
-                    string rodada    = buf2;
-                    string anomesdia = buf;
+                    std::string rodada    = buf2;
+                    std::string anomesdia = buf;
                     //vfn.push_back("gdas1.T" + rodada + "Z.prepbufr.nr." + anomesdia + rodada);
                     vfn.push_back("gdas1.t" + rodada + "z.1bhrs3.tm" + rodada + ".bufr_d." + anomesdia);
                 }
@@ -456,8 +456,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmdd", buf);
                     danal.Format("HH", buf2);
-                    string rodada    = buf2;
-                    string anomesdia = buf;
+                    std::string rodada    = buf2;
+                    std::string anomesdia = buf;
                     //vfn.push_back("gdas1.T" + rodada + "Z.prepbufr.nr." + anomesdia + rodada);
                     vfn.push_back("gdas1.t" + rodada + "z.airsev.tm" + rodada + ".bufr_d." + anomesdia);
                 }
@@ -470,8 +470,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmdd", buf);
                     danal.Format("HH", buf2);
-                    string rodada    = buf2;
-                    string anomesdia = buf;
+                    std::string rodada    = buf2;
+                    std::string anomesdia = buf;
                     //vfn.push_back("gdas1.T" + rodada + "Z.prepbufr.nr." + anomesdia + rodada);
                     vfn.push_back("gdas1.t" + rodada + "z.gpsro.tm" + rodada + ".bufr_d." + anomesdia);
                 }
@@ -484,8 +484,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmdd", buf);
                     danal.Format("HH", buf2);
-                    string rodada    = buf2;
-                    string anomesdia = buf;
+                    std::string rodada    = buf2;
+                    std::string anomesdia = buf;
                     //vfn.push_back("gdas1.T" + rodada + "Z.prepbufr.nr." + anomesdia + rodada);
                     vfn.push_back("gdas1.t" + rodada + "z.mtiasi.tm" + rodada + ".bufr_d." + anomesdia);
                 }
@@ -498,8 +498,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmdd", buf);
                     danal.Format("HH", buf2);
-                    string rodada    = buf2;
-                    string anomesdia = buf;
+                    std::string rodada    = buf2;
+                    std::string anomesdia = buf;
                     //vfn.push_back("gdas1.T" + rodada + "Z.prepbufr.nr." + anomesdia + rodada);
                     vfn.push_back("gdas1.t" + rodada + "z.satwnd.tm" + rodada + ".bufr_d." + anomesdia);
                 }
@@ -512,8 +512,8 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmdd", buf);
                     danal.Format("HH", buf2);
-                    string rodada    = buf2;
-                    string anomesdia = buf;
+                    std::string rodada    = buf2;
+                    std::string anomesdia = buf;
                     //vfn.push_back("gdas1.T" + rodada + "Z.prepbufr.nr." + anomesdia + rodada);
                     vfn.push_back("gdas2.T" + rodada + "Z.SAnl." + anomesdia + rodada);
                 }
@@ -526,14 +526,14 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmdd", buf);
                     danal.Format("HH", buf2);
-                    string rodada    = buf2;
-                    string anomesdia = buf;
+                    std::string rodada    = buf2;
+                    std::string anomesdia = buf;
                     vfn.push_back("ISAI_" + anomesdia + rodada + ".wmo");
                 }
             }
         }
         else {
-            string tobs = (const char*)in("OBSERVATION");
+            std::string tobs = (const char*)in("OBSERVATION");
             std::transform(tobs.begin(), tobs.end(), tobs.begin(), ::tolower);
 
             // Build all filenames
@@ -544,14 +544,14 @@ bool CptecAccess::buildFilenames(MvRequest& in, vector<string>& vfn)
                     // Analise time stamp string
                     MvDate danal = dd + times[j] / 24.;
                     danal.Format("yyyymmddHH", buf);
-                    string cs = buf;
+                    std::string cs = buf;
                     vfn.push_back(cs + "_" + tobs + ".bufr");
                 }
             }
         }
     }
     else {
-        string error = "CptecAccess-> ERROR: MODEL not recognized ";
+        std::string error = "CptecAccess-> ERROR: MODEL not recognized ";
         setError(1, error.c_str());
         return false;
     }
