@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef CPTECACCESS_H
-#define CPTECACCESS_H
+#pragma once
 
 /************************************************************
   Application CptecAccess
@@ -27,10 +26,8 @@ public:
     void serve(MvRequest&, MvRequest&);
 
     // Build the path
-    bool buildPath(MvRequest&, string&);
+    bool buildPath(MvRequest&, std::string&);
 
     // Build the filenames
-    bool buildFilenames(MvRequest&, vector<string>&);
+    bool buildFilenames(MvRequest&, std::vector<std::string>&);
 };
-
-#endif
