@@ -9,6 +9,15 @@
 
 #include "Datacoverage.h"
 
+#include <fstream>
+#include <functional>
+#include <iostream>
+#include <map>
+#include <sstream>
+#include <string>
+#include <vector>
+
+#include "fstream_mars_fix.h"
 
 /////////// Checks whether an obs is satelite or not.
 int is_sat(int subtype)
@@ -164,9 +173,9 @@ int CoverageService::write_values(char* fname, MvObsSet& obs_set)
     int nr_subsets;
 
     // Open and initialise geopoints file
-    outfile.open(fname, ios::out);
-    outfile << "#GEO" << endl;
-    outfile << "#DATA" << endl;
+    outfile.open(fname, std::ios::out);
+    outfile << "#GEO" << std::endl;
+    outfile << "#DATA" << std::endl;
 
     // Main loop (all messages)
     int i;
@@ -200,7 +209,7 @@ int CoverageService::write_values(char* fname, MvObsSet& obs_set)
 
             // Write values in the geopoints file
             outfile << f_lat << " " << f_long;
-            outfile << " 0  0 0 " << symbol << endl;
+            outfile << " 0  0 0 " << symbol << std::endl;
 
             // Check message
             nr_total_++;
@@ -246,8 +255,8 @@ void CoverageService::set_legend_values(MvRequest& s)
 
 
     // Check the subtype values to see if all is well.
-    map<int, int, less<int> >::iterator ii = subtype_nrs_.begin();
-    int stype                              = (*ii).first;
+    auto ii       = subtype_nrs_.begin();
+    int stype     = (*ii).first;
     int found_sat = 0, found_conv = 0;
 
     for (; ii != subtype_nrs_.end(); ii++) {
@@ -328,7 +337,7 @@ void CoverageService::set_legend_values(MvRequest& s)
 
 void CoverageService::check_symbol_table_modes(MvRequest& symb, int table_size)
 {
-    cout << "original PSYMB:" << endl;
+    std::cout << "original PSYMB:" << std::endl;
     symb.print();
     MvRequest s = symb;
 
@@ -362,7 +371,7 @@ void CoverageService::check_symbol_table_modes(MvRequest& symb, int table_size)
     }
 
     symb = s;
-    cout << "adjusted PSYMB:" << endl;
+    std::cout << "adjusted PSYMB:" << std::endl;
     symb.print();
 }
 
@@ -395,7 +404,7 @@ void CoverageService::check_one_symbol_table(MvRequest& new_req,
 // Generate the title string.
 void CoverageService::generate_info_str(MvRequest& t, char* mag_dir)
 {
-    ostringstream ost;
+    std::ostringstream ost;
     int i = 0;
 
     // If checking time given, print time and cutoff.
@@ -408,7 +417,7 @@ void CoverageService::generate_info_str(MvRequest& t, char* mag_dir)
 
 
     // Plot the obs.types. Only types having data are plotted( with nr. of values).
-    map<int, int, less<int> >::iterator ii;
+    auto ii;
     for (i = 0, ii = subtype_nrs_.begin(); ii != subtype_nrs_.end(); ii++, i++) {
         if (i > 0)
             ost << "/";
@@ -436,7 +445,7 @@ char* CoverageService::format_date(const TDynamicTime& tt)
 
 //////////////////////////////// Class ObsValues //////////////////
 ObsValues::ObsValues(MvObs& obs, int cutoff, TDynamicTime c_time, int pss,
-                     vector<long>& descs, int late_check) :
+                     std::vector<long>& descs, int late_check) :
     check_time(c_time),
     plot_ss_(pss),
     descriptors(descs)
@@ -448,10 +457,10 @@ ObsValues::ObsValues(MvObs& obs, int cutoff, TDynamicTime c_time, int pss,
     //e   itype = obs.messageType();
     isbtype_ = obs.messageSubtype();
     //const long satid_desc = 1007; //"satelliteIdentifier"
-    const string satid_key = "satelliteIdentifier";
-    ident_                 = 0;
-    sec2_conf_             = -1;
-    late_                  = 0;
+    const std::string satid_key = "satelliteIdentifier";
+    ident_                      = 0;
+    sec2_conf_                  = -1;
+    late_                       = 0;
 
     if (obs.hasSection2()) {
 #if 0  //FAMI20171024 commented out to compile Metview
@@ -489,7 +498,7 @@ ObsValues::ObsValues(MvObs& obs, int cutoff, TDynamicTime c_time, int pss,
 	    reb_time.ChangeByDays(1);
 
 	  //cout << "Obs_time "; obs_time.Print();
-	  //cout << " Reb time "; reb_time.Print(); cout  << endl;
+	  //cout << " Reb time "; reb_time.Print(); cout  << std::endl;
 
 	  if ( reb_time > check_time )
 	    {
@@ -501,7 +510,7 @@ ObsValues::ObsValues(MvObs& obs, int cutoff, TDynamicTime c_time, int pss,
 }
 
 //------------------------------------------------------------- get_symbol
-int ObsValues::get_symbol(MvObs& obs, map<int, int, less<int> >& stypes)
+int ObsValues::get_symbol(MvObs& obs, std::map<int, int, std::less<int> >& stypes)
 {
     int iflag = UNKNOWN;
 
@@ -602,7 +611,7 @@ void ObsValues::unpack(long& bword, long* src, long* target,
     long kw;
 
     if (extract > bword) {
-        cerr << "Number of bits to extract longer than computer word" << endl;
+        std::cerr << "Number of bits to extract longer than computer word" << std::endl;
         ierr = 3;
         return;
     }
