@@ -16,7 +16,7 @@
 #include "ProcMonitor.h"
 #include "MvQTheme.h"
 
-svc* s = NULL;
+svc* s = nullptr;
 int ac;
 char** av;
 
@@ -29,7 +29,7 @@ void browse_cb(svcid* id, request* r, void*)
 
 void dummy_cb(svcid* id, request* /*r*/, void*)
 {
-    send_reply(id, NULL);
+    send_reply(id, nullptr);
 }
 
 void monitor()
@@ -46,8 +46,8 @@ int main(int argc, char** argv)
     QApplication::setWindowIcon(QIcon(MvQTheme::logo()));
 
     s = app.getService();
-    add_service_callback(s, NULL, dummy_cb, NULL);
-    add_progress_callback(s, NULL, browse_cb, NULL);
+    add_service_callback(s, nullptr, dummy_cb, nullptr);
+    add_progress_callback(s, nullptr, browse_cb, nullptr);
 
     mon = new ProcMonitor(s);
 
