@@ -20,8 +20,8 @@
 unsigned long MvProcStat::uptime_ = 0;
 long MvProcStat::pageSize_        = 0;
 
-vector<MvProcNode*> MvProcNode::items_;
-vector<MvProcRequest*> MvProcNode::procRequests_;
+std::vector<MvProcNode*> MvProcNode::items_;
+std::vector<MvProcRequest*> MvProcNode::procRequests_;
 MvProcNode* MvProcNode::root_             = 0;
 MvProcNodeObserver* MvProcNode::observer_ = 0;
 bool MvProcNode::hasProcFs_               = false;
@@ -32,10 +32,10 @@ bool MvProcNode::hasProcFs_               = false;
 //
 //=============================================
 
-MvProcStat::MvProcStat(const string& /*host*/, long pid) :
+MvProcStat::MvProcStat(const std::string& /*host*/, long pid) :
     cpu_(0)
 {
-    stringstream ss;
+    std::stringstream ss;
     ss << pid;
 
     if (MvProcNode::hasProcFs()) {
@@ -68,7 +68,7 @@ void MvProcStat::readUptime()
         if (fscanf(fp, "%f", &fv) != EOF) {
             uptime_ = time(0) - static_cast<long>(fv);
 
-            cout << "uptime " << uptime_ << endl;
+            std::cout << "uptime " << uptime_ << std::endl;
         }
         fclose(fp);
     }
@@ -84,7 +84,7 @@ void MvProcStat::readStartTime()
 
     FILE* fp;
 
-    if ((fp = fopen(procPath_.c_str(), "r")) != NULL) {
+    if ((fp = fopen(procPath_.c_str(), "r")) != nullptr) {
         for (int i = 0; i < 21; i++) {
             if (fscanf(fp, "%*s") == EOF) {
                 fclose(fp);
@@ -94,7 +94,7 @@ void MvProcStat::readStartTime()
         long lv;
         if (fscanf(fp, "%ld", &lv) != EOF) {
             startTime_ = uptime_ + lv / sysconf(_SC_CLK_TCK);
-            cout << "start time " << startTime_ << " " << time(0) << " " << uptime_ << " " << lv << " " << lv / sysconf(_SC_CLK_TCK) << endl;
+            std::cout << "start time " << startTime_ << " " << time(0) << " " << uptime_ << " " << lv << " " << lv / sysconf(_SC_CLK_TCK) << std::endl;
         }
     }
 
@@ -106,9 +106,9 @@ bool MvProcStat::update()
     if (!MvProcNode::hasProcFs())
         return false;
 
-    int cpuOri         = cpu_;
-    string vmRssOri    = vmRss_;
-    string vmSharedOri = vmShared_;
+    int cpuOri              = cpu_;
+    std::string vmRssOri    = vmRss_;
+    std::string vmSharedOri = vmShared_;
 
     if (updateStats())
         return false;
@@ -131,11 +131,11 @@ int MvProcStat::updateStats()
     FILE *fpP, *fpS;
     CpuTime actCpuTime;
 
-    if ((fpP = fopen(procPath_.c_str(), "r")) == NULL) {
+    if ((fpP = fopen(procPath_.c_str(), "r")) == nullptr) {
         return -1;
     }
 
-    if ((fpS = fopen(sysPath_.c_str(), "r")) == NULL) {
+    if ((fpS = fopen(sysPath_.c_str(), "r")) == nullptr) {
         fclose(fpP);
         return -1;
     }
@@ -172,8 +172,8 @@ int MvProcStat::updateStats()
 
     //Sum up the numbers to get the total cpu time
     long unsigned int v = 0;
-    for (int i = 0; i < 10; i++)
-        v += cpuSys[i];
+    for (unsigned long cpuSy : cpuSys)
+        v += cpuSy;
 
     actCpuTime.total_ = v;
 
@@ -186,7 +186,7 @@ int MvProcStat::updateStats()
     return 0;
 }
 
-string MvProcStat::elapsedTime()
+std::string MvProcStat::elapsedTime()
 {
     if (!MvProcNode::hasProcFs())
         return "-1";
@@ -207,10 +207,10 @@ string MvProcStat::elapsedTime()
         sprintf(c, "%dd:%02dh:%02dm", d, h, m);
 
 
-    //stringstream ss;
+    //std::stringstream ss;
     //ss << h << "h:" << m  << "m";
     //lastElapsedTime_=ss.str();
-    lastElapsedTime_ = string(c);
+    lastElapsedTime_ = std::string(c);
     return lastElapsedTime_;
 }
 
@@ -222,7 +222,7 @@ int MvProcStat::getCpuUsage(CpuTime* current, CpuTime* prev)
 
     long unsigned int tdiff = current->total_ - prev->total_;
 
-    //cout << "cpu " << tdiff << " " << current->uTime_ << " " << prev->uTime_ << endl;
+    //std::cout << "cpu " << tdiff << " " << current->uTime_ << " " << prev->uTime_ << std::endl;
 
     return static_cast<int>(100. * ((current->uTime_ + current->cuTime_) - (prev->uTime_ + prev->cuTime_)) / static_cast<float>(tdiff));
 
@@ -232,9 +232,9 @@ int MvProcStat::getCpuUsage(CpuTime* current, CpuTime* prev)
     //                (double) total_time_diff);
 }
 
-string MvProcStat::byteToMbyte(unsigned long int bv)
+std::string MvProcStat::byteToMbyte(unsigned long int bv)
 {
-    stringstream ss;
+    std::stringstream ss;
     ss.setf(std::ios::fixed, std::ios::floatfield);
     ss.precision(1);
     ss << static_cast<double>(bv) / 1048576. << " M";
@@ -258,13 +258,13 @@ MvProcNode::MvProcNode(long ref, request* r) :
 {
     if (r) {
         if (const char* v = get_value(r, "NAME", 0))
-            name_ = string(v);
+            name_ = std::string(v);
         if (const char* v = get_value(r, "HOST", 0))
-            host_ = string(v);
+            host_ = std::string(v);
         if (const char* v = get_value(r, "USER", 0))
-            user_ = string(v);
+            user_ = std::string(v);
         if (const char* v = get_value(r, "PID", 0)) {
-            pidStr_ = string(v);
+            pidStr_ = std::string(v);
             pid_    = atol(pidStr_.c_str());
             if (pid_ > 0) {
                 stats_ = new MvProcStat(host_, pid_);
@@ -282,7 +282,7 @@ MvProcNode::MvProcNode(long ref, request* r) :
 MvProcNode::~MvProcNode()
 {
     if (items_.size() > 0) {
-        vector<MvProcNode*>::iterator it = std::find(items_.begin(), items_.end(), this);
+        auto it = std::find(items_.begin(), items_.end(), this);
         if (it != items_.end())
             items_.erase(it);
     }
@@ -291,8 +291,8 @@ MvProcNode::~MvProcNode()
         delete stats_;
 
     //Delete children
-    for (vector<MvProcNode*>::iterator it = children_.begin(); it != children_.end(); it++) {
-        delete *it;
+    for (auto& it : children_) {
+        delete it;
     }
 
     children_.clear();
@@ -310,7 +310,7 @@ void MvProcNode::queryNiceName()
             if (n && strcmp(n, name_.c_str()) == 0) {
                 const char* p = get_value(s, "fullname", 0);
                 if (p) {
-                    niceName_ = string(p);
+                    niceName_ = std::string(p);
                     return;
                 }
             }
@@ -344,11 +344,11 @@ int MvProcNode::indexOfChild(MvProcNode* item) const
 
 void MvProcNode::add(long ref, request* r)
 {
-    MvProcNode* proc = new MvProcNode(ref, r);
+    auto* proc = new MvProcNode(ref, r);
 
-    for (vector<MvProcNode*>::iterator it = items_.begin(); it != items_.end(); it++) {
+    for (auto it = items_.begin(); it != items_.end(); it++) {
         if (*it != root_ && proc != *it &&
-            proc->name().find((*it)->name()) == 0 && proc->name().find("@") != string::npos) {
+            proc->name().find((*it)->name()) == 0 && proc->name().find("@") != std::string::npos) {
             proc->setParent(*it);
             return;
         }
@@ -357,25 +357,25 @@ void MvProcNode::add(long ref, request* r)
     proc->setParent(root_);
 
     //Reparent existing items if needed
-    if (!(proc->name().find("@") != string::npos)) {
-        for (vector<MvProcNode*>::iterator it = items_.begin(); it != items_.end(); it++) {
-            if (*it != root_ && proc != *it && (*it)->name().find("@") != string::npos) {
-                string s = (*it)->name().substr(0, (*it)->name().find("@"));
+    if (!(proc->name().find("@") != std::string::npos)) {
+        for (auto& item : items_) {
+            if (item != root_ && proc != item && item->name().find("@") != std::string::npos) {
+                std::string s = item->name().substr(0, item->name().find("@"));
                 if (s == proc->name())
-                    (*it)->setParent(proc);
+                    item->setParent(proc);
             }
         }
     }
 }
 
-void MvProcNode::remove(long ref, string name)
+void MvProcNode::remove(long ref, std::string name)
 {
     MvProcNode* proc = find(ref, name);
     if (proc) {
-        cout << "remove " << proc->name() << endl;
+        std::cout << "remove " << proc->name() << std::endl;
 
         if (proc->parent()) {
-            cout << "remove from parent" << proc->parent()->name() << endl;
+            std::cout << "remove from parent" << proc->parent()->name() << std::endl;
 
             proc->parent()->removeChild(proc);
             delete proc;
@@ -411,9 +411,9 @@ void MvProcNode::addChild(MvProcNode* item)
 void MvProcNode::removeChild(MvProcNode* item)
 {
     if (children_.size() > 0) {
-        vector<MvProcNode*>::iterator it = std::find(children_.begin(), children_.end(), item);
+        auto it = std::find(children_.begin(), children_.end(), item);
         if (it != children_.end()) {
-            cout << "remove child " << (*it)->name() << endl;
+            std::cout << "remove child " << (*it)->name() << std::endl;
             children_.erase(it);
         }
     }
@@ -421,8 +421,8 @@ void MvProcNode::removeChild(MvProcNode* item)
 
 void MvProcNode::updateInfo()
 {
-    for (vector<MvProcNode*>::iterator it = items_.begin(); it != items_.end(); it++) {
-        (*it)->updateStats();
+    for (auto& item : items_) {
+        item->updateStats();
     }
 }
 
@@ -435,11 +435,11 @@ void MvProcNode::updateStats()
         observer_->infoChanged(this);
 }
 
-MvProcNode* MvProcNode::find(long r, string name)
+MvProcNode* MvProcNode::find(long r, std::string name)
 {
-    for (vector<MvProcNode*>::iterator it = items_.begin(); it != items_.end(); it++) {
-        if ((*it)->ref() == r && (*it)->name() == name)
-            return *it;
+    for (auto& item : items_) {
+        if (item->ref() == r && item->name() == name)
+            return item;
     }
     return 0;
 }
@@ -460,16 +460,16 @@ void MvProcNode::killProc()
 }
 
 
-void MvProcNode::addProcRequest(long reqId, long ref, const string& name, request* r)
+void MvProcNode::addProcRequest(long reqId, long ref, const std::string& name, request* r)
 {
     procRequests_.push_back(new MvProcRequest(r));
     assignProcRequest(reqId, ref, name);
 }
 
 
-void MvProcNode::assignProcRequest(long reqId, long ref, const string& name)
+void MvProcNode::assignProcRequest(long reqId, long ref, const std::string& name)
 {
-    for (vector<MvProcRequest*>::iterator it = procRequests_.begin();
+    for (auto it = procRequests_.begin();
          it != procRequests_.end(); it++) {
         if ((*it)->reqId() == reqId) {
             if (MvProcNode* proc = find(ref, name)) {
@@ -494,10 +494,10 @@ MvProcRequest::MvProcRequest(request* r) :
     sourceRef_ = atol(get_value(r, "SOURCE_REF", 0));
 
     if (const char* ch = get_value(r, "TARGET", 0))
-        target_ = string(ch);
+        target_ = std::string(ch);
 
     if (const char* ch = get_value(r, "SOURCE", 0))
-        source_ = string(ch);
+        source_ = std::string(ch);
 
     const char* x = get_value(r, "WAITMODE", 0);
     int sync      = x ? atoi(x) : 0;
@@ -506,17 +506,17 @@ MvProcRequest::MvProcRequest(request* r) :
         req_ = clone_all_requests(r->next);
 
         if (const char* ch = get_value(req_, "_CLASS", 0)) {
-            className_ = string(ch);
+            className_ = std::string(ch);
         }
         else {
             className_ = "REQUEST";
         }
 
         if (const char* ch = get_value(req_, "_NAME", 0)) {
-            name_ = string(ch);  //mbasename(
+            name_ = std::string(ch);  //mbasename(
         }
         else {
-            name_ = string(req_->name);
+            name_ = std::string(req_->name);
         }
 
         if (sync) {
@@ -524,7 +524,7 @@ MvProcRequest::MvProcRequest(request* r) :
         }
 
         if (char* rc = request2string(req_))
-            reqStr_ = string(rc);
+            reqStr_ = std::string(rc);
     }
 }
 
@@ -558,10 +558,7 @@ MvServiceInfo::MvServiceInfo(long ref, request* r) :
     killLevel_ = 0;
 }
 
-MvServiceInfo::~MvServiceInfo()
-{
-    
-}
+MvServiceInfo::~MvServiceInfo() = default;
 
 void MvServiceInfo::debug()
 {
@@ -589,7 +586,7 @@ void MvServiceInfo::open()
 }
 
 
-MvRequestInfo::MvRequestInfo(long ref, long f, long t, request* s, int sync) :
+MvRequestInfo::MvRequestInfo(long ref, long /*f*/, long t, request* s, int sync) :
     MvProcNode(ref, s),
     to_(t)
 {
@@ -602,10 +599,10 @@ MvRequestInfo::MvRequestInfo(long ref, long f, long t, request* s, int sync) :
     if (sync) {
         char buf[1024];
         sprintf(buf, "%s (synchrone)", n);
-        name_ = string(strcache(buf));
+        name_ = std::string(strcache(buf));
     }
     else
-        name_ = string(strcache(n));
+        name_ = std::string(strcache(n));
 
     //icon    = DragAddIcon(drag_request,c,name,this,0,0);
 }
