@@ -172,7 +172,7 @@ QVariant MvQProcModel::headerData(const int section, const Qt::Orientation orien
 MvProcNode* MvQProcModel::itemForIndex(const QModelIndex& index) const
 {
     if (index.isValid()) {
-        if (MvProcNode* item = static_cast<MvProcNode*>(index.internalPointer())) {
+        if (auto* item = static_cast<MvProcNode*>(index.internalPointer())) {
             return item;
         }
     }
