@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQProcModel_H
-#define MvQProcModel_H
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QColor>
@@ -61,5 +60,3 @@ protected:
 
     MvQPixmapCache* pm_;
 };
-
-#endif
