@@ -242,7 +242,7 @@ void ProcMonitor::input(svcid* id, request* r)
     QString mode(get_value(id->r, "MODE", 0));
 
     //std::cout << ref << " " << name << " " << mode << std::endl;
-
+#if 0
     std::cout << "id->r ------------------------>" << std::endl;
 
     print_all_requests(id->r);
@@ -251,6 +251,7 @@ void ProcMonitor::input(svcid* id, request* r)
 
     print_all_requests(r);
     //std::cout << r << " " << id->r << std::endl;
+#endif
 
     if (mode == "REPLY") {
         //long reqid = atol(get_value(r, "REQ_ID", 0));
@@ -306,9 +307,10 @@ void ProcMonitor::input(svcid* id, request* r)
 
         // qDebug() << "followup" << name << reqid;
     }
-
+#if 0
     std::cout << "<-----------------------" << std::endl;
     std::cout << std::endl;
+#endif
 }
 
 void ProcMonitor::adjustView()
