@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef XServ_H
-#define XServ_H
+#pragma once
 
 #include "mars.h"
 #undef D  /// MARS
@@ -21,7 +20,7 @@ class XServBar : public QWidget
 
 public:
     XServBar(svc* s);
-    ~XServBar(){};
+    ~XServBar() = default;
 
 
 public slots:
@@ -35,6 +34,3 @@ private:
     QGridLayout buttonLayout_;
     QWidget* scrollAreaInternalWidget_;
 };
-
-
-#endif
