@@ -12,15 +12,12 @@
 #include "Action.h"
 
 
-ActionCommand::ActionCommand(const string& name) :
+ActionCommand::ActionCommand(const std::string& name) :
     Command(name)
 {
 }
 
-ActionCommand::~ActionCommand()
-{
-    // Not called
-}
+ActionCommand::~ActionCommand() = default;
 
 void ActionCommand::execute(IconObject* o)
 {
