@@ -10,38 +10,36 @@
 #include "Command.h"
 //#include "Log.h"
 
+#include <string>
 #include <map>
 #include <iostream>
 
-static map<string, Command*>* actions = nullptr;
+static std::map<std::string, Command*>* actions = nullptr;
 
-Command::Command(const string& name) :
+Command::Command(const std::string& name) :
     name_(name)
 {
     if (actions == nullptr)
-        actions = new map<string, Command*>;
+        actions = new std::map<std::string, Command*>;
 
     (*actions)[name] = this;
 }
 
-Command::~Command()
-{
-    // Not called
-}
+Command::~Command() = default;
 
 
-void Command::execute(const string& name, IconObject* p)
+void Command::execute(const std::string& name, IconObject* p)
 {
-    map<string, Command*>::iterator j = actions->find(name);
+    auto j = actions->find(name);
     if (j == actions->end())
-        //Log::error(p) << name << ": action not found" << endl;
-        cout << name << ": action not found" << endl;
+        //Log::error(p) << name << ": action not found" << std::endl;
+        std::cout << name << ": action not found" << std::endl;
     else
         (*j).second->execute(p);
 }
 
-bool Command::isValid(const string& name)
+bool Command::isValid(const std::string& name)
 {
-    map<string, Command*>::iterator j = actions->find(name);
+    auto j = actions->find(name);
     return (j != actions->end());
-}
\ No newline at end of file
+}
