@@ -7,32 +7,27 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Command_H
-#define Command_H
+#pragma once
 
 #include <string>
 
-using namespace std;
-
 class IconObject;
 
 class Command
 {
 public:
-    Command(const string& name);
+    Command(const std::string& name);
     virtual ~Command();
 
     virtual void execute(IconObject*) = 0;
-    static void execute(const string&, IconObject*);
-    static bool isValid(const string&);
+    static void execute(const std::string&, IconObject*);
+    static bool isValid(const std::string&);
 
 protected:
-    string name_;
+    std::string name_;
 
 private:
     // No copy allowed
     Command(const Command&);
     Command& operator=(const Command&);
 };
-
-#endif
