@@ -18,17 +18,17 @@
 #include "IconObject.h"
 #include "Request.h"
 
-ComputeEditor::ComputeEditor(const IconClass& kind, const string& name) :
+ComputeEditor::ComputeEditor(const IconClass& kind, const std::string& name) :
     MvQEditor(kind, name)
 {
-    QLabel* label = new QLabel(tr("<b>Formula:<b>"), this);
+    auto* label = new QLabel(tr("<b>Formula:<b>"), this);
     centralLayout_->addWidget(label, 0);
 
     te_ = new MvQLineEdit(this);
     centralLayout_->addWidget(te_, 0);
     centralLayout_->addStretch(1);
 
-    //vector<string> classes;
+    //std::vector<std::string> classes;
     //classes.push_back(kind.name());
 
     //connect(w,SIGNAL(iconDropped(IconObject*)),
@@ -38,9 +38,7 @@ ComputeEditor::ComputeEditor(const IconClass& kind, const string& name) :
             this, SLOT(slotTextChanged()));
 }
 
-ComputeEditor::~ComputeEditor()
-{
-}
+ComputeEditor::~ComputeEditor() = default;
 
 void ComputeEditor::apply()
 {
@@ -90,7 +88,7 @@ void ComputeEditor::merge(IconObjectH)
 
 
 	if(quote) 
-		s = string("\'") + s + string("\'");
+        s = std::string("\'") + s + std::string("\'");
 	text.insert(s);*/
 }
 
