@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Dependancy_H
-#define Dependancy_H
+#pragma once
 
 #include "Counted.h"
 
@@ -34,5 +33,3 @@ public:
     DependancyH(Dependancy* o = 0) :
         Handle<Dependancy>(o) {}
 };
-
-#endif
