@@ -13,9 +13,9 @@
 #include "Task.h"
 #include "IconClass.h"
 
-Drop::Drop(const set<IconObject*>& icons,
+Drop::Drop(const std::set<IconObject*>& icons,
            const Request& request,
-           const string& service, const Request& mode,
+           const std::string& service, const Request& mode,
            QObject* parent) :
     QObject(parent),
     request_(request),
@@ -24,8 +24,8 @@ Drop::Drop(const set<IconObject*>& icons,
     error_(false),
     waiting_(0)
 {
-    for (set<IconObject*>::const_iterator j = icons.begin(); j != icons.end(); ++j) {
-        IconObjectH o = (*j);
+    for (auto icon : icons) {
+        IconObjectH o = icon;
         requests_[o]  = o->request();
         Task* t       = o->action(Action("prepare", "*"));
 
@@ -43,10 +43,7 @@ Drop::Drop(const set<IconObject*>& icons,
     check();
 }
 
-Drop::~Drop()
-{
-//    cout << "Drop::~Drop()" << endl;
-}
+Drop::~Drop() = default;
 
 void Drop::success(Task* t, const Request& r)
 {
@@ -74,13 +71,11 @@ void Drop::check()
     if (!error_) {
         // Request should be sorted
         const char* null = 0;
-        map<int, vector<Request> > m;
+        std::map<int, std::vector<Request> > m;
 
-        for (map<IconObjectH, Request>::iterator j = requests_.begin(); j !=
-                                                                        requests_.end();
-             ++j) {
-            Request r     = (*j).second;
-            IconObject* o = (*j).first;
+        for (auto& request : requests_) {
+            Request r     = request.second;
+            IconObject* o = request.first;
             if (r && r.getVerb()) {
                 int priority = IconClass::find(r.getVerb()).priority();
                 if (null == r("_NAME"))
@@ -93,11 +88,10 @@ void Drop::check()
 
         Request req;
 
-        for (map<int, vector<Request> >::iterator k = m.begin(); k != m.end(); ++k) {
+        for (auto& k : m) {
             Request r;
-            for (vector<Request>::iterator j = (*k).second.begin();
-                 j != (*k).second.end(); ++j)
-                r = r + (*j) + req;
+            for (auto& j : k.second)
+                r = r + j + req;
             req = r;
         }
 
@@ -107,8 +101,8 @@ void Drop::check()
         MvApplication::callService(service_.c_str(), request_, 0);
     }
     else {
-        map<IconObjectH, Request>::iterator it = requests_.begin();
-        request_                               = (*it).second;
+        auto it  = requests_.begin();
+        request_ = (*it).second;
 
         MvApplication::callService(service_.c_str(), request_, 0);
     }
