@@ -7,8 +7,11 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Drop_H
-#define Drop_H
+#pragma once
+
+#include <map>
+#include <set>
+#include <string>
 
 #include "IconObject.h"
 #include "Request.h"
@@ -19,7 +22,7 @@
 class Drop : public QObject, public TaskObserver
 {
 public:
-    Drop(const set<IconObject*>&, const Request&, const string&, const Request&, QObject* obj = 0);
+    Drop(const std::set<IconObject*>&, const Request&, const std::string&, const Request&, QObject* obj = 0);
     virtual ~Drop();
 
     void start();
@@ -36,15 +39,13 @@ private:
     virtual void failure(Task*, const Request&);
 
     Request request_;
-    string service_;
+    std::string service_;
     Request mode_;
     bool error_;
     int waiting_;
 
-    map<IconObjectH, Request> requests_;
-    map<Task*, IconObject*> tasks_;
+    std::map<IconObjectH, Request> requests_;
+    std::map<Task*, IconObject*> tasks_;
 };
 
 inline void destroy(Drop**) {}
-
-#endif
