@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#include <string>
-using std::string;
+#include <assert.h>
 
 #include "Metview.h"
 #include "EditTransaction.h"
@@ -25,8 +24,7 @@ using std::string;
 #include "MacroGuiObject.h"
 #include "PythonGuiObject.h"
 #include "Action.h"
-
-#include <assert.h>
+#include "MvLog.h"
 
 EditTransaction::EditTransaction() :
     Transaction("EDIT")
@@ -73,13 +71,11 @@ void EditTransaction::failure(Task*, const Request& r)
 
 void EditTransaction::callback(MvRequest& r)
 {
-    r.print();
-
     current_ = 0;
 
-//    std::cout << "CALLBACK" << std::endl;
-//    r.print();
-//    std::cout << "----------" << std::endl;
+    std::cout << "CALLBACK" << std::endl;
+    r.print();
+    std::cout << "----------" << std::endl;
 
     MvRequest def = r("DEFINITION");
 
@@ -102,32 +98,31 @@ void EditTransaction::callback(MvRequest& r)
                 f->scan();
                 if (IconObject* o = f->find(uplotDir)) {
                     assert(o->isFolder());
-                    Folder* uf = static_cast<Folder*>(o);
+                    auto* uf = static_cast<Folder*>(o);
                     assert(uf);
                     uf->scan();
                     current_ = IconObject::search(name);
                 }
             }
 
-            if (!current_)
+            if (!current_) {
+                MvLog().dbg() << MV_FN_INFO << "CREATE";
                 current_ = IconFactory::create(Folder::folder("temporary"), def, 0, 0);
+            }
         }
     }
 
     else {
-
-
-
         r.advance();
 
-//        std::cout << "ADVANCE" << std::endl;
-//        r.print();
-//        std::cout << "----------" << std::endl;
+        //        std::cout << "ADVANCE" << std::endl;
+        //        r.print();
+        //        std::cout << "----------" << std::endl;
 
         if (r) {
             if (const char* ch = r("_APPL")) {
                 if (strcmp(ch, "Python") == 0) {
-                     subClass_ = new PythonGuiObject(r);
+                    subClass_ = new PythonGuiObject(r);
                 }
             }
             if (!subClass_) {
@@ -135,12 +130,17 @@ void EditTransaction::callback(MvRequest& r)
             }
             Request t(subClass_->name().c_str());
             current_ = IconFactory::create(Folder::folder("temporary"), t, 0, 0);
-        } else {
+        }
+        else {
             close(current_);
             return;
         }
     }
 
+    MvLog().dbg() << "OBJECT-REC --->";
+    current_->request().print();
+    MvLog().dbg() << "<-------";
+
     current_->edit();
 
     Editor* e = current_->editor();
