@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef EditTransaction_H
-#define EditTransaction_H
+#pragma once
 
 #include "Transaction.h"
 #include "EditorObserver.h"
@@ -48,5 +47,3 @@ inline void destroy(EditTransaction**) {}
 //#ifdef _ODI_OSSG_
 //OS_MARK_SCHEMA_TYPE(EditTransaction);
 //#endif
-
-#endif
