@@ -7,12 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Editor_H
-#define Editor_H
+#pragma once
 
 
 #include <string>
-using std::string;
 
 class IconObject;
 class IconClass;
@@ -29,7 +27,7 @@ public:
     virtual ~Editor();
 
     const IconClass& iconClass();
-    const string& kind();
+    const std::string& kind();
     IconObject* current();
     void observer(EditorObserver*);
 
@@ -41,7 +39,7 @@ public:
 
     virtual void empty();
     virtual void temporary();
-    virtual string alternateEditor();
+    virtual std::string alternateEditor();
     virtual void changed() = 0;
     virtual void raiseIt() = 0;
     virtual void closeIt() = 0;
@@ -49,10 +47,11 @@ public:
     static void open(IconObject*);
 
 protected:
-    Editor(const IconClass&, const string& kind);
+    Editor(const IconClass&, const std::string& kind);
+    virtual void applyTemporayRules() {}
 
     const IconClass& class_;
-    string kind_;
+    std::string kind_;
     EditorObserver* observer_;
     IconObjectH current_;
     bool temporary_;
@@ -64,6 +63,3 @@ private:
     explicit Editor(const Editor&);
     Editor& operator=(const Editor&);
 };
-
-
-#endif
