@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef EditorDrawer_H
-#define EditorDrawer_H
+#pragma once
 
 #include <QString>
 
@@ -19,7 +18,7 @@ class EditorDrawer
 {
 public:
     EditorDrawer(MvQEditor* editor) :
-        editor_(editor){};
+        editor_(editor) {}
 
     virtual QString name()    = 0;
     virtual QWidget* widget() = 0;
@@ -27,5 +26,3 @@ public:
 protected:
     MvQEditor* editor_;
 };
-
-#endif
\ No newline at end of file
