@@ -7,11 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef EditorDrawerFactory_H
-#define EditorDrawerFactory_H
+#pragma once
 
-#include "inc_stl.h"
-using std::string;
+#include <map>
+#include <string>
 
 //UKMO/HP/aCC:
 #ifdef hp
@@ -28,7 +27,7 @@ public:
     virtual ~EditorDrawerFactory();
 
     virtual EditorDrawer* make(MvQEditor*) = 0;
-    static map<string, EditorDrawer*> create(MvQEditor*);
+    static std::map<std::string, EditorDrawer*> create(MvQEditor*);
 
 private:
     // No copy allowed
@@ -49,6 +48,3 @@ public:
     EditorDrawerMaker(int n) :
         EditorDrawerFactory(n) {}
 };
-
-
-#endif
