@@ -12,38 +12,35 @@
 #include "Editor.h"
 #include "NoEditor.h"
 
-typedef multimap<pair<string, string>, Editor*> Map;
+using Map = std::multimap<std::pair<std::string, std::string>, Editor*>;
 static Map editors;
 
-static map<string, EditorFactory*>* makers = 0;
+static std::map<std::string, EditorFactory*>* makers = 0;
 
-EditorFactory::EditorFactory(const string& name) :
+EditorFactory::EditorFactory(const std::string& name) :
     name_(name)
 {
     if (makers == 0)
-        makers = new map<string, EditorFactory*>;
+        makers = new std::map<std::string, EditorFactory*>;
 
     (*makers)[name] = this;
 }
 
-EditorFactory::~EditorFactory()
-{
-    // Not called
-}
+EditorFactory::~EditorFactory() = default;
 
 Editor* EditorFactory::find(const IconClass& c)
 {
     return find(c, c.editor());
 }
 
-Editor* EditorFactory::find(const IconClass& c, const string& type)
+Editor* EditorFactory::find(const IconClass& c, const std::string& type)
 {
     //Cleaning
     /*for(Map::iterator it = editors.begin(); it != editors.end(); )
 	{
 		if(it->second->current() == 0)
 		{
-		  	cout << "Editor deleted:  " <<  it->first.first << " " << it->first.second << endl;
+		  	std::cout << "Editor deleted:  " <<  it->first.first << " " << it->first.second << std::endl;
 			
 			delete it->second;
 			editors.erase(it++);
@@ -55,13 +52,13 @@ Editor* EditorFactory::find(const IconClass& c, const string& type)
 	}*/
 
     //Find or create
-    pair<string, string> name(c.name(), type);
+    std::pair<std::string, std::string> name(c.name(), type);
     Editor* e = 0;
 
-    pair<Map::iterator, Map::iterator> p = editors.equal_range(name);
-    for (Map::iterator j = p.first; j != p.second; ++j) {
+    std::pair<Map::iterator, Map::iterator> p = editors.equal_range(name);
+    for (auto j = p.first; j != p.second; ++j) {
         Editor* editor = (*j).second;
-        pair<string, string> n(editor->iconClass().name(), editor->kind());
+        std::pair<std::string, std::string> n(editor->iconClass().name(), editor->kind());
 
         if (name == n && editor->current() == 0) {
             e = editor;
@@ -70,7 +67,7 @@ Editor* EditorFactory::find(const IconClass& c, const string& type)
     }
 
     if (e == 0) {
-        map<string, EditorFactory*>::iterator j = makers->find(type);
+        auto j = makers->find(type);
         if (j == makers->end()) {
             e = new NoEditor(c, "NoEditor");
         }
@@ -80,10 +77,10 @@ Editor* EditorFactory::find(const IconClass& c, const string& type)
         editors.insert(Map::value_type(name, e));
     }
 
-//    cout << "Editors ---------->" << endl;
-//    for (Map::iterator it = editors.begin(); it != editors.end(); it++) {
-//        cout << " editor: " << it->first.first << " " << it->first.second << endl;
-//    }
+    //    std::cout << "Editors ---------->" << std::endl;
+    //    for (Map::iterator it = editors.begin(); it != editors.end(); it++) {
+    //        std::cout << " editor: " << it->first.first << " " << it->first.second << std::endl;
+    //    }
 
     return e;
 }
