@@ -7,11 +7,9 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef EditorFactory_H
-#define EditorFactory_H
+#pragma once
 
 #include <string>
-using std::string;
 
 #include "mars.h"
 
@@ -21,16 +19,16 @@ class IconClass;
 class EditorFactory
 {
 public:
-    EditorFactory(const string& name);
+    EditorFactory(const std::string& name);
     virtual ~EditorFactory();
 
     virtual Editor* make(const IconClass&) = 0;
 
     static Editor* find(const IconClass& name);
-    static Editor* find(const IconClass& name, const string& type);
+    static Editor* find(const IconClass& name, const std::string& type);
 
 protected:
-    string name_;
+    std::string name_;
 
 private:
     EditorFactory(const EditorFactory&);
@@ -43,9 +41,6 @@ class EditorMaker : public EditorFactory
     Editor* make(const IconClass& n) { return new T(n, name_); }
 
 public:
-    EditorMaker(const string& name) :
+    EditorMaker(const std::string& name) :
         EditorFactory(name) {}
 };
-
-
-#endif
