@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef EditorObserver_H
-#define EditorObserver_H
+#pragma once
 
 class IconObject;
 
@@ -18,6 +17,3 @@ public:
     virtual void apply(IconObject*) = 0;
     virtual void close(IconObject*) = 0;
 };
-
-
-#endif
