@@ -28,15 +28,16 @@
 
 #include "MvQRequestPanelWidget.h"
 
-FamilyEditor::FamilyEditor(const IconClass& name, const string& kind) :
+FamilyEditor::FamilyEditor(const IconClass& name, const std::string& kind) :
     MvQEditor(name, kind),
     scanner_(FamilyScanner::find(name))
 {
-    QFrame* w = new QFrame(this);
+    auto* w = new QFrame(this);
     w->setFrameShape(QFrame::StyledPanel);
 
-    QHBoxLayout* hb = new QHBoxLayout(this);
+    auto* hb = new QHBoxLayout(this);
     w->setLayout(hb);
+
     centralLayout_->addWidget(w);
     centralLayout_->addSpacing(4);
 
@@ -61,19 +62,17 @@ FamilyEditor::FamilyEditor(const IconClass& name, const string& kind) :
     }
 }
 
-FamilyEditor::~FamilyEditor()
-{
-}
+FamilyEditor::~FamilyEditor() = default;
 
 void FamilyEditor::setStartPage()
 {
     if (!current_)
         return;
 
-    vector<string> keyValues;
+    std::vector<std::string> keyValues;
     const Request& r = current_->requestForVerb(class_.name());
 
-    const vector<string>& p = scanner_.params();
+    const std::vector<std::string>& p = scanner_.params();
     for (unsigned int i = 0; i < p.size(); i++) {
         const char* keyVal = r(p[i].c_str());
         if (keyVal) {
@@ -89,22 +88,22 @@ void FamilyEditor::setStartPage()
 
 void FamilyEditor::makePages(int n, Request& r)
 {
-    const vector<string>& p = scanner_.params();
+    const std::vector<std::string>& p = scanner_.params();
     if (n >= static_cast<int>(p.size()))
         return;
 
-    string paramName = p[n];
+    std::string paramName = p[n];
 
-    const vector<string>& v = scanner_.values(paramName);
-    const vector<string>& b = scanner_.beau(paramName);
+    const std::vector<std::string>& v = scanner_.values(paramName);
+    const std::vector<std::string>& b = scanner_.beau(paramName);
 
     for (unsigned int i = 0; i < v.size(); i++) {
         r(paramName.c_str()) = v[i].c_str();
 
         if (combos_.count() < n + 1) {
-            int row          = combos_.count();
-            QLabel* lab      = new QLabel("<b>" + QString::fromStdString(paramName) + ": </b>", this);
-            QComboBox* combo = new QComboBox(this);
+            int row     = combos_.count();
+            auto* lab   = new QLabel("<b>" + QString::fromStdString(paramName) + ": </b>", this);
+            auto* combo = new QComboBox(this);
             comboLayout_->addWidget(lab, row, 0);
             comboLayout_->addWidget(combo, row, 1, Qt::AlignLeft);
             combos_ << combo;
@@ -124,14 +123,14 @@ void FamilyEditor::makePages(int n, Request& r)
 
             if (type) {
                 //Create panel
-                vector<string> classes;
+                std::vector<std::string> classes;
                 classes.push_back(class_.name());
 
-                MvQRequestPanelWidget* w = new MvQRequestPanelWidget(classes, this);
-                RequestPanel* panel      = new RequestPanel(IconClass::find(type), w, this, false, type);
+                auto* w     = new MvQRequestPanelWidget(classes, this);
+                auto* panel = new RequestPanel(IconClass::find(type), w, this, false, type);
                 panels_.push_back(panel);
 
-                QScrollArea* area = new QScrollArea(this);
+                auto* area = new QScrollArea(this);
                 area->setWidgetResizable(true);
                 page_->addWidget(area);
                 area->setWidget(w);
@@ -146,7 +145,7 @@ void FamilyEditor::makePages(int n, Request& r)
 }
 
 
-IconObject* FamilyEditor::copy(const string& /*name*/)
+IconObject* FamilyEditor::copy(const std::string& /*name*/)
 {
     //IconObject* o = IconFactory::create(name, class_);
     //panel_.apply();
@@ -163,9 +162,9 @@ void FamilyEditor::apply()
 
     Request r = current_->requestForVerb(class_.name());
 
-    map<string, string> keyVals;
+    std::map<std::string, std::string> keyVals;
     keyValues(keyVals);
-    for (map<string, string>::const_iterator it = keyVals.begin(); it != keyVals.end(); it++) {
+    for (auto it = keyVals.begin(); it != keyVals.end(); it++) {
         r(it->first.c_str()) = it->second.c_str();
     }
 
@@ -175,10 +174,10 @@ void FamilyEditor::apply()
         Request pr = panels_.at(i)->request();
         r          = r + panels_.at(i)->request();
         //r.print();
-        objects_.at(i)->request(pr);
+        objects_.at(i)->setRequest(pr);
     }
 
-    current_->request(r);
+    current_->setRequest(r);
 }
 
 void FamilyEditor::edit()
@@ -188,8 +187,8 @@ void FamilyEditor::edit()
 
     objects_.clear();
 
-    for (unsigned int i = 0; i < panels_.size(); i++) {
-        const IconClass& kind = panels_.at(i)->iconClass();
+    for (auto& panel : panels_) {
+        const IconClass& kind = panel->iconClass();
 
         //Create icon object
         Request panelReq = current_->requestForVerb(kind.name());
@@ -217,8 +216,8 @@ void FamilyEditor::reset()
 
 void FamilyEditor::close()
 {
-    for (unsigned int i = 0; i < panels_.size(); i++) {
-        panels_.at(i)->close();
+    for (auto& panel : panels_) {
+        panel->close();
     }
     objects_.clear();
 }
@@ -259,12 +258,12 @@ void FamilyEditor::slotChangePage(int)
     MvQEditor::changed();
 }
 
-void FamilyEditor::keyValues(map<string, string>& keyValues)
+void FamilyEditor::keyValues(std::map<std::string, std::string>& keyValues)
 {
-    const vector<string>& p = scanner_.params();
+    const std::vector<std::string>& p = scanner_.params();
     for (unsigned int i = 0; i < p.size(); i++) {
-        string keyVal = p[i];
-        int index     = combos_.at(i)->currentIndex();
+        std::string keyVal = p[i];
+        int index          = combos_.at(i)->currentIndex();
         if (index > -1) {
             keyValues[keyVal] = combos_.at(i)->itemData(index, Qt::UserRole).toString().toStdString();
         }
