@@ -7,8 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef FamilyEditor_H
-#define FamilyEditor_H
+#pragma once
+
+#include <map>
+#include <string>
 
 #include "MvQEditor.h"
 
@@ -28,7 +30,7 @@ class FamilyEditor : public MvQEditor
 {
     Q_OBJECT
 public:
-    FamilyEditor(const IconClass&, const string&);
+    FamilyEditor(const IconClass&, const std::string&);
     virtual ~FamilyEditor();
 
     //Request currentRequest(long custom_expand=0);
@@ -54,22 +56,22 @@ private:
 
     void setStartPage();
     void makePages(int, Request& r);
-    void keyValues(map<string, string>&);
+    void keyValues(std::map<std::string, std::string>&);
 
     virtual void apply();
     virtual void reset();
     virtual void close();
     virtual void edit();
 
-    virtual IconObject* copy(const string&);
+    virtual IconObject* copy(const std::string&);
 
     FamilyScanner& scanner_;
     QList<QComboBox*> combos_;
     QGridLayout* comboLayout_;
 
     QStackedWidget* page_;
-    vector<RequestPanel*> panels_;
-    vector<IconObjectH> objects_;
+    std::vector<RequestPanel*> panels_;
+    std::vector<IconObjectH> objects_;
 };
 
 inline void destroy(FamilyEditor**) {}
@@ -78,5 +80,3 @@ inline void destroy(FamilyEditor**) {}
 //#ifdef _ODI_OSSG_
 //OS_MARK_SCHEMA_TYPE(FamilyEditor);
 //#endif
-
-#endif
