@@ -14,12 +14,14 @@
 #include "IconClass.h"
 #include "IconFactory.h"
 #include "FamilyScanner.h"
+#include "MvLog.h"
 
 FamilyObject::FamilyObject(Folder* parent, const IconClass& kind,
                            const std::string& name, IconInfo* info) :
     StandardObject(parent, kind, name, info),
     scanner_(FamilyScanner::find(kind))
 {
+    //MvLog().info() << MV_FN_INFO << "name=" << name << " kind=" << kind.name() << " class=" << class_->name();
 }
 
 FamilyObject::~FamilyObject() = default;
@@ -48,8 +50,8 @@ void FamilyObject::setRequest(const Request& actRec)
 
     f = f + IconClass::find(r.getVerb()).language().expand(r, EXPAND_NO_DEFAULT | EXPAND_2ND_NAME);
 
-    std::cout << "family req" << std::endl;
-    f.print();
+//    MvLog().info() << MV_FN_INFO << "req=";
+//    f.print();
 
     f.save(path());
 }
@@ -63,8 +65,10 @@ Request FamilyObject::first() const
 Request FamilyObject::second() const
 {
     Request r(path());
-    if (scanner_.validate(r))
+    if (scanner_.validate(r)) {
+        //r.print();
         r.save(path());
+    }
     r.advance();
     return r;
 }
@@ -93,4 +97,17 @@ const IconClass& FamilyObject::iconClass() const
     return IconClass::find(second().getVerb());
 }
 
+void FamilyObject::createFiles()
+{
+    IconObject::createFiles();
+    Path p = path();
+    if (!p.exists()) {
+        Request r;
+        if (scanner_.validate(r)) {
+            //r.print();
+            r.save(path());
+        }
+    }
+}
+
 static IconMaker<FamilyObject> maker("Family");
