@@ -21,14 +21,16 @@
 
 //#define DEBUG_FOLDER__
 
-vector<Folder*> Folder::folders_;
+using std::string;
+
+std::vector<Folder*> Folder::folders_;
 const unsigned int Folder::maxNokidsNum_ = 100;
 
 //Path stores the full path aka fullName
 //Name stores the directory name
 
 Folder::Folder(Folder* p, const IconClass& kind,
-               const string& name, IconInfo* info) :
+               const std::string& name, IconInfo* info) :
     IconObject(p, kind, name, info),
     ready_(false),
     scanIsOn_(false),
@@ -66,8 +68,8 @@ FolderSettings* Folder::settings()
 int Folder::numOfIconKids()
 {
     int cnt = 0;
-    for (KidMap::iterator j = kids_.begin(); j != kids_.end(); ++j)
-        if (!j->second->isFolder())
+    for (auto& kid : kids_)
+        if (!kid.second->isFolder())
             cnt++;
     return cnt;
 }
@@ -97,7 +99,7 @@ void Folder::removeObserver(FolderObserver* o)
     observers_.erase(o);
 }
 
-IconObject* Folder::create(const string& name)
+IconObject* Folder::create(const std::string& name)
 {
     IconObject* obj = find(name);
     if (obj == 0) {
@@ -112,13 +114,13 @@ IconObject* Folder::create(const string& name)
     return obj;
 }
 
-IconObject* Folder::find(const vector<string>& names)
+IconObject* Folder::findMulti(const std::vector<std::string>& names)
 {
 #ifdef DEBUG_FOLDER__
-    cout << "Folder::find " << names.size() << endl;
-    for(int i = 0; i < names.size() ; i++)
-        cout << '|' << names[i] << '|';
-    cout << endl;
+    std::cout << "Folder::find " << names.size() << std::endl;
+    for (int i = 0; i < names.size(); i++)
+        std::cout << '|' << names[i] << '|';
+    std::cout << std::endl;
 #endif
     if (names.size() == 0)
         return this;
@@ -126,19 +128,18 @@ IconObject* Folder::find(const vector<string>& names)
     if (names.size() == 1)
         return find(names[0]);
 
-    vector<string> rest(names.begin() + 1, names.end());
+    std::vector<std::string> rest(names.begin() + 1, names.end());
     IconObject* s = find(names[0]);
 
-    return s ? s->find(rest) : 0;
+    return s ? s->findMulti(rest) : 0;
 }
 
-IconObject* Folder::find(const string& name)
+IconObject* Folder::find(const std::string& name)
 {
     if (!ready_)
         scan();
 
-    KidMap::iterator j = kids_.find(name);
-
+    auto j = kids_.find(name);
     if (j == kids_.end())
         return 0;
     else
@@ -157,7 +158,7 @@ IconObject* Folder::find(const string& name)
 	MvRequest myPref = MvApplication::getPreferences();
 	const char* openEachFolder = myPref( "OPEN_EACH_FOLDER" );
 
-	if ( (openEachFolder != NULL) && (strcmp( openEachFolder, "In Same Window") == 0))
+	if ( (openEachFolder != nullptr) && (strcmp( openEachFolder, "In Same Window") == 0))
 	{
 		if (parent_) parent_->close();
 	}
@@ -181,29 +182,29 @@ void Folder::scan()
     ready_    = true;
     scanIsOn_ = true;
 
-    //cout << "Scan for: " << fullName() << endl;
+    //cout << "Scan for: " << fullName() << std::endl;
 
-    set<string> files = path().files();
+    std::set<string> files = path().files();
 
     //Create and iconObject for each file/dir with the exception of the
     //dirs ending with a # character.
-    for (set<string>::iterator i = files.begin(); i != files.end(); ++i) {
+    for (const auto& file : files) {
         //if((*i).rfind("#") != (*i).size()-1)
         //{
-        create(*i);
+        create(file);
         //}
     }
 
     //Remove non-existing icons
 
-    vector<IconObjectH> erase;
+    std::vector<IconObjectH> erase;
 
-    for (KidMap::iterator j = kids_.begin(); j != kids_.end(); ++j)
-        if (files.find((*j).first) == files.end())
-            erase.push_back((*j).second);
+    for (auto& kid : kids_)
+        if (files.find(kid.first) == files.end())
+            erase.push_back(kid.second);
 
-    for (vector<IconObjectH>::iterator k = erase.begin(); k != erase.end(); ++k)
-        release(*k);
+    for (auto& k : erase)
+        release(k);
 
     saveFolderInfo();
     scanIsOn_ = false;
@@ -214,7 +215,7 @@ void Folder::scan()
 }
 
 
-void Folder::scanForNewFile(const string& name, int x, int y)
+void Folder::scanForNewFile(const std::string& name, int x, int y)
 {
     ready_    = true;
     scanIsOn_ = true;
@@ -231,12 +232,12 @@ void Folder::scanForNewFile(const string& name, int x, int y)
 void Folder::recheckKidsIconClass()
 {
     bool changed = false;
-    for (KidMap::iterator it = kids_.begin(); it != kids_.end(); ++it) {
-        IconObjectH obj = (*it).second;
+    for (auto& kid : kids_) {
+        auto obj = kid.second;
         if (obj->recheckIconClass()) {
             changed = true;
-            for (set<FolderObserver*>::iterator j = observers_.begin(); j != observers_.end(); ++j)
-                (*j)->modified(obj);
+            for (auto observer : observers_)
+                observer->modified(obj);
         }
     }
 
@@ -247,11 +248,11 @@ void Folder::recheckKidsIconClass()
 
 void Folder::recheckKidIconClass(IconObject* obj)
 {
-    for (KidMap::iterator it = kids_.begin(); it != kids_.end(); ++it) {
-        if ((*it).second == obj) {
+    for (auto& kid : kids_) {
+        if (kid.second == obj) {
             if (obj->recheckIconClass()) {
-                for (set<FolderObserver*>::iterator j = observers_.begin(); j != observers_.end(); ++j) {
-                    (*j)->modified(obj);
+                for (auto observer : observers_) {
+                    observer->modified(obj);
                 }
                 saveFolderInfo();
             }
@@ -280,7 +281,7 @@ Folder* Folder::top()
 #endif
 
 #if 0  
-Folder* Folder::folder(const string& name,bool create)
+Folder* Folder::folder(const std::string& name,bool create)
 {
 
   
@@ -308,7 +309,7 @@ Folder* Folder::folder(const string& name,bool create)
 	}
 }
 
-Folder* Folder::folder(const string& name1,const string& name2,bool create)
+Folder* Folder::folder(const std::string& name1,const string& name2,bool create)
 {
 	return 0;
 	
@@ -316,8 +317,8 @@ Folder* Folder::folder(const string& name1,const string& name2,bool create)
 	return f?folder(f->fullName()+"/"+name2,create):0;
 }
 
-Folder* Folder::folder(const string& name1,const string& name2,
-	const string& name3,bool create)
+Folder* Folder::folder(const std::string& name1,const string& name2,
+	const std::string& name3,bool create)
 {
 	return 0;
 	
@@ -330,11 +331,11 @@ Folder* Folder::folder(const string& name1,const string& name2,
 bool Folder::adopt(IconObject* o)
 {
     if (find(o->name()) != 0) {
-        // Log::error(o) << "Icon already exists" << endl;
+        // Log::error(o) << "Icon already exists" << std::endl;
         return false;
     }
 
-    Folder* f = dynamic_cast<Folder*>(o);
+    auto* f = dynamic_cast<Folder*>(o);
     if (f && f->ancestor(this)) {
         marslog(LOG_WARN, "Folder::adopt - Infinite loop when trying to adopt icon=%s", o->name().c_str());
         return false;
@@ -355,8 +356,8 @@ bool Folder::adopt(IconObject* o)
             f->release(o);
     }
 
-    for (set<FolderObserver*>::iterator j = observers_.begin(); j != observers_.end(); ++j)
-        (*j)->arrived(o);
+    for (auto observer : observers_)
+        observer->arrived(o);
 
     if (!scanIsOn_)
         saveFolderInfo();
@@ -379,8 +380,8 @@ bool Folder::release(IconObject* o)
     kids_.erase(o->name());
     folderInfo()->remove(o->name());
 
-    for (set<FolderObserver*>::iterator j = observers_.begin(); j != observers_.end(); ++j)
-        (*j)->gone(o);
+    for (auto observer : observers_)
+        observer->gone(o);
 
     saveFolderInfo();
 
@@ -412,7 +413,7 @@ void Folder::createFiles()
 }
 
 
-string Folder::uniqueName(const string& name)
+string Folder::uniqueName(const std::string& name)
 {
     char buf[1024];
     int i = 0;
@@ -421,8 +422,8 @@ string Folder::uniqueName(const string& name)
         return name;
 
     Path p(name);
-    string fName;
-    string fSuffix;
+    std::string fName;
+    std::string fSuffix;
     p.nameAndSuffix(fName, fSuffix);
 
     //For macro we want to keep the suffix
@@ -441,7 +442,7 @@ string Folder::uniqueName(const string& name)
 }
 
 
-string Folder::duplicateName(const string& name)
+string Folder::duplicateName(const std::string& name)
 {
     char buf[1024];
     int i = 0;
@@ -449,8 +450,8 @@ string Folder::duplicateName(const string& name)
 
     if (name.find("Copy ") == 0) {
         std::size_t n = name.find(" of ");
-        if (n != string::npos) {
-            string s = name.substr(5, n - 5);
+        if (n != std::string::npos) {
+            std::string s = name.substr(5, n - 5);
             if (is_number(s.c_str()))
                 d = n + 4;
         }
@@ -466,15 +467,15 @@ string Folder::duplicateName(const string& name)
 
 void Folder::position(IconObject* o, int x, int y)
 {
-    for (set<FolderObserver*>::iterator j = observers_.begin(); j != observers_.end(); ++j)
-        (*j)->position(o, x, y);
+    for (auto observer : observers_)
+        observer->position(o, x, y);
 
     if (observers_.size() == 0)
         o->position(x, y);
 }
 
 
-void Folder::renamed(IconObject* o, const string& old_name, const string& new_name)
+void Folder::renamed(IconObject* o, const std::string& old_name, const string& new_name)
 {
     IconObjectH save = o;
     kids_.erase(old_name);
@@ -482,8 +483,8 @@ void Folder::renamed(IconObject* o, const string& old_name, const string& new_na
 
     folderInfo()->rename(old_name, new_name);
 
-    for (set<FolderObserver*>::iterator j = observers_.begin(); j != observers_.end(); ++j)
-        (*j)->renamed(o, old_name);
+    for (auto observer : observers_)
+        observer->renamed(o, old_name);
 
     saveFolderInfo();
 }
@@ -491,8 +492,7 @@ void Folder::renamed(IconObject* o, const string& old_name, const string& new_na
 void Folder::tellObservers(TellObserverProc proc, IconObject* o)
 {
     IconObjectH save = o;
-    for (set<FolderObserver*>::iterator j = observers_.begin(); j != observers_.end(); ++j) {
-        FolderObserver* f = *j;
+    for (auto f : observers_) {
         (f->*proc)(o);
     }
 }
@@ -521,12 +521,12 @@ bool Folder::ancestor(IconObject* o)
     if (o == this)
         return true;
 
-    for (KidMap::iterator j = kids_.begin(); j != kids_.end(); ++j) {
-        IconObject* p = (*j).second;
+    for (auto& kid : kids_) {
+        IconObject* p = kid.second;
         if (o == p)
             return true;
 
-        Folder* f = dynamic_cast<Folder*>(p);
+        auto* f = dynamic_cast<Folder*>(p);
         if (f && f->ancestor(o))
             return true;
     }
@@ -675,18 +675,9 @@ void Folder::destroy()
 {
     if (!isLink())  //-- do not delete contents if link!
     {
-        //-- IBM/AIX/xlC+STL loops with this construct:
-        //for(KidMap::iterator j = kids_.begin(); j != kids_.end(); ++j)
-        //{
-        //	IconObject *p = (*j).second;
-        //	p->destroy();
-        //}
-
-        //-- this one ok for xlC+STL:
-        KidMap::iterator j = kids_.begin();
-        while (j != kids_.end()) {
-            IconObject* p = (*j).second;
-            ++j;
+        auto kidsCopy = kids_;
+        for (auto& kid : kidsCopy) {
+            IconObject* p = kid.second;
             p->destroy();
         }
     }
@@ -694,18 +685,16 @@ void Folder::destroy()
     IconObject::destroy();
 }
 
-void Folder::iconClasses(map<string, IconObjectH>& res)
+void Folder::iconClasses(std::map<std::string, IconObjectH>& res)
 {
-    KidMap::iterator j = kids_.begin();
-    while (j != kids_.end()) {
-        res[(*j).second->className()] = (*j).second;
-        ++j;
+    for (auto& kid : kids_) {
+        res[kid.second->className()] = kid.second;
     }
 }
 
-set<string> Folder::can()
+std::set<string> Folder::can()
 {
-    set<string> c = IconObject::can();
+    std::set<string> c = IconObject::can();
     c.erase("edit");
     c.erase("log");
     c.insert("open");
@@ -720,10 +709,6 @@ Request Folder::request() const
     return Request("");
 }
 
-void Folder::request(const Request&)
-{
-}
-
 //========================================================
 //
 //  Static methods
@@ -737,7 +722,7 @@ Folder* Folder::top()
 }
 
 
-Folder* Folder::folder(const string& name, bool create)
+Folder* Folder::folder(const std::string& name, bool create)
 {
     Folder* f;
 
@@ -763,11 +748,11 @@ Folder* Folder::folder(const string& name, bool create)
     }
 }
 /*  
-Folder* Folder::folder(const string&path,bool create) 
+Folder* Folder::folder(const std::string&path,bool create) 
 {
         if(path.empty()) return 0;
 	
-	if(path.find("/") != string::npos)
+	if(path.find("/") !=std::string::npos)
 	{
 		for(vector<Folder*>::iterator it=Folder::folders_.begin(); it != Folder::folders_.end(); it++)
 		{
@@ -794,20 +779,20 @@ Folder* Folder::folder(const string&path,bool create)
 	return 0;
 }*/
 
-Folder* Folder::folder(const string& name1, const string& name2, bool create)
+Folder* Folder::folder(const std::string& name1, const string& name2, bool create)
 {
     Folder* f = folder(name1, create);
     return f ? folder(f->fullName() + "/" + name2, create) : 0;
 }
 
-Folder* Folder::folder(const string& name1, const string& name2,
-                       const string& name3, bool /*create*/)
+Folder* Folder::folder(const std::string& name1, const string& name2,
+                       const std::string& name3, bool /*create*/)
 {
     Folder* f = folder(name1, name2);
     return f ? folder(f->fullName() + "/" + name3) : 0;
 }
 
-IconObject* Folder::icon(const string& /*fullName*/)
+IconObject* Folder::icon(const std::string& /*fullName*/)
 {
     /*Path p(fullName);
 	Folder *f=Folder::folder(p.directory().str());
