@@ -7,52 +7,47 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef FolderDatabase_H
-#define FolderDatabase_H
+#pragma once
 
 #include <map>
 #include <string>
 #include <vector>
 
-using namespace std;
 
 class FolderDatabase
 {
 public:
-    static string path(const string&);
+    static std::string path(const std::string&);
 
 protected:
     FolderDatabase();
 
     void read();
     void write();
-    string find(const string&);
-    string add(const string&);
-    string uniquePath();
-    virtual bool isOwner(const string&) = 0;
+    std::string find(const std::string&);
+    std::string add(const std::string&);
+    std::string uniquePath();
+    virtual bool isOwner(const std::string&) = 0;
 
-    string homePath_;
-    string rootPath_;
-    string dbPath_;
-    string dbFile_;
-    map<string, string> folders_;
+    std::string homePath_;
+    std::string rootPath_;
+    std::string dbPath_;
+    std::string dbFile_;
+    std::map<std::string, std::string> folders_;
 
-    static vector<FolderDatabase*> db_;
+    static std::vector<FolderDatabase*> db_;
 };
 
 class InternalFolderDatabase : public FolderDatabase
 {
 public:
     InternalFolderDatabase();
-    bool isOwner(const string&);
+    bool isOwner(const std::string&);
 };
 
 class ExternalFolderDatabase : public FolderDatabase
 {
 public:
     ExternalFolderDatabase();
-    bool isOwner(const string&);
+    bool isOwner(const std::string&);
 };
-
-
-#endif
