@@ -14,6 +14,7 @@
 #include <map>
 #include <sstream>
 #include <string>
+#include <unordered_map>
 #include <vector>
 #include "fstream_mars_fix.h"
 
@@ -21,6 +22,7 @@
 #include "IconInfo.h"
 #include "Request.h"
 #include "Tokenizer.h"
+#include "MvLog.h"
 
 std::string FolderInfo::fileName_ = "._mv_iconlist_";
 
@@ -42,9 +44,6 @@ void FolderInfo::read()
         return;
 
     std::string line;
-
-    //getline(in,line);
-
     Tokenizer parse(",");
     std::vector<std::string> n;
     int cnt = 0;
@@ -59,10 +58,13 @@ void FolderInfo::read()
             std::istringstream issY(n[1]);
             issY >> y;
 
+            auto icName = n[2];
+            adjustIcName(icName);
+
             pos              = line.find("," + n[3]);
             std::string name = line.substr(pos + 1);
 
-            info_[name] = new IconInfo(n[2], x, y);
+            info_[name] = new IconInfo(icName, x, y);
         }
 
         n.clear();
@@ -173,9 +175,6 @@ bool FolderInfo::read(const Path& folderPath, std::map<std::string, std::string>
         return false;
 
     std::string line;
-
-    //getline(in,line);
-
     Tokenizer parse(",");
     std::vector<std::string> n;
     std::size_t pos;
@@ -184,7 +183,9 @@ bool FolderInfo::read(const Path& folderPath, std::map<std::string, std::string>
         parse(line, n);
         if (n.size() >= 4) {
             pos                         = line.find("," + n[3]);
-            icons[line.substr(pos + 1)] = n[2];
+            auto icName = n[2];
+            adjustIcName(icName);
+            icons[line.substr(pos + 1)] = icName;
         }
 
         n.clear();
@@ -194,3 +195,42 @@ bool FolderInfo::read(const Path& folderPath, std::map<std::string, std::string>
 
     return true;
 }
+
+// Correct iconclass names for family icons. See: METV-3184.
+void FolderInfo::adjustIcName(std::string& icName)
+{
+    static std::unordered_map<std::string, std::string> cls = {
+            {"LINE_HOVM","MHOVMOELLERDATA_FAMILY"},
+            {"AREA_HOVM","MHOVMOELLERDATA_FAMILY"},
+            {"EXPAND_HOVM","MHOVMOELLERDATA_FAMILY"},
+            {"VERTICAL_HOVM","MHOVMOELLERDATA_FAMILY"},
+            {"POTT_M", "POTT_FAMILY"},
+            {"POTT_P", "POTT_FAMILY"},
+            {"EQPOTT_M", "POTT_FAMILY"},
+            {"EQPOTT_P", "POTT_FAMILY"},
+            {"SEQPOTT_M", "POTT_FAMILY"},
+            {"SEQPOTT_M", "POTT_FAMILY"},
+            {"GRIB_THERMO","THERMODATA_FAMILY"},
+            {"BUFR_THERMO","THERMODATA_FAMILY"},
+            {"ROTWIND","DIVROT_FAMILY"},
+            {"DIVWIND","DIVROT_FAMILY"},
+            {"UVWIND","DIVROT_FAMILY"},
+            {"VELPOT","VELSTR_FAMILY"},
+            {"STREAMFN","VELSTR_FAMILY"},
+            {"SAMPLE_FORMULA_DOD", "SIMPLE_FORMULA_FAMILY"},
+            {"SAMPLE_FORMULA_DON", "SIMPLE_FORMULA_FAMILY"},
+            {"SAMPLE_FORMULA_NOD", "SIMPLE_FORMULA_FAMILY"},
+            {"SAMPLE_FORMULA_NON", "SIMPLE_FORMULA_FAMILY"},
+            {"SAMPLE_FORMULA_FD", "SIMPLE_FORMULA_FAMILY"},
+            {"SAMPLE_FORMULA_FN", "SIMPLE_FORMULA_FAMILY"},
+            {"SAMPLE_FORMULA_FDD", "SIMPLE_FORMULA_FAMILY"},
+            {"SAMPLE_FORMULA_FDN", "SIMPLE_FORMULA_FAMILY"},
+            {"SAMPLE_FORMULA_FND", "SIMPLE_FORMULA_FAMILY"},
+            {"SAMPLE_FORMULA_FNN,", "SIMPLE_FORMULA_FAMILY"}
+        };
+
+    auto it = cls.find(icName);
+    if (it != cls.end()) {
+        icName = it->second;
+    }
+}
