@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef FolderPresenter_H
-#define FolderPresenter_H
+#pragma once
 
 class Folder;
 class QObject;
@@ -20,6 +19,3 @@ public:
     virtual bool isDisplayed()      = 0;
     virtual QObject* realObject()   = 0;
 };
-
-
-#endif
