@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef FolderSearchData_H
-#define FolderSearchData_H
+#pragma once
 
 #include <vector>
 #include <string>
@@ -18,7 +17,7 @@ class IconObject;
 class FolderSearchDataObserver
 {
 public:
-    FolderSearchDataObserver(){};
+    FolderSearchDataObserver()  = default;
     virtual void matchChanged() = 0;
 };
 
@@ -37,7 +36,7 @@ public:
     bool match(IconObject*);
     void load(IconObject*);
     void matchChanged();
-    void setOwner(void* p) { owner_ = p; };
+    void setOwner(void* p) { owner_ = p; }
     void* owner() const { return owner_; }
     void resetCurrent();
     IconObject* first();
@@ -52,5 +51,3 @@ protected:
     std::vector<IconObject*> matchVec_;
     int current_;
 };
-
-#endif
\ No newline at end of file
