@@ -7,15 +7,13 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef FolderSettings_H
-#define FolderSettings_H
+#pragma once
 
 #include <string>
 
 #include "Desktop.h"
 #include "Path.h"
 
-using namespace std;
 
 class Folder;
 
@@ -48,5 +46,3 @@ protected:
     int iconSize_;
     bool halfSizeImported_;
 };
-
-#endif
\ No newline at end of file
