@@ -11,30 +11,27 @@
 #include "Request.h"
 #include "MvIconParameter.h"
 
-static map<string, HelpFactory*>* makers = 0;
+static std::map<std::string, HelpFactory*>* makers = 0;
 
-HelpFactory::HelpFactory(const string& name)
+HelpFactory::HelpFactory(const std::string& name)
 {
     if (makers == 0)
-        makers = new map<string, HelpFactory*>;
+        makers = new std::map<std::string, HelpFactory*>;
 
     (*makers)[name] = this;
 }
 
-HelpFactory::~HelpFactory()
-{
-    // Not called
-}
+HelpFactory::~HelpFactory() = default;
 
 MvQRequestPanelHelp* HelpFactory::create(RequestPanel& owner, const MvIconParameter& param)
 {
     const char* help = param.help();
 
     if (help) {
-        map<string, HelpFactory*>::iterator j = makers->find(help);
+        auto j = makers->find(help);
         if (j != makers->end())
-            return (*j).second->make(owner, param);
+            return j->second->make(owner, param);
     }
 
-    return 0;
+    return nullptr;
 }
