@@ -7,11 +7,9 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef HelpFactory_H
-#define HelpFactory_H
+#pragma once
 
 #include <string>
-using std::string;
 
 #include "mars.h"
 
@@ -22,7 +20,7 @@ class MvIconParameter;
 class HelpFactory
 {
 public:
-    HelpFactory(const string& name);
+    HelpFactory(const std::string& name);
     virtual ~HelpFactory();
 
     virtual MvQRequestPanelHelp* make(RequestPanel& owner, const MvIconParameter& def) = 0;
@@ -41,9 +39,6 @@ class HelpMaker : public HelpFactory
     MvQRequestPanelHelp* make(RequestPanel& owner, const MvIconParameter& def) { return new T(owner, def); }
 
 public:
-    HelpMaker(const string& name) :
+    HelpMaker(const std::string& name) :
         HelpFactory(name) {}
 };
-
-
-#endif
