@@ -9,6 +9,16 @@
 
 #include "IconClass.h"
 
+#include <algorithm>
+#include <fstream>
+#include <iostream>
+#include <map>
+#include <set>
+#include <sstream>
+#include <string>
+#include <vector>
+#include "fstream_mars_fix.h"
+
 #include "ConfigLoader.h"
 #include "Service.h"
 #include "IconInfo.h"
@@ -20,16 +30,14 @@
 #include "MvRequestUtil.hpp"
 #include "MvScanFileType.h"
 
-#include <algorithm>
-
-static map<string, const IconClass*> classes;
+static std::map<std::string, const IconClass*> classes;
 
 // All icon classed subclass from this one
 static IconClass super("*", 0);
 
-static set<string> allActions;
+static std::set<std::string> allActions;
 
-IconClass::IconClass(const string& name, request* r, const IconClass* sup) :
+IconClass::IconClass(const std::string& name, request* r, const IconClass* sup) :
     MvIconClassCore(name, r),
     super_(sup)
 {
@@ -45,50 +53,49 @@ IconClass::~IconClass()
 
 void IconClass::scan(ClassScanner& s)
 {
-    map<string, const IconClass*>::iterator j;
+    std::map<std::string, const IconClass*>::iterator j;
     for (j = classes.begin(); j != classes.end(); ++j)
         s.next(*(*j).second);
 }
 
 #if 0
-const string& IconClass::name() const
+const std::string& IconClass::name() const
 {
     return name_;
 }
 
 #endif
 
-bool IconClass::isValid(const string& name)
+bool IconClass::isValid(const std::string& name)
 {
-    map<string, const IconClass*>::iterator j = classes.find(name);
-    return (j != classes.end());
+    return (classes.find(name) != classes.end());
 }
 
-const IconClass& IconClass::find(const string& name)
+const IconClass& IconClass::find(const std::string& name)
 {
-    map<string, const IconClass*>::iterator j = classes.find(name);
+    auto j = classes.find(name);
     if (j != classes.end())
         return *(*j).second;
 
     return *(new IconClass(name, empty_request(0)));
 }
 
-const IconClass& IconClass::find(const string& name, const string& defaultType, bool caseSensitive)
+const IconClass& IconClass::find(const std::string& name, const std::string& defaultType, bool caseSensitive)
 {
     if (caseSensitive) {
-        map<string, const IconClass*>::iterator j = classes.find(name);
+        auto j = classes.find(name);
         if (j != classes.end())
             return *(*j).second;
     }
     else {
-        for (map<string, const IconClass*>::iterator it = classes.begin(); it != classes.end(); it++) {
+        for (auto& classe : classes) {
             //We convert the class name to uppercase for comparison
-            std::string str = it->first;
+            std::string str = classe.first;
             std::transform(str.begin(), str.end(), str.begin(), ::toupper);
             std::string ucName = name;
             std::transform(ucName.begin(), ucName.end(), ucName.begin(), ::toupper);
             if (str == ucName) {
-                return *(*it).second;
+                return *classe.second;
             }
         }
     }
@@ -96,23 +103,23 @@ const IconClass& IconClass::find(const string& name, const string& defaultType,
     return find(defaultType);
 }
 
-void IconClass::find(const string& str, vector<const IconClass*>& res, bool onlyCreatable)
+void IconClass::find(const std::string& str, std::vector<const IconClass*>& res, bool onlyCreatable)
 {
-    for (map<string, const IconClass*>::iterator it = classes.begin(); it != classes.end(); it++) {
-        const IconClass* kind = it->second;
+    for (auto& classe : classes) {
+        const auto* kind = classe.second;
 
         if (onlyCreatable && kind->canBeCreated() == false)
             continue;
 
-        string s;
+        std::string s;
 
-        string strTerm = str;
+        std::string strTerm = str;
         std::transform(strTerm.begin(), strTerm.end(), strTerm.begin(), ::tolower);
 
         //Default name
         s = kind->defaultName();
         std::transform(s.begin(), s.end(), s.begin(), ::tolower);
-        if (s.find(strTerm) != string::npos) {
+        if (s.find(strTerm) != std::string::npos) {
             res.push_back(kind);
             continue;
         }
@@ -120,7 +127,7 @@ void IconClass::find(const string& str, vector<const IconClass*>& res, bool only
         //Name
         s = kind->name();
         std::transform(s.begin(), s.end(), s.begin(), ::tolower);
-        if (s.find(strTerm) != string::npos) {
+        if (s.find(strTerm) != std::string::npos) {
             res.push_back(kind);
             continue;
         }
@@ -128,7 +135,7 @@ void IconClass::find(const string& str, vector<const IconClass*>& res, bool only
         //Type
         s = kind->type();
         std::transform(s.begin(), s.end(), s.begin(), ::tolower);
-        if (s.find(strTerm) != string::npos) {
+        if (s.find(strTerm) != std::string::npos) {
             res.push_back(kind);
             continue;
         }
@@ -136,7 +143,7 @@ void IconClass::find(const string& str, vector<const IconClass*>& res, bool only
         //icon box
         s = kind->iconBox();
         std::transform(s.begin(), s.end(), s.begin(), ::tolower);
-        if (s.find(strTerm) != string::npos) {
+        if (s.find(strTerm) != std::string::npos) {
             res.push_back(kind);
             continue;
         }
@@ -166,10 +173,9 @@ bool IconClass::canBecome(const IconClass& other) const
     if (isSubClassOf(other))
         return true;
 
-    for (set<const IconClass*>::const_iterator k = outputs_.begin();
-         k != outputs_.end(); ++k) {
+    for (auto output : outputs_) {
         if (
-            (*k)->canBecome(other))
+            output->canBecome(other))
             return true;
     }
     return false;
@@ -179,7 +185,7 @@ bool IconClass::canBecome(const IconClass& other) const
 //called for the first time all the initailisation has been done! We also suppose that there is
 //at least one action defined for any of the classes so after the first call of can() can_cannot be
 //empty!
-set<string> IconClass::can() const
+std::set<std::string> IconClass::can() const
 {
     if (can_.empty())
         can_ = generateCan();
@@ -188,9 +194,9 @@ set<string> IconClass::can() const
 }
 
 //Generate a list of the supported actions (can_)
-set<string> IconClass::generateCan() const
+std::set<std::string> IconClass::generateCan() const
 {
-    set<string> c;
+    std::set<std::string> c;
 
     //First check if all the actions are allowed for the class
     static Action all("*", "*");
@@ -199,7 +205,7 @@ set<string> IconClass::generateCan() const
 
         //Now we need to remove some actions if they are not defined explicitly for this
         //class or its output classes in ObjectList
-        static std::set<string> nonAllActions;
+        static std::set<std::string> nonAllActions;
         if (nonAllActions.empty()) {
             nonAllActions.insert("extract");
             nonAllActions.insert("analyse");
@@ -211,22 +217,21 @@ set<string> IconClass::generateCan() const
         }
 
         //Loop for the actions to be checked
-        for (set<string>::const_iterator it = nonAllActions.begin(); it != nonAllActions.end(); it++) {
+        for (const auto& nonAllAction : nonAllActions) {
             bool need = false;
 
             //Flag the action if it is not present in the services!
-            Action nonAllAc(*it, "*");
-            map<Action, Service*>::const_iterator itS = services_.find(nonAllAc);
+            Action nonAllAc(nonAllAction, "*");
+            auto itS = services_.find(nonAllAc);
             if (itS != services_.end()) {
                 continue;
             }
 
             //Flag the action if it is not present in the otput classes
-            for (set<const IconClass*>::const_iterator k = outputs_.begin();
-                 k != outputs_.end(); ++k) {
-                // cout << name_ << " can, adding " << (*k)->name_ << endl;
-                set<string> oc                    = (*k)->can();
-                set<string>::const_iterator itIcs = oc.find(*it);
+            for (auto output : outputs_) {
+                // std::cout << name_ << " can, adding " << (*k)->name_ << std::endl;
+                auto oc    = output->can();
+                auto itIcs = oc.find(nonAllAction);
                 if (itIcs != oc.end()) {
                     need = true;
                     break;
@@ -235,7 +240,7 @@ set<string> IconClass::generateCan() const
 
             //If the action is flagged we remove it
             if (!need)
-                c.erase(*it);
+                c.erase(nonAllAction);
         }
     }
 
@@ -245,16 +250,14 @@ set<string> IconClass::generateCan() const
             c = super_->can();
         }
 
-        for (map<Action, Service*>::const_iterator j = services_.begin();
-             j != services_.end(); ++j) {
-            c.insert((*j).first.name());
+        for (const auto& service : services_) {
+            c.insert(service.first.name());
         }
 
 
-        for (set<const IconClass*>::const_iterator k = outputs_.begin();
-             k != outputs_.end(); ++k) {
-            // cout << name_ << " can, adding " << (*k)->name_ << endl;
-            set<string> oc = (*k)->can();
+        for (auto output : outputs_) {
+            // std::cout << name_ << " can, adding " << (*k)->name_ << std::endl;
+            auto oc = output->can();
             c.insert(oc.begin(), oc.end());
         }
     }
@@ -270,7 +273,7 @@ set<string> IconClass::generateCan() const
 
 void IconClass::service(const Action& action, const IconClass* output, Service* s) const
 {
-    IconClass* self = const_cast<IconClass*>(this);
+    auto* self = const_cast<IconClass*>(this);
     if (output)
         self->outputs_.insert(output);
 
@@ -280,17 +283,17 @@ void IconClass::service(const Action& action, const IconClass* output, Service*
     allActions.insert(action.name());
 
     //cout << name_ << " can " << action << " ";
-    //if(output) cout << " output " << output->name_;
-    //cout << " with " << *s << endl;
+    //if(output) std::cout << " output " << output->name_;
+    //cout << " with " << *s << std::endl;
 
     self->services_[action] = s;
 }
 
 Service* IconClass::service(const Action& action) const
 {
-    //cout << "IconClass::service class " << name_ << endl;
-    //cout << "IconClass::service for " << action << endl;
-    map<Action, Service*>::const_iterator j = services_.find(action);
+    //cout << "IconClass::service class " << name_ << std::endl;
+    //cout << "IconClass::service for " << action << std::endl;
+    auto j = services_.find(action);
     if (j == services_.end()) {
         Service* s = super_ ? super_->service(action) : 0;
         if (s == 0 && !(action.name() == "*"))
@@ -298,33 +301,33 @@ Service* IconClass::service(const Action& action) const
         else
             return s;
     }
-    cout << *((*j).second) << endl;
-    return (*j).second;
+    std::cout << *(j->second) << std::endl;
+    return j->second;
 }
 
 static SimpleLoader<IconClass> loadClasses("object", 0);
 
 //==================================================================
 
-const string missing("///");
+const std::string missing("///");
 
-static bool is_request(const char* file, string& s)
+static bool is_request(const char* file, std::string& s)
 {
     if (!file)
         return false;
 
-    ifstream in(file);
+    std::ifstream in(file);
 
     int maxLines = 5;
     int actLine  = 0;
-    string typeStr;
+    std::string typeStr;
 
     if (in.good()) {
-        string line;
+        std::string line;
         while (getline(in, line) && actLine < maxLines) {
-            vector<string> vec;
-            stringstream sst(line);
-            string s;
+            std::vector<std::string> vec;
+            std::stringstream sst(line);
+            std::string s;
             while (sst >> s) {
                 vec.push_back(s);
             }
@@ -335,7 +338,7 @@ static bool is_request(const char* file, string& s)
                     typeStr = typeStr.substr(0, typeStr.size() - 1);
                 }
 
-                //We convert the string to uppercase for comparison
+                //We convert the std::string to uppercase for comparison
                 std::transform(typeStr.begin(), typeStr.end(), typeStr.begin(), ::toupper);
                 break;
             }
@@ -348,12 +351,12 @@ static bool is_request(const char* file, string& s)
     in.close();
 
     if (!typeStr.empty()) {
-        for (map<string, const IconClass*>::iterator it = classes.begin(); it != classes.end(); it++) {
+        for (auto& classe : classes) {
             //We convert the class name to uppercase for comparison
-            std::string str = it->first;
+            std::string str = classe.first;
             std::transform(str.begin(), str.end(), str.begin(), ::toupper);
             if (str == typeStr) {
-                s = it->first;
+                s = classe.first;
                 return true;
             }
         }
@@ -361,7 +364,7 @@ static bool is_request(const char* file, string& s)
     return false;
 }
 
-static string guess_file(const char* file)
+static std::string guess_file(const char* file)
 {
     struct stat buf;
 
@@ -375,11 +378,11 @@ static string guess_file(const char* file)
         case S_IFREG:
             //return scan_file(file);
             {
-                string ft = ScanFileType(file);
+                std::string ft = ScanFileType(file);
                 if (ft != "NOTE")
                     return ft;
 
-                string ft2;
+                std::string ft2;
                 if (is_request(file, ft2))
                     return ft2;
                 else
@@ -396,9 +399,9 @@ const IconClass& IconClass::guess(const Path& file)
     return guess(file.str());
 }
 
-const IconClass& IconClass::guess(const string& file)
+const IconClass& IconClass::guess(const std::string& file)
 {
-    string kind = guess_file(file.c_str());
+    std::string kind = guess_file(file.c_str());
     return find(kind);
 }
 
@@ -417,17 +420,17 @@ void IconClass::guess(const std::string& fullName, std::string& icName, std::str
 
         //We need to parse the dot file by ourselves because requests cannot be used here (they are not thread safe).
         if (dot.exists()) {
-            ifstream in(dot.str().c_str());
-            string str;
+            std::ifstream in(dot.str().c_str());
+            std::string str;
             while (getline(in, str)) {
-                if (str.find("ICON_CLASS") != string::npos) {
+                if (str.find("ICON_CLASS") != std::string::npos) {
                     std::size_t pos = str.find("=");
-                    if (pos != string::npos && pos < str.size() - 1) {
+                    if (pos != std::string::npos && pos < str.size() - 1) {
                         str = str.substr(pos + 1, str.size());
-                        string type;
-                        for (unsigned int i = 0; i < str.size(); i++) {
-                            if (str[i] != ' ' && str[i] != ',' && str[i] != '\n')
-                                type += str[i];
+                        std::string type;
+                        for (char i : str) {
+                            if (i != ' ' && i != ',' && i != '\n')
+                                type += i;
                         }
 
                         const IconClass& ic = IconClass::find(type, "NOTE", false);
@@ -476,8 +479,8 @@ IconObject* IconClass::createOneFromRequest(Folder* f, int x, int y) const
 
 IconObject* IconClass::defaultObject() const
 {
-    Folder* f   = Folder::folder("defaults");
-    string name = defaultName();
+    Folder* f        = Folder::folder("defaults");
+    std::string name = defaultName();
 
     IconObject* obj = f->find(name);
     if (obj)
@@ -494,34 +497,34 @@ IconObject* IconClass::defaultObject() const
 string IconClass::defaultName() const
 {
     const char* def = get_value(request_, "default_name", 0);
-    return def ? string(def) : name_;
+    return def ? std::string(def) : name_;
 }
 
 string IconClass::iconBox() const
 {
     const char* def = get_value(request_, "icon_box", 0);
-    return def ? string(def) : string();
+    return def ? std::string(def) : std::string();
 }
 
 string IconClass::helpPage() const
 {
     const char* def = get_value(request_, "help_page", 0);
-    return def ? string(def) : name_;
+    return def ? std::string(def) : name_;
 }
 
 string IconClass::doubleClickMethod() const
 {
     const char* def = get_value(request_, "doubleclick_method", 0);
-    return def ? string(def) : string();
+    return def ? std::string(def) : std::string();
 }
 
 string IconClass::defaultMethod() const
 {
     const char* def = get_value(request_, "default_method", 0);
-    return def ? string(def) : "edit";
+    return def ? std::string(def) : "edit";
 }
 
-bool IconClass::skipDepandancies(const string& action) const
+bool IconClass::skipDepandancies(const std::string& action) const
 {
     const char* def = get_value(request_, "skip_dependancies", 0);
     return def ? (strcmp(def, action.c_str()) == 0) : false;
@@ -532,24 +535,24 @@ Path IconClass::pixmap() const
     const char* def = get_value(request_, "pixmap", 0);
     if (def) {
         Path p(def);
-        string fname          = p.name();
-        string::size_type pos = fname.rfind(".icon");
-        if (pos != string::npos) {
+        std::string fname          = p.name();
+        std::string::size_type pos = fname.rfind(".icon");
+        if (pos != std::string::npos) {
             fname = fname.substr(0, pos);
         }
 
-        string s       = getenv("METVIEW_DIR_SHARE");
-        string svgName = s + "/icons_mv5/" + fname + ".svg";
+        std::string s       = getenv("METVIEW_DIR_SHARE");
+        std::string svgName = s + "/icons_mv5/" + fname + ".svg";
 
         Path psvg(s + "/icons_mv5/" + fname + ".svg");
         if (psvg.exists()) {
-            //cout << "svg " << psvg.str() << endl;
+            //cout << "svg " << psvg.str() << std::endl;
             return psvg;
         }
         else {
             Path pxpm(s + "/icons_mv5/" + fname + ".xpm");
             if (pxpm.exists()) {
-                //cout << "svg " << psvg.str() << endl;
+                //cout << "svg " << psvg.str() << std::endl;
                 return pxpm;
             }
         }
@@ -583,7 +586,7 @@ bool IconClass::canHaveLog() const
 string IconClass::type() const
 {
     const char* def = get_value(request_, "type", 0);
-    return def ? string(def) : name_;
+    return def ? std::string(def) : name_;
 }
 
 Path IconClass::definitionFile() const
@@ -628,7 +631,7 @@ int IconClass::priority() const
 {
     // Very, very UGLY if....
 
-    string t = type();
+    std::string t = type();
 
     if (t == "Visdef")
         return 1;
