@@ -181,7 +181,7 @@ QString IconDescription::info(IconObject* obj)
 
         //icon class
         auto subCol = MvQTheme::subText();
-        txt += " " + MvQ::formatText(QString::fromStdString(obj->editorClass().name()), subCol);
+        txt += " " + MvQ::formatText(QString::fromStdString(obj->iconClass().name()), subCol);
 
         //file size
         if (!obj->isFolder()) {
