@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef IconDescription_H
-#define IconDescription_H
+#pragma once
 
 #include <QString>
 #include <QPixmap>
@@ -33,7 +32,7 @@ public:
     virtual void start();
     virtual void reply(const Request&, int);
     virtual void progress(const Request&) {}
-    virtual void message(const string&) {}
+    virtual void message(const std::string&) {}
 
 private:
     // No copy allowed
@@ -49,8 +48,8 @@ class IconDescriptionCacheItem
 {
 public:
     friend class IconDescriptionCache;
-    QPixmap pix() const {return pix_;}
-    QString text() const {return text_;}
+    QPixmap pix() const { return pix_; }
+    QString text() const { return text_; }
 
 protected:
     std::string path_;
@@ -94,7 +93,5 @@ protected:
     QStringList serviceClasses_;
 
     IconDescriptionMakerObserver* replyObserver_{nullptr};
-    IconDescriptionCache  contentsCache_;
+    IconDescriptionCache contentsCache_;
 };
-
-#endif
