@@ -11,38 +11,36 @@
 #include "ConfigLoader.h"
 #include "Request.h"
 
-static vector<IconGroupTools*> tools;
+static std::vector<IconGroupTools*> tools;
 
 IconGroupTools::IconGroupTools(request* r) :
     request_(r)
 {
 }
 
-IconGroupTools::~IconGroupTools()
+IconGroupTools::~IconGroupTools() = default;
+
+std::string IconGroupTools::name()
 {
+    return std::string(get_value(request_, "name", 0));
 }
 
-string IconGroupTools::name()
+bool IconGroupTools::can(const std::string& name)
 {
-    return string(get_value(request_, "name", 0));
-}
-
-bool IconGroupTools::can(const string& name)
-{
-    for (vector<IconGroupTools*>::iterator it = tools.begin(); it != tools.end(); it++)
-        if ((*it)->name() == name)
+    for (auto& tool : tools)
+        if (tool->name() == name)
             return true;
     return false;
 }
 
-void IconGroupTools::run(const string& name, const vector<IconObject*>& items)
+void IconGroupTools::run(const std::string& name, const std::vector<IconObject*>& items)
 {
-    for (vector<IconGroupTools*>::iterator it = tools.begin(); it != tools.end(); it++)
-        if ((*it)->name() == name)
-            (*it)->run(items);
+    for (auto& tool : tools)
+        if (tool->name() == name)
+            tool->run(items);
 }
 
-void IconGroupTools::run(const vector<IconObject*>& items)
+void IconGroupTools::run(const std::vector<IconObject*>& items)
 {
     MvRequest r(get_value(request_, "action", 0));
 
@@ -50,14 +48,14 @@ void IconGroupTools::run(const vector<IconObject*>& items)
         r.setValue("PARAM", par);
     }
 
-    for (vector<IconObject*>::const_iterator it = items.begin(); it != items.end(); it++) {
-        r.addValue("ITEMS", (*it)->fullName().c_str());
+    for (auto item : items) {
+        r.addValue("ITEMS", item->fullName().c_str());
     }
 
     // indicate that the ui manager should wait for the ui app to finish!!
     r("_WAIT_APP") = "1";
 
-    MvApplication::callService(get_value(request_, "service", 0), r, 0);
+    MvApplication::callService(get_value(request_, "service", 0), r, nullptr);
 }
 
 
