@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef IconGroupTools_H
-#define IconGroupTools_H
+#pragma once
 
 #include "Metview.h"
 #include "IconObject.h"
@@ -19,20 +18,18 @@ public:
     IconGroupTools(request*);
     ~IconGroupTools();
 
-    string name();
+    std::string name();
     static void load(request*);
-    static void run(const string&, const vector<IconObject*>& items);
-    static bool can(const string&);
+    static void run(const std::string&, const std::vector<IconObject*>& items);
+    static bool can(const std::string&);
 
 private:
     // No copy allowed
     IconGroupTools(const IconGroupTools&);
     IconGroupTools& operator=(const IconGroupTools&);
-    void run(const vector<IconObject*>& items);
+    void run(const std::vector<IconObject*>& items);
 
     request* request_;
 };
 
 inline void destroy(IconGroupTools**) {}
-
-#endif
