@@ -36,6 +36,7 @@
 #include <assert.h>
 
 #include "Metview.h"
+#include "MvLog.h"
 
 #include <sys/stat.h>
 
@@ -105,11 +106,10 @@ Folder* IconObject::parent() const
 
 IconInfo& IconObject::info() const
 {
-    if (info_ == 0) {
+    if (info_ == nullptr) {
         Request info("USER_INTERFACE");
-        info("ICON_CLASS") = className().c_str();
-
-        auto* o  = const_cast<IconObject*>(this);
+        info("ICON_CLASS") = editorClassName().c_str();
+        auto* o  = const_cast<IconObject*>(this);    
         o->info_ = new IconInfo(info);
         o->saveInfo();
     }
@@ -177,6 +177,11 @@ const IconClass& IconObject::iconClass() const
     return *class_;
 }
 
+const std::string& IconObject::editorClassName() const
+{
+    return editorClass().name();
+}
+
 const IconClass& IconObject::editorClass() const
 {
     return iconClass();
