@@ -73,7 +73,8 @@ public:
     virtual ~IconObject();
 
     virtual const std::string& name() const;
-    virtual const std::string& className() const;
+    const std::string& className() const;
+    const std::string& editorClassName() const;
 
     virtual std::string dotName(const std::string&) const;
     virtual std::string embeddedName(const std::string&) const;
