@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef IconObserver_H
-#define IconObserver_H
+#pragma once
 
 class IconObject;
 
@@ -20,6 +19,3 @@ public:
     virtual void iconEdited(IconObject*) {}
     virtual void iconClosed(IconObject*) {}
 };
-
-
-#endif
\ No newline at end of file
