@@ -13,8 +13,8 @@
 
 
 Input::Input() :
-    file_(0),
-    notifier_(0)
+    file_(nullptr),
+    notifier_(nullptr)
 {
 }
 
@@ -28,15 +28,15 @@ void Input::stop()
     if (file_) {
         if (notifier_) {
             delete notifier_;
-            notifier_ = 0;
+            notifier_ = nullptr;
         }
-        file_ = 0;
+        file_ = nullptr;
     }
 }
 
 void Input::start(FILE* f)
 {
-    if (file_ == 0 && f != 0) {
+    if (file_ == nullptr && f != nullptr) {
         file_ = f;
 
         int n = fileno(f);
