@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Input_H
-#define Input_H
+#pragma once
 
 #include <QObject>
 
@@ -41,5 +40,3 @@ private:
     FILE* file_;
     QSocketNotifier* notifier_;
 };
-
-#endif
