@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef InternalService_H
-#define InternalService_H
+#pragma once
 
 #include "Service.h"
 
@@ -27,5 +26,3 @@ private:
 };
 
 inline void destroy(InternalService**) {}
-
-#endif
