@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef InternalTask_H
-#define InternalTask_H
+#pragma once
 
 #include "Task.h"
 #include "Action.h"
@@ -23,10 +22,10 @@ public:
     InternalTask(const Action&, IconObject*);
     virtual ~InternalTask();
 
-    virtual void addContext(const Request&){};
+    virtual void addContext(const Request&) {}
 
 protected:
-    void print(ostream&) const;
+    void print(std::ostream&) const;
 
 private:
     // No copy allowed
@@ -43,10 +42,8 @@ private:
     bool error_;
     int waiting_;
 
-    typedef map<TaskH, DependancyH> Map;
+    typedef std::map<TaskH, DependancyH> Map;
     Map tasks_;
 };
 
 inline void destroy(InternalTask**) {}
-
-#endif
