@@ -7,11 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Items_H
-#define Items_H
+#pragma once
 
 #include <string>
-using std::string;
+#include <vector>
 
 #include "Metview.h"
 
@@ -25,8 +24,8 @@ public:
 
     static void load(request*);
     static void createAll();
-    static IconObject* find(const string&);
-    static void objects(vector<IconObject*>&);
+    static IconObject* find(const std::string&);
+    static void objects(std::vector<IconObject*>&);
 
 private:
     Items(const Items&);
@@ -44,5 +43,3 @@ inline void destroy(Items**) {}
 //#ifdef _ODI_OSSG_
 //OS_MARK_SCHEMA_TYPE(Items);
 //#endif
-
-#endif
