@@ -15,27 +15,24 @@
 
 #include "MvQTextLine.h"
 
-static map<string, LineFactory*>* makers = 0;
+static std::map<std::string, LineFactory*>* makers = 0;
 
-LineFactory::LineFactory(const string& name)
+LineFactory::LineFactory(const std::string& name)
 {
     if (makers == 0)
-        makers = new map<string, LineFactory*>;
+        makers = new std::map<std::string, LineFactory*>;
 
     // Put in reverse order...
     (*makers)[name] = this;
 }
 
-LineFactory::~LineFactory()
-{
-    // Not called
-}
+LineFactory::~LineFactory() = default;
 
 MvQRequestPanelLine* LineFactory::create(RequestPanel& e, const MvIconParameter& p)
 {
     const char* o = p.interface();
     if (o != 0) {
-        map<string, LineFactory*>::iterator j = makers->find(o);
+        auto j = makers->find(o);
         if (j != makers->end())
             return (*j).second->make(e, p);
     }
