@@ -7,11 +7,9 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef LineFactory_H
-#define LineFactory_H
+#pragma once
 
 #include <string>
-using std::string;
 
 #include "mars.h"
 
@@ -23,7 +21,7 @@ class MvIconParameter;
 class LineFactory
 {
 public:
-    LineFactory(const string&);
+    LineFactory(const std::string&);
     virtual ~LineFactory();
 
     virtual MvQRequestPanelLine* make(RequestPanel&, const MvIconParameter&) = 0;
@@ -40,9 +38,6 @@ class LineMaker : public LineFactory
     MvQRequestPanelLine* make(RequestPanel& e, const MvIconParameter& p) { return new T(e, p); }
 
 public:
-    LineMaker(const string& name) :
+    LineMaker(const std::string& name) :
         LineFactory(name) {}
 };
-
-
-#endif
