@@ -7,11 +7,11 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Log_H
-#define Log_H
+#pragma once
 
-#include "inc_iostream.h"
-#include "inc_stl.h"
+#include <memory>
+#include <ostream>
+#include <string>
 
 #include "Path.h"
 
@@ -23,17 +23,17 @@ public:
     Log(IconObject*);
     ~Log();
 
-    operator ostream&();
+    operator std::ostream&();
     const Path& path();
 
-    static ostream& info(IconObject*);
-    static ostream& warning(IconObject*);
-    static ostream& error(IconObject*);
-    static ostream& syserr(ostream&);
+    static std::ostream& info(IconObject*);
+    static std::ostream& warning(IconObject*);
+    static std::ostream& error(IconObject*);
+    static std::ostream& syserr(std::ostream&);
 
-    static ostream& info(const string&);
-    static ostream& warning(const string&);
-    static ostream& error(const string&);
+    static std::ostream& info(const std::string&);
+    static std::ostream& warning(const std::string&);
+    static std::ostream& error(const std::string&);
 
 private:
     // No copy allowed
@@ -41,12 +41,12 @@ private:
     Log& operator=(const Log&);
 
     Path path_;
-    std::unique_ptr<ostream> out_;
-    std::unique_ptr<ostream> tee_;
+    std::unique_ptr<std::ostream> out_;
+    std::unique_ptr<std::ostream> tee_;
     IconObject* object_;
 
-    static ostream& global();
-    static ostream& find(IconObject*);
+    static std::ostream& global();
+    static std::ostream& find(IconObject*);
 };
 
 inline void destroy(Log**) {}
@@ -55,5 +55,3 @@ inline void destroy(Log**) {}
 //#ifdef _ODI_OSSG_
 //OS_MARK_SCHEMA_TYPE(Log);
 //#endif
-
-#endif
