@@ -9,7 +9,7 @@
 
 #include "MacroGuiObject.h"
 
-static string next_name()
+static std::string next_name()
 {
     static int i = 0;
     char buf[80];
@@ -25,17 +25,15 @@ MacroGuiObject::MacroGuiObject(const Request& lang, const IconClass* super) :
 {
 }
 
-MacroGuiObject::~MacroGuiObject()
-{
-}
+MacroGuiObject::~MacroGuiObject() = default;
 
 MvIconLanguage& MacroGuiObject::language() const
 {
-    MacroGuiObject* c = const_cast<MacroGuiObject*>(this);
+    auto* c = const_cast<MacroGuiObject*>(this);
     return c->lang_;
 }
 
-string MacroGuiObject::editor() const
+std::string MacroGuiObject::editor() const
 {
     return "TemporaryEditor";
 }
