@@ -7,27 +7,23 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MacroObject_H
-#define MacroObject_H
+#pragma once
 
 #include "FileObject.h"
 
 #include <string>
-using std::string;
 
 class MacroObject : public FileObject
 {
 public:
     MacroObject(Folder* parent,
-                const IconClass& kind, const string& name,
+                const IconClass& kind, const std::string& name,
                 IconInfo* info);
 
     virtual ~MacroObject();
 
 private:
-    virtual void createFiles();
+    void createFiles() override;
 };
 
 inline void destroy(MacroObject**) {}
-
-#endif
