@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MacroParamEditor_H
-#define MacroParamEditor_H
+#pragma once
 
 #include "MvQEditor.h"
 
@@ -33,7 +32,7 @@ class MvQMacroParamDropWidget : public QWidget
     Q_OBJECT
 
 public:
-    MvQMacroParamDropWidget(MacroParamEditor*, const vector<string>&, QWidget* parent = 0);
+    MvQMacroParamDropWidget(MacroParamEditor*, const std::vector<std::string>&, QWidget* parent = 0);
     void reset(IconObjectH);
 
 public slots:
@@ -50,7 +49,7 @@ class MacroParamEditor : public MvQEditor
     Q_OBJECT
 
 public:
-    MacroParamEditor(const IconClass&, const string&);
+    MacroParamEditor(const IconClass&, const std::string&);
     virtual ~MacroParamEditor();
 
     void editMacro(IconObjectH);
@@ -82,7 +81,7 @@ private:
     virtual void replace(IconObjectH);
     virtual void merge(IconObjectH);
 
-    virtual IconObject* copy(const string&);
+    virtual IconObject* copy(const std::string&);
 
     //Iconobserver methods
     virtual void iconEdited(IconObject*);
@@ -95,9 +94,7 @@ private:
     RequestPanel* paramPanel_;
     MacroParamStateH state_;
     IconObjectH macro_;
-    vector<string> classes_;
+    std::vector<std::string> classes_;
 };
 
 inline void destroy(MacroParamEditor**) {}
-
-#endif
