@@ -7,13 +7,11 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MacroParamObject_H
-#define MacroParamObject_H
+#pragma once
 
 #include "StandardObject.h"
 
 #include <string>
-using std::string;
 
 #include "MacroParamState.h"
 
@@ -21,7 +19,7 @@ class MacroParamObject : public StandardObject
 {
 public:
     MacroParamObject(Folder* parent,
-                     const IconClass& kind, const string& name,
+                     const IconClass& kind, const std::string& name,
                      IconInfo* info);
     virtual ~MacroParamObject();
 
@@ -33,15 +31,12 @@ private:
     MacroParamObject(const MacroParamObject&);
     MacroParamObject& operator=(const MacroParamObject&);
 
-    MvIconLanguage& language() const;
-    Request fullRequest() const;
-    void request(const Request&);
-    Request request() const;
-
+    MvIconLanguage& language() const override;
+    Request fullRequest() const override;
+    void setRequest(const Request&) override;
+    Request request() const override;
 
     MacroParamStateH state_;
 };
 
 inline void destroy(MacroParamObject**) {}
-
-#endif
