@@ -40,7 +40,7 @@ Request MacroParamState::request() const
 void MacroParamState::request(const Request& r)
 {
     request_ = r;
-    temp_    = 0;
+    temp_    = nullptr;
 }
 
 IconObject* MacroParamState::iconObject()
@@ -56,7 +56,7 @@ void MacroParamState::macro(IconObject* macro)
     if (macro_ != macro)
         macro_ = macro;
 
-    temp_ = 0;
+    temp_ = nullptr;
     if (class_) {
         delete class_;
         class_ = nullptr;
@@ -87,7 +87,7 @@ Request MacroParamState::interface() const
 Request MacroParamState::requests() const
 {
     if (!macro_) {
-        //Log::error(owner_) << "Missing macro icon" << endl;
+        //Log::error(owner_) << "Missing macro icon" << std::endl;
         return Request("");
     }
 
