@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MessageObserver_H
-#define MessageObserver_H
+#pragma once
 
 #include "Counted.h"
 
@@ -39,5 +38,3 @@ public:
     MessageObserverH(MessageObserver* o) :
         Handle<MessageObserver>(o) {}
 };
-
-#endif
