@@ -10,16 +10,13 @@
 #include "MethodCommand.h"
 #include "IconObject.h"
 
-MethodCommand::MethodCommand(const string& name, Proc proc) :
+MethodCommand::MethodCommand(const std::string& name, Proc proc) :
     Command(name),
     proc_(proc)
 {
 }
 
-MethodCommand::~MethodCommand()
-{
-    // Not called
-}
+MethodCommand::~MethodCommand() = default;
 
 void MethodCommand::execute(IconObject* o)
 {
@@ -34,4 +31,4 @@ static MethodCommand deleteCmd("delete", &IconObject::toWastebasket);
 static MethodCommand infoCmd("log", &IconObject::showLog);
 static MethodCommand emptyCmd("empty", &IconObject::empty);
 static MethodCommand destroyCmd("destroy", &IconObject::destroy);
-static MethodCommand clearCmd("clear", &IconObject::modified);
\ No newline at end of file
+static MethodCommand clearCmd("clear", &IconObject::modified);
