@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MetviewService_H
-#define MetviewService_H
+#pragma once
 
 #include "Service.h"
 
@@ -18,7 +17,7 @@ class IconObject;
 class MetviewService : public Service
 {
 public:
-    MetviewService(const string&);
+    MetviewService(const std::string&);
     virtual ~MetviewService();
 
 private:
@@ -30,5 +29,3 @@ private:
 };
 
 inline void destroy(MetviewService**) {}
-
-#endif
