@@ -15,7 +15,7 @@
 
 int main(int argc, char** argv)
 {
-    MvQDesktop* app = new MvQDesktop(argc, argv, "Desktop");
+    auto* app = new MvQDesktop(argc, argv, "Desktop");
 
     //Initialise resorces from a static library (libMvQtGui)
     //Q_INIT_RESOURCE(edit);
