@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQActionList_H
-#define MvQActionList_H
+#pragma once
 
 #include <QList>
 
@@ -26,5 +25,3 @@ public:
 protected:
     QList<QAction*> lst_;
 };
-
-#endif
