@@ -83,7 +83,7 @@ MvQAdvancedSearchDialog::MvQAdvancedSearchDialog(QWidget* callerWidget, Folder*
 
     tab->addTab(buildMainTab(), tr("&Basic"));
     tab->addTab(buildContentsTab(), tr("&Contents"));
-    tab->addTab(buildPropTab(), tr("&Properites"));
+    tab->addTab(buildPropTab(), tr("&Properties"));
 
     //Some init
     folderLe_->setText(currentRelPath);
@@ -469,12 +469,13 @@ void MvQAdvancedSearchDialog::slotFind()
 #endif
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-            dt = toDateE_->date().startOfDay();
+            dt = toDateE_->date().endOfDay();
 #else
-            dt               = QDateTime(toDateE_->date());
+            dt = QDateTime(toDateE_->date());
+            dt = dt.addSecs(86399);
 #endif
 #if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
-            options.fromTime = dt.toSecsSinceEpoch();
+            options.toTime = dt.toSecsSinceEpoch();
 #else
             options.toTime   = dt.toTime_t();
 #endif
