@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQBookmarks_H
-#define MvQBookmarks_H
+#pragma once
 
 #include <QDialog>
 #include <QListView>
@@ -18,7 +17,6 @@
 #include "MvQKeyModel.h"
 
 #include <string>
-using namespace std;
 
 
 class QAction;
@@ -41,7 +39,7 @@ class MvQBookmarksModel : public MvQKeyModel
 {
 public:
     MvQBookmarksModel(MvKeyProfile* prof) :
-        MvQKeyModel(prof, ShortNameMode, 0){}
+        MvQKeyModel(prof, ShortNameMode, 0) {}
     QVariant data(const QModelIndex&, int role = Qt::DisplayRole) const;
 };
 
@@ -52,7 +50,7 @@ class MvQBookmarks : public QObject
 
 public:
     MvQBookmarks(QWidget*);
-    ~MvQBookmarks(){}
+    ~MvQBookmarks() {}
 
     static void init();
     static void save();
@@ -139,7 +137,7 @@ class MvQBookmarksPanel : public MvQBookmarks
 
 public:
     MvQBookmarksPanel(QWidget*);
-    ~MvQBookmarksPanel(){}
+    ~MvQBookmarksPanel() {}
 
     QWidget* widget() { return widget_; }
 
@@ -163,7 +161,7 @@ class MvQBookmarksDialog : public QDialog
 
 public:
     MvQBookmarksDialog(MvKey*, QString, QWidget* parent = 0);
-    ~MvQBookmarksDialog(){}
+    ~MvQBookmarksDialog() {}
 
 public slots:
     void accept();
@@ -180,7 +178,7 @@ class MvQBookmarksGroupDialog : public QDialog
 
 public:
     MvQBookmarksGroupDialog(MvKey*, QString, QWidget* parent = 0);
-    ~MvQBookmarksGroupDialog(){}
+    ~MvQBookmarksGroupDialog() {}
 
 public slots:
     void accept();
@@ -192,5 +190,3 @@ protected:
     QLineEdit* labelEdit_;
     QPlainTextEdit* pathEdit_;
 };
-
-#endif
