@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQBoolLine_H
-#define MvQBoolLine_H
+#pragma once
 
 #include <QString>
 
@@ -30,7 +29,7 @@ public:
 
     QString currentValue() { return QString(); }
     void addValue(QString) {}
-    void refresh(const vector<string>&);
+    void refresh(const std::vector<std::string>&);
 
 public slots:
     void slotStatusChanged(bool);
@@ -41,6 +40,3 @@ protected:
     QRadioButton* radioOn_;
     QRadioButton* radioOff_;
 };
-
-
-#endif
