@@ -37,7 +37,7 @@
 MvQColourHelp::MvQColourHelp(RequestPanel& owner, const MvIconParameter& param) :
     MvQRequestPanelHelp(owner, param)
 {
-    selector_ = new MvQColourSelectionWidget(parentWidget_);  //QWidget;
+    selector_ = new MvQColourSelectionWidget(parentWidget_, true);
 
     connect(selector_, SIGNAL(colourSelected(QColor)),
             this, SLOT(slotSelected(QColor)));
@@ -130,7 +130,7 @@ MvQColourListHelp::MvQColourListHelp(RequestPanel& owner, const MvIconParameter&
 
     //Colour selector
 
-    selector_ = new MvQColourSelectionWidget(w_);
+    selector_ = new MvQColourSelectionWidget(w_, true);
     vb->addWidget(selector_);
 
     connect(selector_, SIGNAL(colourSelected(QColor)),
@@ -261,7 +261,7 @@ MvQColourGradHelp::MvQColourGradHelp(RequestPanel& owner, const MvIconParameter&
 
     //Colour selector
 
-    selector_ = new MvQColourSelectionWidget(w_);
+    selector_ = new MvQColourSelectionWidget(w_, true);
     vb->addWidget(selector_);
 
     connect(selector_, SIGNAL(colourSelected(QColor)),
