@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQComboBoxLine_H
-#define MvQComboBoxLine_H
+#pragma once
 
 #include <QComboBox>
 #include <QString>
@@ -41,7 +40,7 @@ public:
     QString currentValue() { return QString(); }
     void addValue(QString) {}
 
-    void refresh(const vector<string>&);
+    void refresh(const std::vector<std::string>&);
 
 public slots:
     void slotCurrentChanged(int);
@@ -52,6 +51,3 @@ protected:
     MvQEditorComboBox* cbEdit_;
     bool reportChange_;
 };
-
-
-#endif
