@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQContextMenu_H
-#define MvQContextMenu_H
+#pragma once
 
 #include <QAction>
 #include <QList>
@@ -134,6 +133,3 @@ public:
 protected:
     static MvQContextMenu* instance_;
 };
-
-
-#endif
