@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQDesktop_H
-#define MvQDesktop_H
+#pragma once
 
 #include <QString>
 
@@ -16,12 +15,11 @@
 #include "MvRequest.h"
 #include "MvProtocol.h"
 
-using namespace std;
 
 class MvQDesktop : public MvQApplication
 {
 public:
-    MvQDesktop(int& argc, char** argv, string);
+    MvQDesktop(int& argc, char** argv, std::string);
     ~MvQDesktop();
 
     void init();
@@ -30,5 +28,3 @@ public:
     // Processing the request
     virtual void serve(MvProtocol&, MvRequest&);
 };
-
-#endif
