@@ -447,13 +447,21 @@ void MvQDetailedFolderView::checkDropTarget(QDropEvent* event)
 
     Qt::DropAction dropAction = event->proposedAction();
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QModelIndex index = indexAt(event->position().toPoint());
+#else
     QModelIndex index = indexAt(event->pos());
+#endif
     IconObject* obj   = folderModel_->objectFromIndex(filterModel_->mapToSource(index));
 
     if (obj != dragObj && obj && obj->isFolder() && !obj->locked()) {
         MvQDropTarget::Instance()->reset(QString::fromStdString(obj->name()), (dropAction == Qt::MoveAction));
         if (window()) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            MvQDropTarget::Instance()->move(mapToGlobal(event->position().toPoint()) + QPoint(20, 20));
+#else
             MvQDropTarget::Instance()->move(mapToGlobal(event->pos()) + QPoint(20, 20));
+#endif
         }
         return;
     }
@@ -552,8 +560,11 @@ void MvQDetailedFolderView::dropEvent(QDropEvent* event)
                 event->ignore();
                 return;
             }
-
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            performDrop(event->proposedAction(), mimeData, event->position().toPoint(), fromSameView);
+#else
             performDrop(event->proposedAction(), mimeData, event->pos(), fromSameView);
+#endif
 
             event->accept();
             return;
