@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQDetailedFolderView_H
-#define MvQDetailedFolderView_H
+#pragma once
 
 #include <QSettings>
 #include <QTreeView>
@@ -59,7 +58,7 @@ protected:
 
     MvQContextItemSet* cmSet();
     void setupShortCut();
-    void setPositions(){}
+    void setPositions() {}
     void blink(const QModelIndex&);
     void showIcon(const QModelIndex&);
     void rename(IconObject*);
@@ -104,5 +103,3 @@ protected:
     MvQActionList* appDesktopActions_;
     IconObject* itemInfo_{nullptr};
 };
-
-#endif
