@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQDrawerView_H
-#define MvQDrawerView_H
+#pragma once
 
 #include "MvQIconStripView.h"
 
@@ -21,9 +20,7 @@ public:
     ~MvQDrawerView();
 
 protected:
-    void attachModel(){};
-    void detachModel(){};
+    void attachModel() {}
+    void detachModel() {}
     MvQContextItemSet* cmSet();
 };
-
-#endif
\ No newline at end of file
