@@ -25,7 +25,7 @@
 
 #include "MvQStyleDb.h"
 #include "MvQTheme.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 MvQEcLayerDb* MvQEcLayerDb::instance_ = 0;
 
@@ -124,9 +124,9 @@ QStringList MvQEcLayerDb::titleWords() const
     for (int i = 0; i < items_.count(); i++) {
         foreach (QString s, items_[i]->title().split(" ",
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-            Qt::SkipEmptyParts)) {
+                                                     Qt::SkipEmptyParts)) {
 #else
-            QString::SkipEmptyParts)) {
+                                                     QString::SkipEmptyParts)) {
 #endif
             s.remove(")").remove("(");
             if (s.size() >= 2) {
@@ -169,7 +169,7 @@ void MvQEcLayerDb::load()
         QString name = it.key();
         //qDebug() << name;
 
-        MvQEcLayerDbItem* item = new MvQEcLayerDbItem(name);
+        auto* item = new MvQEcLayerDbItem(name);
 
         QStringList styles;
 
