@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQECLAYERTREEWIDGET_H
-#define MVQECLAYERTREEWIDGET_H
+#pragma once
 
 #include <QColor>
 #include <QStyledItemDelegate>
@@ -50,5 +49,3 @@ protected:
     QTreeView* tree_;
     QTextEdit* te_;
 };
-
-#endif  // MVQECLAYERTREEWIDGET_H
