@@ -25,7 +25,7 @@
 #include "MvQEcLayerDb.h"
 #include "MvQStyleTreeWidget.h"
 
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 #include "HelpFactory.h"
 
@@ -40,9 +40,7 @@ MvQEcStyleModel::MvQEcStyleModel(QObject* parent) :
 {
 }
 
-MvQEcStyleModel::~MvQEcStyleModel()
-{
-}
+MvQEcStyleModel::~MvQEcStyleModel() = default;
 
 int MvQEcStyleModel::columnCount(const QModelIndex& /*parent */) const
 {
@@ -83,16 +81,7 @@ QVariant MvQEcStyleModel::headerData(const int section, const Qt::Orientation or
     if (orient != Qt::Horizontal || (role != Qt::DisplayRole && role != Qt::ToolTipRole))
         return QAbstractItemModel::headerData(section, orient, role);
 
-    if (role == Qt::DisplayRole) {
-        switch (section) {
-            case 0:
-                return " Styles";
-            default:
-                return QVariant();
-        }
-    }
-
-    return QVariant();
+    return role == Qt::DisplayRole && section == 0 ? " Styles" : QVariant();
 }
 
 QModelIndex MvQEcStyleModel::index(int row, int column, const QModelIndex& parent) const
@@ -109,7 +98,7 @@ QModelIndex MvQEcStyleModel::index(int row, int column, const QModelIndex& paren
     return QModelIndex();
 }
 
-QModelIndex MvQEcStyleModel::parent(const QModelIndex& child) const
+QModelIndex MvQEcStyleModel::parent(const QModelIndex& /*child*/) const
 {
     return QModelIndex();
 }
@@ -173,7 +162,7 @@ MvQEcStyleSelectionWidget::MvQEcStyleSelectionWidget(QWidget* parent) :
 }
 
 
-void MvQEcStyleSelectionWidget::slotItemSelected(const QModelIndex& current, const QModelIndex& prev)
+void MvQEcStyleSelectionWidget::slotItemSelected(const QModelIndex& current, const QModelIndex& /*prev*/)
 {
     QModelIndex idxSrc = sortModel_->mapToSource(current);
     if (idxSrc.isValid()) {
@@ -275,15 +264,15 @@ void MvQEcStyleHelp::slotSelected(int idx)
 {
     if (idx >= 0 && idx < MvQStyleDb::instance()->items().count()) {
         if (MvQStyleDb::instance()->items()[idx]->name() != oriName_) {
-            std::vector<string> vs;
-            vs.push_back(metview::toString<int>(idx));
+            std::vector<std::string> vs;
+            vs.push_back(std::to_string(idx));
             emit edited(vs);
             oriName_.clear();
         }
     }
 }
 
-void MvQEcStyleHelp::refresh(const vector<string>& values)
+void MvQEcStyleHelp::refresh(const std::vector<std::string>& values)
 {
     if (values.size() == 0)
         return;
