@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQSTYLELINE_H
-#define MVQSTYLELINE_H
+#pragma once
 
 #include "MvQRequestPanelLine.h"
 #include "MvIconParameter.h"
@@ -32,14 +31,14 @@ public:
     MvQEcStyleLine(RequestPanel& owner, const MvIconParameter& param);
     ~MvQEcStyleLine() {}
 
-    void refresh(const vector<string>&);
+    void refresh(const std::vector<std::string>&);
     void widgetClicked();
-    void changed(const char* param, const vector<string>&) {}
-    void changed(const char* param, const string&);
+    void changed(const char* /*param*/, const std::vector<std::string>&) {}
+    void changed(const char* param, const std::string&);
     bool isDependent() const { return true; }
 
 public slots:
-    void slotHelperEdited(const vector<string>&);
+    void slotHelperEdited(const std::vector<std::string>&);
 
 protected:
     void next(const MvIconParameter&, const char* first, const char* second);
@@ -52,5 +51,3 @@ protected:
     QLabel* styleNameLabel_;
     std::string layerParam_;
 };
-
-#endif  // MVQSTYLELINE_H
