@@ -59,8 +59,6 @@
 
 MvQEditorDragLabel::MvQEditorDragLabel(QPixmap pix, int maxHeight, QWidget* parent) :
     QLabel(parent),
-    obj_(nullptr),
-    canDrag_(false),
     oriPix_(pix)
 {
     setPixmap(oriPix_);
@@ -75,12 +73,12 @@ MvQEditorDragLabel::MvQEditorDragLabel(QPixmap pix, int maxHeight, QWidget* pare
     QPen pen = MvQTheme::pen("iconeditor", "drag_label_border");
     pen.setWidth(2);
     painter.setPen(pen);
-    painter.drawRect(QRect(0,0,
-                           highlightPix_.width(),highlightPix_.height()).
-                           adjusted(1,1,-1,-1));
+    painter.drawRect(QRect(0, 0,
+                           highlightPix_.width(), highlightPix_.height())
+                         .adjusted(1, 1, -1, -1));
 }
 
-void MvQEditorDragLabel::setIconObject(IconObject *obj)
+void MvQEditorDragLabel::setIconObject(IconObject* obj)
 {
     obj_ = obj;
 }
@@ -110,8 +108,8 @@ void MvQEditorDragLabel::mousePressEvent(QMouseEvent* event)
 
     canDrag_ = false;
     if (event->button() == Qt::LeftButton) {
-       startPos_ = event->pos();
-       canDrag_  = true;
+        startPos_ = event->pos();
+        canDrag_  = true;
     }
 
     QLabel::mousePressEvent(event);
@@ -134,7 +132,7 @@ void MvQEditorDragLabel::mouseMoveEvent(QMouseEvent* event)
 void MvQEditorDragLabel::performDrag(Qt::DropAction dropAction, QPoint scenePos)
 {
     if (obj_) {
-        QDrag *drag = buildDrag(obj_, scenePos);
+        QDrag* drag = buildDrag(obj_, scenePos);
         if (drag) {
             emit dragStarted();
             //We always initiate a copy action
@@ -148,10 +146,10 @@ void MvQEditorDragLabel::performDrag(Qt::DropAction dropAction, QPoint scenePos)
     canDrag_ = false;
 }
 
-QDrag* MvQEditorDragLabel::buildDrag(IconObject* dragObj, QPoint dragPos)
+QDrag* MvQEditorDragLabel::buildDrag(IconObject* dragObj, QPoint /*dragPos*/)
 {
     if (dragObj) {
-        QDrag* drag = new QDrag(this);
+        auto* drag = new QDrag(this);
 
         //Hotspot is the bottom right corner of the dragged object's pixmap
         //we overwrite it if dragPos is null!! We use normalised coordinates
@@ -167,9 +165,9 @@ QDrag* MvQEditorDragLabel::buildDrag(IconObject* dragObj, QPoint dragPos)
         objLst << dragObj;
 
         //Create and set drag mime data
-        MvQIconMimeData* mimeData = new MvQIconMimeData(nullptr,
-                                                        dragObj, hotSpotInPix,
-                                                        objLst, pixDistanceLst);
+        auto* mimeData = new MvQIconMimeData(nullptr,
+                                             dragObj, hotSpotInPix,
+                                             objLst, pixDistanceLst);
 
         mimeData->setFromEditor(true);
         mimeData->setFromHelper(false);
@@ -191,7 +189,7 @@ MvQEditorHeader::MvQEditorHeader(MvQEditor* owner, QPixmap pix) :
     QWidget(owner),
     owner_(owner)
 {
-    QHBoxLayout* hb = new QHBoxLayout(this);
+    auto* hb = new QHBoxLayout(this);
     hb->setSpacing(0);
     hb->setContentsMargins(0, 0, 0, 0);
 
@@ -206,14 +204,14 @@ MvQEditorHeader::MvQEditorHeader(MvQEditor* owner, QPixmap pix) :
     hb->addWidget(pixLabel_);
 
     connect(pixLabel_, SIGNAL(dragStarted()),
-            owner_,SLOT(save()));
+            owner_, SLOT(save()));
 
     stackLayout_ = new QStackedLayout();
     hb->addLayout(stackLayout_);
 
     //Info panel
-    QWidget* w           = new QWidget;
-    QHBoxLayout* labelHb = new QHBoxLayout(w);
+    auto* w       = new QWidget;
+    auto* labelHb = new QHBoxLayout(w);
     labelHb->setSpacing(0);
     labelHb->setContentsMargins(2, 1, 2, 1);
     stackLayout_->addWidget(w);
@@ -241,8 +239,8 @@ MvQEditorHeader::MvQEditorHeader(MvQEditor* owner, QPixmap pix) :
             this, SLOT(slotStartEdit(bool)));
 
     //Editor
-    w                   = new QWidget;
-    QHBoxLayout* editHb = new QHBoxLayout(w);
+    w            = new QWidget;
+    auto* editHb = new QHBoxLayout(w);
     editHb->setSpacing(0);
     editHb->setContentsMargins(2, 1, 2, 1);
     stackLayout_->addWidget(w);
@@ -252,12 +250,12 @@ MvQEditorHeader::MvQEditorHeader(MvQEditor* owner, QPixmap pix) :
 
     //Rename buttonBox_
 
-    QToolButton* acceptTb = new QToolButton(this);
+    auto* acceptTb = new QToolButton(this);
     acceptTb->setAutoRaise(true);
     acceptTb->setIcon(QPixmap(QString::fromUtf8(":/desktop/accept.svg")));
     editHb->addWidget(acceptTb);
 
-    QToolButton* cancelTb = new QToolButton(this);
+    auto* cancelTb = new QToolButton(this);
     cancelTb->setAutoRaise(true);
     cancelTb->setIcon(QPixmap(QString::fromUtf8(":/desktop/cancel.svg")));
     editHb->addWidget(cancelTb);
@@ -304,7 +302,7 @@ void MvQEditorHeader::updateLabel(IconObject* obj)
         return;
 
     auto subCol = MvQTheme::subText();
-    QString str = MvQ::formatText("Icon name: ", subCol) +  QString::fromStdString(obj->name()) + "<br>";
+    QString str = MvQ::formatText("Icon name: ", subCol) + QString::fromStdString(obj->name()) + "<br>";
     str += MvQ::formatText("Folder: ", subCol);
     str += QString::fromStdString(obj->parent()->fullName()) + "<br>";
     str += MvQ::formatText("Type: ", subCol);
@@ -320,8 +318,8 @@ void MvQEditorHeader::updateLabel(IconObject* obj)
     str += dt.toString("yyyy-MM-dd hh:mm");
 
     if (obj->locked())
-        str += MvQ::formatText(" Status: ", subCol) + 
-            MvQ::formatText("Read only", Qt::red);
+        str += MvQ::formatText(" Status: ", subCol) +
+               MvQ::formatText("Read only", Qt::red);
 
     label_->setText(str);
     pixLabel_->setIconObject(obj);
@@ -351,19 +349,16 @@ void MvQEditorHeader::paintEvent(QPaintEvent*)
 MvQEditorTextPanel::MvQEditorTextPanel(const IconClass& c, Editor* owner, QWidget* parent) :
     QWidget(parent),
     class_(c),
-    owner_(owner),
-    current_(0),
-    correct_(true),
-    beingLoaded_(false)
+    owner_(owner)
 {
-    QVBoxLayout* vb = new QVBoxLayout;
+    auto* vb = new QVBoxLayout;
     setLayout(vb);
 
     vb->setSpacing(0);
     vb->setContentsMargins(0, 0, 0, 0);
 
     //Warning label
-    QHBoxLayout* warnLayout = new QHBoxLayout();
+    auto* warnLayout = new QHBoxLayout();
     vb->addLayout(warnLayout);
 
     warnLabel_ = new MessageLabel(this);
@@ -371,7 +366,7 @@ MvQEditorTextPanel::MvQEditorTextPanel(const IconClass& c, Editor* owner, QWidge
     warnLayout->addWidget(warnLabel_, 1);
 
     //Message label
-    QHBoxLayout* msgLayout = new QHBoxLayout();
+    auto* msgLayout = new QHBoxLayout();
     vb->addLayout(msgLayout);
 
     msgLabel_ = new MessageLabel(this);
@@ -391,7 +386,7 @@ void MvQEditorTextPanel::setObject(IconObject* obj)
 
     QString str = tr("This is the contents of the file storing your icon settings. ");
 
-    if (obj->locked()) {
+    if (obj->locked() || !obj->storedAsRequestFile()) {
         te_->setReadOnly(true);
     }
     else {
@@ -408,33 +403,22 @@ void MvQEditorTextPanel::loadRequestFile()
 {
     beingLoaded_ = true;
     QFile f(QString::fromStdString(current_->path().str()));
-    f.open(QFile::ReadOnly | QFile::Text);
-    QTextStream rs(&f);
-    te_->setPlainText(rs.readAll());
-    f.close();
+    if (f.open(QFile::ReadOnly | QFile::Text)) {
+        QTextStream rs(&f);
+        te_->setPlainText(rs.readAll());
+    } else {
+        te_->clear();
+    }
     beingLoaded_ = false;
 }
 
-/*bool MvQEditorTextPanel::checkVerb()
-{
-  	const char* v=current_->request().getVerb();
-        const char* ic=current_->iconClass().name().c_str();
-	
-  	if(strcmp(v,ic) != 0)
-	{
-	  	QString s="<b><font color=\'red\'> Error: </b></font> Request type <b>" + QString(v) + "</b> in text does not match icon type <b>"  + QString(ic) + "</b>! ";
-		s+="Please change request type to <b>" + QString(ic) + "</b> or revert the icon back to system default.";
-		
-		msgLabel_->setText(s);	
-		
-		return false;
-	}
-	
-	return true;
-}*/
-
 bool MvQEditorTextPanel::check(bool fromSave)
 {
+    if (!current_ || !current_->storedAsRequestFile()) {
+        correct_ = true;
+        return correct_;
+    }
+
     QString s = te_->toPlainText();
     Request r = Request::fromText(s.toStdString());
     QString verb;
@@ -492,7 +476,7 @@ void MvQEditorTextPanel::slotTextChanged()
 void MvQEditorTextPanel::save()
 {
     FILE* f = fopen(current_->path().str().c_str(), "w");
-    if (f == NULL) {
+    if (f == nullptr) {
         //marslog(LOG_EROR|LOG_PERR,"%s",tmp);
         return;
     }
@@ -515,17 +499,14 @@ void MvQEditorTextPanel::load()
 //
 //================================================
 
-MvQEditor::MvQEditor(const IconClass& name, const string& kind, QWidget* parent) :
+MvQEditor::MvQEditor(const IconClass& name, const std::string& kind, QWidget* parent) :
     QDialog(parent),
-    Editor(name, kind),
-    showDisabledAc_(NULL),
-    drawerFilled_(false),
-    ignoreChange_(false)
+    Editor(name, kind)
 {
     //Set Window icon
     setWindowIcon(MvQIconProvider::pixmap(name, 24));
 
-    QVBoxLayout* vb = new QVBoxLayout;
+    auto* vb = new QVBoxLayout;
     vb->setSpacing(0);
     vb->setContentsMargins(0, 0, 0, 0);
     setLayout(vb);
@@ -544,7 +525,7 @@ MvQEditor::MvQEditor(const IconClass& name, const string& kind, QWidget* parent)
     toolBarLayout_->setContentsMargins(0, 0, 0, 0);
 
     //Widget to provide bg for the toolbars
-    QWidget* w = new QWidget(this);
+    auto* w = new QWidget(this);
     w->setProperty("editor", "true");
     w->setLayout(toolBarLayout_);
     vb->addWidget(w);
@@ -555,7 +536,7 @@ MvQEditor::MvQEditor(const IconClass& name, const string& kind, QWidget* parent)
     toolbarRight_ = new QToolBar(w);
     toolBarLayout_->addWidget(toolbarRight_);
 
-    QWidget* spacer = new QWidget(this);
+    auto* spacer = new QWidget(this);
     spacer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     sepAc_ = toolbarRight_->addWidget(spacer);
 
@@ -566,14 +547,14 @@ MvQEditor::MvQEditor(const IconClass& name, const string& kind, QWidget* parent)
     guiAc_ = new QAction(this);
     guiAc_->setIcon(QPixmap(":/desktop/gui_edit.svg"));
     guiAc_->setCheckable(true);
-    guiAc_->setToolTip(tr("<b>GUI</b> edit mode.<br> To switch between edit modes changes have to be <u>saved<u>!"));
+    guiAc_->setToolTip(tr("<b>GUI</b> mode.<br> To switch between view modes changes have to be <u>saved<u>!"));
     toolbarRight_->addAction(guiAc_);
 
     //Text edit
     textAc_ = new QAction(this);
     textAc_->setIcon(QPixmap(":/desktop/text_edit.svg"));
     textAc_->setCheckable(true);
-    textAc_->setToolTip(tr("<b>Text</b> edit mode.<br> To switch between edit modes changes have to be <u>saved</u>!"));
+    textAc_->setToolTip(tr("<b>Text</b> mode.<br> To switch between view modes changes have to be <u>saved</u>!"));
     toolbarRight_->addAction(textAc_);
 
     viewAg_ = new QActionGroup(this);
@@ -621,8 +602,8 @@ MvQEditor::MvQEditor(const IconClass& name, const string& kind, QWidget* parent)
 
     drawerPanel_ = new MvQEditorDrawerPanel(this);
 
-    /*map<string, EditorDrawer*> drawers=EditorDrawerFactory::create(this);
-	for(map<string, EditorDrawer*>::iterator j = drawers.begin();j != drawers.end(); ++j) 
+    /*map<std::string, EditorDrawer*> drawers=EditorDrawerFactory::create(this);
+	for(map<std::string, EditorDrawer*>::iterator j = drawers.begin();j != drawers.end(); ++j) 
 	{
 	  	drawerPanel_->addDrawer((*j).second->widget(),
 						(*j).second->name());
@@ -663,16 +644,13 @@ MvQEditor::MvQEditor(const IconClass& name, const string& kind, QWidget* parent)
 }
 
 
-MvQEditor::~MvQEditor()
-{
-}
+MvQEditor::~MvQEditor() = default;
 
 
-bool MvQEditor::eventFilter(QObject *obj, QEvent * event)
+bool MvQEditor::eventFilter(QObject* obj, QEvent* event)
 {
-    if(static_cast<MvQEditor*>(obj)  == this &&
-       event->type() == QEvent::KeyPress && ((QKeyEvent*)event)->key() == Qt::Key_Escape )
-    {
+    if (static_cast<MvQEditor*>(obj) == this &&
+        event->type() == QEvent::KeyPress && ((QKeyEvent*)event)->key() == Qt::Key_Escape) {
         return true;
     }
     return false;
@@ -706,11 +684,13 @@ void MvQEditor::updateFilterCountLabel()
     if (filterLe_) {
         if (filterLe_->text().isEmpty()) {
             filterCountLabel_->clear();
-        } else {
+        }
+        else {
             int cnt = filterNonMatchCount();
             if (cnt == 0) {
                 filterCountLabel_->clear();
-            } else {
+            }
+            else {
                 filterCountLabel_->setText("(" + QString::number(cnt) + " hidden)");
             }
         }
@@ -787,10 +767,10 @@ void MvQEditor::edit()
 
     //Populate drawers if needed
     if (!drawerFilled_) {
-        map<string, EditorDrawer*> drawers = EditorDrawerFactory::create(this);
-        for (map<string, EditorDrawer*>::iterator j = drawers.begin(); j != drawers.end(); ++j) {
-            drawerPanel_->addDrawer((*j).second->widget(),
-                                    (*j).second->name());
+        std::map<std::string, EditorDrawer*> drawers = EditorDrawerFactory::create(this);
+        for (auto& drawer : drawers) {
+            drawerPanel_->addDrawer(drawer.second->widget(),
+                                    drawer.second->name());
         }
         drawerFilled_ = true;
     }
@@ -829,7 +809,7 @@ void MvQEditor::edit()
     okPb_->setEnabled(!current_->locked());
 }
 
-bool MvQEditor::isTextMode()
+bool MvQEditor::isTextMode() const
 {
     return (viewSw_->currentIndex() == TextViewMode);
 }
@@ -864,7 +844,7 @@ void MvQEditor::rename(QString text)
         return;
 
     if (!text.isEmpty()) {
-        string n = text.toStdString();
+        auto n = text.toStdString();
         if (n != current_->name()) {
             current_->editor(0);
             current_->rename(n);
