@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQEditor_H
-#define MvQEditor_H
+#pragma once
 
 #include <QtGlobal>
 #include <QDialog>
@@ -41,9 +40,9 @@ class MessageLabel;
 
 class MvQEditorDragLabel : public QLabel
 {
-     Q_OBJECT
+    Q_OBJECT
 public:
-    MvQEditorDragLabel(QPixmap, int, QWidget* parent=nullptr);
+    MvQEditorDragLabel(QPixmap, int, QWidget* parent = nullptr);
     void setIconObject(IconObject*);
 
 signals:
@@ -51,18 +50,18 @@ signals:
 
 protected:
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-    void enterEvent(QEnterEvent*);
+    void enterEvent(QEnterEvent*) override;
 #else
     void enterEvent(QEvent*);
 #endif
-    void leaveEvent(QEvent*);
-    void mousePressEvent(QMouseEvent*);
-    void mouseMoveEvent(QMouseEvent*);
+    void leaveEvent(QEvent*) override;
+    void mousePressEvent(QMouseEvent*) override;
+    void mouseMoveEvent(QMouseEvent*) override;
     void performDrag(Qt::DropAction, QPoint);
     QDrag* buildDrag(IconObject* dragObj, QPoint dragPos);
 
-    IconObject *obj_;
-    bool canDrag_;
+    IconObject* obj_{nullptr};
+    bool canDrag_{false};
     QPoint startPos_;
     QPixmap oriPix_;
     QPixmap highlightPix_;
@@ -85,13 +84,13 @@ public slots:
 protected:
     void paintEvent(QPaintEvent*);
 
-    MvQEditor* owner_;
-    QStackedLayout* stackLayout_;
-    QLabel* label_;
-    QToolButton* renameTb_;
-    QLineEdit* edit_;
-    IconObject* obj_;
-    MvQEditorDragLabel* pixLabel_;
+    MvQEditor* owner_{nullptr};
+    QStackedLayout* stackLayout_{nullptr};
+    QLabel* label_{nullptr};
+    QToolButton* renameTb_{nullptr};
+    QLineEdit* edit_{nullptr};
+    IconObject* obj_{nullptr};
+    MvQEditorDragLabel* pixLabel_{nullptr};
 };
 
 class MvQEditorTextPanel : public QWidget
@@ -112,13 +111,13 @@ protected:
     void loadRequestFile();
 
     const IconClass& class_;
-    Editor* owner_;
-    IconObject* current_;
-    QPlainTextEdit* te_;
-    MessageLabel* warnLabel_;
-    MessageLabel* msgLabel_;
-    bool correct_;
-    bool beingLoaded_;
+    Editor* owner_{nullptr};
+    IconObject* current_{nullptr};
+    QPlainTextEdit* te_{nullptr};
+    MessageLabel* warnLabel_{nullptr};
+    MessageLabel* msgLabel_{nullptr};
+    bool correct_{true};
+    bool beingLoaded_{false};
 };
 
 class MvQEditor : public QDialog, public Editor
@@ -126,27 +125,27 @@ class MvQEditor : public QDialog, public Editor
     Q_OBJECT
 
 public:
-    MvQEditor(const IconClass& name, const string& kind, QWidget* parent = 0);
-    ~MvQEditor();
+    MvQEditor(const IconClass& name, const std::string& kind, QWidget* parent = 0);
+    virtual ~MvQEditor();
 
-    void changed();
+    void changed() override;
     virtual void merge(IconObjectH)   = 0;
     virtual void replace(IconObjectH) = 0;
     void rename(QString);
 
     //Observer method
-    void iconChanged(IconObject*);
+    void iconChanged(IconObject*) override;
 
 public slots:
     void slotChangeView(QAction*);
     void slotButtonClicked(QAbstractButton*);
-    void accept();
-    void reject();
+    void accept() override;
+    void reject() override;
     void slotTextChanged();
 
 protected slots:
     virtual void slotFilterItems(QString) = 0;
-    virtual void slotShowDisabled(bool) = 0;
+    virtual void slotShowDisabled(bool)   = 0;
     void save();
 
 protected:
@@ -156,62 +155,59 @@ protected:
         TextViewMode = 1
     };
 
-    bool eventFilter(QObject *obj, QEvent * event);
+    bool eventFilter(QObject* obj, QEvent* event) override;
     void setupShowDisabledActions();
     void setupLineFilter();
     void updateFilterCountLabel();
-    virtual int filterNonMatchCount() {return 0;}
+    virtual int filterNonMatchCount() { return 0; }
     bool showDisabled() const;
 
     void addToToolBar(QList<QAction*>);
-    void raiseIt();
-    void showIt();
-    void closeIt();
+    void raiseIt() override;
+    void showIt() override;
+    void closeIt() override;
     virtual void apply() = 0;
     virtual void reset() = 0;
     virtual void close() = 0;
-    virtual void edit();
-    virtual void temporary();
-    void closeEvent(QCloseEvent*);
+    virtual void edit() override;
+    virtual void temporary() override;
+    void closeEvent(QCloseEvent*) override;
     void readSettings();
     void writeSettings();
     virtual void readSettings(QSettings&)  = 0;
     virtual void writeSettings(QSettings&) = 0;
 
-    bool isTextMode();
+    bool isTextMode() const;
 
-    QLabel* headerLabel_;
-    QLineEdit* headerEdit_;
-    MvQEditorHeader* headerPanel_;
-    //QToolButton* viewTb_;
-    QAction* showDisabledAc_;
+    QLabel* headerLabel_{nullptr};
+    QLineEdit* headerEdit_{nullptr};
+    MvQEditorHeader* headerPanel_{nullptr};
+    QAction* showDisabledAc_{nullptr};
     QLineEdit* filterLe_{nullptr};
     QLabel* filterCountLabel_{nullptr};
-    QAction* sepAc_;
-    QAction* guiAc_;
-    QAction* textAc_;
-    QActionGroup* viewAg_;
+    QAction* sepAc_{nullptr};
+    QAction* guiAc_{nullptr};
+    QAction* textAc_{nullptr};
+    QActionGroup* viewAg_{nullptr};
 
-    QVBoxLayout* centralLayout_;
+    QVBoxLayout* centralLayout_{nullptr};
 
-    QDialogButtonBox* buttonBox_;
-    QPushButton* savePb_;
-    QPushButton* okPb_;
-    QPushButton* cancelPb_;
-    QPushButton* resetPb_;
+    QDialogButtonBox* buttonBox_{nullptr};
+    QPushButton* savePb_{nullptr};
+    QPushButton* okPb_{nullptr};
+    QPushButton* cancelPb_{nullptr};
+    QPushButton* resetPb_{nullptr};
 
-    QStackedWidget* viewSw_;
-    MvQDrawerPanel* drawerPanel_;
-    bool drawerFilled_;
-    QToolBar* toolbarLeft_;
-    QToolBar* toolbarRight_;
-    MvQEditorTextPanel* textPanel_;
+    QStackedWidget* viewSw_{nullptr};
+    MvQDrawerPanel* drawerPanel_{nullptr};
+    bool drawerFilled_{false};
+    QToolBar* toolbarLeft_{nullptr};
+    QToolBar* toolbarRight_{nullptr};
+    MvQEditorTextPanel* textPanel_{nullptr};
 
 private:
     void updateWindowTitle();
 
-    QHBoxLayout* toolBarLayout_;
-    bool ignoreChange_;
+    QHBoxLayout* toolBarLayout_{nullptr};
+    bool ignoreChange_{false};
 };
-
-#endif
