@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQEDITORLISTMENU_H
-#define MVQEDITORLISTMENU_H
+#pragma once
 
 #include <QMenu>
 #include <QList>
@@ -47,5 +46,3 @@ protected:
     //QAction* actionTabs_;
     //QAction* actionAdd_;
 };
-
-#endif  // MVQEDITORLISTMENU_H
