@@ -8,8 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 
-#ifndef MvQExternalHelp_H
-#define MvQExternalHelp_H
+#pragma once
 
 #include "MvQRequestPanelHelp.h"
 #include "MvIconParameter.h"
@@ -23,22 +22,20 @@ class MvQExternalHelp : public MvQRequestPanelHelp,
 {
 public:
     MvQExternalHelp(RequestPanel& owner, const MvIconParameter& param);
-    ~MvQExternalHelp(){};
+    ~MvQExternalHelp() = default;
 
     void start();
     bool dialog() { return true; }
     QWidget* widget() { return 0; }
 
 protected:
-    virtual void refresh(const vector<string>&);
+    virtual void refresh(const std::vector<std::string>&);
     virtual long flags() { return 9; }
     virtual void set(Request&);
 
     void reply(const Request&, int);
     void progress(const Request&);
-    void message(const string&);
+    void message(const std::string&);
 
     Request request_;
 };
-
-#endif
\ No newline at end of file
