@@ -58,7 +58,7 @@
 #include "Folder.h"
 #include "Tools.h"
 
-bool MvQFileBrowser::quitStarted_   = false;
+bool MvQFileBrowser::quitStarted_          = false;
 bool MvQFileBrowser::sessionLogoutStarted_ = false;
 
 QList<MvQFileBrowser*> MvQFileBrowser::browsers_;
@@ -88,11 +88,11 @@ MvQFileBrowser::MvQFileBrowser(QStringList relPathLst, QWidget* parent) :
     // Layout
     //-----------------------------
 
-    QVBoxLayout* mainLayout = new QVBoxLayout;
+    auto* mainLayout = new QVBoxLayout;
     mainLayout->setSpacing(0);
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
-    QWidget* w = new QWidget;
+    auto* w = new QWidget;
     w->setLayout(mainLayout);
 
     setCentralWidget(w);
@@ -125,7 +125,7 @@ MvQFileBrowser::MvQFileBrowser(QStringList relPathLst, QWidget* parent) :
     // Central part
     //------------------------------
 
-    QVBoxLayout* centralVb = new QVBoxLayout;
+    auto* centralVb = new QVBoxLayout;
     centralVb->setSpacing(0);
     centralVb->setContentsMargins(0, 0, 0, 0);
 
@@ -174,7 +174,7 @@ MvQFileBrowser::MvQFileBrowser(QStringList relPathLst, QWidget* parent) :
     int spWidth = mainSplitter_->size().width();
     if (spWidth > 0) {
         QList<int> spSize;
-        spSize << 150 << spWidth - 2*150 << 150;
+        spSize << 150 << spWidth - 2 * 150 << 150;
         mainSplitter_->setSizes(spSize);
     }
 
@@ -211,7 +211,7 @@ MvQFileBrowser::MvQFileBrowser(QStringList relPathLst, QWidget* parent) :
 
     folderPanel_->setHistoryMenu(findMenu(MvQMainWindow::HistoryMenu));
 
-    MvQBookmarksMenu* bookmarksMenu = new MvQBookmarksMenu(this, findMenu(MvQMainWindow::BookmarksMenu));
+    auto* bookmarksMenu = new MvQBookmarksMenu(this, findMenu(MvQMainWindow::BookmarksMenu));
     connectBookmarksObject(bookmarksMenu);
     connectBookmarksObject(bookmarksPanel_);
 
@@ -239,9 +239,7 @@ MvQFileBrowser::MvQFileBrowser(QStringList relPathLst, QWidget* parent) :
             this, SLOT(slotCommitDataRequest(QSessionManager&)), Qt::DirectConnection);
 }
 
-MvQFileBrowser::~MvQFileBrowser()
-{
-}
+MvQFileBrowser::~MvQFileBrowser() = default;
 
 //Show the brower for the first time!
 void MvQFileBrowser::showIt()
@@ -268,21 +266,21 @@ void MvQFileBrowser::showIt()
 
 void MvQFileBrowser::closeEvent(QCloseEvent* event)
 {
-     qDebug() << "closeEvent";
-     if (!quitStarted_) {
+    qDebug() << "closeEvent";
+    if (!quitStarted_) {
         qDebug() << "  start close";
         if (browsers_.count() == 1) {
-             qDebug() << "  start quit";
-             MvQFileBrowser::aboutToQuit(this);
-             qDebug() << "closeEvent finished";
-             return;
+            qDebug() << "  start quit";
+            MvQFileBrowser::aboutToQuit(this);
+            qDebug() << "closeEvent finished";
+            return;
         }
         qDebug() << "  accept close event";
         browsers_.removeOne(this);
         saveFolderInfo();
         event->accept();
-     }
-     qDebug() << "closeEvent finished";
+    }
+    qDebug() << "closeEvent finished";
 }
 
 void MvQFileBrowser::slotQuit()
@@ -294,9 +292,8 @@ void MvQFileBrowser::slotQuit()
 //This slot is called when the window mangager quits to ask the app to
 //close in a correct way. We set the sessionLogoutStarted_ flag to indicate that
 //this happened.
-void MvQFileBrowser::slotCommitDataRequest(QSessionManager& manager)
+void MvQFileBrowser::slotCommitDataRequest(QSessionManager&)
 {
-    qDebug() << "slotCommitDataRequest";
     sessionLogoutStarted_ = true;
 }
 
@@ -309,11 +306,11 @@ void MvQFileBrowser::slotCommitDataRequest(QSessionManager& manager)
 
 void MvQFileBrowser::setupFileActions()
 {
-    QAction* ac = new QAction(this);
+    auto* ac = new QAction(this);
     ac->setToolTip(tr("Open a new tab"));
     ac->setText(tr("New &tab"));
     ac->setShortcut(tr("Ctrl+T"));
-    QAction* newTabAction = ac;
+    auto* newTabAction = ac;
 
     connect(newTabAction, SIGNAL(triggered(bool)),
             folderPanel_, SLOT(slotNewTab(bool)));
@@ -340,7 +337,7 @@ void MvQFileBrowser::setupFileActions()
 
     MvQMainWindow::MenuType menuType = MvQMainWindow::FileMenu;
 
-    QAction* sep = new QAction(this);
+    auto* sep = new QAction(this);
     sep->setSeparator(true);
 
     menuItems_[menuType].push_back(new MvQMenuItem(newTabAction, MvQMenuItem::MenuTarget));
@@ -461,7 +458,7 @@ void MvQFileBrowser::setupNavigateActions()
     connect(breadcrumbs_, SIGNAL(commandRequested(QString, QString)),
             folderPanel_, SLOT(slotPathCommand(QString, QString)));
 
-    QAction* sep = new QAction(this);
+    auto* sep = new QAction(this);
     sep->setSeparator(true);
 
     MvQMainWindow::MenuType menuType = MvQMainWindow::NavigateMenu;
@@ -516,7 +513,7 @@ void MvQFileBrowser::setupViewActions()
 
     QList<QAction*> viewModeLst;
 
-    QMenu* viewModeMenu = new QMenu(this);
+    auto* viewModeMenu = new QMenu(this);
     viewModeMenu->setObjectName(QString::fromUtf8("viewModeSubMenu"));
     viewModeMenu->setTitle(tr("&View mode"));
 
@@ -659,7 +656,7 @@ void MvQFileBrowser::setupViewActions()
             this, SLOT(slotClosePreview()));
 
     connect(actionPreview_, SIGNAL(toggled(bool)),
-           previewPanel_, SLOT(setVisible(bool)));
+            previewPanel_, SLOT(setVisible(bool)));
 
     //-------------------------------
     // Bottom part
@@ -693,9 +690,9 @@ void MvQFileBrowser::setupViewActions()
     // Icon resize
     //-------------------------
 
-    const vector<int>& sVec = MvQIconProvider::sizes();
-    for (vector<int>::const_iterator it = sVec.begin(); it != sVec.end(); it++) {
-        iconSizes_ << *it;
+    const std::vector<int>& sVec = MvQIconProvider::sizes();
+    for (int it : sVec) {
+        iconSizes_ << it;
     }
 
     action = new QAction(this);
@@ -757,16 +754,16 @@ void MvQFileBrowser::setupViewActions()
     connect(actionRevertViewToDefault_, SIGNAL(triggered()),
             this, SLOT(slotRevertViewToDefault()));
 
-    QAction* sep = new QAction(this);
+    auto* sep = new QAction(this);
     sep->setSeparator(true);
 
-    QAction* sep1 = new QAction(this);
+    auto* sep1 = new QAction(this);
     sep1->setSeparator(true);
 
-    QAction* sep2 = new QAction(this);
+    auto* sep2 = new QAction(this);
     sep2->setSeparator(true);
 
-    QAction* sep3 = new QAction(this);
+    auto* sep3 = new QAction(this);
     sep3->setSeparator(true);
 
     //Build menuitems
@@ -802,7 +799,7 @@ void MvQFileBrowser::setupViewActions()
     menuItems_[menuType].push_back(new MvQMenuItem(sep3, MvQMenuItem::MenuTarget));
 
     if (sidebarAg_->actions().count() > 1) {
-        QMenu* sidebarMenu = new QMenu(this);
+        auto* sidebarMenu = new QMenu(this);
         sidebarMenu->setObjectName(QString::fromUtf8("sidebarSubMenu"));
         sidebarMenu->setTitle(tr("Side&bar"));
 
@@ -833,7 +830,7 @@ void MvQFileBrowser::setupViewActions()
 
 void MvQFileBrowser::setupToolsActions()
 {
-    QAction* actionLog = new QAction(this);
+    auto* actionLog = new QAction(this);
     actionLog->setIcon(QPixmap(":/desktop/log.svg"));
     actionLog->setToolTip(tr("Log"));
     actionLog->setText(tr("Log..."));
@@ -845,7 +842,7 @@ void MvQFileBrowser::setupToolsActions()
     Tools::make(lst, this);
 
     //Preferences
-    QAction* actionPref = new QAction(this);
+    auto* actionPref = new QAction(this);
     actionPref->setIcon(QPixmap(":/desktop/cogwheel.svg"));
     actionPref->setToolTip(tr("Preferences"));
     actionPref->setText(tr("Preferences..."));
@@ -854,7 +851,7 @@ void MvQFileBrowser::setupToolsActions()
             this, SLOT(slotPreferences()));
 
     //Icon filter
-    QAction* actionFilter = new QAction(this);
+    auto* actionFilter = new QAction(this);
     actionFilter->setIcon(QPixmap(":/desktop/filter.svg"));
     actionFilter->setToolTip(tr("Show icon filter bar"));
     actionFilter->setText(tr("Icon filter bar"));
@@ -869,7 +866,7 @@ void MvQFileBrowser::setupToolsActions()
             actionFilter, SLOT(toggle()));
 
 
-    QAction* actionFilterNext = new QAction(this);
+    auto* actionFilterNext = new QAction(this);
     actionFilterNext->setIcon(QPixmap(":/desktop/arrow_down.svg"));
     actionFilterNext->setToolTip(tr("Show next filtered icon"));
     actionFilterNext->setText(tr("Filter show next"));
@@ -879,7 +876,7 @@ void MvQFileBrowser::setupToolsActions()
     connect(actionFilterNext, SIGNAL(triggered()),
             searchPanel_, SLOT(slotFindNext()));
 
-    QAction* actionFilterPrev = new QAction(this);
+    auto* actionFilterPrev = new QAction(this);
     actionFilterPrev->setIcon(QPixmap(":/desktop/arrow_up.svg"));
     actionFilterPrev->setToolTip(tr("Show previous filtered icon"));
     actionFilterPrev->setText(tr("Filter show previous"));
@@ -893,7 +890,7 @@ void MvQFileBrowser::setupToolsActions()
             actionFilterPrev, SLOT(setEnabled(bool)));
 
     //Find
-    QAction* actionFind = new QAction(this);
+    auto* actionFind = new QAction(this);
     actionFind->setIcon(QPixmap(":/desktop/search.svg"));
     actionFind->setToolTip(tr("Search icons"));
     actionFind->setText(tr("Search icons..."));
@@ -917,7 +914,7 @@ void MvQFileBrowser::setupToolsActions()
 
     menuItems_[menuType].push_back(new MvQMenuItem(actionLog, MvQMenuItem::MenuTarget));
 
-    QAction* sep = new QAction(this);
+    auto* sep = new QAction(this);
     sep->setSeparator(true);
     menuItems_[menuType].push_back(new MvQMenuItem(sep, MvQMenuItem::MenuTarget));
 
@@ -925,7 +922,7 @@ void MvQFileBrowser::setupToolsActions()
     menuItems_[menuType].push_back(new MvQMenuItem(actionFilterNext, MvQMenuItem::MenuTarget));
     menuItems_[menuType].push_back(new MvQMenuItem(actionFilterPrev, MvQMenuItem::MenuTarget));
 
-    QAction* sep1 = new QAction(this);
+    auto* sep1 = new QAction(this);
     sep1->setSeparator(true);
     menuItems_[menuType].push_back(new MvQMenuItem(sep1, MvQMenuItem::MenuTarget));
 
@@ -939,7 +936,7 @@ void MvQFileBrowser::setupToolsActions()
         menuItems_[menuType].push_back(new MvQMenuItem(ac, MvQMenuItem::MenuTarget));
     }
 
-    QAction* sep2 = new QAction(this);
+    auto* sep2 = new QAction(this);
     sep2->setSeparator(true);
     menuItems_[menuType].push_back(new MvQMenuItem(sep2, MvQMenuItem::MenuTarget));
 
@@ -949,7 +946,7 @@ void MvQFileBrowser::setupToolsActions()
 void MvQFileBrowser::setupHelpActions()
 {
     // About
-    QAction* actionAbout = new QAction(this);
+    auto* actionAbout = new QAction(this);
     actionAbout->setObjectName(QString::fromUtf8("actionAbout"));
     actionAbout->setText(tr("&About ") + "Desktop");
 
@@ -963,7 +960,7 @@ void MvQFileBrowser::setupHelpActions()
 void MvQFileBrowser::setupIconSizeWidget()
 {
     //Descrease size
-    QToolButton* tb = new QToolButton(this);
+    auto* tb = new QToolButton(this);
     tb->setDefaultAction(actionIconSizeDown_);
     tb->setAutoRaise(true);
     statusBar()->addPermanentWidget(tb);
@@ -1031,7 +1028,8 @@ void MvQFileBrowser::updateWindowTitle()
                 txt += " - " + QString::fromStdString(f->parent()->fullName());
             }
             txt += " - Metview";
-        } else {
+        }
+        else {
             txt = "Metview";
         }
     }
@@ -1541,7 +1539,7 @@ MvQFileBrowser* MvQFileBrowser::makeBrowser(QString fullName)
 
 MvQFileBrowser* MvQFileBrowser::makeBrowser(QStringList pathLst)
 {
-    MvQFileBrowser* browser = new MvQFileBrowser(pathLst);
+    auto* browser = new MvQFileBrowser(pathLst);
 
     browsers_ << browser;
 
@@ -1671,7 +1669,7 @@ void MvQFileBrowser::save(MvQFileBrowser* topBrowser)
     }
 
     QSettings settings(MVQ_QSETTINGS_DEFAULT_ARGS, "MV4-Desktop");
-    std::cout << "MvQFileBrowser::save settings path is: " << settings.fileName().toStdString() << endl;
+    std::cout << "MvQFileBrowser::save settings path is: " << settings.fileName().toStdString() << std::endl;
 
     //We have to clear it not to remember all the previous windows
     settings.clear();
