@@ -7,15 +7,13 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQFileWatcher_H
-#define MvQFileWatcher_H
+#pragma once
 
 #include <QObject>
 
 #include <stdio.h>
 #include <string>
 
-using namespace std;
 
 class QFileSystemWatcher;
 
@@ -27,7 +25,7 @@ public:
     MvQFileWatcher();
     virtual ~MvQFileWatcher();
 
-    void start(FILE*, const string&);
+    void start(FILE*, const std::string&);
     void stop();
 
 signals:
@@ -45,5 +43,3 @@ private:
     FILE* file_;
     QFileSystemWatcher* watcher_;
 };
-
-#endif
