@@ -33,11 +33,11 @@ MvQFolderDrawerPanel::MvQFolderDrawerPanel(QWidget* parent) :
     if (parentFolder_) {
         parentFolder_->scan();
 
-        const map<string, IconObjectH>& kids = parentFolder_->kids();
-        for (map<string, IconObjectH>::const_iterator it = kids.begin(); it != kids.end(); it++) {
-            IconObject* obj = it->second;
-            if (it->second->isFolder()) {
-                Folder* folder = static_cast<Folder*>(obj);
+        const std::map<std::string, IconObjectH>& kids = parentFolder_->kids();
+        for (const auto& kid : kids) {
+            IconObject* obj = kid.second;
+            if (kid.second->isFolder()) {
+                auto* folder = static_cast<Folder*>(obj);
                 createDrawer(folder);
             }
         }
@@ -46,7 +46,7 @@ MvQFolderDrawerPanel::MvQFolderDrawerPanel(QWidget* parent) :
     }
 
     //Add cornerbutton
-    QToolButton* tb = new QToolButton(this);
+    auto* tb = new QToolButton(this);
     tb->setIcon(QPixmap(QString::fromUtf8(":/desktop/add_drawer.svg")));
     tb->setAutoRaise(true);
     tb->setToolTip(tr("Add new drawer"));
@@ -84,10 +84,10 @@ void MvQFolderDrawerPanel::setIconPositions()
 
 void MvQFolderDrawerPanel::createDrawer(Folder* folder)
 {
-    MvQFolderModel* model = new MvQFolderModel(this);
+    auto* model = new MvQFolderModel(this);
     model->setFolder(folder);
 
-    MvQDrawerView* drawer = new MvQDrawerView(model);
+    auto* drawer = new MvQDrawerView(model);
     MvQDrawerPanel::addDrawer(drawer, QString::fromStdString(folder->name()));
     //drawer->setHelper(true);
 
@@ -107,7 +107,7 @@ void MvQFolderDrawerPanel::createDrawer(Folder* folder)
 
 void MvQFolderDrawerPanel::slotCreateDrawer(bool)
 {
-    string offeredName = getUniqueName("Drawer");
+    std::string offeredName = getUniqueName("Drawer");
 
     bool ok;
     QString text = QInputDialog::getText(0,
@@ -118,7 +118,7 @@ void MvQFolderDrawerPanel::slotCreateDrawer(bool)
     if (!ok || text.isEmpty())
         return;
 
-    string name = text.toStdString();
+    std::string name = text.toStdString();
 
     parentFolder_ = Folder::folder("stationary");
     if (!parentFolder_)
@@ -140,8 +140,8 @@ void MvQFolderDrawerPanel::renameDrawer(int index)
                                          drawerText(index), &ok);
 
     if (ok && !text.isEmpty()) {
-        Folder* folder = indexToFolder(index);
-        string name    = getUniqueName(text.toStdString());
+        Folder* folder   = indexToFolder(index);
+        std::string name = getUniqueName(text.toStdString());
         if (folder)
             folder->rename(name);
     }
@@ -169,16 +169,16 @@ void MvQFolderDrawerPanel::deleteDrawer(int index)
 
 void MvQFolderDrawerPanel::arrived(IconObject* obj)
 {
-    Folder* folder = static_cast<Folder*>(obj);
+    auto* folder = static_cast<Folder*>(obj);
     if (!folder)
         return;
 
     createDrawer(folder);
 }
 
-void MvQFolderDrawerPanel::renamed(IconObject* obj, const string&)
+void MvQFolderDrawerPanel::renamed(IconObject* obj, const std::string&)
 {
-    Folder* folder = static_cast<Folder*>(obj);
+    auto* folder = static_cast<Folder*>(obj);
     if (!folder)
         return;
 
@@ -187,7 +187,7 @@ void MvQFolderDrawerPanel::renamed(IconObject* obj, const string&)
 
 void MvQFolderDrawerPanel::gone(IconObject* obj)
 {
-    Folder* folder = static_cast<Folder*>(obj);
+    auto* folder = static_cast<Folder*>(obj);
     if (!folder)
         return;
 
@@ -218,7 +218,7 @@ void MvQFolderDrawerPanel::command(QString name, int index)
 void MvQFolderDrawerPanel::slotCommandFromView(QString name, QPoint /*pos*/)
 {
     if (name == "deleteDrawer" || name == "renameDrawer") {
-        MvQDrawerView* view = static_cast<MvQDrawerView*>(sender());
+        auto* view = static_cast<MvQDrawerView*>(sender());
         if (!view)
             return;
 
@@ -229,19 +229,19 @@ void MvQFolderDrawerPanel::slotCommandFromView(QString name, QPoint /*pos*/)
 }
 
 
-string MvQFolderDrawerPanel::getUniqueName(const string& name)
+std::string MvQFolderDrawerPanel::getUniqueName(const std::string& name)
 {
     Folder* folder = Folder::folder("stationary");
     if (folder) {
         return folder->uniqueName(name);
     }
-    return string(name);
+    return std::string(name);
 }
 
 int MvQFolderDrawerPanel::folderToIndex(Folder* f)
 {
     for (int i = 0; i < drawerCount(); i++) {
-        MvQDrawerView* view = static_cast<MvQDrawerView*>(drawer(i));
+        auto* view = static_cast<MvQDrawerView*>(drawer(i));
 
         if (view->currentFolder() == f)
             return i;
@@ -252,12 +252,12 @@ int MvQFolderDrawerPanel::folderToIndex(Folder* f)
 
 Folder* MvQFolderDrawerPanel::indexToFolder(int index)
 {
-    MvQDrawerView* view = static_cast<MvQDrawerView*>(drawer(index));
+    auto* view = static_cast<MvQDrawerView*>(drawer(index));
     return (view) ? view->currentFolder() : 0;
 }
 
 MvQFolderModel* MvQFolderDrawerPanel::indexToModel(int index)
 {
-    MvQDrawerView* view = static_cast<MvQDrawerView*>(drawer(index));
+    auto* view = static_cast<MvQDrawerView*>(drawer(index));
     return (view) ? view->folderModel() : 0;
 }
