@@ -7,16 +7,13 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQFolderDrawerPanel_H
-#define MvQFolderDrawerPanel_H
+#pragma once
 
 #include "MvQDrawerPanel.h"
 #include "FolderObserver.h"
 
 #include <string>
 
-using namespace std;
-
 class MvQContextItemSet;
 class MvQFolderModel;
 
@@ -52,7 +49,7 @@ protected:
     void gone(IconObject*);
     void position(IconObject*, int, int) {}
 
-    string getUniqueName(const string&);
+    std::string getUniqueName(const std::string&);
     int folderToIndex(Folder*);
     Folder* indexToFolder(int);
     MvQFolderModel* indexToModel(int);
@@ -60,5 +57,3 @@ protected:
 
     Folder* parentFolder_;
 };
-
-#endif
