@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQFolderHistory_H
-#define MvQFolderHistory_H
+#pragma once
 
 #include <QList>
 #include <QObject>
@@ -53,5 +52,3 @@ protected:
     static QList<MvQFolderHistory*> fhLst_;
     static QStringList items_;
 };
-
-#endif
\ No newline at end of file
