@@ -282,7 +282,7 @@ QPoint MvQSimpleIconItemProperty::position(QString, QPoint refPos)
     return refPos;
 }
 
-QPoint MvQSimpleIconItemProperty::positionFromHotSpot(QString name, QPoint pos, QPointF hotSpotAtPos)
+QPoint MvQSimpleIconItemProperty::positionFromHotSpot(QString /*name*/, QPoint pos, QPointF hotSpotAtPos)
 {
     //hotSpotAtPos is the relative position inside the icon pixmap
     QPoint d(iconSize_ * hotSpotAtPos.x(), iconSize_ * hotSpotAtPos.y());
@@ -455,9 +455,9 @@ QPoint MvQDetailedIconItemProperty::storedPosition(QPoint viewRefPos)
     return viewRefPos;
 }
 
-QPoint MvQDetailedIconItemProperty::referencePosition(IconObject* obj)
+QPoint MvQDetailedIconItemProperty::referencePosition(IconObject*)
 {
-    return QPoint();
+    return {};
 }
 
 QPoint MvQDetailedIconItemProperty::referencePositionFromStored(QPoint storedPos)
@@ -474,7 +474,7 @@ QPoint MvQDetailedIconItemProperty::referencePositionFromStored(QPoint storedPos
 
 MvQFolderItemProperty::MvQFolderItemProperty() :
     viewMode_(Desktop::IconViewMode),
-    current_(0)
+    current_(nullptr)
 
 {
     prop_[Desktop::IconViewMode]     = new MvQClassicIconItemProperty;
