@@ -56,10 +56,10 @@ MvQFolderModel::MvQFolderModel(int iconSize, QObject* parent) :
 
 void MvQFolderModel::init()
 {
-    searchData_      = 0;
-    folder_          = 0,
+    searchData_      = nullptr;
+    folder_          = nullptr,
     initialScanIsOn_ = false,
-    lastArrived_     = 0;
+    lastArrived_     = nullptr;
 
     itemProp_ = new MvQFolderItemProperty();
 
@@ -114,7 +114,7 @@ bool MvQFolderModel::setFolder(Folder* folder, int iconSize)
     }
 
     folder_      = folder;
-    lastArrived_ = 0;
+    lastArrived_ = nullptr;
 
     if (folder_) {
         //We are not an observer at the moment so arrived() will
@@ -315,7 +315,7 @@ bool MvQFolderModel::setData(const QModelIndex& index, const QVariant& value, in
     IconObject* obj = objectFromIndex(index);
 
     if (role == Qt::EditRole) {
-        string new_name = value.toString().toStdString();
+        std::string new_name = value.toString().toStdString();
 
         if (obj && obj->name() != new_name) {
             QString oriName = QString::fromStdString(obj->name());
@@ -365,7 +365,7 @@ QModelIndex MvQFolderModel::index(int row, int column, const QModelIndex& /*pare
         return QModelIndex();
     }
 
-    return createIndex(row, column, (void*)0);
+    return createIndex(row, column, (void*)nullptr);
 }
 
 
@@ -392,13 +392,13 @@ Qt::ItemFlags MvQFolderModel::flags(const QModelIndex& index) const
 IconObject* MvQFolderModel::objectFromIndex(const QModelIndex& index) const
 {
     if (!index.isValid()) {
-        return 0;
+        return nullptr;
     }
 
     if (index.row() >= 0 && index.row() < items_.count())
         return items_.at(index.row());
 
-    return 0;
+    return nullptr;
 }
 
 QModelIndex MvQFolderModel::indexFromObject(IconObject* obj)
@@ -407,7 +407,7 @@ QModelIndex MvQFolderModel::indexFromObject(IconObject* obj)
         return QModelIndex();
 
     int i = items_.indexOf(obj);
-    return (i >= 0) ? createIndex(i, 0, (void*)0) : QModelIndex();
+    return (i >= 0) ? createIndex(i, 0, (void*)nullptr) : QModelIndex();
 }
 
 //Should be called between beginResetModel() and endResetModel() !!
@@ -417,10 +417,10 @@ void MvQFolderModel::loadItems()
     if (!folder_)
         return;
 
-    const map<string, IconObjectH>& kids = folder_->kids();
-    for (map<string, IconObjectH>::const_iterator it = kids.begin(); it != kids.end(); it++)
-        if (isAccepted(it->second)) {
-            items_ << it->second;
+    const std::map<std::string, IconObjectH>& kids = folder_->kids();
+    for (const auto& kid : kids)
+        if (isAccepted(kid.second)) {
+            items_ << kid.second;
         }
 }
 
@@ -430,7 +430,7 @@ void MvQFolderModel::loadItems()
 //
 //-------------------------------------
 
-void MvQFolderModel::setAcceptedClasses(const vector<string>& c)
+void MvQFolderModel::setAcceptedClasses(const std::vector<std::string>& c)
 {
     beginResetModel();
     classes_ = c;
@@ -441,8 +441,8 @@ void MvQFolderModel::setAcceptedClasses(const vector<string>& c)
 bool MvQFolderModel::isAccepted(const IconClass& kind) const
 {
     if (classes_.size() > 0) {
-        for (vector<string>::const_iterator it = classes_.begin(); it != classes_.end(); ++it) {
-            if (kind.canBecome(IconClass::find(*it)))
+        for (const auto& classe : classes_) {
+            if (kind.canBecome(IconClass::find(classe)))
                 return true;
         }
         return false;
@@ -514,7 +514,7 @@ void MvQFolderModel::setIconSize(int size)
     emit iconSizeChanged();
 }
 
-void MvQFolderModel::setPositionHint(const string& cn, int x, int y)
+void MvQFolderModel::setPositionHint(const std::string& cn, int x, int y)
 {
     posHint_.className = cn;
     posHint_.x         = x;
@@ -571,7 +571,7 @@ void MvQFolderModel::position(IconObject*, int, int)
 {
 }
 
-void MvQFolderModel::renamed(IconObject* obj, const string& oriName)
+void MvQFolderModel::renamed(IconObject* obj, const std::string& oriName)
 {
     if (isAccepted(obj)) {
         //Update saerch data
@@ -709,7 +709,7 @@ bool MvQFolderModel::hasSearchData() const
     }
 
     if (searchData_->owner() != this) {
-        searchData_ = 0;
+        searchData_ = nullptr;
         return false;
     }
 
