@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQFolderModel_H
-#define MvQFolderModel_H
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QAbstractListModel>
@@ -42,7 +41,7 @@ public:
         x         = 0;
         y         = 0;
     }
-    string className;
+    std::string className;
     int x;
     int y;
 };
@@ -97,7 +96,7 @@ public:
     void arrived(IconObject*);
     void gone(IconObject*);
     void position(IconObject*, int, int);
-    void renamed(IconObject*, const string&);
+    void renamed(IconObject*, const std::string&);
 
     void waiting(IconObject*);
     void error(IconObject*);
@@ -112,9 +111,9 @@ public:
     int iconSize() const;
     MvQFolderItemProperty* itemProp() const { return itemProp_; }
 
-    void setAcceptedClasses(const vector<string>&);
+    void setAcceptedClasses(const std::vector<std::string>&);
     bool isAccepted(const IconClass&) const;
-    void setPositionHint(const string&, int, int);
+    void setPositionHint(const std::string&, int, int);
 
     void setSearchData(FolderSearchData*);
     void removeSearchData();
@@ -138,7 +137,7 @@ protected:
     Folder* folder_;
     QList<IconObject*> items_;
     bool initialScanIsOn_;
-    vector<string> classes_;
+    std::vector<std::string> classes_;
     IconObject* lastArrived_;
     MvQFolderItemProperty* itemProp_;
     PositionHint posHint_;
@@ -171,5 +170,3 @@ protected:
     std::string type_;
     QList<IconObject*> matchLst_;
 };
-
-#endif
