@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQFolderNavigation_H
-#define MvQFolderNavigation_H
+#pragma once
 
 #include <QDebug>
 #include <QStringList>
@@ -20,7 +19,7 @@ public:
         pos_(-1), maxSize_(300) {}
 
     void clear();
-    bool isEmpty() const {return folders_.isEmpty();}
+    bool isEmpty() const { return folders_.isEmpty(); }
     bool hasNext();
     bool hasPrev();
     QString next();
@@ -38,6 +37,3 @@ protected:
     int pos_;
     int maxSize_;
 };
-
-
-#endif
