@@ -898,12 +898,15 @@ void MvQFolderPanel::slotPathCommand(QString name, QString path)
 {
     if (name == "openInTab") {
         addWidget(path);
-    }
-    else if (name == "openInWin") {
+    } else if (name == "openInWin") {
         MvQFileBrowser::openBrowser(path, this);
-    }
-    else if (name == "bookmark") {
+    } else if (name == "bookmark") {
         MvQBookmarks::addItem(path);
+    } else if (name == "copy_path") {
+        auto pathStr = path.toStdString();
+        if (Folder *f = Folder::folder(pathStr, false)) {
+            MvQ::toClipboard(QString::fromStdString(f->path().str()));
+        }
     }
     else if (name == "locate") {
     }
