@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQFolderPanel_H
-#define MvQFolderPanel_H
+#pragma once
 
 #include <QList>
 #include <QSettings>
@@ -36,7 +35,6 @@ class Folder;
 
 #include "IconObject.h"
 
-using namespace std;
 
 class MvQTabWidget : public QWidget
 {
@@ -65,7 +63,7 @@ public slots:
     void removeTab(int);
     void removeOtherTabs(int);
     void setCurrentIndex(int);
-    virtual void slotTabList() = 0;
+    virtual void slotTabList()    = 0;
     virtual void slotRecentTabs() = 0;
 
 private slots:
@@ -133,7 +131,7 @@ public:
     void addIconAction(QAction*);
     void addDesktopAction(QAction*);
     bool showIcon(IconObject*, bool addFolder);
-    void setPreviewPanel(PreviewPanel* p) {previewPanel_ = p;}
+    void setPreviewPanel(PreviewPanel* p) { previewPanel_ = p; }
 
     void writeSettings(QSettings&);
     void readSettings(QSettings&);
@@ -194,5 +192,3 @@ protected:
     MvQActionList desktopActions_;
     PreviewPanel* previewPanel_{nullptr};
 };
-
-#endif
