@@ -114,12 +114,11 @@ IconObject* MvQFolderViewBase::itemInfo(const QModelIndex& index, IndexType inde
 void MvQFolderViewBase::handleDoubleClick(const QModelIndex& index)
 {
     IconObject* obj = folderModel_->objectFromIndex(filterModel_->mapToSource(index));
-    if (obj) {
+    if (obj && !obj->isBrokenLink()) {
         QString method = QString::fromStdString(obj->iconClass().defaultMethod()).toLower();
 
         if (obj->isFolder()) {
             iconCommand("open", obj);
-            return;
         }
         else if (!method.isEmpty()) {
             obj->command(method.toStdString());
