@@ -39,13 +39,13 @@ MvQFolderViewDelegate::MvQFolderViewDelegate(QWidget* parent) :
 
 void MvQFolderViewDelegate::setColours()
 {
-    QString group  = "folderview";
-    editPen_     = QPen(MvQTheme::colour(group, "edit_pen"));
-    editBrush_   = MvQTheme::brush(group, "edit_brush");
-    hoverPen_    = QPen(MvQTheme::colour(group, "hover_pen"));
-    hoverBrush_  = MvQTheme::brush(group, "hover_brush");
-    selectPen_   = QPen(MvQTheme::colour(group, "select_pen"));
-    selectBrush_ = MvQTheme::brush(group, "select_brush");
+    QString group = "folderview";
+    editPen_      = QPen(MvQTheme::colour(group, "edit_pen"));
+    editBrush_    = MvQTheme::brush(group, "edit_brush");
+    hoverPen_     = QPen(MvQTheme::colour(group, "hover_pen"));
+    hoverBrush_   = MvQTheme::brush(group, "hover_brush");
+    selectPen_    = QPen(MvQTheme::colour(group, "select_pen"));
+    selectBrush_  = MvQTheme::brush(group, "select_brush");
 }
 
 void MvQFolderViewDelegate::blink(const QModelIndex& index)
@@ -77,7 +77,7 @@ QWidget* MvQFolderViewDelegate::createEditor(QWidget* parent, const QStyleOption
                                              const QModelIndex& index) const
 {
     if (index.column() == 0) {
-        QLineEdit* le = new QLineEdit(parent);
+        auto* le = new QLineEdit(parent);
         //timeEdit->setDisplayFormat("mm:ss");
 
         //connect(le,SIGNAL(editingFinished()),
@@ -95,7 +95,7 @@ QWidget* MvQFolderViewDelegate::createEditor(QWidget* parent, const QStyleOption
 void MvQFolderViewDelegate::setEditorData(QWidget* editor, const QModelIndex& index) const
 {
     if (index.column() == 0) {
-        QLineEdit* le = qobject_cast<QLineEdit*>(editor);
+        auto* le = qobject_cast<QLineEdit*>(editor);
         le->setObjectName("iconLabel");
         QString txt = index.model()->data(index, Qt::EditRole).toString();
         le->setText(txt);
@@ -120,7 +120,7 @@ void MvQFolderViewDelegate::setModelData(QWidget* editor,
                                          const QModelIndex& index) const
 {
     if (index.column() == 0) {
-        QLineEdit* le = qobject_cast<QLineEdit*>(editor);
+        auto* le = qobject_cast<QLineEdit*>(editor);
         model->setData(index, le->text());
     }
     else {
@@ -130,7 +130,7 @@ void MvQFolderViewDelegate::setModelData(QWidget* editor,
 
 void MvQFolderViewDelegate::slotInitEditor(int /*oldPos*/, int /*newPos*/)
 {
-    QLineEdit* le = qobject_cast<QLineEdit*>(sender());
+    auto* le = qobject_cast<QLineEdit*>(sender());
 
     le->setCursorPosition(0);
     le->deselect();
@@ -171,8 +171,8 @@ void MvQIconDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
         const QStyle* style   = vopt.widget ? vopt.widget->style() : QApplication::style();
         const QWidget* widget = vopt.widget;
 
-        QString txt    = index.data(Qt::DisplayRole).toString();
-        QPixmap pixmap = index.data(Qt::DecorationRole).value<QPixmap>();
+        QString txt = index.data(Qt::DisplayRole).toString();
+        auto pixmap = index.data(Qt::DecorationRole).value<QPixmap>();
 
         //Save painter state
         painter->save();
@@ -212,7 +212,7 @@ void MvQIconDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
         painter->drawPixmap(iconRect, pixmap);
 
         //Text rect
-        QFont font = index.data(Qt::FontRole).value<QFont>();
+        auto font = index.data(Qt::FontRole).value<QFont>();
         painter->setFont(font);
 
         if (blink)
@@ -277,29 +277,29 @@ void MvQDetailedViewDelegate::paint(QPainter* painter, const QStyleOptionViewIte
             }
             else if (index.data(MvQFolderModel::EditorRole).toBool()) {
                 painter->fillRect(fillRect, editBrush_);
-//                painter->setPen(editPen_);
-//                painter->drawLine(fillRect.topLeft(), fillRect.topRight());
-//                painter->drawLine(fillRect.bottomLeft(), fillRect.bottomRight());
+                //                painter->setPen(editPen_);
+                //                painter->drawLine(fillRect.topLeft(), fillRect.topRight());
+                //                painter->drawLine(fillRect.bottomLeft(), fillRect.bottomRight());
             }
             else if (option.state & QStyle::State_Selected) {
                 //QRect fillRect=option.rect.adjusted(0,1,-1,-textRect.height()-1);
                 painter->fillRect(fillRect, selectBrush_);
-//                painter->setPen(selectPen_);
-//                painter->drawLine(fillRect.topLeft(), fillRect.topRight());
-//                painter->drawLine(fillRect.bottomLeft(), fillRect.bottomRight());
+                //                painter->setPen(selectPen_);
+                //                painter->drawLine(fillRect.topLeft(), fillRect.topRight());
+                //                painter->drawLine(fillRect.bottomLeft(), fillRect.bottomRight());
             }
             else if (option.state & QStyle::State_MouseOver) {
                 //QRect fillRect=option.rect.adjusted(0,1,-1,-1);
                 painter->fillRect(fillRect, hoverBrush_);
-//                painter->setPen(hoverPen_);
-//                painter->drawLine(fillRect.topLeft(), fillRect.topRight());
-//                painter->drawLine(fillRect.bottomLeft(), fillRect.bottomRight());
+                //                painter->setPen(hoverPen_);
+                //                painter->drawLine(fillRect.topLeft(), fillRect.topRight());
+                //                painter->drawLine(fillRect.bottomLeft(), fillRect.bottomRight());
             }
         }
 
         //Pixmap
         if (index.column() == 0) {
-            QPixmap pixmap = index.data(Qt::DecorationRole).value<QPixmap>();
+            auto pixmap    = index.data(Qt::DecorationRole).value<QPixmap>();
             QRect iconRect = style->subElementRect(QStyle::SE_ItemViewItemDecoration, &vopt, widget);
             //iconRect.adjust(2,2,-2,-2);
             painter->drawPixmap(iconRect, pixmap);
@@ -307,7 +307,7 @@ void MvQDetailedViewDelegate::paint(QPainter* painter, const QStyleOptionViewIte
 
 
         //Text rect
-        QFont font = index.data(Qt::FontRole).value<QFont>();
+        auto font = index.data(Qt::FontRole).value<QFont>();
         painter->setFont(font);
         if (blink)
             painter->setPen(Qt::white);
