@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQFolderViewDelegate_H
-#define MvQFolderViewDelegate_H
+#pragma once
 
 #include <QBrush>
 #include <QPen>
@@ -72,5 +71,3 @@ public:
                const QModelIndex& index) const;
     QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
 };
-
-#endif
\ No newline at end of file
