@@ -139,7 +139,7 @@ MvQFolderWatcher* MvQFolderWatcher::find(FolderPresenter* fp)
         if (item->folderPresenter() == fp)
             return item;
     }
-    return NULL;
+    return nullptr;
 }
 
 void MvQFolderWatcher::print()
