@@ -61,7 +61,7 @@ MvQFolderWidget::MvQFolderWidget(QString expectedFolderPath, MvQFolderHistory* f
     // Layout
     //-----------------------------
 
-    QVBoxLayout* mainLayout = new QVBoxLayout(this);
+    auto* mainLayout = new QVBoxLayout(this);
     mainLayout->setSpacing(0);
     mainLayout->setContentsMargins(1, 1, 1, 1);
 
@@ -77,14 +77,14 @@ MvQFolderWidget::MvQFolderWidget(QString expectedFolderPath, MvQFolderHistory* f
     views_ = new MvQFolderViewHandler(centralLayout_, folderModel_->itemProp());
 
     //Icon view
-    MvQIconFolderView* iconView = new MvQIconFolderView(folderModel_, iconActions, desktopActions, this);
+    auto* iconView = new MvQIconFolderView(folderModel_, iconActions, desktopActions, this);
     views_->add(Desktop::IconViewMode, iconView);
 
     //Simple view - the same object as icon view!!
     views_->add(Desktop::SimpleViewMode, iconView);
 
     //Detailed view
-    MvQDetailedFolderView* detailedView = new MvQDetailedFolderView(folderModel_, iconActions, desktopActions, this);
+    auto* detailedView = new MvQDetailedFolderView(folderModel_, iconActions, desktopActions, this);
     views_->add(Desktop::DetailedViewMode, detailedView);
 
     foreach (QWidget* v, views_->uniqueWidgets()) {
