@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQFolderWidget_H
-#define MvQFolderWidget_H
+#pragma once
 
 #include <QModelIndex>
 #include <QSettings>
@@ -32,8 +31,6 @@ class MvQFolderNavigation;
 class MvQFolderViewBase;
 class MvQFolderViewHandler;
 
-using namespace std;
-
 
 class MvQFolderWidget : public QWidget, public FolderPresenter
 {
@@ -105,5 +102,3 @@ private:
     //does not exists
     QString expectedFolderPath_;
 };
-
-#endif
