@@ -8,8 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 
-#ifndef MvQGeoHelp_H
-#define MvQGeoHelp_H
+#pragma once
 
 #include "MvQRequestPanelHelp.h"
 #include "MvIconParameter.h"
@@ -26,7 +25,7 @@ class MvQGeoHelp : public MvQRequestPanelHelp,
 {
 public:
     MvQGeoHelp(RequestPanel& owner, const MvIconParameter& param);
-    ~MvQGeoHelp(){};
+    ~MvQGeoHelp() = default;
 
     void start();
     bool dialog() { return true; }
@@ -35,16 +34,14 @@ public:
     QWidget* widget() { return 0; }
 
 protected:
-    virtual void refresh(const vector<string>&);
+    virtual void refresh(const std::vector<std::string>&);
     virtual long flags() { return 9; }
     virtual void set(Request&);
 
     void reply(const Request&, int);
     void progress(const Request&);
-    void message(const string&);
+    void message(const std::string&);
     void message(const Request&);
 
     Request request_;
 };
-
-#endif
\ No newline at end of file
