@@ -29,6 +29,7 @@
 #include "MvQMethods.h"
 #include "MvQTheme.h"
 
+#include <QtGlobal>
 #include <QApplication>
 #include <QClipboard>
 #include <QDrag>
@@ -1033,7 +1034,11 @@ void MvQIconFolderView::mousePressEvent(QMouseEvent* event)
             foreach (QObject* chObj, editor_->editor()->children()) {
                 if (chObj->isWidgetType()) {
                     if (auto* w = static_cast<QWidget*>(chObj)) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+                        QPoint posInW = w->mapFromGlobal(event->globalPosition().toPoint());
+#else
                         QPoint posInW = w->mapFromGlobal(event->globalPos());
+#endif
                         if (w->rect().contains(posInW)) {
                             outside = false;
                             break;
