@@ -8,8 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 
-#ifndef MvQIconHelp_H
-#define MvQIconHelp_H
+#pragma once
 
 #include "MvQRequestPanelHelp.h"
 #include "MvIconParameter.h"
@@ -27,16 +26,16 @@ class MvQIconHelp : public MvQRequestPanelHelp
 
 public:
     MvQIconHelp(RequestPanel& owner, const MvIconParameter& param);
-    ~MvQIconHelp(){};
+    ~MvQIconHelp() = default;
 
-    void start(){};
+    void start() {}
     bool dialog() { return false; }
     QWidget* widget();
 
 public slots:
 
 protected:
-    virtual void refresh(const vector<string>&);
+    virtual void refresh(const std::vector<std::string>&);
     virtual long flags() { return 9; }
     virtual void set(Request&) {}
     void fill(const MvIconParameter&);
@@ -46,5 +45,3 @@ protected:
     QWidget* holderW_;
     bool multiple_;
 };
-
-#endif
