@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQIconHelpView_H
-#define MvQIconHelpView_H
+#pragma once
 
 #include "MvQIconStripView.h"
 
@@ -23,5 +22,3 @@ public:
 protected:
     MvQContextItemSet* cmSet();
 };
-
-#endif
\ No newline at end of file
