@@ -7,13 +7,11 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQIconObjectModel_H
-#define MvQIconObjectModel_H
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QString>
 
-using namespace std;
 
 class MvQIconObjectModel : public QAbstractItemModel
 {
@@ -28,6 +26,3 @@ public:
     QVariant headerData(const int section, const Qt::Orientation orient, const int role) const;
     void update();
 };
-
-
-#endif
