@@ -34,9 +34,9 @@ static MvQIcon embeddedIcon(":/desktop/embedded.svg");
 static MvQIcon homeIcon(":/desktop/home.svg");
 
 int MvQIconProvider::defaultSize_ = 32;
-std::map<string, MvQIcon*> MvQIconProvider::icons_;
-std::map<string, Folder*> MvQIconProvider::folders_;
-vector<int> MvQIconProvider::sizes_(sizeArr, sizeArr + sizeof(sizeArr) / sizeof(sizeArr[0]));
+std::map<std::string, MvQIcon*> MvQIconProvider::icons_;
+std::map<std::string, Folder*> MvQIconProvider::folders_;
+std::vector<int> MvQIconProvider::sizes_(sizeArr, sizeArr + sizeof(sizeArr) / sizeof(sizeArr[0]));
 
 //===========================================
 //
@@ -51,7 +51,7 @@ MvQIcon::MvQIcon(QString path) :
 
 QPixmap MvQIcon::pixmap(int size)
 {
-    map<int, QPixmap>::iterator it = pixmaps_.find(size);
+    auto it = pixmaps_.find(size);
     if (it != pixmaps_.end())
         return it->second;
     else {
@@ -169,7 +169,7 @@ MvQUnknownIcon::MvQUnknownIcon(QString n) :
 //calls this a fallback!!!
 QPixmap MvQUnknownIcon::pixmap(int size)
 {
-    map<int, QPixmap>::iterator it = pixmaps_.find(size);
+    auto it = pixmaps_.find(size);
     if (it != pixmaps_.end())
         return it->second;
     else {
@@ -209,30 +209,28 @@ QPixmap MvQUnknownIcon::pixmap(int size)
 //
 //===========================================
 
-MvQIconProvider::MvQIconProvider()
-{
-}
+MvQIconProvider::MvQIconProvider() = default;
 
 MvQIcon* MvQIconProvider::icon(const IconClass& kind)
 {
-    map<string, MvQIcon*>::iterator it = icons_.find(kind.name());
+    auto it = icons_.find(kind.name());
     if (it != icons_.end())
         return it->second;
 
-    MvQIcon* p = new MvQIcon(MvQTheme::icIconFile(kind.pixmap()));
+    auto* p             = new MvQIcon(MvQTheme::icIconFile(kind.pixmap()));
     icons_[kind.name()] = p;
     return p;
 }
 
 MvQIcon* MvQIconProvider::icon(const std::string& kind)
 {
-    map<string, MvQIcon*>::iterator it = icons_.find(kind);
+    auto it = icons_.find(kind);
     if (it != icons_.end())
         return it->second;
 
     if (IconClass::isValid(kind)) {
         const IconClass& ic = IconClass::find(kind);
-        MvQIcon* p          = new MvQIcon(MvQTheme::icIconFile(ic.pixmap()));
+        auto* p             = new MvQIcon(MvQTheme::icIconFile(ic.pixmap()));
         icons_[kind]        = p;
         return p;
     }
@@ -259,12 +257,12 @@ QPixmap MvQIconProvider::greyedOutPixmap(IconObject* obj, int size)
     return (obj) ? icon(obj->iconClass())->greyedOutPixmap(obj, size) : unknownIcon.pixmap(size);
 }
 
-QPixmap MvQIconProvider::bookmarkPixmap(string fullName, int size)
+QPixmap MvQIconProvider::bookmarkPixmap(std::string fullName, int size)
 {
     if (fullName == "FOLDERGROUP")
         return bookmarkGroupIcon.pixmap(size);
 
-    std::map<string, Folder*>::iterator it = folders_.find(fullName);
+    auto it = folders_.find(fullName);
     if (it != folders_.end()) {
         if (it->second)
             return pixmap(it->second, size);
