@@ -7,20 +7,15 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQIconProvider_H
-#define MvQIconProvider_H
-
-#include <QImage>
-#include <QMap>
-#include <QPixmap>
+#pragma once
 
 #include <map>
 #include <vector>
 #include <string>
 
-using std::map;
-using std::string;
-using std::vector;
+#include <QImage>
+#include <QMap>
+#include <QPixmap>
 
 class Folder;
 class IconClass;
@@ -59,22 +54,20 @@ public:
     static QPixmap pixmap(const std::string& type, int size);
     static QPixmap greyedOutPixmap(IconObject*, int);
 
-    static QPixmap bookmarkPixmap(string, int);
+    static QPixmap bookmarkPixmap(std::string, int);
     static QPixmap lockPixmap(int);
     static QPixmap warningPixmap(int);
     static QPixmap homePixmap(int);
 
     static int defaultSize() { return defaultSize_; }
-    static const vector<int>& sizes() { return sizes_; }
+    static const std::vector<int>& sizes() { return sizes_; }
 
 private:
     static MvQIcon* icon(const IconClass&);
     static MvQIcon* icon(const std::string& kind);
 
-    static vector<int> sizes_;
+    static std::vector<int> sizes_;
     static int defaultSize_;
-    static std::map<string, MvQIcon*> icons_;
-    static std::map<string, Folder*> folders_;
+    static std::map<std::string, MvQIcon*> icons_;
+    static std::map<std::string, Folder*> folders_;
 };
-
-#endif
