@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQIconStripView_H
-#define MvQIconStripView_H
+#pragma once
 
 #include "MvQListFolderViewBase.h"
 
@@ -23,5 +22,3 @@ public:
 protected:
     void performDrop(Qt::DropAction, const MvQIconMimeData*, QPoint, bool);
 };
-
-#endif
\ No newline at end of file
