@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQListFolderViewBase_H
-#define MvQListFolderViewBase_H
+#pragma once
 
 #include <QListView>
 
@@ -49,20 +48,20 @@ signals:
     void desktopCommandRequested(QString, QPoint);
 
 protected:
-    void attachModel(){}
-    void detachModel(){}
+    void attachModel() {}
+    void detachModel() {}
 
     void setAllowMoveAction(bool b) { allowMoveAction_ = b; }
     void setEnterFolders(bool b) { enterFolders_ = b; }
 
     void setupShortCut();
-    void setPositions(){}
+    void setPositions() {}
     void blink(const QModelIndex&);
-    void showIcon(const QModelIndex&){}
+    void showIcon(const QModelIndex&) {}
     void rename(IconObject*);
 
     void folderChanged();
-    void iconCommandFromMain(QString){}
+    void iconCommandFromMain(QString) {}
     virtual void iconCommand(QString, IconObjectH);
     virtual void desktopCommand(QString, QPoint);
 
@@ -93,5 +92,3 @@ private:
     QShortcut* defaultShortCut_;
     IconObject* itemInfo_{nullptr};
 };
-
-#endif
