@@ -32,23 +32,25 @@ protected:
 
 ParamHelperList::ParamHelperList(const MvIconParameter& param)
 {
-    header_ << "Value" << "Description";
-    value_ << QStringList() <<  QStringList();
+    header_ << "Value"
+            << "Description";
+    value_ << QStringList() << QStringList();
     param.scan(*this);
 }
 
-void ParamHelperList::next(const MvIconParameter &p, const char* first, const char* second)
+void ParamHelperList::next(const MvIconParameter& p, const char* first, const char* second)
 {
-     if (isalnum(*first)) {
-         std::string s(first);
-         auto sb = p.beautifiedName(first);
-         value_[1] << QString::fromStdString(sb);
-         if (second) {
+    if (isalnum(*first)) {
+        std::string s(first);
+        auto sb = p.beautifiedName(first);
+        value_[1] << QString::fromStdString(sb);
+        if (second) {
             value_[0] << QString(second);
-         } else {
+        }
+        else {
             value_[0] << QString(first);
-         }
-     }
+        }
+    }
 }
 
 //----------------------------------
@@ -76,15 +78,16 @@ QWidget* MvQListHelp::widget()
     return selector_;
 }
 
-void MvQListHelp::refresh(const vector<string>& values)
+void MvQListHelp::refresh(const std::vector<std::string>& values)
 {
     if (values.size() > 0) {
         if (!multiple_) {
             QString txt(values[0].c_str());
             selector_->setCurrentValue(txt);
-        } else {
+        }
+        else {
             QStringList lst;
-            for (auto s: values) {
+            for (auto s : values) {
                 lst << QString::fromStdString(s);
             }
             selector_->updateValueChecked(lst);
@@ -98,7 +101,8 @@ void MvQListHelp::slotSelectionChanged(QString s, bool)
         std::vector<std::string> val;
         val.push_back(s.toStdString());
         emit edited(val);
-    } else {
+    }
+    else {
         QStringList val;
         QVector<bool> st;
         selector_->queryValueChecked(val, st);
