@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQListHelp_H
-#define MvQListHelp_H
+#pragma once
 
 #include "MvQRequestPanelHelp.h"
 #include "MvIconParameter.h"
@@ -26,9 +25,9 @@ class MvQListHelp : public MvQRequestPanelHelp
 
 public:
     MvQListHelp(RequestPanel& owner, const MvIconParameter& param);
-    ~MvQListHelp(){}
+    ~MvQListHelp() {}
 
-    void start(){}
+    void start() {}
     bool dialog() { return false; }
     QWidget* widget();
 
@@ -36,12 +35,10 @@ public slots:
     void slotSelectionChanged(QString s, bool);
 
 protected:
-    virtual void refresh(const vector<string>&);
+    virtual void refresh(const std::vector<std::string>&);
     virtual long flags() { return 9; }
     virtual void set(Request&) {}
 
     bool multiple_;
     MvQFilterTreeWidget* selector_{nullptr};
 };
-
-#endif
