@@ -38,16 +38,16 @@ MvQLogDialog::MvQLogDialog() :
     //Window decoration
     setWindowIcon(QPixmap(":/desktop/log.svg"));
 
-    QVBoxLayout* vb = new QVBoxLayout(this);
+    auto* vb = new QVBoxLayout(this);
 
     //-----------------------
     //Header
     //------------------------
 
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     vb->addLayout(hb);
 
-    QLabel* logLabel = new QLabel(this);
+    auto* logLabel = new QLabel(this);
     logLabel->setPixmap(QPixmap(":/desktop/log.svg"));
     hb->addWidget(logLabel);
 
@@ -69,7 +69,7 @@ MvQLogDialog::MvQLogDialog() :
     hb = new QHBoxLayout;
     vb->addLayout(hb);
 
-    QToolButton* clearTb = new QToolButton(this);
+    auto* clearTb = new QToolButton(this);
     clearTb->setAutoRaise(true);
     clearTb->setText(tr("Clear"));
     clearTb->setToolTip(tr("Clear log"));
@@ -105,7 +105,7 @@ MvQLogDialog::MvQLogDialog() :
     //Buttonbox
     //-------------------
 
-    QDialogButtonBox* buttonBox = new QDialogButtonBox(this);
+    auto* buttonBox = new QDialogButtonBox(this);
     vb->addWidget(buttonBox);
 
     buttonBox->addButton(QDialogButtonBox::Close);
@@ -137,9 +137,9 @@ void MvQLogDialog::open(IconObject* icon)
 {
     MvQLogDialog* e = icon->logWindow();
     if (e == 0) {
-        for (std::set<MvQLogDialog*>::iterator j = windows.begin(); j != windows.end(); ++j)
-            if ((*j)->current_ == 0)
-                e = (*j);
+        for (auto window : windows)
+            if (window->current_ == 0)
+                e = window;
 
         if (e == 0)
             e = new MvQLogDialog();
@@ -197,7 +197,7 @@ void MvQLogDialog::load()
 
     Path p = current_->logPath();
 
-    cout << "log: " << p.str() << endl;
+    std::cout << "log: " << p.str() << std::endl;
 
     //Read contents
     QFile f(QString::fromStdString(p.str()));
@@ -265,7 +265,7 @@ void MvQLogDialog::slotDone(FILE*)
 {
     watcher_->stop();
     //enable();
-    cout << "done" << endl;
+    std::cout << "done" << std::endl;
 }
 
 void MvQLogDialog::slotReady(const char* buf)
