@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQLogDialog_H
-#define MvQLogDialog_H
+#pragma once
 
 #include "IconObject.h"
 
@@ -62,6 +61,3 @@ private:
 
 
 inline void destroy(MvQLogDialog**) {}
-
-
-#endif
