@@ -79,10 +79,10 @@ void MvQNewIconListWidget::mouseMoveEvent(QMouseEvent* event)
         if (distance >= QApplication::startDragDistance()) {
             QListWidgetItem* item = itemAt(startPos_);
             if (item) {
-                QString cname                = item->data(Qt::UserRole).toString();
-                MvQNewIconMimeData* mimeData = new MvQNewIconMimeData(cname, MvQNewIconMimeData::UserDef);
+                QString cname  = item->data(Qt::UserRole).toString();
+                auto* mimeData = new MvQNewIconMimeData(cname, MvQNewIconMimeData::UserDef);
 
-                QDrag* drag = new QDrag(this);
+                auto* drag = new QDrag(this);
                 drag->setPixmap(MvQIconProvider::pixmap(IconClass::find(cname.toStdString()), 20));
                 drag->setHotSpot(QPoint(20, 20));
                 drag->setMimeData(mimeData);
@@ -108,7 +108,7 @@ MvQNewIconPanel::MvQNewIconPanel(SelectionMode mode, QWidget* parent) :
     QWidget(parent),
     selectionMode_(mode)
 {
-    QVBoxLayout* vb = new QVBoxLayout;
+    auto* vb = new QVBoxLayout;
     vb->setSpacing(2);
     vb->setContentsMargins(2, 2, 2, 2);
     setLayout(vb);
@@ -118,7 +118,7 @@ MvQNewIconPanel::MvQNewIconPanel(SelectionMode mode, QWidget* parent) :
     //In panel mode we need a close button
     if (selectionMode_ == PanelMode) {
         //Top row
-        QHBoxLayout* hb = new QHBoxLayout;
+        auto* hb = new QHBoxLayout;
         hb->setSpacing(0);
         hb->setContentsMargins(0, 0, 0, 0);
 
@@ -128,7 +128,7 @@ MvQNewIconPanel::MvQNewIconPanel(SelectionMode mode, QWidget* parent) :
         label = new QLabel("<b>" + tr("Create new icon") + "</b>", this);
         hb->addWidget(label, 1);
 
-        QToolButton* closeTb = new QToolButton(this);
+        auto* closeTb = new QToolButton(this);
         closeTb->setAutoRaise(true);
         closeTb->setIcon(QPixmap(":/desktop/remove.svg"));
         closeTb->setToolTip(tr("Close sidebar"));
@@ -139,13 +139,13 @@ MvQNewIconPanel::MvQNewIconPanel(SelectionMode mode, QWidget* parent) :
     }
 
     //Button row
-    QHBoxLayout* hbButton = new QHBoxLayout;
+    auto* hbButton = new QHBoxLayout;
     vb->addLayout(hbButton);
     hbButton->setSpacing(0);
 
     QSize icSize(16, 16);
 
-    QToolButton* recentTb = new QToolButton(this);
+    auto* recentTb = new QToolButton(this);
     recentTb->setIconSize(icSize);
     recentTb->setToolTip(tr("Most recent"));
     recentTb->setCheckable(true);
@@ -155,7 +155,7 @@ MvQNewIconPanel::MvQNewIconPanel(SelectionMode mode, QWidget* parent) :
     recentTb->setFocusPolicy(Qt::NoFocus);
     hbButton->addWidget(recentTb);
 
-    QToolButton* groupTb = new QToolButton(this);
+    auto* groupTb = new QToolButton(this);
     groupTb->setIconSize(icSize);
     groupTb->setToolTip(tr("Types"));
     groupTb->setCheckable(true);
@@ -165,7 +165,7 @@ MvQNewIconPanel::MvQNewIconPanel(SelectionMode mode, QWidget* parent) :
     groupTb->setFocusPolicy(Qt::NoFocus);
     hbButton->addWidget(groupTb);
 
-    QToolButton* searchTb = new QToolButton(this);
+    auto* searchTb = new QToolButton(this);
     searchTb->setIconSize(icSize);
     searchTb->setToolTip(tr("Filter"));
     searchTb->setCheckable(true);
@@ -214,14 +214,14 @@ MvQNewIconPanel::MvQNewIconPanel(SelectionMode mode, QWidget* parent) :
     // Type widget
     //---------------------------
 
-    QWidget* typeW      = new QWidget(this);
-    QVBoxLayout* typeVb = new QVBoxLayout(typeW);
+    auto* typeW  = new QWidget(this);
+    auto* typeVb = new QVBoxLayout(typeW);
     //typeVb->setSpacing(0);
     typeVb->setContentsMargins(1, 1, 1, 1);
 
     //Type
-    QHBoxLayout* typeHb = new QHBoxLayout;
-    QLabel* typeLabel   = new QLabel(tr("Type: "));
+    auto* typeHb    = new QHBoxLayout;
+    auto* typeLabel = new QLabel(tr("Type: "));
     typeHb->addWidget(typeLabel);
     typeCb_ = new QComboBox(this);
     typeHb->addWidget(typeCb_, 1);
@@ -256,14 +256,14 @@ MvQNewIconPanel::MvQNewIconPanel(SelectionMode mode, QWidget* parent) :
     // Search widget
     //------------------
 
-    QWidget* searchW      = new QWidget(this);
-    QVBoxLayout* searchVb = new QVBoxLayout(searchW);
+    auto* searchW  = new QWidget(this);
+    auto* searchVb = new QVBoxLayout(searchW);
     searchVb->setSpacing(0);
     searchVb->setContentsMargins(1, 1, 1, 1);
 
-    QHBoxLayout* searchHb = new QHBoxLayout;
-    label                 = new QLabel(tr("Filter:"));
-    searchLine_           = new QLineEdit(searchW);
+    auto* searchHb = new QHBoxLayout;
+    label          = new QLabel(tr("Filter:"));
+    searchLine_    = new QLineEdit(searchW);
     searchHb->addWidget(label);
     searchHb->addSpacing(2);
     searchHb->addWidget(searchLine_, 1);
@@ -323,8 +323,8 @@ void MvQNewIconPanel::next(const IconClass& c)
             w = it.value();
         }
 
-        QListWidgetItem* typeItem = new QListWidgetItem(MvQIconProvider::pixmap(c, 20),
-                                                        QString::fromStdString(c.defaultName()));
+        auto* typeItem = new QListWidgetItem(MvQIconProvider::pixmap(c, 20),
+                                             QString::fromStdString(c.defaultName()));
 
         typeItem->setData(Qt::UserRole, QString::fromStdString(c.name()));
 
@@ -354,7 +354,7 @@ void MvQNewIconPanel::slotIconSelected(QListWidgetItem* item)
 
 void MvQNewIconPanel::slotSearch(QString str)
 {
-    vector<const IconClass*> res;
+    std::vector<const IconClass*> res;
 
     if (str.simplified().isEmpty()) {
         if (searchList_->count() != static_cast<int>(iconClasses_.size())) {
@@ -369,11 +369,11 @@ void MvQNewIconPanel::slotSearch(QString str)
         searchList_->clear();
     }
 
-    for (vector<const IconClass*>::iterator it = res.begin(); it != res.end(); it++) {
-        QListWidgetItem* item = new QListWidgetItem(MvQIconProvider::pixmap(*(*it), 32),
-                                                    QString::fromStdString((*it)->defaultName()));
+    for (auto& re : res) {
+        auto* item = new QListWidgetItem(MvQIconProvider::pixmap(*re, 32),
+                                         QString::fromStdString(re->defaultName()));
 
-        item->setData(Qt::UserRole, QString::fromStdString((*it)->name()));
+        item->setData(Qt::UserRole, QString::fromStdString(re->name()));
         searchList_->addItem(item);
     }
 
@@ -418,8 +418,8 @@ void MvQNewIconPanel::updateRecentList()
     for (int i = lst.count() - 1; i >= 0; i--) {
         const IconClass& kind = IconClass::find(lst[i].toStdString());
 
-        QListWidgetItem* item = new QListWidgetItem(MvQIconProvider::pixmap(kind, 32),
-                                                    QString::fromStdString(kind.defaultName()));
+        auto* item = new QListWidgetItem(MvQIconProvider::pixmap(kind, 32),
+                                         QString::fromStdString(kind.defaultName()));
 
         item->setData(Qt::UserRole, QString::fromStdString(kind.name()));
         recentList_->addItem(item);
@@ -489,6 +489,20 @@ void MvQNewIconPanel::keyPressEvent(QKeyEvent* event)
     QWidget::keyPressEvent(event);
 }
 
+void MvQNewIconPanel::writeSettings(QSettings& settings)
+{
+    settings.setValue("currentMode", currentMode());
+    settings.setValue("currentTypeGroup", typeCb_->currentText());
+}
+
+void MvQNewIconPanel::readSettings(QSettings& settings)
+{
+    if (settings.contains("currentMode")) {
+        setCurrentMode(settings.value("currentMode").toInt());
+    }
+
+    MvQ::initComboBox(settings, "currentTypeGroup", typeCb_);
+}
 
 //==============================
 //
@@ -501,7 +515,7 @@ MvQNewIconDialog::MvQNewIconDialog(QWidget* parent) :
 {
     setWindowTitle(tr("Create new icon"));
 
-    QVBoxLayout* vb = new QVBoxLayout;
+    auto* vb = new QVBoxLayout;
     vb->setSpacing(0);
     vb->setContentsMargins(1, 1, 1, 1);
     setLayout(vb);
@@ -509,12 +523,8 @@ MvQNewIconDialog::MvQNewIconDialog(QWidget* parent) :
     iconWidget_ = new MvQNewIconPanel(MvQNewIconPanel::DialogMode, this);
     vb->addWidget(iconWidget_, 1);
 
-    // Buttonbox
-    //QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok
-    //                              | QDialogButtonBox::Cancel);
-
-    QDialogButtonBox* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok |
-                                                       QDialogButtonBox::Close);
+    auto* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok |
+                                           QDialogButtonBox::Close);
 
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
@@ -533,12 +543,6 @@ MvQNewIconDialog::~MvQNewIconDialog()
     writeSettings();
 }
 
-//When the close button is pressed
-void MvQNewIconDialog::reject()
-{
-    QDialog::reject();
-}
-
 //It is called when return is pressed on the
 //dialog. We pick the current selection in the active selection panel.
 void MvQNewIconDialog::accept()
@@ -571,7 +575,7 @@ void MvQNewIconDialog::writeSettings()
 
     settings.beginGroup("main");
     settings.setValue("size", size());
-    settings.setValue("currentMode", iconWidget_->currentMode());
+    iconWidget_->writeSettings(settings);
     settings.endGroup();
 }
 
@@ -587,8 +591,6 @@ void MvQNewIconDialog::readSettings()
         resize(QSize(350, 500));
     }
 
-    if (settings.contains("currentMode")) {
-        iconWidget_->setCurrentMode(settings.value("currentMode").toInt());
-    }
+    iconWidget_->readSettings(settings);
     settings.endGroup();
 }
