@@ -7,12 +7,12 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQNewIconWidget_H
-#define MvQNewIconWidget_H
+#pragma once
 
 #include <QDialog>
 #include <QListWidget>
 #include <QMap>
+#include <QSettings>
 #include <QStyledItemDelegate>
 
 class QAbstractButton;
@@ -33,7 +33,7 @@ class MvQNewIconListWidget : public QListWidget
     Q_OBJECT
 
 public:
-    MvQNewIconListWidget(QWidget* parent = 0);
+    MvQNewIconListWidget(QWidget* parent = nullptr);
 signals:
     void iconCreated(QString);
 
@@ -55,7 +55,7 @@ public:
         DialogMode
     };
 
-    MvQNewIconPanel(SelectionMode, QWidget* parent = 0);
+    MvQNewIconPanel(SelectionMode, QWidget* parent = nullptr);
     ~MvQNewIconPanel();
 
     void next(const IconClass&);
@@ -66,6 +66,9 @@ public:
     //Observer method
     void notifyRecentChanged();
 
+    void writeSettings(QSettings&);
+    void readSettings(QSettings&);
+
 public slots:
     void slotTypeChanged(int);
     void slotIconSelected(QListWidgetItem*);
@@ -89,7 +92,7 @@ protected:
     QMap<QString, MvQNewIconListWidget*> iconLists_;
     QLineEdit* searchLine_;
     MvQNewIconListWidget* searchList_;
-    vector<const IconClass*> iconClasses_;
+    std::vector<const IconClass*> iconClasses_;
     QButtonGroup* modeBg_;
     SelectionMode selectionMode_;
 };
@@ -99,13 +102,12 @@ class MvQNewIconDialog : public QDialog
     Q_OBJECT
 
 public:
-    MvQNewIconDialog(QWidget* parent = 0);
+    MvQNewIconDialog(QWidget* parent = nullptr);
     ~MvQNewIconDialog();
     const IconClass& selected();
 
 public slots:
     void accept();
-    void reject();
     void slotIconSelected(QString);
 
 private:
@@ -115,6 +117,3 @@ private:
     MvQNewIconPanel* iconWidget_;
     QString selected_;
 };
-
-
-#endif
