@@ -25,7 +25,7 @@
 #include "MvQIconProvider.h"
 #include "MvQMethods.h"
 
-vector<string> MvQPageView::classes_;
+std::vector<std::string> MvQPageView::classes_;
 QMap<MvQPageHandlerItem::HandlerType, QPixmap> MvQPageHandlerItem::pix_;
 QMap<MvQPageHandlerItem::HandlerType, QPixmap> MvQPageHandlerItem::pixHover_;
 
@@ -467,7 +467,7 @@ void MvQPageSelectionItem::pagePressed(MvQPageItem* item, QGraphicsSceneMouseEve
 void MvQPageSelectionItem::dropEvent(QGraphicsSceneDragDropEvent* event)
 {
     if (event->mimeData()->hasFormat("metview/icon")) {
-        const MvQIconMimeData* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
+        const auto* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
 
         if (!mimeData) {
             return;
@@ -740,7 +740,7 @@ void MvQPageItem::moveBy(QPointF delta)
 void MvQPageItem::dropEvent(QGraphicsSceneDragDropEvent* event)
 {
     if (event->mimeData()->hasFormat("metview/icon")) {
-        const MvQIconMimeData* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
+        const auto* mimeData = qobject_cast<const MvQIconMimeData*>(event->mimeData());
 
         if (!mimeData) {
             return;
@@ -872,7 +872,7 @@ MvQPageItem* MvQSuperPageItem::addPage(double x, double y, double w, double h)
 {
     QRectF rect(x, y, w, h);
 
-    MvQPageItem* item = new MvQPageItem(view_, rect, this);
+    auto* item = new MvQPageItem(view_, rect, this);
     item->setParentItem(this);
 
     return item;
@@ -1228,7 +1228,7 @@ void MvQRulerItem::adjustSize()
 //
 //========================================
 
-MvQPageView::MvQPageView(const vector<string>& classes, QUndoStack* undoStack, QWidget* parent) :
+MvQPageView::MvQPageView(const std::vector<std::string>& classes, QUndoStack* undoStack, QWidget* parent) :
     QGraphicsView(parent),
     undoStack_(undoStack),
     scene_(0),
@@ -1300,10 +1300,10 @@ void MvQPageView::clearPages()
     }
 }
 
-bool MvQPageView::matchClass(const string& cname)
+bool MvQPageView::matchClass(const std::string& cname)
 {
-    for (vector<string>::const_iterator it = classes_.begin(); it != classes_.end(); ++it) {
-        if (*it == cname)
+    for (const auto& classe : classes_) {
+        if (classe == cname)
             return true;
     }
 
@@ -1366,7 +1366,7 @@ MvQPageItem* MvQPageView::addPage(double x, double y, double w, double h)
     if (!superPage_)
         return 0;
 
-    MvQPageAddCommand* cmd = new MvQPageAddCommand(this, x, y, w, h);
+    auto* cmd = new MvQPageAddCommand(this, x, y, w, h);
     undoStack_->push(cmd);
 
     return cmd->page();
@@ -1374,7 +1374,7 @@ MvQPageItem* MvQPageView::addPage(double x, double y, double w, double h)
 
 void MvQPageView::pagesResized(QList<MvQPageItem*> pages, QList<QRectF> oriPaperRects)
 {
-    MvQUndoCommand* cmdParent = new MvQUndoCommand(this, 0);
+    auto* cmdParent = new MvQUndoCommand(this, 0);
     cmdParent->setText("resize");
 
     for (int i = 0; i < pages.count(); i++) {
@@ -1388,7 +1388,7 @@ void MvQPageView::pagesResized(QList<MvQPageItem*> pages, QList<QRectF> oriPaper
 
 void MvQPageView::pagesMoved(QList<MvQPageItem*> pages, const QPointF& delta)
 {
-    MvQUndoCommand* cmdParent = new MvQUndoCommand(this, 0);
+    auto* cmdParent = new MvQUndoCommand(this, 0);
     cmdParent->setText("move");
 
     foreach (MvQPageItem* item, pages) {
@@ -1405,7 +1405,7 @@ void MvQPageView::duplicateSelection()
     if (!selector_ || !selector_->hasPages())
         return;
 
-    MvQUndoCommand* cmdParent = new MvQUndoCommand(this, 0);
+    auto* cmdParent = new MvQUndoCommand(this, 0);
     cmdParent->setText("duplicate");
 
     foreach (MvQPageItem* item, selector_->pages()) {
@@ -1420,7 +1420,7 @@ void MvQPageView::deleteSelection()
     if (!selector_ || !selector_->hasPages())
         return;
 
-    MvQUndoCommand* cmdParent = new MvQUndoCommand(this, 0);
+    auto* cmdParent = new MvQUndoCommand(this, 0);
     cmdParent->setText("delete");
 
     foreach (MvQPageItem* item, selector_->pages()) {
@@ -1435,7 +1435,7 @@ void MvQPageView::joinSelection()
     if (!selector_ || selector_->pages().count() < 2)
         return;
 
-    MvQPageJoinCommand* cmd = new MvQPageJoinCommand(this, selector_->pages());
+    auto* cmd = new MvQPageJoinCommand(this, selector_->pages());
     undoStack_->push(cmd);
 }
 
@@ -1444,7 +1444,7 @@ void MvQPageView::splitSelection(int row, int column)
     if (!selector_ || !selector_->hasPages())
         return;
 
-    MvQUndoCommand* cmdParent = new MvQUndoCommand(this, 0);
+    auto* cmdParent = new MvQUndoCommand(this, 0);
     cmdParent->setText("split");
 
     foreach (MvQPageItem* item, selector_->pages()) {
@@ -1459,7 +1459,7 @@ void MvQPageView::expandSelection()
     if (!selector_ || !selector_->hasPages())
         return;
 
-    MvQUndoCommand* cmdParent = new MvQUndoCommand(this, 0);
+    auto* cmdParent = new MvQUndoCommand(this, 0);
     cmdParent->setText("expand");
 
     QRectF selRect    = selector_->mapToParent(selector_->boundingRect()).boundingRect();
@@ -1478,7 +1478,7 @@ void MvQPageView::connectSelection()
     if (!selector_ || selector_->pages().count() < 2)
         return;
 
-    MvQPageConnectCommand* cmd = new MvQPageConnectCommand(this, selector_->pages());
+    auto* cmd = new MvQPageConnectCommand(this, selector_->pages());
     undoStack_->push(cmd);
 }
 
@@ -1498,7 +1498,7 @@ void MvQPageView::disconnectSelection()
     if (!hasSub)
         return;
 
-    MvQUndoCommand* cmdParent = new MvQUndoCommand(this, 0);
+    auto* cmdParent = new MvQUndoCommand(this, 0);
     cmdParent->setText("disconnect");
 
     foreach (MvQPageItem* item, selector_->pages()) {
