@@ -255,75 +255,88 @@ MvQPaletteSelectionWidget::MvQPaletteSelectionWidget(QWidget* parent) :
 {
     auto* vb = new QVBoxLayout(this);
 
+    auto *topHb = new QHBoxLayout(this);
+    vb->addLayout(topHb);
+
+    topHb->addStretch(1);
+
+    showFilterTb_ = new QToolButton(this);
+    showFilterTb_->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+    showFilterTb_->setText(tr("Show all filters"));
+    showFilterTb_->setIcon(QPixmap(":/desktop/filter.svg"));
+    showFilterTb_->setCheckable(true);
+    showFilterTb_->setChecked(false);
+    topHb->addWidget(showFilterTb_);
+
     resetTb_ = new QToolButton(this);
     resetTb_->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     resetTb_->setText(tr("Clear all filters"));
     resetTb_->setIcon(QPixmap(":/desktop/undo.svg"));
-    vb->addWidget(resetTb_);
+    topHb->addWidget(resetTb_);
 
-    auto* grid = new QGridLayout();
-    vb->addLayout(grid);
+    filterGrid_ = new QGridLayout();
+    vb->addLayout(filterGrid_);
 
     int cbWidth = 42;  //number of characters!
 
     //name
     int row = 0;
-    grid->addWidget(new QLabel(tr("Name:"), this), row, 0);
-    grid->setContentsMargins(1, 1, 1, 1);
-    grid->setVerticalSpacing(2);
+    filterGrid_->addWidget(new QLabel(tr("Name:"), this), row, 0);
+    filterGrid_->setContentsMargins(1, 1, 1, 1);
+    filterGrid_->setVerticalSpacing(2);
 
     nameLe_ = new QLineEdit(this);
-    nameLe_->setPlaceholderText("ANY");
-    //#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
-    //    nameLe_->setClearButtonEnabled(true);
-    //#endif
-    grid->addWidget(nameLe_, row, 1);
+    //nameLe_->setPlaceholderText("");
+#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
+    nameLe_->setClearButtonEnabled(true);
+#endif
+    filterGrid_->addWidget(nameLe_, row, 1,1,2);
 
-    nameResetTb_ = new QToolButton(this);
-    nameResetTb_->setIcon(QPixmap(":/desktop/undo.svg"));
-    nameResetTb_->setAutoRaise(true);
-    nameResetTb_->setToolTip(tr("Clear filter"));
-    grid->addWidget(nameResetTb_, row, 2);
+//    nameResetTb_ = new QToolButton(this);
+//    nameResetTb_->setIcon(QPixmap(":/desktop/undo.svg"));
+//    nameResetTb_->setAutoRaise(true);
+//    nameResetTb_->setToolTip(tr("Clear filter"));
+//    filterGrid_->addWidget(nameResetTb_, row, 2);
     row++;
 
     //origin
-    grid->addWidget(new QLabel(tr("Origin:"), this), row, 0);
-    grid->setContentsMargins(1, 1, 1, 1);
-    grid->setVerticalSpacing(2);
+    filterGrid_->addWidget(new QLabel(tr("Origin:"), this), row, 0);
+    filterGrid_->setContentsMargins(1, 1, 1, 1);
+    filterGrid_->setVerticalSpacing(2);
 
     originCb_ = new QComboBox(this);
     originCb_->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
     originCb_->setMinimumContentsLength(cbWidth);
     originCb_->addItem("ANY");
     originCb_->addItems(MvQPaletteDb::instance()->origins());
-    grid->addWidget(originCb_, row, 1);
+    filterGrid_->addWidget(originCb_, row, 1);
 
     originResetTb_ = new QToolButton(this);
     originResetTb_->setIcon(QPixmap(":/desktop/undo.svg"));
     originResetTb_->setAutoRaise(true);
     originResetTb_->setToolTip(tr("Clear filter"));
-    grid->addWidget(originResetTb_, row, 2);
+    filterGrid_->addWidget(originResetTb_, row, 2);
     row++;
 
     //colour
-    grid->addWidget(new QLabel(tr("Colour:"), this), row, 0);
+    filterGrid_->addWidget(new QLabel(tr("Colour:"), this), row, 0);
 
     colourCb_ = new QComboBox(this);
     colourCb_->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
     colourCb_->setMinimumContentsLength(cbWidth);
     colourCb_->addItem("ANY");
     colourCb_->addItems(MvQPaletteDb::instance()->colours());
-    grid->addWidget(colourCb_, row, 1);
+    filterGrid_->addWidget(colourCb_, row, 1);
 
     colourResetTb_ = new QToolButton(this);
     colourResetTb_->setIcon(QPixmap(":/desktop/undo.svg"));
     colourResetTb_->setAutoRaise(true);
     colourResetTb_->setToolTip(tr("Clear filter"));
-    grid->addWidget(colourResetTb_, row, 2);
+    filterGrid_->addWidget(colourResetTb_, row, 2);
     row++;
 
     //Num of colours in palette
-    grid->addWidget(new QLabel(tr("Count:"), this), row, 0);
+    filterGrid_->addWidget(new QLabel(tr("Count:"), this), row, 0);
 
     numCb_ = new QComboBox(this);
     numCb_->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
@@ -335,42 +348,42 @@ MvQPaletteSelectionWidget::MvQPaletteSelectionWidget(QWidget* parent) :
         numLst << QString::number(MvQPaletteDb::instance()->nLevels()[i]);
     numCb_->addItems(numLst);
 
-    grid->addWidget(numCb_, row, 1);
+    filterGrid_->addWidget(numCb_, row, 1);
 
     numResetTb_ = new QToolButton(this);
     numResetTb_->setIcon(QPixmap(":/desktop/undo.svg"));
     numResetTb_->setAutoRaise(true);
     numResetTb_->setToolTip(tr("Clear filter"));
-    grid->addWidget(numResetTb_, row, 2);
+    filterGrid_->addWidget(numResetTb_, row, 2);
 
     row++;
 
     //params
-    grid->addWidget(new QLabel(tr("Parameter:"), this), row, 0);
+    filterGrid_->addWidget(new QLabel(tr("Parameter:"), this), row, 0);
 
     paramCb_ = new QComboBox(this);
     paramCb_->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
     paramCb_->setMinimumContentsLength(cbWidth);
     paramCb_->addItem("ANY");
     paramCb_->addItems(MvQPaletteDb::instance()->parameters());
-    grid->addWidget(paramCb_, row, 1);
+    filterGrid_->addWidget(paramCb_, row, 1);
 
     paramResetTb_ = new QToolButton(this);
     paramResetTb_->setIcon(QPixmap(":/desktop/undo.svg"));
     paramResetTb_->setAutoRaise(true);
     paramResetTb_->setToolTip(tr("Clear filter"));
-    grid->addWidget(paramResetTb_, row, 2);
+    filterGrid_->addWidget(paramResetTb_, row, 2);
 
     row++;
 
-    grid->setColumnStretch(1, 1);
+    filterGrid_->setColumnStretch(1, 1);
 
     //tree view and model
 
     tree_ = new QTreeView(this);
     tree_->setRootIsDecorated(false);
     tree_->setUniformRowHeights(true);
-    tree_->setMinimumHeight(200);
+    tree_->setMinimumHeight(270);
     vb->addWidget(tree_, 1);
 
     model_ = new MvQPaletteModel(this);
@@ -389,6 +402,10 @@ MvQPaletteSelectionWidget::MvQPaletteSelectionWidget(QWidget* parent) :
     tree_->setSortingEnabled(true);
     tree_->sortByColumn(1, Qt::AscendingOrder);
     tree_->setModel(sortModel_);
+    tree_->resizeColumnToContents(0);
+
+    connect(showFilterTb_, SIGNAL(clicked(bool)),
+            this, SLOT(slotShowFilters(bool)));
 
     connect(resetTb_, SIGNAL(clicked()),
             this, SLOT(slotClearFilter()));
@@ -396,8 +413,8 @@ MvQPaletteSelectionWidget::MvQPaletteSelectionWidget(QWidget* parent) :
     connect(nameLe_, SIGNAL(textChanged(QString)),
             this, SLOT(slotNameFilter(QString)));
 
-    connect(nameResetTb_, SIGNAL(clicked()),
-            nameLe_, SLOT(clear()));
+//    connect(nameResetTb_, SIGNAL(clicked()),
+//            nameLe_, SLOT(clear()));
 
     connect(originCb_, SIGNAL(currentIndexChanged(int)),
             this, SLOT(slotOriginFilter(int)));
@@ -428,6 +445,9 @@ MvQPaletteSelectionWidget::MvQPaletteSelectionWidget(QWidget* parent) :
 
     //Init the button states!!
     checkButtonState();
+
+    // init filters visibility
+    slotShowFilters(showFilterTb_->isChecked());
 }
 
 void MvQPaletteSelectionWidget::slotOriginFilter(int)
@@ -522,6 +542,25 @@ void MvQPaletteSelectionWidget::slotItemSelected(const QModelIndex& current, con
     }
 }
 
+void MvQPaletteSelectionWidget::showFilters(bool visible)
+{
+    for (int i=1; i < filterGrid_->rowCount(); i++) {
+        for (int j=0; j < 3; j++) {
+            if (QLayoutItem* item = filterGrid_->itemAtPosition(i, j)) {
+                if (QWidget *w = item->widget()) {
+                    w->setVisible(visible);
+                }
+            }
+        }
+    }
+}
+
+void MvQPaletteSelectionWidget::slotShowFilters(bool visible)
+{
+    showFilters(visible);
+    slotClearFilter();
+}
+
 void MvQPaletteSelectionWidget::slotClearFilter()
 {
     ignoreFilterChanged_ = true;
@@ -539,14 +578,14 @@ void MvQPaletteSelectionWidget::slotClearFilter()
 
 void MvQPaletteSelectionWidget::checkButtonState()
 {
-    nameResetTb_->setEnabled(!nameLe_->text().isEmpty());
+    //nameResetTb_->setEnabled(!nameLe_->text().isEmpty());
     originResetTb_->setEnabled(originCb_->currentText() != "ANY");
     colourResetTb_->setEnabled(colourCb_->currentText() != "ANY");
     numResetTb_->setEnabled(numCb_->currentText() != "ANY");
     paramResetTb_->setEnabled(paramCb_->currentText() != "ANY");
 
     resetTb_->setEnabled(originResetTb_->isEnabled() ||
-                         nameResetTb_->isEnabled() || colourResetTb_->isEnabled() ||
+                         !nameLe_->text().isEmpty() || colourResetTb_->isEnabled() ||
                          numResetTb_->isEnabled() || paramResetTb_->isEnabled());
 }
 
