@@ -19,6 +19,7 @@
 #include <QStyledItemDelegate>
 
 class QComboBox;
+class QGridLayout;
 class QLabel;
 class QLineEdit;
 class QPushButton;
@@ -101,14 +102,18 @@ protected slots:
     void slotResetParamFilter();
     void slotItemSelected(const QModelIndex&, const QModelIndex&);
     void slotClearFilter();
+    void slotShowFilters(bool visible);
 
 signals:
     void itemSelected(int);
 
 protected:
     void checkButtonState();
+    void showFilters(bool visible);
 
     bool ignoreFilterChanged_;
+    QGridLayout* filterGrid_;
+    QToolButton* showFilterTb_;
     QToolButton* resetTb_;
 
     QLineEdit* nameLe_;
@@ -117,7 +122,7 @@ protected:
     QComboBox* numCb_;
     QComboBox* paramCb_;
 
-    QToolButton* nameResetTb_;
+    //QToolButton* nameResetTb_;
     QToolButton* originResetTb_;
     QToolButton* colourResetTb_;
     QToolButton* numResetTb_;
