@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQPALETTELINE_H
-#define MVQPALETTELINE_H
+#pragma once
 
 #include "MvQRequestPanelLine.h"
 #include "MvIconParameter.h"
@@ -29,11 +28,11 @@ public:
     //QString currentValue() {return QString();}
     //void addValue(QString) {}
 
-    void refresh(const vector<string>&);
+    void refresh(const std::vector<std::string>&);
     void widgetClicked();
 
 public slots:
-    void slotHelperEdited(const vector<string>&);
+    void slotHelperEdited(const std::vector<std::string>&);
 
 protected:
     void next(const MvIconParameter&, const char* first, const char* second);
@@ -44,5 +43,3 @@ protected:
     QLabel* palPixLabel_;
     QLabel* palNameLabel_;
 };
-
-#endif  // MVQPALETTELINE_H
