@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQRecentIcons_H
-#define MvQRecentIcons_H
+#pragma once
 
 #include <QStringList>
 
@@ -17,7 +16,7 @@ class MvQRecentIcons;
 class RecentIconsObserver
 {
 public:
-    RecentIconsObserver(){};
+    RecentIconsObserver()              = default;
     virtual void notifyRecentChanged() = 0;
 };
 
@@ -37,5 +36,3 @@ protected:
     static QStringList items_;
     static QList<RecentIconsObserver*> observers_;
 };
-
-#endif
\ No newline at end of file
