@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQRequestPanelHelp_H
-#define MvQRequestPanelHelp_H
+#pragma once
 
 #include "RequestPanelItem.h"
 
@@ -29,20 +28,20 @@ class MvQRequestPanelHelp : public QObject
 
 public:
     MvQRequestPanelHelp(RequestPanel&, const MvIconParameter&);
-    virtual ~MvQRequestPanelHelp(){}
+    virtual ~MvQRequestPanelHelp() {}
 
     virtual void start()  = 0;
     virtual bool dialog() = 0;
     virtual QIcon dialogIcon() { return QIcon(); }
     virtual bool useLargeDialogIcon() { return false; }
-    virtual QWidget* widget()                   = 0;
-    virtual void refresh(const vector<string>&) = 0;
-    virtual void setExternalActions(QList<QAction*>){}
+    virtual QWidget* widget()                             = 0;
+    virtual void refresh(const std::vector<std::string>&) = 0;
+    virtual void setExternalActions(QList<QAction*>) {}
 
     static MvQRequestPanelHelp* build(RequestPanel&, const MvIconParameter&);
 
 signals:
-    void edited(const vector<string>&);
+    void edited(const std::vector<std::string>&);
     void edited(QStringList, QVector<bool>);
     void editConfirmed();
 
@@ -51,5 +50,3 @@ protected:
     const MvIconParameter& param_;
     QWidget* parentWidget_;
 };
-
-#endif
