@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQRequestPanelWidget_H
-#define MvQRequestPanelWidget_H
+#pragma once
 
 #include <QWidget>
 
@@ -46,5 +45,3 @@ protected:
     std::vector<std::string> classes_;
     bool delayedRepaintScheduled_;
 };
-
-#endif
