@@ -8,8 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 
-#ifndef MvQScrolledTextLine_H
-#define MvQScrolledTextLine_H
+#pragma once
 
 #include "MvQRequestPanelLine.h"
 
@@ -26,12 +25,12 @@ class MvQScrolledTextLine : public MvQRequestPanelLine
 
 public:
     MvQScrolledTextLine(RequestPanel& owner, const MvIconParameter& param);
-    ~MvQScrolledTextLine(){};
+    ~MvQScrolledTextLine() = default;
 
     QString currentValue() { return QString(); }
     void addValue(QString) {}
 
-    void refresh(const vector<string>&);
+    void refresh(const std::vector<std::string>&);
 
 public slots:
     void slotTextEdited();
@@ -39,5 +38,3 @@ public slots:
 protected:
     QPlainTextEdit* textEdit_;
 };
-
-#endif
