@@ -31,13 +31,13 @@ MvQFolderSearchPanel::MvQFolderSearchPanel(QWidget* parent) :
     searchData_ = new FolderSearchData;
     searchData_->setObserver(this);
 
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     hb->setSpacing(4);
     hb->setContentsMargins(2, 1, 0, 2);
     setLayout(hb);
 
     //Name
-    QLabel* label = new QLabel(this);
+    auto* label = new QLabel(this);
     label->setText(tr("&Name:"));
     nameLe_ = new MvQLineEdit(this);
     nameLe_->setPlaceholderText("Filter name ...");
@@ -89,7 +89,7 @@ MvQFolderSearchPanel::MvQFolderSearchPanel(QWidget* parent) :
     connect(prevPb_, SIGNAL(clicked()),
             this, SLOT(slotFindPrev()));
 
-    QToolButton* closeTb = new QToolButton(this);
+    auto* closeTb = new QToolButton(this);
     closeTb->setAutoRaise(true);
     closeTb->setIcon(QPixmap(":/desktop/close_grey.svg"));
     closeTb->setToolTip(tr("Close find panel"));
