@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQSearchPanel_H
-#define MvQSearchPanel_H
+#pragma once
 
 #include <QWidget>
 
@@ -57,5 +56,3 @@ protected:
     QPushButton* prevPb_;
     FolderSearchData* searchData_;
 };
-
-#endif
