@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQSliderLine_H
-#define MvQSliderLine_H
+#pragma once
 
 #include <QString>
 
@@ -30,7 +29,7 @@ public:
 
     QString currentValue() { return QString(); }
     void addValue(QString) {}
-    void refresh(const vector<string>&);
+    void refresh(const std::vector<std::string>&);
 
 public slots:
     void slotValueChanged(int);
@@ -39,6 +38,3 @@ protected:
     MvQSlider* slider_;
     QLabel* valueLabel_;
 };
-
-
-#endif
