@@ -8,8 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 
-#ifndef MvQStationsHelp_H
-#define MvQStationsHelp_H
+#pragma once
 
 #include "MvQPalette.h"
 #include "MvQRequestPanelHelp.h"
@@ -27,9 +26,9 @@ class MvQStationsHelp : public MvQRequestPanelHelp
 
 public:
     MvQStationsHelp(RequestPanel& owner, const MvIconParameter& param);
-    ~MvQStationsHelp(){};
+    ~MvQStationsHelp() = default;
 
-    void start(){};
+    void start() {}
     bool dialog() { return false; }
     QWidget* widget();
 
@@ -37,10 +36,8 @@ public slots:
     void slotSelected(QString);
 
 protected:
-    virtual void refresh(const vector<string>&);
+    virtual void refresh(const std::vector<std::string>&);
 
 private:
     MvQStationsWidget* selector_;
 };
-
-#endif
