@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQStringLine_H
-#define MvQStringLine_H
+#pragma once
 
 #include "MvQRequestPanelLine.h"
 
@@ -26,17 +25,17 @@ class MvQStringLine : public MvQRequestPanelLine
 
 public:
     MvQStringLine(RequestPanel& owner, const MvIconParameter& param);
-    ~MvQStringLine(){};
+    ~MvQStringLine() = default;
 
     QString currentValue() { return QString(); }
     void addValue(QString) {}
 
-    void refresh(const vector<string>&);
+    void refresh(const std::vector<std::string>&);
 
 public slots:
     void slotCleared();
     void slotTextEdited(const QString&);
-    void slotHelperEdited(const vector<string>&);
+    void slotHelperEdited(const std::vector<std::string>&);
 
 protected:
     void dispatchChange();
@@ -44,4 +43,3 @@ protected:
 
     MvQLineEdit* lineEdit_;
 };
-#endif
