@@ -32,7 +32,7 @@
 #include "MvQStyleLine.h"
 #include "MvQStyleTreeWidget.h"
 
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 #include "HelpFactory.h"
 
@@ -47,9 +47,7 @@ MvQStyleModel::MvQStyleModel(QObject* parent) :
 {
 }
 
-MvQStyleModel::~MvQStyleModel()
-{
-}
+MvQStyleModel::~MvQStyleModel() = default;
 
 int MvQStyleModel::columnCount(const QModelIndex& /*parent */) const
 {
@@ -92,16 +90,7 @@ QVariant MvQStyleModel::headerData(const int section, const Qt::Orientation orie
     if (orient != Qt::Horizontal || (role != Qt::DisplayRole && role != Qt::ToolTipRole))
         return QAbstractItemModel::headerData(section, orient, role);
 
-    if (role == Qt::DisplayRole) {
-        switch (section) {
-            case 0:
-                return " Matching styles";
-            default:
-                return QVariant();
-        }
-    }
-
-    return QVariant();
+    return role == Qt::DisplayRole && section == 0 ? " Matching styles" : QVariant();
 }
 
 QModelIndex MvQStyleModel::index(int row, int column, const QModelIndex& parent) const
@@ -118,7 +107,7 @@ QModelIndex MvQStyleModel::index(int row, int column, const QModelIndex& parent)
     return QModelIndex();
 }
 
-QModelIndex MvQStyleModel::parent(const QModelIndex& child) const
+QModelIndex MvQStyleModel::parent(const QModelIndex& /*child*/) const
 {
     return QModelIndex();
 }
@@ -164,7 +153,7 @@ MvQStyleSelectionWidget::MvQStyleSelectionWidget(QWidget* parent) :
     QWidget(parent),
     ignoreFilterChanged_(false)
 {
-    QVBoxLayout* vb = new QVBoxLayout(this);
+    auto* vb = new QVBoxLayout(this);
 
     nameLe_ = new QLineEdit(this);
     nameLe_->setPlaceholderText("Filter");
@@ -175,7 +164,7 @@ MvQStyleSelectionWidget::MvQStyleSelectionWidget(QWidget* parent) :
     QStringList allNames = MvQStyleDb::instance()->names();
     allNames << MvQStyleDb::instance()->layers() << MvQStyleDb::instance()->keywords() << MvQStyleDb::instance()->colours();
 
-    QCompleter* nameCompleter = new QCompleter(allNames, this);
+    auto* nameCompleter = new QCompleter(allNames, this);
     nameCompleter->setCaseSensitivity(Qt::CaseInsensitive);
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     nameCompleter->setFilterMode(Qt::MatchContains);
@@ -209,7 +198,7 @@ MvQStyleSelectionWidget::MvQStyleSelectionWidget(QWidget* parent) :
             this, SLOT(slotNameFilter(QString)));
 
     connect(browser_->tree()->selectionModel(), SIGNAL(currentChanged(QModelIndex, QModelIndex)),
-             this, SLOT(slotItemSelected(QModelIndex, QModelIndex)));
+            this, SLOT(slotItemSelected(QModelIndex, QModelIndex)));
 }
 
 void MvQStyleSelectionWidget::slotNameFilter(QString s)
@@ -233,7 +222,7 @@ void MvQStyleSelectionWidget::clearFilter()
     sortModel_->invalidate();
 }
 
-void MvQStyleSelectionWidget::slotItemSelected(const QModelIndex& current, const QModelIndex& prev)
+void MvQStyleSelectionWidget::slotItemSelected(const QModelIndex& current, const QModelIndex& /*prev*/)
 {
     QModelIndex idxSrc = sortModel_->mapToSource(current);
     if (idxSrc.isValid()) {
@@ -296,15 +285,15 @@ void MvQStyleHelp::slotSelected(int idx)
 {
     if (idx >= 0 && idx < MvQStyleDb::instance()->items().count()) {
         if (MvQStyleDb::instance()->items()[idx]->name() != oriName_) {
-            std::vector<string> vs;
-            vs.push_back(metview::toString<int>(idx));
+            std::vector<std::string> vs;
+            vs.push_back(std::to_string(idx));
             emit edited(vs);
             oriName_.clear();
         }
     }
 }
 
-void MvQStyleHelp::refresh(const vector<string>& values)
+void MvQStyleHelp::refresh(const std::vector<std::string>& values)
 {
     if (values.size() == 0)
         return;
