@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQSTYLELINE_H
-#define MVQSTYLELINE_H
+#pragma once
 
 #include "MvQRequestPanelLine.h"
 #include "MvIconParameter.h"
@@ -31,11 +30,11 @@ public:
     MvQStyleLine(RequestPanel& owner, const MvIconParameter& param);
     ~MvQStyleLine() {}
 
-    void refresh(const vector<string>&);
+    void refresh(const std::vector<std::string>&);
     void widgetClicked();
 
 public slots:
-    void slotHelperEdited(const vector<string>&);
+    void slotHelperEdited(const std::vector<std::string>&);
 
 protected:
     void next(const MvIconParameter&, const char* first, const char* second);
@@ -46,5 +45,3 @@ protected:
     QLabel* stylePixLabel_;
     QLabel* styleNameLabel_;
 };
-
-#endif  // MVQSTYLELINE_H
