@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQTemplateDrawer_H
-#define MvQTemplateDrawer_H
+#pragma once
 
 #include <QObject>
 #include "EditorDrawer.h"
@@ -45,5 +44,3 @@ public:
 protected:
     MvQContextItemSet* cmSet();
 };
-
-#endif
\ No newline at end of file
