@@ -31,24 +31,25 @@
 #include "Path.h"
 #include "Request.h"
 
-MvQTemporaryEditor::MvQTemporaryEditor(const IconClass& name, const string& kind, QWidget* parent) :
+MvQTemporaryEditor::MvQTemporaryEditor(const IconClass& name, const std::string& kind, QWidget* parent) :
     QDialog(parent),
     Editor(name, kind)
 {
-    QVBoxLayout* vb = new QVBoxLayout;
+    auto* vb = new QVBoxLayout;
     vb->setSpacing(0);
     vb->setContentsMargins(1, 1, 1, 1);
     setLayout(vb);
 
     //Header
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     vb->addLayout(hb);
 
     // TODO: do not use if
-    QLabel* pixLabel = new QLabel(this);
+    auto* pixLabel = new QLabel(this);
     if (name.name().find("python_") == 0) {
         pixLabel->setPixmap(MvQIconProvider::pixmap(IconClass::find("PYTHON"), 32));
-    } else {
+    }
+    else {
         pixLabel->setPixmap(MvQIconProvider::pixmap(IconClass::find("MACRO"), 32));
     }
 
@@ -69,7 +70,7 @@ MvQTemporaryEditor::MvQTemporaryEditor(const IconClass& name, const string& kind
     hb->addWidget(headerLabel_, 1);
 
     //Panel layout
-    QWidget* w     = new QWidget(this);
+    auto* w        = new QWidget(this);
     centralLayout_ = new QHBoxLayout;
     centralLayout_->setSpacing(0);
     centralLayout_->setContentsMargins(1, 1, 1, 1);
@@ -94,9 +95,7 @@ MvQTemporaryEditor::MvQTemporaryEditor(const IconClass& name, const string& kind
     vb->addWidget(buttonBox_);
 }
 
-MvQTemporaryEditor::~MvQTemporaryEditor()
-{
-}
+MvQTemporaryEditor::~MvQTemporaryEditor() = default;
 
 void MvQTemporaryEditor::changed()
 {
@@ -120,12 +119,12 @@ void MvQTemporaryEditor::updateHeader()
     if (!current_)
         return;
 
-    auto subCol = MvQTheme::subText();
+    auto subCol  = MvQTheme::subText();
     QString name = "Macro";
     if (class_.name().find("python_") == 0) {
         name = "Python";
     }
-    QString t = "Editor started from a " + name +  " script";
+    QString t = "Editor started from a " + name + " script";
     headerLabel_->setText(MvQ::formatText(t, subCol));
 }
 
