@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQTemporaryEditor_H
-#define MvQTemporaryEditor_H
+#pragma once
 
 #include <QDialog>
 
@@ -25,7 +24,7 @@ class MvQTemporaryEditor : public QDialog, public Editor
     Q_OBJECT
 
 public:
-    MvQTemporaryEditor(const IconClass& name, const string& kind, QWidget* parent = 0);
+    MvQTemporaryEditor(const IconClass& name, const std::string& kind, QWidget* parent = 0);
     ~MvQTemporaryEditor();
 
     void changed();
@@ -52,5 +51,3 @@ protected:
     QPushButton* cancelPb_;
     QPushButton* resetPb_;
 };
-
-#endif
