@@ -31,13 +31,13 @@ MvQTextLine::MvQTextLine(RequestPanel& owner, const MvIconParameter& param) :
             this, SLOT(slotCleared()));
 }
 
-void MvQTextLine::refresh(const vector<string>& values)
+void MvQTextLine::refresh(const std::vector<std::string>& values)
 {
-    string s;
-    for (vector<string>::const_iterator j = values.begin(); j != values.end(); ++j) {
+    std::string s;
+    for (const auto& value : values) {
         if (s.length())
             s += "/";
-        s += *j;
+        s += value;
     }
 
     //Now this is the tricky part. Whenever the user types in a new character the
@@ -48,7 +48,7 @@ void MvQTextLine::refresh(const vector<string>& values)
     //during the editing the string changes back to "7". In this case we do not want to set the linedit.
     //So we need to carefully compare the new and the previous string and decide what to do.
 
-    string prevText = lineEdit_->text().toStdString();
+    std::string prevText = lineEdit_->text().toStdString();
 
     if (s.empty() || s != prevText) {
         //Single strings
@@ -97,7 +97,7 @@ void MvQTextLine::refresh(const vector<string>& values)
 
 void MvQTextLine::dispatchChange()
 {
-    vector<string> vals;
+    std::vector<std::string> vals;
     QString txt = lineEdit_->text();
     foreach (QString s, txt.split("/")) {
         vals.push_back(s.toStdString());
@@ -111,7 +111,7 @@ void MvQTextLine::updateHelper()
     if (doNotUpdateHelper_ || !helper_)
         return;
 
-    vector<string> vals;
+    std::vector<std::string> vals;
     QString txt = lineEdit_->text();
     foreach (QString s, txt.split("/")) {
         vals.push_back(s.toStdString());
@@ -137,39 +137,40 @@ void MvQTextLine::slotHelperEdited(QStringList vals, QVector<bool> st)
     QString txt     = lineEdit_->text();
     QStringList lst = txt.split("/");
 
-    for(int i=0; i < vals.size(); i++) {
+    for (int i = 0; i < vals.size(); i++) {
         if (st[i] && !lst.contains(vals[i])) {
             lst << vals[i];
-        } else if (!st[i] && lst.contains(vals[i])) {
+        }
+        else if (!st[i] && lst.contains(vals[i])) {
             lst.removeAll(vals[i]);
         }
     }
 
-//    for (vector<string>::const_iterator it = values.begin(); it != values.end(); it++) {
-//        QString s(it->c_str());
-//        if (!lst.contains(s))
-//            lst << s;
-//    }
+    //    for (std::vector<std::string>::const_iterator it = values.begin(); it != values.end(); it++) {
+    //        QString s(it->c_str());
+    //        if (!lst.contains(s))
+    //            lst << s;
+    //    }
 
-//    for (vector<string>::const_iterator it = noValues.begin(); it != noValues.end(); it++) {
-//        QString s(it->c_str());
-//        if (lst.contains(s))
-//            lst.removeAll(s);
-//    }
+    //    for (std::vector<std::string>::const_iterator it = noValues.begin(); it != noValues.end(); it++) {
+    //        QString s(it->c_str());
+    //        if (lst.contains(s))
+    //            lst.removeAll(s);
+    //    }
 
     QString res = lst.join("/");
     if (res.startsWith("/"))
         res.remove(0, 1);
 
     if (res != txt) {
-        doNotUpdateHelper_=true;
+        doNotUpdateHelper_ = true;
         lineEdit_->setText(res);
         dispatchChange();
-        doNotUpdateHelper_=false;
+        doNotUpdateHelper_ = false;
     }
 }
 
-void MvQTextLine::slotHelperEdited(const vector<string>& values)
+void MvQTextLine::slotHelperEdited(const std::vector<std::string>& values)
 {
     if (values.size() > 0) {
         QString s(values[0].c_str());
