@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQTextLine_H
-#define MvQTextLine_H
+#pragma once
 
 #include "MvQRequestPanelLine.h"
 
@@ -26,17 +25,17 @@ class MvQTextLine : public MvQRequestPanelLine
     Q_OBJECT
 public:
     MvQTextLine(RequestPanel& owner, const MvIconParameter& param);
-    ~MvQTextLine(){};
+    ~MvQTextLine() {}
 
     QString currentValue() { return QString(); }
     void addValue(QString) {}
 
-    void refresh(const vector<string>&);
+    void refresh(const std::vector<std::string>&) override;
 
 public slots:
     void slotCleared();
     void slotTextEdited(const QString&);
-    void slotHelperEdited(const vector<string>&) override;
+    void slotHelperEdited(const std::vector<std::string>&) override;
     void slotHelperEdited(QStringList, QVector<bool>) override;
 
 protected:
@@ -46,5 +45,3 @@ protected:
     MvQLineEdit* lineEdit_;
     bool doNotUpdateHelper_{false};
 };
-
-#endif
