@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQViewDrawer_H
-#define MvQViewDrawer_H
+#pragma once
 
 #include <QObject>
 
@@ -37,7 +36,7 @@ protected:
     MvQFolderModel* model_;
     MvQViewDrawerView* view_;
     Folder* folder_;
-    vector<string> classes_;
+    std::vector<std::string> classes_;
 };
 
 
@@ -50,5 +49,3 @@ public:
 protected:
     MvQContextItemSet* cmSet();
 };
-
-#endif
\ No newline at end of file
