@@ -7,15 +7,14 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef NoEditor_H
-#define NoEditor_H
+#pragma once
 
 #include "Editor.h"
 
 class NoEditor : public Editor
 {
 public:
-    NoEditor(const IconClass&, const string&);
+    NoEditor(const IconClass&, const std::string&);
     virtual ~NoEditor();
 
     void changed() {}
@@ -31,5 +30,3 @@ private:
 };
 
 inline void destroy(NoEditor**) {}
-
-#endif
