@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef PYTHONGUIOBJECT_H
-#define PYTHONGUIOBJECT_H
+#pragma once
 
 #include "Metview.h"
 #include "IconClass.h"
@@ -28,12 +27,10 @@ private:
     PythonGuiObject& operator=(const PythonGuiObject&);
 
     virtual MvIconLanguage& language() const;
-    virtual string editor() const;
+    virtual std::string editor() const;
 
     MvIconLanguage lang_;
     IconMaker<StandardObject> maker_;
 };
 
 inline void destroy(PythonGuiObject**) {}
-
-#endif // PYTHONGUIOBJECT_H
