@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Queue_H
-#define Queue_H
+#pragma once
 
 #include "TaskObserver.h"
 #include "Task.h"
@@ -37,10 +36,8 @@ private:
     virtual void run();
 
     IconObjectH owner_;
-    list<TaskH> tasks_;
+    std::list<TaskH> tasks_;
     TaskH active_;
 };
 
 inline void destroy(Queue**) {}
-
-#endif
