@@ -46,13 +46,13 @@ RequestPanel::RequestPanel(const IconClass& kind, MvQRequestPanelWidget* panelWi
     scan();
 
     //Check if there are params depending on others' values (it is idependent of the Rules!!!)
-    for (vector<RequestPanelItem*>::iterator j = items_.begin(); j != items_.end(); ++j) {
-        if ((*j)->isDependent()) {
-            dependentItems_.push_back(*j);
+    for (auto& item : items_) {
+        if (item->isDependent()) {
+            dependentItems_.push_back(item);
         }
     }
 
-    QWidget* w = new QWidget(panelWidget_);
+    auto* w = new QWidget(panelWidget_);
     addWidget(w, count(), 1);
     setRowStretch(count() - 1, 1);
 
@@ -61,8 +61,8 @@ RequestPanel::RequestPanel(const IconClass& kind, MvQRequestPanelWidget* panelWi
 
 RequestPanel::~RequestPanel()
 {
-    for (vector<RequestPanelItem*>::iterator it = items_.begin(); it != items_.end(); it++)
-        delete (*it);
+    for (auto& item : items_)
+        delete item;
 }
 
 const IconClass& RequestPanel::iconClass()
@@ -122,7 +122,7 @@ void RequestPanel::merge(IconObject* o)
     // MAP_AREA_DEFINITION=CORNERS.
 
     if (!strcmp(r1.getVerb(), "GEOVIEW") && !strcmp(o->request().getVerb(), "MAPVIEW")) {
-        if ((const char*)(o->request()("AREA")) != NULL) {
+        if ((const char*)(o->request()("AREA")) != nullptr) {
             r.setValue("MAP_AREA_DEFINITION", "CORNERS");
         }
     }
@@ -153,8 +153,7 @@ void RequestPanel::next(const MvIconParameter& p)
 
 void RequestPanel::call(Method proc)
 {
-    for (vector<RequestPanelItem*>::iterator j = items_.begin(); j != items_.end(); ++j) {
-        RequestPanelItem* o = *j;
+    for (auto o : items_) {
         (o->*proc)();
     }
 }
@@ -168,7 +167,7 @@ void RequestPanel::apply()
 
 const Request& RequestPanel::request(long flags)
 {
-    map<long, Request>::iterator j = cache_.find(flags);
+    auto j = cache_.find(flags);
     if (j != cache_.end())
         return (*j).second;
     return cache_[flags] = class_.language().expand(cache_[EXPAND_2ND_NAME], flags);
@@ -176,8 +175,6 @@ const Request& RequestPanel::request(long flags)
 
 void RequestPanel::request(const Request& r, long flags)
 {
-    //r.print();
-
     cache_.clear();
     cache_[EXPAND_2ND_NAME] = class_.language().expand(r, EXPAND_2ND_NAME);
     if (flags != EXPAND_2ND_NAME)
@@ -186,8 +183,8 @@ void RequestPanel::request(const Request& r, long flags)
 
 void RequestPanel::edit(IconObject* o)
 {
-    for (vector<RequestPanelItem*>::iterator j = items_.begin(); j != items_.end(); ++j)
-        (*j)->edit(o);
+    for (auto& item : items_)
+        item->edit(o);
 }
 
 void RequestPanel::close()
@@ -227,14 +224,14 @@ void RequestPanel::changed(RequestPanelItem& p, bool canUpdate)
     owner_->changed();
 }
 
-void RequestPanel::set(const char* p, const string& v)
+void RequestPanel::set(const char* p, const std::string& v)
 {
     Request r = request();
     r(p)      = v.c_str();
     request(r);
 
-    for (vector<RequestPanelItem*>::iterator j = dependentItems_.begin(); j != dependentItems_.end(); ++j) {
-        (*j)->changed(p, v);
+    for (auto& dependentItem : dependentItems_) {
+        dependentItem->changed(p, v);
     }
 
     if (!apply_)
@@ -243,14 +240,14 @@ void RequestPanel::set(const char* p, const string& v)
     owner_->changed();
 }
 
-void RequestPanel::set(const char* p, const vector<string>& v)
+void RequestPanel::set(const char* p, const std::vector<std::string>& v)
 {
     Request r = request();
     r.set(p, v);
     request(r);
 
-    for (vector<RequestPanelItem*>::iterator j = dependentItems_.begin(); j != dependentItems_.end(); ++j) {
-        (*j)->changed(p, v);
+    for (auto& dependentItem : dependentItems_) {
+        dependentItem->changed(p, v);
     }
 
     if (!apply_)
@@ -280,9 +277,9 @@ void RequestPanel::setToDefault(RequestPanelItem* item)
     if (!apply_) {
         item->reset();
 
-        for (vector<RequestPanelItem*>::iterator j = items_.begin(); j != items_.end(); ++j) {
-            if ((*j) != item)
-                (*j)->update();
+        for (auto& j : items_) {
+            if (j != item)
+                j->update();
         }
     }
 
@@ -303,8 +300,8 @@ IconObjectH RequestPanel::currentObject()
 int RequestPanel::defaultCnt()
 {
     int cnt = 0;
-    for (vector<RequestPanelItem*>::iterator it = items_.begin(); it != items_.end(); it++)
-        if ((*it)->hasDefaultTb())
+    for (auto& item : items_)
+        if (item->hasDefaultTb())
             cnt++;
     return cnt;
 }
@@ -318,7 +315,7 @@ void RequestPanel::updateParentWidget()
 
 void RequestPanel::setFilter(QString txt)
 {
-    filterText_= txt;
+    filterText_ = txt;
     runFilter();
 }
 
@@ -326,12 +323,13 @@ void RequestPanel::runFilter()
 {
     if (!filterText_.isEmpty()) {
         auto txt = filterText_.toLower();
-        for(auto item: items_) {
+        for (auto item : items_) {
             auto name = QString::fromStdString(item->parameter().beautifiedName());
             item->setVisibleByFilter(name.toLower().contains(txt));
         }
-    } else {
-        for(auto item: items_) {
+    }
+    else {
+        for (auto item : items_) {
             item->setVisibleByFilter(true);
         }
     }
@@ -341,7 +339,7 @@ void RequestPanel::runFilter()
 int RequestPanel::filterNonMatchCount()
 {
     int cnt = 0;
-    for(auto item: items_) {
+    for (auto item : items_) {
         if ((showDisabledItems_ || !item->isGray()) && !item->isVisibleByFilter()) {
             cnt++;
         }
@@ -352,8 +350,18 @@ int RequestPanel::filterNonMatchCount()
 void RequestPanel::setShowDisabledItems(bool b)
 {
     showDisabledItems_ = b;
-    for (vector<RequestPanelItem*>::iterator it = items_.begin(); it != items_.end(); ++it) {
-        (*it)->adjustDisabled();
+    for (auto& item : items_) {
+        item->adjustDisabled();
     }
     panelWidget_->delayedForceRepaint();
 }
+
+void RequestPanel::applyTemporaryRules(bool temporary)
+{
+    if (temporary) {
+        for(auto item: items_) {
+            item->setVisibleByTemporary(temporary);
+        }
+        panelWidget_->delayedForceRepaint();
+    }
+}
