@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef RequestPanel_H
-#define RequestPanel_H
+#pragma once
 
 #include <QGridLayout>
 
@@ -30,8 +29,8 @@ public:
 
     void changed();
     void changed(RequestPanelItem&, bool = true);
-    void set(const char*, const string&);
-    void set(const char*, const vector<string>&);
+    void set(const char*, const std::string&);
+    void set(const char*, const std::vector<std::string>&);
     void clear(const char*);
 
     void registerObserver(RequestPanelItem*);
@@ -50,6 +49,7 @@ public:
     void itemWasChangedToDefault();
     void setFilter(QString);
     void runFilter();
+    void applyTemporaryRules(bool temporary);
     int filterNonMatchCount();
     void setShowDisabledItems(bool);
 
@@ -65,7 +65,7 @@ public:
     bool showDisabledItems() const { return showDisabledItems_; }
 
 protected:
-    vector<RequestPanelItem*> items_;
+    std::vector<RequestPanelItem*> items_;
     const IconClass& class_;
     bool apply_;
 
@@ -78,10 +78,10 @@ private:
 
     virtual void next(const MvIconParameter&);
 
-    map<long, Request> cache_;
+    std::map<long, Request> cache_;
     MvQRequestPanelWidget* panelWidget_;
     Editor* owner_;
-    vector<RequestPanelItem*> dependentItems_;
+    std::vector<RequestPanelItem*> dependentItems_;
     bool showDisabledItems_;
     QString filterText_;
 };
@@ -105,5 +105,3 @@ public:
 //#ifdef _ODI_OSSG_
 //OS_MARK_SCHEMA_TYPE(RequestPanel);
 //#endif
-
-#endif
