@@ -8,8 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 
-#ifndef ResolveTransaction_H
-#define ResolveTransaction_H
+#pragma once
 
 
 #include "Transaction.h"
@@ -46,5 +45,3 @@ inline void destroy(ResolveTransaction**) {}
 //#ifdef _ODI_OSSG_
 //OS_MARK_SCHEMA_TYPE(ResolveTransaction);
 //#endif
-
-#endif
