@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef RootFolder_H
-#define RootFolder_H
+#pragma once
 
 #include "SystemFolder.h"
 
@@ -23,14 +22,12 @@ private:
     RootFolder(const RootFolder&);
     RootFolder& operator=(const RootFolder&);
 
-    virtual Path path() const;
-    virtual Path dotPath() const;
-    virtual string fullName() const;
-    virtual Folder* parent() const;
-    virtual Path logPath();
-    bool isEmbedded() { return false; }
+    Path path() const override;
+    Path dotPath() const override;
+    std::string fullName() const override;
+    Folder* parent() const override;
+    Path logPath() override;
+    bool isEmbedded() override { return false; }
 };
 
 inline void destroy(RootFolder**) {}
-
-#endif
