@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Runnable_H
-#define Runnable_H
+#pragma once
 
 #include <QObject>
 
@@ -38,6 +37,3 @@ private:
     //QT slot???
     //static Boolean workCB(XtPointer);
 };
-
-
-#endif
