@@ -13,10 +13,10 @@
 
 #include <map>
 
-typedef map<string, Service*> Map;
+using Map            = std::map<std::string, Service*>;
 static Map* services = nullptr;
 
-Service::Service(const string& name) :
+Service::Service(const std::string& name) :
     name_(name)
 {
     if (services == nullptr)
@@ -24,19 +24,17 @@ Service::Service(const string& name) :
     (*services)[name] = this;
 }
 
-Service::~Service()
-{
-}
-string Service::name()
+Service::~Service() = default;
+
+std::string Service::name()
 {
     return name_;
 }
 
-Service* Service::find(const string& name)
+Service* Service::find(const std::string& name)
 {
     if (services) {
-        Map::iterator j = services->find(name);
-
+        auto j = services->find(name);
         if (j != services->end())
             return (*j).second;
     }
@@ -49,7 +47,7 @@ Service* Service::find(const string& name)
     return nullptr;
 }
 
-void Service::print(ostream& s) const
+void Service::print(std::ostream& s) const
 {
     s << name_;
 }
