@@ -9,31 +9,29 @@
 
 #include "ServiceEditor.h"
 
+#include <fstream>
+#include "fstream_mars_fix.h"
+
 #include "EditorFactory.h"
 #include "IconObject.h"
 #include "Request.h"
 #include "IconClass.h"
 #include "Editor.h"
 #include "ReplyObserver.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "MvTmpFile.h"
 
-#include <fstream>
 #include <assert.h>
 #include <signal.h>
 
 #define SERVICEEDITOR_MV_DEBUG__
 
-ServiceEditor::ServiceEditor(const IconClass& name, const string& kind) :
+ServiceEditor::ServiceEditor(const IconClass& name, const std::string& kind) :
     Editor(name, kind),
     replyObserver_(nullptr)
 {
 }
 
-ServiceEditor::~ServiceEditor()
-{
-}
-
 void ServiceEditor::raiseIt()
 {
     getRemotePid();
@@ -46,11 +44,12 @@ void ServiceEditor::raiseIt()
             MvRequest r("RAISE_WINDOW");
             r("PID") = remotePid_;
             MvApplication::sendMessage(r);
-        // the remote editor app is not running but we have not got the reply
-        } else {
+            // the remote editor app is not running but we have not got the reply
+        }
+        else {
             // disable the replyobserver
             if (replyObserver_) {
-                replyObserver_->editor_=nullptr;
+                replyObserver_->editor_ = nullptr;
             }
             //edit again
             edit();
@@ -73,7 +72,7 @@ void ServiceEditor::closeIt()
 
 void ServiceEditor::edit(void)
 {
-    string path = current_->path().str();
+    std::string path = current_->path().str();
     assert(replyObserver_ == nullptr);
     assert(remotePid_ == -1);
     assert(pidFile_.empty());
@@ -90,7 +89,7 @@ void ServiceEditor::edit(void)
 void ServiceEditor::editDone()
 {
     replyObserver_ = nullptr;
-    remotePid_ = -1;
+    remotePid_     = -1;
     pidFile_.clear();
     Editor::editDone();
 }
@@ -101,7 +100,7 @@ void ServiceEditor::getRemotePid()
         std::ifstream f(pidFile_);
         if (f.good()) {
             int pid = 0;
-            f >> pid;      
+            f >> pid;
             if (metview::isPidValid(pid)) {
                 remotePid_ = pid;
                 return;
@@ -120,17 +119,12 @@ bool ServiceEditor::isRemoteRunning() const
 
 //=================================================================
 
-ServiceEditorObserver::ServiceEditorObserver(ServiceEditor* editor, string& path) :
+ServiceEditorObserver::ServiceEditorObserver(ServiceEditor* editor, std::string& path) :
     editor_(editor),
     path_(path)
 {
 }
 
-ServiceEditorObserver::~ServiceEditorObserver()
-{
-}
-
-
 void ServiceEditorObserver::start(const std::string& pidFile)
 {
     if (!editor_)
@@ -143,34 +137,34 @@ void ServiceEditorObserver::start(const std::string& pidFile)
 
     if (kind == "WMSCLIENT") {
         r.read(path_.c_str());
-        r("_NAME")    = path_.c_str();
-        r("_CLASS")   = kind.c_str();
-    } else if (kind == "RTTOV_INPUT_DATA" || kind == "SCM_INPUT_DATA") {
-        r = MvRequest(kind.c_str());
-        r("PATH")     = path_.c_str();
-        r("_NAME")    = path_.c_str();
-        r("_CLASS")   = kind.c_str();
+        r("_NAME")  = path_.c_str();
+        r("_CLASS") = kind.c_str();
+    }
+    else if (kind == "RTTOV_INPUT_DATA" || kind == "SCM_INPUT_DATA") {
+        r           = MvRequest(kind.c_str());
+        r("PATH")   = path_.c_str();
+        r("_NAME")  = path_.c_str();
+        r("_CLASS") = kind.c_str();
     }
     else {
-        r = ("MACROEDIT");
-        r("PATH")     = path_.c_str();                       // path to macro
+        r             = ("MACROEDIT");
+        r("PATH")     = path_.c_str();                        // path to macro
         r("LANGUAGE") = editor_->iconClass().name().c_str();  // icon class, e.g. MACRO or MAGML
         r("_CLASS")   = editor_->iconClass().name().c_str();  // icon class, e.g. MACRO or MAGML
     }
 
-    r("_ACTION")  = "edit";
+    r("_ACTION")   = "edit";
     r("_PID_FILE") = pidFile.c_str();
     r("_WAIT_APP") = "1";
     r.print();
 
     callService("UiAppManager", r);
-
 }
 
 // the qt editor application finished
-void ServiceEditorObserver::reply(const Request& r, int err)
+void ServiceEditorObserver::reply(const Request& /*r*/, int /*err*/)
 {
-    if(editor_) {
+    if (editor_) {
         editor_->notifyObserverApply();
         editor_->editDone();
     }
