@@ -7,15 +7,14 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef ShellService_H
-#define ShellService_H
+#pragma once
 
 #include "Service.h"
 
 class ShellService : public Service
 {
 public:
-    ShellService(const string&);
+    ShellService(const std::string&);
     virtual ~ShellService();
 
 private:
@@ -27,5 +26,3 @@ private:
 };
 
 inline void destroy(ShellService**) {}
-
-#endif
