@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef ShellTask_H
-#define ShellTask_H
+#pragma once
 
 #include "Task.h"
 #include "IconObject.h"
@@ -18,13 +17,13 @@
 class ShellTask : public Task, public Input
 {
 public:
-    ShellTask(const string&, IconObject*);
+    ShellTask(const std::string&, IconObject*);
     virtual ~ShellTask();
 
-    virtual void addContext(const Request&){};
+    virtual void addContext(const Request&) {}
 
 protected:
-    void print(ostream&) const;
+    void print(std::ostream&) const;
     void Object(IconObjectH xx) { object_ = xx; }
 
     // From Task
@@ -39,12 +38,10 @@ private:
 
     IconObjectH object_;
     FILE* file_;
-    string cmd_;
+    std::string cmd_;
 
     // From Input
     virtual void ready(const char*);
 };
 
 inline void destroy(ShellTask**) {}
-
-#endif
