@@ -24,7 +24,7 @@
 #include "MvQRequestPanelWidget.h"
 
 
-SimpleEditor::SimpleEditor(const IconClass& kind, const string& name) :
+SimpleEditor::SimpleEditor(const IconClass& kind, const std::string& name) :
     MvQEditor(kind, name)
 {
     setupLineFilter();
@@ -36,10 +36,10 @@ SimpleEditor::SimpleEditor(const IconClass& kind, const string& name) :
 
     centralLayout_->addWidget(panelArea_);
 
-    vector<string> classes;
+    std::vector<std::string> classes;
     classes.push_back(kind.name());
 
-    MvQRequestPanelWidget* w = new MvQRequestPanelWidget(classes, this);
+    auto* w = new MvQRequestPanelWidget(classes, this);
     Q_ASSERT(showDisabledAc_);
     panel_ = new RequestPanel(kind, w, this, showDisabled());
 
@@ -54,7 +54,7 @@ SimpleEditor::~SimpleEditor()
     delete panel_;
 }
 
-IconObject* SimpleEditor::copy(const string& /*name*/)
+IconObject* SimpleEditor::copy(const std::string& /*name*/)
 {
     //IconObject* o = IconFactory::create(name, class_);
     //panel_.apply();
@@ -75,7 +75,7 @@ void SimpleEditor::edit()
 void SimpleEditor::apply()
 {
     panel_->apply();
-    current_->request(panel_->request());
+    current_->setRequest(panel_->request());
 }
 
 void SimpleEditor::reset()
@@ -130,7 +130,7 @@ void SimpleEditor::slotFilterItems(QString txt)
 
 int SimpleEditor::filterNonMatchCount()
 {
-   return panel_->filterNonMatchCount();
+    return panel_->filterNonMatchCount();
 }
 
 void SimpleEditor::slotShowDisabled(bool st)
@@ -140,6 +140,11 @@ void SimpleEditor::slotShowDisabled(bool st)
     updateFilterCountLabel();
 }
 
+void SimpleEditor::applyTemporayRules()
+{
+    Q_ASSERT(panel_);
+    panel_->applyTemporaryRules(temporary_);
+}
 
 static EditorMaker<SimpleEditor> editorMaker1("SimpleEditor");
 static EditorMaker<SimpleEditor> editorMaker2("RetrieveEditor");
