@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef SystemFolder_H
-#define SystemFolder_H
+#pragma once
 
 #include "Folder.h"
 
@@ -16,18 +15,18 @@ class SystemFolder : public Folder
 {
 public:
     SystemFolder(Folder* parent, const IconClass& kind,
-                 const string& name, IconInfo* info);
+                 const std::string& name, IconInfo* info);
 
     virtual ~SystemFolder();
 
 protected:
-    set<string> can();
+    std::set<std::string> can() override;
 
 private:
     SystemFolder(const SystemFolder&);
     SystemFolder& operator=(const SystemFolder&);
 
-    virtual bool renamable() const;
+    bool renamable() const override;
 };
 
 inline void destroy(SystemFolder**) {}
@@ -36,5 +35,3 @@ inline void destroy(SystemFolder**) {}
 //#ifdef _ODI_OSSG_
 //OS_MARK_SCHEMA_TYPE(SystemFolder);
 //#endif
-
-#endif
