@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Task_H
-#define Task_H
+#pragma once
 
 #include <set>
 
@@ -34,7 +33,7 @@ protected:
     void success(const Request&);
     void failure(const Request&);
 
-    virtual void print(ostream&) const = 0;
+    virtual void print(std::ostream&) const = 0;
 
     bool stopped_;
 
@@ -45,7 +44,7 @@ private:
 
     std::set<TaskObserver*> observers_;
 
-    friend ostream& operator<<(ostream& s, const Task& p)
+    friend std::ostream& operator<<(std::ostream& s, const Task& p)
     {
         p.print(s);
         return s;
@@ -54,5 +53,3 @@ private:
 };
 
 typedef Handle<Task> TaskH;
-
-#endif
