@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef TaskObserver_H
-#define TaskObserver_H
+#pragma once
 
 class Request;
 class Task;
@@ -19,5 +18,3 @@ public:
     virtual void success(Task*, const Request&) = 0;
     virtual void failure(Task*, const Request&) = 0;
 };
-
-#endif
