@@ -11,8 +11,8 @@
 
 #include <stdio.h>
 
-TeeBuffer::TeeBuffer(ostream& one, ostream& two) :
-    streambuf(),
+TeeBuffer::TeeBuffer(std::ostream& one, std::ostream& two) :
+    std::streambuf(),
     one_(one),
     two_(two)
 {
@@ -54,6 +54,6 @@ void TeeBuffer::dumpBuffer()
 
     setp(pbase(), epptr());
 
-    one_ << flush;
-    two_ << flush;
+    one_ << std::flush;
+    two_ << std::flush;
 }
