@@ -7,18 +7,16 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef TeeBuffer_H
-#define TeeBuffer_H
+#pragma once
 
-#include <iostream>
+#include <ostream>
 #include <streambuf>
 
-using namespace std;
 
-class TeeBuffer : public streambuf
+class TeeBuffer : public std::streambuf
 {
 public:
-    TeeBuffer(ostream&, ostream&);
+    TeeBuffer(std::ostream&, std::ostream&);
     ~TeeBuffer();
 
 protected:
@@ -31,8 +29,8 @@ private:
     TeeBuffer& operator=(const TeeBuffer&);
 
     char buffer_[1024];
-    ostream& one_;
-    ostream& two_;
+    std::ostream& one_;
+    std::ostream& two_;
 
     void dumpBuffer(void);
 };
@@ -43,5 +41,3 @@ inline void destroy(TeeBuffer**) {}
 //#ifdef _ODI_OSSG_
 //OS_MARK_SCHEMA_TYPE(TeeBuffer);
 //#endif
-
-#endif
