@@ -7,17 +7,15 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef TeeStream_H
-#define TeeStream_H
+#pragma once
 
-#include <iostream>
+#include <ostream>
 
-using namespace std;
 
-class TeeStream : public ostream
+class TeeStream : public std::ostream
 {
 public:
-    TeeStream(ostream&, ostream&);
+    TeeStream(std::ostream&, std::ostream&);
     ~TeeStream();
 
 private:
@@ -32,5 +30,3 @@ inline void destroy(TeeStream**) {}
 //#ifdef _ODI_OSSG_
 //OS_MARK_SCHEMA_TYPE(TeeStream);
 //#endif
-
-#endif
