@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef TemporaryEditor_H
-#define TemporaryEditor_H
+#pragma once
 
 #include "MvQTemporaryEditor.h"
 
@@ -21,7 +20,7 @@ class RequestPanel;
 class TemporaryEditor : public MvQTemporaryEditor
 {
 public:
-    TemporaryEditor(const IconClass&, const string&);
+    TemporaryEditor(const IconClass&, const std::string&);
     virtual ~TemporaryEditor();
 
 private:
@@ -33,12 +32,10 @@ private:
     virtual void close();
     virtual void edit();
 
-    virtual IconObject* copy(const string&);
+    virtual IconObject* copy(const std::string&);
 
     RequestPanel* panel_;
     QScrollArea* panelArea_;
 };
 
 inline void destroy(TemporaryEditor**) {}
-
-#endif
