@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Tools_H
-#define Tools_H
+#pragma once
 
 #include "Metview.h"
 
@@ -40,5 +39,3 @@ private:
 };
 
 inline void destroy(Tools**) {}
-
-#endif
