@@ -42,7 +42,7 @@
 #include "MvQPageView.h"
 #include "MvQMethods.h"
 
-vector<PaperSize*> PaperSizeHandler::std_;
+std::vector<PaperSize*> PaperSizeHandler::std_;
 
 
 //==============================================
@@ -52,7 +52,7 @@ vector<PaperSize*> PaperSizeHandler::std_;
 //==============================================
 
 
-ViewEditor::ViewEditor(const IconClass& name, const string& kind) :
+ViewEditor::ViewEditor(const IconClass& name, const std::string& kind) :
     MvQEditor(name, kind)
 {
     paper_ = new PaperSizeHandler;
@@ -77,7 +77,7 @@ ViewEditor::ViewEditor(const IconClass& name, const string& kind) :
     undoAc->setIcon(QPixmap(":/desktop/undo.svg"));
 
     //Duplicate
-    QAction* duplicateAc = new QAction(this);
+    auto* duplicateAc = new QAction(this);
     duplicateAc->setToolTip(tr("Duplicate selected frames"));
     duplicateAc->setIcon(QPixmap(":/desktop/duplicate.svg"));
 
@@ -85,7 +85,7 @@ ViewEditor::ViewEditor(const IconClass& name, const string& kind) :
             this, SLOT(slotDuplicateSelection(bool)));
 
     //page setup
-    QAction* pageAc = new QAction(this);
+    auto* pageAc = new QAction(this);
     pageAc->setToolTip(tr("Page setup"));
     pageAc->setIcon(QPixmap(":/desktop/page_setup.svg"));
 
@@ -110,17 +110,17 @@ ViewEditor::ViewEditor(const IconClass& name, const string& kind) :
     connect(gridAc_, SIGNAL(toggled(bool)),
             this, SLOT(slotGrid(bool)));
 
-    QAction* selectAllAc = new QAction(this);
+    auto* selectAllAc = new QAction(this);
     selectAllAc->setToolTip(tr("Select all frames"));
     selectAllAc->setIcon(QPixmap(":/desktop/page_select_all.svg"));
 
     connect(selectAllAc, SIGNAL(triggered(bool)),
             this, SLOT(slotSelectAll(bool)));
 
-    QAction* sep = new QAction(this);
+    auto* sep = new QAction(this);
     sep->setSeparator(true);
 
-    QAction* sep1 = new QAction(this);
+    auto* sep1 = new QAction(this);
     sep1->setSeparator(true);
 
     QList<QAction*> acLst;
@@ -131,7 +131,7 @@ ViewEditor::ViewEditor(const IconClass& name, const string& kind) :
     // Define view layout in the middle
     //--------------------------------------
 
-    QHBoxLayout* viewLayout = new QHBoxLayout();
+    auto* viewLayout = new QHBoxLayout();
     centralLayout_->addLayout(viewLayout);
 
     //-----------------------
@@ -139,42 +139,42 @@ ViewEditor::ViewEditor(const IconClass& name, const string& kind) :
     //-----------------------
 
     //Sidebar on the right
-    QVBoxLayout* rightVb = new QVBoxLayout;
+    auto* rightVb = new QVBoxLayout;
     rightVb->setSpacing(0);
     rightVb->setContentsMargins(1, 1, 1, 1);
     viewLayout->addLayout(rightVb);
 
-    QToolBar* sidebar_ = new QToolBar(this);
+    auto* sidebar_ = new QToolBar(this);
     sidebar_->setIconSize(QSize(24, 24));
     sidebar_->setOrientation(Qt::Vertical);
     rightVb->addWidget(sidebar_);
 
-    QAction* addAc = new QAction(this);
+    auto* addAc = new QAction(this);
     addAc->setToolTip(tr("Add new frame"));
     addAc->setIcon(QPixmap(":/desktop/page_add.svg"));
 
-    QAction* joinAc = new QAction(this);
+    auto* joinAc = new QAction(this);
     joinAc->setToolTip(tr("Join selected frames"));
     joinAc->setIcon(QPixmap(":/desktop/page_join.svg"));
 
-    QAction* splitAc = new QAction(this);
+    auto* splitAc = new QAction(this);
     splitAc->setToolTip(tr("Split selected frames"));
     splitAc->setIcon(QPixmap(":/desktop/page_split.svg"));
 
-    QAction* deleteAc = new QAction(this);
+    auto* deleteAc = new QAction(this);
     deleteAc->setToolTip(tr("Delete selected frames"));
     deleteAc->setIcon(QPixmap(":/desktop/page_delete.svg"));
 
-    QAction* expandAc = new QAction(this);
+    auto* expandAc = new QAction(this);
     expandAc->setToolTip(tr("Expand selected frames"));
     expandAc->setIcon(QPixmap(":/desktop/page_expand.svg"));
 
-    QAction* connectAc = new QAction(this);
+    auto* connectAc = new QAction(this);
     connectAc->setToolTip(tr("Connect selected frames - NOT YET SUPPORTED"));
     connectAc->setIcon(QPixmap(":/desktop/page_connect.svg"));
     connectAc->setEnabled(false);
 
-    QAction* disconnectAc = new QAction(this);
+    auto* disconnectAc = new QAction(this);
     disconnectAc->setToolTip(tr("Disonnect selected frames"));
     disconnectAc->setIcon(QPixmap(":/desktop/page_disconnect.svg"));
 
@@ -215,9 +215,9 @@ ViewEditor::ViewEditor(const IconClass& name, const string& kind) :
     // View
     //--------------------
 
-    MvIconLanguage& lang                = IconClass::find("PLOT_PAGE").language();
-    Request interface             = lang.interfaceRequest("VIEW");
-    const vector<string>& classes = interface.get("class");
+    MvIconLanguage& lang                    = IconClass::find("PLOT_PAGE").language();
+    Request interface                       = lang.interfaceRequest("VIEW");
+    const std::vector<std::string>& classes = interface.get("class");
 
     view_ = new MvQPageView(classes, undoStack_, this);
     viewLayout->addWidget(view_, 1);
@@ -231,15 +231,13 @@ ViewEditor::ViewEditor(const IconClass& name, const string& kind) :
     updateButtonStatus(0);
 }
 
-ViewEditor::~ViewEditor()
-{
-}
+ViewEditor::~ViewEditor() = default;
 
 void ViewEditor::apply()
 {
     savePaperSize(request_);
     savePages(current_, request_);
-    current_->request(request_);
+    current_->setRequest(request_);
 }
 
 void ViewEditor::reset()
@@ -282,10 +280,10 @@ void ViewEditor::loadPaperSize(const Request& r)
 
     setPaperSize(h, w);
 
-    //cout << "h = " << h << " w = " << w << endl;
+    //cout << "h = " << h << " w = " << w << std::endl;
 
     /*	
-  cout << "paperSize " << endl;
+  std::cout << "paperSize " << std::endl;
 	r.print();
 
 	// Set paper size...
@@ -299,7 +297,7 @@ void ViewEditor::loadPaperSize(const Request& r)
 	{  	
 		for(int i = 0; i < static_cast<int>(paperSizes_.size()) ; i++)
 		{
-			if(paperSizes_[i].name() == string(size))
+            if(paperSizes_[i].name() == std::string(size))
 			{
 				if(strcmp(orien,"PORTRAIT") == 0)
 				{
@@ -324,7 +322,7 @@ void ViewEditor::loadPaperSize(const Request& r)
 	
 	setPaperSize(h,w);
 
-	cout << "h = " << h << " w = " << w << endl;
+	cout << "h = " << h << " w = " << w << std::endl;
 	*/
 }
 
@@ -347,10 +345,10 @@ void ViewEditor::loadPages(IconObject* o, const Request& r)
 {
     //Clear the view
 
-    vector<IconObjectH> sub = o->subObjects("PAGES", r);
+    std::vector<IconObjectH> sub = o->subObjects("PAGES", r);
 
-    for (vector<IconObjectH>::iterator itPage = sub.begin(); itPage != sub.end(); ++itPage) {
-        MvRequest pageReq = (*itPage)->request();
+    for (auto& itPage : sub) {
+        MvRequest pageReq = itPage->request();
 
         pageReq.print();
 
@@ -360,12 +358,12 @@ void ViewEditor::loadPages(IconObject* o, const Request& r)
         double bottom         = pageReq("BOTTOM");
         MvQPageItem* pageItem = view_->addPage(left, top, right - left, bottom - top);
 
-        vector<IconObjectH> viewVec = (*itPage)->subObjects("VIEW", pageReq);
+        std::vector<IconObjectH> viewVec = itPage->subObjects("VIEW", pageReq);
 
         IconObject* viewObj = viewVec.size() ? static_cast<IconObject*>(viewVec[0]) : defaultView();
         pageItem->setViewIcon(viewObj);
 
-        loadSubPages(pageItem, *itPage, pageReq);
+        loadSubPages(pageItem, itPage, pageReq);
     }
 }
 
@@ -404,9 +402,9 @@ void ViewEditor::loadSubPages(MvQPageItem* p, IconObject* o, const Request& r)
 	}*/
 
     // New Style
-    vector<IconObjectH> sub = o->subObjects("SUB_PAGES", r);
-    for (vector<IconObjectH>::iterator ii = sub.begin(); ii != sub.end(); ++ii) {
-        MvRequest subR = (*ii)->request();
+    std::vector<IconObjectH> sub = o->subObjects("SUB_PAGES", r);
+    for (auto& ii : sub) {
+        MvRequest subR = ii->request();
 
         subR.print();
 
@@ -430,7 +428,7 @@ void ViewEditor::savePages(IconObject* o, Request& r)
     pageFolder->destroy();
     pageFolder = o->embeddedFolder("Pages", true);
 
-    vector<IconObjectH> pages;
+    std::vector<IconObjectH> pages;
 
     foreach (MvQPageItem* p, view_->pages()) {
         Request pageReq("PLOT_PAGE");
@@ -443,7 +441,7 @@ void ViewEditor::savePages(IconObject* o, Request& r)
         FolderH subPageFolder = page->embeddedFolder("Sub Pages", true);
         pages.push_back(page);
 
-        vector<IconObjectH> subpages;
+        std::vector<IconObjectH> subpages;
 
         foreach (QRectF subRect, p->subPaperRects()) {
             Request subReq("PLOT_SUBPAGE");
@@ -456,15 +454,15 @@ void ViewEditor::savePages(IconObject* o, Request& r)
 
         IconObjectH view = p->viewIcon();
         if (view)
-            page->setSubObjects("VIEW", vector<IconObjectH>(1, view), pageReq);
+            page->setSubObjects("VIEW", std::vector<IconObjectH>(1, view), pageReq);
 
-        page->request(pageReq);
+        page->setRequest(pageReq);
     }
 
     r.print();
 
     current_->setSubObjects("PAGES", pages, r);
-    current_->request(r);
+    current_->setRequest(r);
 }
 
 void ViewEditor::saveRectToRequest(QRectF rect, Request& r)
@@ -518,7 +516,7 @@ void ViewEditor::setPaperSize(double height, double width)
     view_->setSuperPage(width, height, snapAc_->isChecked(), snap_->x(), snap_->y(), gridAc_->isChecked());
 }
 
-string ViewEditor::alternateEditor()
+std::string ViewEditor::alternateEditor()
 {
     return "SimpleEditor";
 }
@@ -675,18 +673,18 @@ void PaperSizeHandler::set(const Request& r)
     const char* size  = r("LAYOUT_SIZE");
     const char* orien = r("LAYOUT_ORIENTATION");
 
-    string sizeStr = "A4";
+    std::string sizeStr = "A4";
     if (size)
-        sizeStr = string(size);
+        sizeStr = std::string(size);
 
     orientation_ = "LANDSCAPE";
     if (orien)
-        orientation_ = string(orien);
+        orientation_ = std::string(orien);
 
     bool found = false;
-    for (int i = 0; i < static_cast<int>(std_.size()); i++) {
-        if (std_.at(i)->name() == sizeStr && std_.at(i)->orientation() == orientation_) {
-            current_ = std_[i];
+    for (auto& i : std_) {
+        if (i->name() == sizeStr && i->orientation() == orientation_) {
+            current_ = i;
             found    = true;
             break;
         }
@@ -699,14 +697,14 @@ void PaperSizeHandler::set(const Request& r)
     }
 }
 
-void PaperSizeHandler::set(const string& sizeStr, const string& orien, double w, double h)
+void PaperSizeHandler::set(const std::string& sizeStr, const std::string& orien, double w, double h)
 {
     orientation_ = orien;
 
     bool found = false;
-    for (int i = 0; i < static_cast<int>(std_.size()); i++) {
-        if (std_.at(i)->name() == sizeStr && std_.at(i)->orientation() == orien) {
-            current_ = std_[i];
+    for (auto& i : std_) {
+        if (i->name() == sizeStr && i->orientation() == orien) {
+            current_ = i;
             found    = true;
             break;
         }
@@ -806,7 +804,7 @@ MvQPaperSizeWidget::MvQPaperSizeWidget(PaperSizeHandler* paper, QWidget* parent)
     paper_(paper)
 
 {
-    QGridLayout* grid = new QGridLayout;
+    auto* grid = new QGridLayout;
     setLayout(grid);
 
     QLabel* label;
@@ -819,12 +817,12 @@ MvQPaperSizeWidget::MvQPaperSizeWidget(PaperSizeHandler* paper, QWidget* parent)
     label->setBuddy(sizeCb_);
 
     std::set<std::string> nameSet;
-    for (vector<PaperSize*>::const_iterator it = paper_->stdSizes().begin(); it != paper_->stdSizes().end(); it++) {
+    for (auto it : paper_->stdSizes()) {
         //We do not allow duplicated names
-        if (nameSet.find((*it)->name()) == nameSet.end()) {
-            sizeCb_->addItem(QString::fromStdString((*it)->name()));
-            sizeCb_->setItemData(sizeCb_->count() - 1, QString::fromStdString((*it)->name()));
-            nameSet.insert((*it)->name());
+        if (nameSet.find(it->name()) == nameSet.end()) {
+            sizeCb_->addItem(QString::fromStdString(it->name()));
+            sizeCb_->setItemData(sizeCb_->count() - 1, QString::fromStdString(it->name()));
+            nameSet.insert(it->name());
         }
     }
 
@@ -957,7 +955,7 @@ MvQGridSnapWidget::MvQGridSnapWidget(GridSnapHandler* snap, QWidget* parent) :
     snap_(snap)
 
 {
-    QGridLayout* grid = new QGridLayout;
+    auto* grid = new QGridLayout;
     setLayout(grid);
 
     QLabel* label;
@@ -986,9 +984,9 @@ MvQGridSnapWidget::MvQGridSnapWidget(GridSnapHandler* snap, QWidget* parent) :
     // Init
     //----------------------------------
 
-    for (unsigned int i = 0; i < snap_->values().size(); i++) {
-        xCb_->addItem(QString::number(snap_->values().at(i)) + " " + QString::fromStdString(snap_->units()));
-        yCb_->addItem(QString::number(snap_->values().at(i)) + " " + QString::fromStdString(snap_->units()));
+    for (float i : snap_->values()) {
+        xCb_->addItem(QString::number(i) + " " + QString::fromStdString(snap_->units()));
+        yCb_->addItem(QString::number(i) + " " + QString::fromStdString(snap_->units()));
     }
 
     xCb_->setCurrentIndex((snap_->xIndex() != -1) ? snap_->xIndex() : 3);
@@ -1017,10 +1015,10 @@ MvQPageSetupDialog::MvQPageSetupDialog(PaperSizeHandler* paperH, GridSnapHandler
 {
     setWindowTitle(tr("Page setup"));
 
-    QVBoxLayout* vb = new QVBoxLayout;
+    auto* vb = new QVBoxLayout;
     setLayout(vb);
 
-    QTabWidget* tab = new QTabWidget(this);
+    auto* tab = new QTabWidget(this);
     vb->addWidget(tab);
 
     paper_ = new MvQPaperSizeWidget(paperH, this);
@@ -1030,7 +1028,7 @@ MvQPageSetupDialog::MvQPageSetupDialog(PaperSizeHandler* paperH, GridSnapHandler
     tab->addTab(snap_, tr("Grid"));
 
     // Buttonbox
-    QDialogButtonBox* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    auto* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
@@ -1070,20 +1068,20 @@ MvQSplitDialog::MvQSplitDialog(QWidget* parent) :
 {
     setWindowTitle(tr("Split"));
 
-    QVBoxLayout* vb = new QVBoxLayout;
+    auto* vb = new QVBoxLayout;
     setLayout(vb);
 
     //Mode selector
-    QFrame* modeFrame = new QFrame(this);
+    auto* modeFrame = new QFrame(this);
     modeFrame->setFrameShape(QFrame::StyledPanel);
 
-    QHBoxLayout* hb = new QHBoxLayout(this);
+    auto* hb = new QHBoxLayout(this);
     modeFrame->setLayout(hb);
     vb->addWidget(modeFrame);
     vb->addSpacing(4);
 
-    QLabel* label = new QLabel(tr("Selection mode:"));
-    modeCb_       = new QComboBox(this);
+    auto* label = new QLabel(tr("Selection mode:"));
+    modeCb_     = new QComboBox(this);
     modeCb_->addItem(tr("Manual"));
     modeCb_->addItem(tr("Graphical"));
     hb->addWidget(label);
@@ -1097,10 +1095,10 @@ MvQSplitDialog::MvQSplitDialog(QWidget* parent) :
     // Manual mode
     //---------------------------
 
-    QWidget* w           = new QWidget(this);
-    QVBoxLayout* mLayout = new QVBoxLayout();
+    auto* w       = new QWidget(this);
+    auto* mLayout = new QVBoxLayout();
     w->setLayout(mLayout);
-    QGridLayout* mgLayout = new QGridLayout();
+    auto* mgLayout = new QGridLayout();
     mLayout->addLayout(mgLayout);
     mLayout->addStretch(1);
 
@@ -1124,8 +1122,8 @@ MvQSplitDialog::MvQSplitDialog(QWidget* parent) :
     // Graphical mode
     //---------------------------
 
-    w                    = new QWidget(this);
-    QVBoxLayout* gLayout = new QVBoxLayout;
+    w             = new QWidget(this);
+    auto* gLayout = new QVBoxLayout;
     w->setLayout(gLayout);
 
     label_ = new QLabel(this);
@@ -1159,7 +1157,7 @@ MvQSplitDialog::MvQSplitDialog(QWidget* parent) :
             this, SLOT(slotSelectionChanged(int, int)));
 
     // Buttonbox
-    QDialogButtonBox* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    auto* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
