@@ -7,25 +7,24 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef Wastebasket_H
-#define Wastebasket_H
+#pragma once
 
 #include "SystemFolder.h"
 
 class Wastebasket : public SystemFolder
 {
 public:
-    Wastebasket(Folder* parent, const IconClass& kind, const string& name, IconInfo* info);
+    Wastebasket(Folder* parent, const IconClass& kind, const std::string& name, IconInfo* info);
     virtual ~Wastebasket();
 
-    virtual void empty();
+    void empty() override;
 
 private:
     Wastebasket(const Wastebasket&);
     Wastebasket& operator=(const Wastebasket&);
 
-    virtual bool adopt(IconObject*);
-    virtual set<string> can();
+    bool adopt(IconObject*) override;
+    std::set<std::string> can() override;
 };
 
 inline void destroy(Wastebasket**) {}
@@ -34,5 +33,3 @@ inline void destroy(Wastebasket**) {}
 //#ifdef _ODI_OSSG_
 //OS_MARK_SCHEMA_TYPE(Wastebasket);
 //#endif
-
-#endif
