@@ -9,10 +9,12 @@
 
 #include "Divrot.h"
 
+#include <iostream>
+
 
 void Divrot ::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "Divrot::serve in" << endl;
+    std::cout << "Divrot::serve in" << std::endl;
     in.print();
 
     // Get data
@@ -23,7 +25,7 @@ void Divrot ::serve(MvRequest& in, MvRequest& out)
     if (!Apply(out))
         return;
 
-    cout << "Divrot::serve out" << endl;
+    std::cout << "Divrot::serve out" << std::endl;
     out.print();
 }
 
@@ -94,7 +96,7 @@ bool Divrot::appendWindComponent(grib_handle* gh)
         smooth_BPPSMTH(gh);
 
     size_t buflen      = 0;  //-- get the GRIB msg into 'buffer'
-    const void* buffer = NULL;
+    const void* buffer = nullptr;
     if ((ret = grib_get_message(gh, &buffer, &buflen))) {
         setError(1, "Error on GRIB decoding: grib_get_message returned %d in Divrot::appendWindComponent", ret);
         return false;
@@ -219,7 +221,7 @@ Divrot::check_ecCodes( int ret, const char* gribApiFunc, const char* MvFunc )
 int main(int argc, char** argv)
 {
     // From the environment, check whether we're in 'standard' or 'MIR' mode
-    char* marsmode    = getenv("MV_MARS_MODE");
+    char* marsmode          = getenv("MV_MARS_MODE");
     const char* servicename = "Divrot";
 
     if (marsmode && strcmp(marsmode, "MIR") == 0) {
