@@ -8,7 +8,10 @@
  ***************************** LICENSE END *************************************/
 
 #include <fstream>
+#include <iostream>
 #include <sstream>
+#include "fstream_mars_fix.h"
+
 #include <Metview.h>
 #include <MvScanFileType.h>
 #include <MvNetwork.h>
@@ -19,7 +22,7 @@ class Download : public MvService
 {
 public:
     Download(const char* name) :
-        MvService(name){};
+        MvService(name) {}
     void serve(MvRequest&, MvRequest&);
     bool sanitiseUrl(std::string& url);
 };
@@ -39,7 +42,7 @@ std::string filetoString(std::string filename)
     // get the text stream and convert into a string
     std::stringstream stream;
     stream << ifStream.rdbuf();
-    string str = stream.str();
+    std::string str = stream.str();
     return str;
 }
 
@@ -83,7 +86,7 @@ bool Download::sanitiseUrl(std::string& url)
 
 void Download::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "Entry Download::serve..." << endl;
+    std::cout << "Entry Download::serve..." << std::endl;
     in.print();
 
 
@@ -96,15 +99,15 @@ void Download::serve(MvRequest& in, MvRequest& out)
 
 
     // get the target path (optional parameter)
-    string target;
-    string errText;
+    std::string target;
+    std::string errText;
     if (!in.getPath("TARGET", target, true)) {
         setError(1, "Download-> Target path has not been supplied");
         return;
     }
 
 
-    string urlStr(url);
+    std::string urlStr(url);
     bool urlChanged = sanitiseUrl(urlStr);
 
     if (urlChanged) {
@@ -113,10 +116,10 @@ void Download::serve(MvRequest& in, MvRequest& out)
 
 
     // perform the network transfer
-    string outname(marstmp());
+    std::string outname(marstmp());
 
-    MvNetwork* net = new MvNetwork();
-    bool ok        = net->get(urlStr, outname, "", errText);
+    auto* net = new MvNetwork();
+    bool ok   = net->get(urlStr, outname, "", errText);
 
     if (!ok) {
         setError(1, "Download-> Failed to download data: %s", errText.c_str());
@@ -124,9 +127,10 @@ void Download::serve(MvRequest& in, MvRequest& out)
     }
 
 
-    string h          = net->header();
+    std::string h     = net->header();
     long responseCode = net->responseCode();
-    sendProgress("Download-> header %s response code: %ld", h.c_str(), responseCode);
+    // XXX comment out for now - need to trim to 1024 chars for mars logging
+    //sendProgress("Download-> header %s response code: %ld", h.c_str(), responseCode);
     char responseCodeString[32];
     sprintf(responseCodeString, "%ld", responseCode);
 
@@ -154,7 +158,7 @@ void Download::serve(MvRequest& in, MvRequest& out)
     // if we got to here, the download seems to have been ok
     // if the user specified a TARGET, we should copy the file there
     if (!target.empty()) {
-        string copyCommand = "cp " + outname + " \"" + target + "\"";
+        std::string copyCommand = "cp " + outname + " \"" + target + "\"";
         sendProgress("Download-> Copy: %s", copyCommand.c_str());
         int ret2 = system(copyCommand.c_str());
 
@@ -166,12 +170,12 @@ void Download::serve(MvRequest& in, MvRequest& out)
 
 
     // Create output request
-    string iconType = ScanFileType(outname.c_str());  // dynamically find the type
+    std::string iconType = ScanFileType(outname.c_str());  // dynamically find the type
     out.setVerb(iconType.c_str());
     out("PATH")           = outname.c_str();
     out("_RESPONSE_CODE") = responseCodeString;
 
-    cout << "Exit Download::serve..." << endl;
+    std::cout << "Exit Download::serve..." << std::endl;
     out.print();
 
     return;
