@@ -374,8 +374,10 @@ void Event::Loop()
 
 void Event::EndOfModule(const char* name)
 {
-    if (name && gOpt.exit == name)
-        marslog(LOG_EXIT, "%s exited, closing all lines", name);
+    if (name && gOpt.exit == name) {
+        marslog(LOG_INFO, "%s exited, closing all lines", name);
+        marsexit(0);
+    }
 }
 
 //==============================================================================
