@@ -21,23 +21,27 @@
 #include "Event.h"
 
 
-Service* Service::gHead    = 0;
-Service* Service::gMonitor = 0;
+Service* Service::gHead    = nullptr;
+Service* Service::gMonitor = nullptr;
 
 //==============================================================================
 
-typedef int (*pvoid)();
-
 // clang on Linux showed a problem with the signature of mxdrproc (METV-2881)
 #if defined(__linux__) && defined(__clang__)
-typedef int (*mxdrproc2)(char*,char*,int);
+using mxdrparam = caddr_t;
 #else
-// in most cases we want to use the version defined in mars.h
-typedef mxdrproc mxdrproc2;
+// in most cases we want to use void*
+using mxdrparam = void*;
 #endif
 
-void _xdrrec_create(XDR *xdrs, unsigned int sendsize, unsigned int recvsize,
-                    mxdrparam handle, mxdrproc2 readfunc, mxdrproc2 writefunc)
+#if !defined(__linux__) || defined(__INTEL_COMPILER)
+typedef int (*mxdrproc)(void*, void*, int);
+#else
+typedef int (*mxdrproc)(char*, char*, int);
+#endif
+
+void _xdrrec_create(XDR* xdrs, unsigned int sendsize, unsigned int recvsize,
+                    mxdrparam handle, mxdrproc readfunc, mxdrproc writefunc)
 {
     xdrrec_create(xdrs, sendsize, recvsize, handle, readfunc, writefunc);
 };
@@ -52,14 +56,14 @@ Service::Service(int soc)
     Event::AddInput(soc);
 
     //#if defined(sun) || defined(__alpha) ...and Linux/GNU...
-    _xdrrec_create(&x_, 0, 0, (mxdrparam)&soc_, (mxdrproc2)readtcp, (mxdrproc2)writetcp);
+    _xdrrec_create(&x_, 0, 0, (mxdrparam)&soc_, (mxdrproc)readtcp, (mxdrproc)writetcp);
     //#else
     // 	xdrrec_create(&x_, 0,0,(void*)&soc_,(mxdrproc)readtcp,(mxdrproc)writetcp);
     //#endif
 
-    name_          = 0;
-    host_          = 0;
-    user_          = 0;
+    name_          = nullptr;
+    host_          = nullptr;
+    user_          = nullptr;
     ref_           = -1;
     timeout_       = 0;
     alive_         = 0;
@@ -131,7 +135,7 @@ void Service::ThreadProc()
         if (q) {
             marslog(LOG_INFO, "Thread --> encode_request for %s %p", name_, this);
 
-            //print_all_requests(q->Request());
+            // print_all_requests(q->Request());
 
             request* r = q->Request();
 
@@ -173,7 +177,7 @@ void Service::HandleRegister(request* r)
     user_     = strcache(get_value(r, "USER", 0));
     host_     = strcache(get_value(r, "HOST", 0));
     pid_      = atol(get_value(r, "PID", 0));
-    lastcall_ = time(0);
+    lastcall_ = time(nullptr);
     valid_    = 1;
 
     marslog(LOG_INFO, "Register: %s %s %s %d as ref %d",
@@ -267,7 +271,7 @@ Service::~Service()
 
 
     Service* s = gHead;
-    Service* t = 0;
+    Service* t = nullptr;
 
     // Remove self for the list
     while (s) {
@@ -285,7 +289,7 @@ Service::~Service()
     // Check if monitor
 
     if (this == gMonitor)
-        gMonitor = 0;
+        gMonitor = nullptr;
 
     marslog(LOG_INFO, "Closing service %s", name_ ? name_ : "(null)");
     marslog(LOG_INFO, "%d outstanding replies", outstanding_);
@@ -298,7 +302,7 @@ Service::~Service()
     OutputQueue::RemoveAll(this);
 
     if (name_) {
-        NotifyMonitor("EXIT", 0);
+        NotifyMonitor("EXIT", nullptr);
         request* r = empty_request("DEATH");
         set_value(r, "NAME", "%s", name_);
         set_value(r, "USER", "%s", user_);
@@ -337,7 +341,7 @@ void Service::HandleService(request* r)
     const char* target = get_value(r, "TARGET", 0);
 
     // Append request info
-    if (get_value(r, "SOURCE", 0) == 0) {
+    if (get_value(r, "SOURCE", 0) == nullptr) {
         set_value(r, "REQ_ID", "%ld", Event::UniqueID());
         set_value(r, "SOURCE", "%s", name_);
         set_value(r, "SOURCE_REF", "%ld", ref_);
@@ -359,9 +363,9 @@ void Service::HandleService(request* r)
 static jmp_buf env;
 
 //#if (defined(__cplusplus) || defined(c_plusplus) || !defined(__alpha))
-//static void catch_alarm(...)
+// static void catch_alarm(...)
 //#else
-//static void catch_alarm(int)
+// static void catch_alarm(int)
 //#endif
 
 // Sun, HP and Alpha have (int) as parameter!
@@ -419,9 +423,9 @@ int Service::EncodeRequest(request* r)
 // 3) but at ECMWF we do need this ifdef...??!!
 //
 #if defined(hpux) && !defined(__GNU__)
-        switch (select(FD_SETSIZE, 0, (int*)&fds, NULL, &timeout))
+        switch (select(FD_SETSIZE, 0, (int*)&fds, nullptr, &timeout))
 #else
-        switch (select(FD_SETSIZE, 0, &fds, NULL, &timeout))
+        switch (select(FD_SETSIZE, nullptr, &fds, nullptr, &timeout))
 #endif
         {
             case 0:
@@ -489,7 +493,7 @@ void Service::HandleReply(request* r)
 
     outstanding_--;
 
-    lastcall_ = time(0);
+    lastcall_ = time(nullptr);
 
     // Remove from queue
 
@@ -528,7 +532,7 @@ void Service::HandleStop(request* r)
 //==============================================================================
 void Service::NotifyMonitor(const char* mode, request* r, long ref, const char* name)
 {
-    static request* u = 0;
+    static request* u = nullptr;
     if (!u)
         u = empty_request("PROGRESS");
 
@@ -640,7 +644,7 @@ void Service::Broadcast(request* r)
 
 void Service::BroadcastMessage(request* r)
 {
-    static request* u = 0;
+    static request* u = nullptr;
     if (!u)
         u = empty_request("MESSAGE");
     u->next = r;
@@ -663,7 +667,7 @@ void Service::HandleDrop(request* r)
 {
     const char* target = get_value(r, "TARGET", 0);
 
-    if (get_value(r, "SOURCE", 0) == 0) {
+    if (get_value(r, "SOURCE", 0) == nullptr) {
         set_value(r, "SOURCE", "%s", name_);
         set_value(r, "SOURCE_REF", "%ld", ref_);
     }
@@ -677,7 +681,7 @@ void Service::HandleDrop(request* r)
 
 void Service::HandleMessage(request* r)
 {
-    if (get_value(r, "SOURCE", 0) == NULL) {
+    if (get_value(r, "SOURCE", 0) == nullptr) {
         set_value(r, "SOURCE", "%s", name_);
         set_value(r, "SOURCE_REF", "%ld", ref_);
     }
@@ -688,8 +692,8 @@ void Service::HandleMessage(request* r)
 
 void Service::HandleGetInfo(request*)
 {
-    static request* u = NULL;
-    if (u == NULL)
+    static request* u = nullptr;
+    if (u == nullptr)
         u = empty_request("REPLY");
     u->next = mars.setup;
     SendRequest(u);
@@ -733,7 +737,7 @@ void Service::HandleStart(request* r)
     }
     else
         WaitingQueue::StartModule(name);
-    SendRequest(NULL);
+    SendRequest(nullptr);
 }
 
 //==============================================================================
@@ -758,7 +762,7 @@ Service* Service::Find(const char* name)
             return s;
         s = s->next_;
     }
-    return 0;
+    return nullptr;
 }
 
 //==============================================================================
@@ -771,7 +775,7 @@ Service* Service::Find(long ref)
             return s;
         s = s->next_;
     }
-    return 0;
+    return nullptr;
 }
 
 //==============================================================================
@@ -794,7 +798,7 @@ void Service::HandleMaximum(request* r)
 
 int Service::CheckTimeout()
 {
-    time_t now = time(0);
+    time_t now = time(nullptr);
     int alive  = 0;
 
     Service* s = gHead;
@@ -834,7 +838,7 @@ void Service::UserMessage(const char* fmt, ...)
 
 //==============================================================================
 
-typedef void (Service::*reqproc)(request*);
+using reqproc = void (Service::*)(request*);
 
 struct
 {
@@ -917,24 +921,24 @@ struct
 
 void Service::Dispatch(request* r)
 {
-    lastcall_ = time(NULL);
-    for (size_t i = 0; i < NUMBER(handlers); i++)
-        if (handlers[i].name == r->name)
-            (this->*handlers[i].proc)(r);
+    lastcall_ = time(nullptr);
+    for (auto& handler : handlers)
+        if (handler.name == r->name)
+            (this->*handler.proc)(r);
 }
 
 //==============================================================================
 
 void Service::ProcessIncoming()
 {
-    request* r       = NULL;
+    request* r       = nullptr;
     static int first = 1;
 
-//    marslog(LOG_INFO, "Service incoming: %s", name_);
+    //    marslog(LOG_INFO, "Service incoming: %s", name_);
 
     if (first) {
-        for (size_t i = 0; i < NUMBER(handlers); i++)
-            handlers[i].name = strcache(handlers[i].name);
+        for (auto& handler : handlers)
+            handler.name = strcache(handler.name);
         first = 0;
     }
 
