@@ -10,7 +10,7 @@
 #include <time.h>
 
 #include "Event.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 Queue WaitingQueue::gQueue;
 QIter WaitingQueue::gIter;
@@ -69,7 +69,7 @@ void WaitingQueue::Append(request* r, const char* name)
 
 void WaitingQueue::Later(request* r, const char* name)
 {
-    WElem* p = new WElem(r, name);
+    auto* p = new WElem(r, name);
     p->Update();
     p->Late(1);
     Append(p);
@@ -165,7 +165,7 @@ int WaitingQueue::StartModule(const char* name)
 
                 const char* mvSlog = getenv("MV_SLOG");
                 if ((strcmp(name, "mars") == 0 && metview::isForceMarsLogSet()) ||
-                   (mvSlog && strcmp(mvSlog, "yes") == 0)) {
+                    (mvSlog && strcmp(mvSlog, "yes") == 0)) {
                     //-- do not block module output --//
                     sprintf(buf, "exec %s </dev/null &", no_quotes(cmd));
                 }
