@@ -24,7 +24,7 @@
 #include "Metview.h"
 #include "MvServiceTask.h"
 #include "MvScanFileType.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "Path.h"
 
 #include <QApplication>
@@ -49,7 +49,7 @@ private:
     void inputFileErrorExit(const std::string& fileName);
     void showErrorAndExit(const std::string& msg, bool printUsage);
 
-    int argc_ {0};
+    int argc_{0};
     char** argv_;
     std::vector<std::string> supportedTypes_{"GRIB", "BUFR", "GEOPOINTS", "NETCDF", "ODB"};
 };
@@ -71,7 +71,7 @@ void MvExamineManager::runExaminer(const std::string& fileName, const std::strin
 {
     MvRequest mvReq(dataType.c_str());
     mvReq.setValue("PATH", fileName.c_str());
-    mvReq("_ACTION") = "examine";
+    mvReq("_ACTION")   = "examine";
     mvReq("_WAIT_APP") = "1";
     mvReq.print();
     MvTask* task = new MvServiceTask(this, "UiAppManager", mvReq);
@@ -88,7 +88,7 @@ void MvExamineManager::showErrorAndExit(const std::string& msg, bool printUsage)
             s += "<br><br><b>Usage</b>: metview -e [grib|bufr|geopoints|netcdf|odb] file_path";
         }
         QMessageBox::critical(nullptr, "Metview Data Examiner",
-                          QString::fromStdString(s));
+                              QString::fromStdString(s));
     }
     exit(13);
 }
@@ -104,7 +104,7 @@ void MvExamineManager::formatDataType(std::string& dataType) const
 bool MvExamineManager::checkDataType(const std::string& dataType, bool exitOnInvalid)
 {
     if (std::find(supportedTypes_.begin(), supportedTypes_.end(), dataType) ==
-            supportedTypes_.end()) {
+        supportedTypes_.end()) {
         if (exitOnInvalid) {
             dataTypeErrorExit(dataType);
         }
@@ -116,28 +116,30 @@ bool MvExamineManager::checkDataType(const std::string& dataType, bool exitOnInv
 void MvExamineManager::dataTypeErrorExit(const std::string& dataType)
 {
     std::string typeStr;
-    for (std::size_t i=0; i < supportedTypes_.size(); ++i) {
+    for (std::size_t i = 0; i < supportedTypes_.size(); ++i) {
         std::string s = supportedTypes_[i];
         metview::toLower(s);
         typeStr += s;
-        if (i < supportedTypes_.size()-2) {
+        if (i < supportedTypes_.size() - 2) {
             typeStr += ", ";
-        } else if (i == supportedTypes_.size()-2) {
+        }
+        else if (i == supportedTypes_.size() - 2) {
             typeStr += " and ";
         }
     }
     showErrorAndExit("Invalid type=" + dataType +
-                         " is specified! Supported types are: " + typeStr, true);
+                         " is specified! Supported types are: " + typeStr,
+                     true);
 }
 
 bool MvExamineManager::checkInputFile(const std::string& fileName, bool exitOnInvalid)
 {
     Path pp(fileName);
     if (!pp.exists()) {
-       if (exitOnInvalid) {
+        if (exitOnInvalid) {
             inputFileErrorExit(fileName);
-       }
-       return false;
+        }
+        return false;
     }
     return true;
 }
@@ -165,19 +167,23 @@ MvExamineManager::MvExamineManager(int argc, char** argv) :
         if (argc > 2) {
             fileName = std::string(argv[2]);
             checkInputFile(fileName, true);
-        } else {
+        }
+        else {
             showErrorAndExit("No file_path is specified!", true);
         }
-    } else {
+    }
+    else {
         fileName = std::string(argv[1]);
         if (!checkInputFile(fileName, false)) {
             if (argc > 2 && strlen(argv[2]) > 0 && argv[2][0] != '-') {
                 if (checkInputFile(argv[2], false)) {
                     dataTypeErrorExit(dataType);
-                } else {
+                }
+                else {
                     inputFileErrorExit(fileName);
                 }
-            } else {
+            }
+            else {
                 inputFileErrorExit(fileName);
             }
             assert(0);
