@@ -7,11 +7,19 @@
 
  ***************************** LICENSE END *************************************/
 
-#include "inc_iostream.h"
+#include <fstream>
+#include <iomanip>
+#include <iostream>
+#include <map>
+#include <string>
+#include <vector>
+
+#include "fstream_mars_fix.h"
+
 #include "Metview.h"
 
 #include "MvDate.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "Tokenizer.h"
 
 #include <fcntl.h>
@@ -50,15 +58,15 @@ protected:
     bool generateAgeClassesFile(const std::string&, MvRequest& in);
     bool generateReceptorsFile(const std::string&, MvRequest& in);
 
-    std::map<string, string> directionIds_;
-    std::map<string, string> outputIds_;
-    std::map<string, string> particleDumpIds_;
-    std::map<string, string> onOffIds_;
-    std::map<string, string> sourceUnitsIds_;
-    std::map<string, string> receptorUnitsIds_;
-    std::map<string, string> writeInitIds_;
-    std::map<string, string> relLevelUnitsIds_;
-    std::map<string, string> domainFillIds_;
+    std::map<std::string, std::string> directionIds_;
+    std::map<std::string, std::string> outputIds_;
+    std::map<std::string, std::string> particleDumpIds_;
+    std::map<std::string, std::string> onOffIds_;
+    std::map<std::string, std::string> sourceUnitsIds_;
+    std::map<std::string, std::string> receptorUnitsIds_;
+    std::map<std::string, std::string> writeInitIds_;
+    std::map<std::string, std::string> relLevelUnitsIds_;
+    std::map<std::string, std::string> domainFillIds_;
     std::string runDate_;
     bool forward_;
     int receptorNum_;
@@ -120,7 +128,7 @@ std::string FlexpartRun::getReleaseDate(const std::string& rawStr, const std::st
 
 bool FlexpartRun::generatePathnamesFile(const std::string& fPathnames, MvRequest& in, const std::string& optionsPath, const std::string& outPath)
 {
-    string inPath, fAvailable;
+    std::string inPath, fAvailable;
 
     MvRequest dataR = in("INPUT_DATA");
 
@@ -410,8 +418,8 @@ bool FlexpartRun::generateReleasesFile(const std::string& fRelease, MvRequest& i
     FLEXPART_CHK(in.getValue("RELEASE_SPECIES", sp));
 
     out << sp.size() << std::endl;
-    for (unsigned int i = 0; i < sp.size(); i++) {
-        out << sp[i] << std::endl;
+    for (auto& i : sp) {
+        out << i << std::endl;
     }
     out << "===================================================================" << std::endl;
 
@@ -491,14 +499,14 @@ bool FlexpartRun::generateReleasesFile(const std::string& fRelease, MvRequest& i
 
         if (massVec.size() != sp.size()) {
             std::string errTxt = "Incosistent number of items specified for parameter: MASSES! Expected: " +
-                                 metview::toString<int>(sp.size()) + " found: " + metview::toString<int>(massVec.size());
+                                 std::to_string(sp.size()) + " found: " + std::to_string(massVec.size());
             marslog(LOG_EROR, "%s", errTxt.c_str());
             setError(13);
             return false;
         }
 
-        for (unsigned int j = 0; j < massVec.size(); j++) {
-            out << massVec.at(j) << std::endl;
+        for (auto& j : massVec) {
+            out << j << std::endl;
         }
 
         parName = "NAME";
@@ -528,7 +536,7 @@ bool FlexpartRun::generateOutGridFile(const std::string& fGrid, MvRequest& in)
 *** HEADER ***\n\
 *** HEADER ***\n\n";
 
-    //string west,south,name,nx,ny,dx,dy,dz;
+    //std::string west,south,name,nx,ny,dx,dy,dz;
 
     parName = "OUTPUT_AREA";
     std::vector<std::string> area;
@@ -579,7 +587,7 @@ bool FlexpartRun::generateOutGridFile(const std::string& fGrid, MvRequest& in)
     }
 
     double dval;
-    vector<double> levL;  //we need to set a limit!
+    std::vector<double> levL;  //we need to set a limit!
     for (int i = 0; i < cnt && i < 200; i++) {
         in.getValue(dval, "OUTPUT_LEVELS", i);
         levL.push_back(dval);
@@ -626,9 +634,9 @@ bool FlexpartRun::generateOutGridFile(const std::string& fGrid, MvRequest& in)
     out << "DYOUTLAT" << std::endl;
     out << std::endl;
 
-    for (size_t i = 0; i < levL.size(); i++) {
+    for (double i : levL) {
         out << "-------" << std::endl;
-        out << "    " << std::setw(5) << std::setprecision(1) << levL[i] << std::endl;
+        out << "    " << std::setw(5) << std::setprecision(1) << i << std::endl;
         out << "LEVEL" << std::endl;
         out << std::endl;
     }
@@ -641,7 +649,7 @@ bool FlexpartRun::generateOutGridFile(const std::string& fGrid, MvRequest& in)
 
 bool FlexpartRun::generateAgeClassesFile(const std::string& fAge, MvRequest& in)
 {
-    ofstream out(fAge.c_str());
+    std::ofstream out(fAge.c_str());
 
     out << "*** HEADER ***\n\
 *** HEADER ***\n*** HEADER ***\n\
@@ -697,8 +705,7 @@ bool FlexpartRun::generateReceptorsFile(const std::string& fRec, MvRequest& in)
     parLst.push_back("RECEPTOR_LATITUDES");
     parLst.push_back("RECEPTOR_LONGITUDES");
 
-    for (unsigned int i = 0; i < parLst.size(); i++) {
-        std::string s = parLst[i];
+    for (auto s : parLst) {
         FLEXPART_CHK(in.getValue(s, vals[s]));
     }
 
@@ -715,9 +722,9 @@ bool FlexpartRun::generateReceptorsFile(const std::string& fRec, MvRequest& in)
     }
 #endif
 
-    for (map<string, vector<string> >::iterator it = vals.begin(); it != vals.end(); it++) {
-        if (it->second.size() != cnt) {
-            std::string errTxt = "Incosistent number of items specified for parameter: " + it->first + "!";
+    for (auto& val : vals) {
+        if (val.second.size() != cnt) {
+            std::string errTxt = "Incosistent number of items specified for parameter: " + val.first + "!";
             marslog(LOG_EROR, "%s", errTxt.c_str());
             setError(13);
             return false;
@@ -733,7 +740,7 @@ bool FlexpartRun::generateReceptorsFile(const std::string& fRec, MvRequest& in)
         out << "--" << std::endl;
         out << "--" << std::endl;
 
-        float fVal = metview::fromString<float>(vals["RECEPTOR_LONGITUDES"].at(i));
+        auto fVal = metview::fromString<float>(vals["RECEPTOR_LONGITUDES"].at(i));
         out << "    " << std::setw(6) << std::setprecision(4) << fVal << std::endl;
 
         out << "--" << std::endl;
@@ -754,7 +761,7 @@ bool FlexpartRun::generateReceptorsFile(const std::string& fRec, MvRequest& in)
 
 void FlexpartRun::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "--------------FlexpartRun::serve()--------------" << std::endl;
+    std::cout << "--------------FlexpartRun::serve()--------------" << std::endl;
     in.print();
 
     //Find out flexpart script paths
@@ -858,7 +865,7 @@ void FlexpartRun::serve(MvRequest& in, MvRequest& out)
                       resourcePath + "\" \"" + speciesPath + "\"";
 
     //marslog(LOG_INFO,"Execute command: %s",cmd.c_str());
-    cout << "Execute command: " << cmd << std::endl;
+    std::cout << "Execute command: " << cmd << std::endl;
 
     //Flexpart ouput goes into the stdout and into this file
     std::string flexpartLogFile = tmpPath + "/" + flexpartLogFileName;
@@ -908,10 +915,10 @@ void FlexpartRun::serve(MvRequest& in, MvRequest& out)
 
     //Run the posproc script
     cmd = ppScript + " \"" + tmpPath + "\" \"" + flexpartLogFileName + "\" \"" + ppLogFileName + "\" \"" + resPath +
-          "\" \"" + forwardStr + +"\" \"" + metview::toString<int>(receptorNum_) + "\"";
+          "\" \"" + forwardStr + +"\" \"" + std::to_string(receptorNum_) + "\"";
 
     //marslog(LOG_INFO,"Execute command: %s",cmd.c_str());
-    cout << "Execute command: " << cmd << std::endl;
+    std::cout << "Execute command: " << cmd << std::endl;
 
     ret = system(cmd.c_str());
 
