@@ -7,12 +7,19 @@
 
  ***************************** LICENSE END *************************************/
 
-#include "inc_iostream.h"
+#include <fstream>
+#include <iostream>
+#include <map>
+#include <string>
+#include <vector>
+
+#include "fstream_mars_fix.h"
+
 #include "Metview.h"
 
 #include "MvDate.h"
 #include "Tokenizer.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 #include <fcntl.h>
 #include <unistd.h>
@@ -20,7 +27,6 @@
 #include <dirent.h>
 #include <errno.h>
 
-using namespace std;
 
 //#define FLEXTRA_CHK(str) if(!(str)) return false
 #define FLEXTRA_CHK(str) ({if(!(str)) {setError(13); return false;} })
@@ -42,24 +48,24 @@ public:
 protected:
     void initIds();
 
-    bool getMvDate(const string& dd, const string& tt, MvDate&);
+    bool getMvDate(const std::string& dd, const std::string& tt, MvDate&);
 
-    bool generatePathnamesFile(const string&, MvRequest&, const string&, const string&);
-    bool generateCommandFile(const string&, MvRequest&);
-    bool generateStartPointsFile(const string&, MvRequest&);
-    bool generateStartCetFile(const string&, MvRequest&);
-    bool generateStartFlightFile(const string& fStart, MvRequest& in);
+    bool generatePathnamesFile(const std::string&, MvRequest&, const std::string&, const std::string&);
+    bool generateCommandFile(const std::string&, MvRequest&);
+    bool generateStartPointsFile(const std::string&, MvRequest&);
+    bool generateStartCetFile(const std::string&, MvRequest&);
+    bool generateStartFlightFile(const std::string& fStart, MvRequest& in);
     bool getDateRange(MvDate& rangeStart, MvDate& rangeEnd, MvRequest& in);
-    bool getPredefInputPath(const string&, const MvDate&, const MvDate&, string&);
+    bool getPredefInputPath(const std::string&, const MvDate&, const MvDate&, std::string&);
 
 
-    map<string, string> directionIds_;
-    map<string, string> modeIds_;
-    map<string, string> intervalIds_;
-    map<string, string> cetTypeIds_;
-    map<string, string> cetLevelUnitsIds_;
-    map<string, string> flightTypeIds_;
-    map<string, string> flightLevelUnitsIds_;
+    std::map<std::string, std::string> directionIds_;
+    std::map<std::string, std::string> modeIds_;
+    std::map<std::string, std::string> intervalIds_;
+    std::map<std::string, std::string> cetTypeIds_;
+    std::map<std::string, std::string> cetLevelUnitsIds_;
+    std::map<std::string, std::string> flightTypeIds_;
+    std::map<std::string, std::string> flightLevelUnitsIds_;
 };
 
 void FlextraRun::initIds()
@@ -94,25 +100,25 @@ void FlextraRun::initIds()
     flightLevelUnitsIds_["HPA"]        = "3";
 }
 
-bool FlextraRun::getMvDate(const string& dd, const string& tt, MvDate& res)
+bool FlextraRun::getMvDate(const std::string& dd, const std::string& tt, MvDate& res)
 {
     if (dd.size() != 8 || tt.size() != 6)
         return false;
 
-    string sDate = dd.substr(0, 4) + "-" + dd.substr(4, 2) + "-" + dd.substr(6, 2);
-    string sTime = tt.substr(0, 2) + ":" + tt.substr(2, 2) + ":" + dd.substr(4, 2);
+    std::string sDate = dd.substr(0, 4) + "-" + dd.substr(4, 2) + "-" + dd.substr(6, 2);
+    std::string sTime = tt.substr(0, 2) + ":" + tt.substr(2, 2) + ":" + dd.substr(4, 2);
 
-    string s = sDate + " " + sTime;
+    std::string s = sDate + " " + sTime;
 
     res = MvDate(s.c_str());
 
     return true;
 }
 
-bool FlextraRun::generatePathnamesFile(const string& fPathnames, MvRequest& in, const string& optionsPath, const string& outPath)
+bool FlextraRun::generatePathnamesFile(const std::string& fPathnames, MvRequest& in, const std::string& optionsPath, const std::string& outPath)
 {
-    string inPath, fAvailable;
-    string errTxt;
+    std::string inPath, fAvailable;
+    std::string errTxt;
 
     const char* input_mode = in("FLEXTRA_INPUT_MODE");
     if (!input_mode) {
@@ -150,7 +156,7 @@ bool FlextraRun::generatePathnamesFile(const string& fPathnames, MvRequest& in,
 #if 0
 	else if(strcmp(input_mode,"EC_EUROPE") == 0 || strcmp(input_mode,"EC_GLOBAL") == 0)
 	{
-		string envVar=(strcmp(input_mode,"EC_EUROPE") == 0)?"MV_FLEXTRA_INPUT_EUROPE":"MV_FLEXTRA_INPUT_GLOBAL";
+		std::string envVar=(strcmp(input_mode,"EC_EUROPE") == 0)?"MV_FLEXTRA_INPUT_EUROPE":"MV_FLEXTRA_INPUT_GLOBAL";
 		  
 	  	char *predefPath=getenv(envVar.c_str());
 		if(predefPath == 0)  
@@ -160,7 +166,7 @@ bool FlextraRun::generatePathnamesFile(const string& fPathnames, MvRequest& in,
 			return false;			
 		}
 		
-		string rootPath(predefPath);
+		std::string rootPath(predefPath);
 	  	MvDate startDate,endDate;
 		if(!getDateRange(startDate,endDate,in))
 		{  	
@@ -186,23 +192,23 @@ bool FlextraRun::generatePathnamesFile(const string& fPathnames, MvRequest& in,
     }
 
     //Pathnames file
-    ofstream out(fPathnames.c_str());
-    out << optionsPath << "/" << endl;
-    out << outPath << "/" << endl;
-    out << inPath << "/" << endl;
-    out << fAvailable << endl;
-    out << "================================================" << endl;
+    std::ofstream out(fPathnames.c_str());
+    out << optionsPath << "/" << std::endl;
+    out << outPath << "/" << std::endl;
+    out << inPath << "/" << std::endl;
+    out << fAvailable << std::endl;
+    out << "================================================" << std::endl;
     out << " ";
     out.close();
 
     return true;
 }
 
-bool FlextraRun::generateCommandFile(const string& fCmd, MvRequest& in)
+bool FlextraRun::generateCommandFile(const std::string& fCmd, MvRequest& in)
 {
-    ofstream out(fCmd.c_str());
+    std::ofstream out(fCmd.c_str());
 
-    string str, str2, trMode;
+    std::string str, str2, trMode;
 
     //Find outrun mode. It is needed for the starting dates
     FLEXTRA_CHK(in.getValueId("FLEXTRA_RUN_MODE", trMode, modeIds_));
@@ -214,10 +220,10 @@ bool FlextraRun::generateCommandFile(const string& fCmd, MvRequest& in)
 *********************************************\n\n";
 
     FLEXTRA_CHK(in.getValue("FLEXTRA_RUN_LABEL", str, true));
-    out << str << endl;
+    out << str << std::endl;
 
     FLEXTRA_CHK(in.getValueId("FLEXTRA_TRAJECTORY_DIRECTION", str, directionIds_));
-    out << str << endl;
+    out << str << std::endl;
 
     //format is: hhhmmss
     FLEXTRA_CHK(in.getValue("FLEXTRA_TRAJECTORY_LENGTH", str));
@@ -226,20 +232,20 @@ bool FlextraRun::generateCommandFile(const string& fCmd, MvRequest& in)
         setError(13);
         return false;
     }
-    out << str2 << endl;
+    out << str2 << std::endl;
 
     if (trMode != "3") {
         FLEXTRA_CHK(in.getDate("FLEXTRA_FIRST_STARTING_DATE", str));
         out << str << " ";
 
         FLEXTRA_CHK(in.getTime("FLEXTRA_FIRST_STARTING_TIME", str));
-        out << str << endl;
+        out << str << std::endl;
 
         FLEXTRA_CHK(in.getDate("FLEXTRA_LAST_STARTING_DATE", str));
         out << str << " ";
 
         FLEXTRA_CHK(in.getTime("FLEXTRA_LAST_STARTING_TIME", str));
-        out << str << endl;
+        out << str << std::endl;
 
         //format is: hhhmmss
         FLEXTRA_CHK(in.getValue("FLEXTRA_STARTING_TIME_INTERVAL", str));
@@ -249,7 +255,7 @@ bool FlextraRun::generateCommandFile(const string& fCmd, MvRequest& in)
             return false;
         }
         //FLEXTRA_CHK(in.getTimeLenInSec("FLEXTRA_STARTING_TIME_INTERVAL",str));
-        out << str2 << endl;
+        out << str2 << std::endl;
     }
 
     //In FLIGHT mode the starting date,time and interval are disabled in the
@@ -257,22 +263,22 @@ bool FlextraRun::generateCommandFile(const string& fCmd, MvRequest& in)
     //computations. However FLEXTRA does need a proper date here, otherwise it crashes.
     //So we use the first date and time from the FLIGHT starting points here.
     else {
-        vector<string> startDate, startTime;
+        std::vector<std::string> startDate, startTime;
         FLEXTRA_CHK(in.getValue("FLEXTRA_FLIGHT_STARTING_DATES", startDate));
         FLEXTRA_CHK(in.getValue("FLEXTRA_FLIGHT_STARTING_TIMES", startTime));
         int cnt = startDate.size();
 
         if (cnt > 0 && static_cast<int>(startTime.size()) == cnt) {
-            string dStr, tStr;
+            std::string dStr, tStr;
             FLEXTRA_CHK(MvRequest::getDate("FLEXTRA_FLIGHT_STARTING_DATES", startDate[0], dStr));
             FLEXTRA_CHK(MvRequest::getTime("FLEXTRA_FLIGHT_STARTING_TIMES", startTime[0], tStr));
-            out << dStr << " " << tStr << endl;
+            out << dStr << " " << tStr << std::endl;
 
             FLEXTRA_CHK(MvRequest::getDate("FLEXTRA_FLIGHT_STARTING_DATES", startDate[cnt - 1], dStr));
             FLEXTRA_CHK(MvRequest::getTime("FLEXTRA_FLIGHT_STARTING_TIMES", startTime[cnt - 1], tStr));
-            out << dStr << " " << tStr << endl;
+            out << dStr << " " << tStr << std::endl;
 
-            out << "030000" << endl;
+            out << "030000" << std::endl;
         }
     }
 
@@ -281,7 +287,7 @@ bool FlextraRun::generateCommandFile(const string& fCmd, MvRequest& in)
     FLEXTRA_CHK(in.getTimeLenInSec("FLEXTRA_OUTPUT_INTERVAL_VALUE", str));
 
 #if 0
-    if(str.find("0") != string::npos &&  str.find_first_not_of("0") == string::npos)
+    if(str.find("0") !=std::string::npos &&  str.find_first_not_of("0") == std::string::npos)
 	{
 		marslog(LOG_EROR,"Invalid value specified for FLEXTRA_OUTPUT_INTERVAL_VALUE: %s",str.c_str());		
 		marslog(LOG_EROR,"It has to be greater than 0!");
@@ -291,7 +297,7 @@ bool FlextraRun::generateCommandFile(const string& fCmd, MvRequest& in)
 	
     //FLEXTRA_CHK(getTimeLen(str,str2,"FLEXTRA_OUTPUT_INTERVAL_VALUE",true));
 #endif
-    out << str << endl;
+    out << str << std::endl;
 
     //It might be disabled in the inteface (for CET and FLIGHT modes)
     in.getValue("FLEXTRA_UNCERTAINTY_TRAJECTORIES", str, true);
@@ -307,35 +313,35 @@ bool FlextraRun::generateCommandFile(const string& fCmd, MvRequest& in)
         FLEXTRA_CHK(in.getValue("FLEXTRA_V_RANDOM_ERROR", str));
         out << str << " ";
         FLEXTRA_CHK(in.getValue("FLEXTRA_W_RANDOM_ERROR", str));
-        out << str << endl;
+        out << str << std::endl;
     }
     else {
-        out << "0 0.5 2.0 0.08 0.08 0.08" << endl;
+        out << "0 0.5 2.0 0.08 0.08 0.08" << std::endl;
     }
 
 
     FLEXTRA_CHK(in.getValue("FLEXTRA_INTERPOLATION_TYPE", str));
-    out << str << endl;
+    out << str << std::endl;
 
     FLEXTRA_CHK(in.getValue("FLEXTRA_CFL_SPATIAL", str));
-    out << str << endl;
+    out << str << std::endl;
 
     FLEXTRA_CHK(in.getValue("FLEXTRA_CFL_TEMPORAL", str));
-    out << str << endl;
+    out << str << std::endl;
 
     //FLEXTRA_CHK(getParamValueId(str,in,"FLEXTRA_RUN_MODE",modeIds_));
-    out << trMode << endl;
+    out << trMode << std::endl;
 
     out.close();
 
     return true;
 }
 
-bool FlextraRun::generateStartPointsFile(const string& fStart, MvRequest& in)
+bool FlextraRun::generateStartPointsFile(const std::string& fStart, MvRequest& in)
 {
-    ofstream out(fStart.c_str());
+    std::ofstream out(fStart.c_str());
 
-    string str;
+    std::string str;
 
 
     out << "**********************************************************************\n\
@@ -367,7 +373,7 @@ bool FlextraRun::generateStartPointsFile(const string& fStart, MvRequest& in)
 
     in.getValue("FLEXTRA_RUN_MODE", str);
 
-    vector<string> type, name, lat, lon, lev, levUnit;
+    std::vector<std::string> type, name, lat, lon, lev, levUnit;
 
     FLEXTRA_CHK(in.getValue("FLEXTRA_NORMAL_TYPES", type));
     FLEXTRA_CHK(in.getValue("FLEXTRA_NORMAL_NAMES", name));
@@ -383,7 +389,7 @@ bool FlextraRun::generateStartPointsFile(const string& fStart, MvRequest& in)
         return false;
     }
 
-    string errTxt = "Incosistent number of items specified for parameter: FLEXTRA_NORMAL_";
+    std::string errTxt = "Incosistent number of items specified for parameter: FLEXTRA_NORMAL_";
     if (name.size() != cnt)
         errTxt += "NAMES!";
     else if (lat.size() != cnt)
@@ -395,20 +401,20 @@ bool FlextraRun::generateStartPointsFile(const string& fStart, MvRequest& in)
     else if (levUnit.size() != cnt)
         errTxt += "LEVEL_UNITS!";
 
-    if (errTxt.find("!") != string::npos) {
+    if (errTxt.find("!") != std::string::npos) {
         marslog(LOG_EROR, "%s", errTxt.c_str());
         setError(13);
         return false;
     }
 
     for (unsigned int i = 0; i < cnt; i++) {
-        out << lon[i] << endl;
-        out << lat[i] << endl;
-        out << type[i] << endl;
-        out << levUnit[i] << endl;
-        out << lev[i] << endl;
-        out << name[i] << endl;
-        out << "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" << endl;
+        out << lon[i] << std::endl;
+        out << lat[i] << std::endl;
+        out << type[i] << std::endl;
+        out << levUnit[i] << std::endl;
+        out << lev[i] << std::endl;
+        out << name[i] << std::endl;
+        out << "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" << std::endl;
     }
 
     out.close();
@@ -416,11 +422,11 @@ bool FlextraRun::generateStartPointsFile(const string& fStart, MvRequest& in)
     return true;
 }
 
-bool FlextraRun::generateStartCetFile(const string& fStart, MvRequest& in)
+bool FlextraRun::generateStartCetFile(const std::string& fStart, MvRequest& in)
 {
-    ofstream out(fStart.c_str());
+    std::ofstream out(fStart.c_str());
 
-    string str;
+    std::string str;
 
 
     out << "**********************************************************************\n\
@@ -450,7 +456,7 @@ bool FlextraRun::generateStartCetFile(const string& fStart, MvRequest& in)
 **********************************************************************\n\
 ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n";
 
-    string type, name, levUnit, dx, dy, dz, levTop, levBottom;
+    std::string type, name, levUnit, dx, dy, dz, levTop, levBottom;
     FLEXTRA_CHK(in.getValueId("FLEXTRA_CET_TYPE", type, cetTypeIds_));
     FLEXTRA_CHK(in.getValue("FLEXTRA_CET_NAME", name));
     FLEXTRA_CHK(in.getValueId("FLEXTRA_CET_LEVEL_UNITS", levUnit, cetLevelUnitsIds_));
@@ -468,35 +474,35 @@ bool FlextraRun::generateStartCetFile(const string& fStart, MvRequest& in)
     }
 
     double dval;
-    vector<double> areaL;
+    std::vector<double> areaL;
     for (int i = 0; i < cnt; i++) {
         in.getValue(dval, "FLEXTRA_CET_AREA", i);
         areaL.push_back(dval);
     }
-    out << areaL[1] << endl;
-    out << areaL[0] << endl;
-    out << areaL[3] << endl;
-    out << areaL[2] << endl;
-    out << dx << endl;
-    out << dy << endl;
-    out << type << endl;
-    out << levUnit << endl;
-    out << levBottom << endl;
-    out << levTop << endl;
-    out << dz << endl;
-    out << name << endl;
-    out << "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" << endl;
+    out << areaL[1] << std::endl;
+    out << areaL[0] << std::endl;
+    out << areaL[3] << std::endl;
+    out << areaL[2] << std::endl;
+    out << dx << std::endl;
+    out << dy << std::endl;
+    out << type << std::endl;
+    out << levUnit << std::endl;
+    out << levBottom << std::endl;
+    out << levTop << std::endl;
+    out << dz << std::endl;
+    out << name << std::endl;
+    out << "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" << std::endl;
 
     out.close();
 
     return true;
 }
 
-bool FlextraRun::generateStartFlightFile(const string& fStart, MvRequest& in)
+bool FlextraRun::generateStartFlightFile(const std::string& fStart, MvRequest& in)
 {
-    ofstream out(fStart.c_str());
+    std::ofstream out(fStart.c_str());
 
-    string str;
+    std::string str;
 
 
     out << "**********************************************************************\n\
@@ -527,13 +533,13 @@ bool FlextraRun::generateStartFlightFile(const string& fStart, MvRequest& in)
 *                                                                    *\n\
 **********************************************************************\n";
 
-    string type, name, levUnit;
+    std::string type, name, levUnit;
     FLEXTRA_CHK(in.getValueId("FLEXTRA_FLIGHT_TYPE", type, flightTypeIds_));
     FLEXTRA_CHK(in.getValue("FLEXTRA_FLIGHT_NAME", name));
     FLEXTRA_CHK(in.getValueId("FLEXTRA_FLIGHT_LEVEL_UNITS", levUnit, flightLevelUnitsIds_));
 
 
-    vector<string> lat, lon, lev, startDate, startTime;
+    std::vector<std::string> lat, lon, lev, startDate, startTime;
     FLEXTRA_CHK(in.getValue("FLEXTRA_FLIGHT_LATITUDES", lat));
     FLEXTRA_CHK(in.getValue("FLEXTRA_FLIGHT_LONGITUDES", lon));
     FLEXTRA_CHK(in.getValue("FLEXTRA_FLIGHT_LEVELS", lev));
@@ -547,7 +553,7 @@ bool FlextraRun::generateStartFlightFile(const string& fStart, MvRequest& in)
         return false;
     }
 
-    string errTxt = "Incosistent number of items specified for parameter: FLEXTRA_FLIGHT_";
+    std::string errTxt = "Incosistent number of items specified for parameter: FLEXTRA_FLIGHT_";
     if (lon.size() != cnt)
         errTxt += "LONGITUDES!";
     else if (lev.size() != cnt)
@@ -557,27 +563,27 @@ bool FlextraRun::generateStartFlightFile(const string& fStart, MvRequest& in)
     else if (startTime.size() != cnt)
         errTxt += "STARTING_TIMES!";
 
-    if (errTxt.find("!") != string::npos) {
+    if (errTxt.find("!") != std::string::npos) {
         marslog(LOG_EROR, "%s", errTxt.c_str());
         setError(13);
         return false;
     }
 
-    out << name << endl;
-    out << type << endl;
-    out << levUnit << endl;
-    out << "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" << endl;
+    out << name << std::endl;
+    out << type << std::endl;
+    out << levUnit << std::endl;
+    out << "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" << std::endl;
 
     for (unsigned int i = 0; i < cnt; i++) {
-        string tStr, dStr;
+        std::string tStr, dStr;
         FLEXTRA_CHK(MvRequest::getDate("FLEXTRA_FLIGHT_STARTING_DATES", startDate[i], dStr));
         FLEXTRA_CHK(MvRequest::getTime("FLEXTRA_FLIGHT_STARTING_TIMES", startTime[i], tStr));
 
-        out << dStr << " " << tStr << endl;
-        out << lon[i] << endl;
-        out << lat[i] << endl;
-        out << lev[i] << endl;
-        out << "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" << endl;
+        out << dStr << " " << tStr << std::endl;
+        out << lon[i] << std::endl;
+        out << lat[i] << std::endl;
+        out << lev[i] << std::endl;
+        out << "++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++" << std::endl;
     }
 
     out.close();
@@ -592,7 +598,7 @@ bool FlextraRun::generateStartFlightFile(const string& fStart, MvRequest& in)
 
 bool FlextraRun::getDateRange(MvDate& rangeStart, MvDate& rangeEnd, MvRequest& in)
 {
-    string str, dStr, tStr, trMode;
+    std::string str, dStr, tStr, trMode;
     int lenSec;
     MvDate startDate1, startDate2;
 
@@ -622,7 +628,7 @@ bool FlextraRun::getDateRange(MvDate& rangeStart, MvDate& rangeEnd, MvRequest& i
     //computations. However FLEXTRA does need a proper date here, otherwise it crashes.
     //So we use the first date and time from the FLIGHT starting points here.
     else {
-        vector<string> startDate, startTime;
+        std::vector<std::string> startDate, startTime;
         FLEXTRA_CHK(in.getValue("FLEXTRA_FLIGHT_STARTING_DATES", startDate));
         FLEXTRA_CHK(in.getValue("FLEXTRA_FLIGHT_STARTING_TIMES", startTime));
         int cnt = startDate.size();
@@ -649,26 +655,26 @@ bool FlextraRun::getDateRange(MvDate& rangeStart, MvDate& rangeEnd, MvRequest& i
     return true;
 }
 
-bool FlextraRun::getPredefInputPath(const string& rootPath, const MvDate& startDate, const MvDate& /*endDate*/, string& resDir)
+bool FlextraRun::getPredefInputPath(const std::string& rootPath, const MvDate& startDate, const MvDate& /*endDate*/, std::string& resDir)
 {
     //Scan rootpath for FLEXTRA input directories
     DIR* dp;
     struct dirent* dirp;
-    if ((dp = opendir(rootPath.c_str())) == NULL) {
+    if ((dp = opendir(rootPath.c_str())) == nullptr) {
         marslog(LOG_EROR, "Failed to open directory: %s", rootPath.c_str());
         return false;
     }
 
-    vector<MvDate> dateVec;
-    vector<string> pathVec;
+    std::vector<MvDate> dateVec;
+    std::vector<std::string> pathVec;
 
-    string::size_type pos;
-    while ((dirp = readdir(dp)) != NULL) {
-        string name(dirp->d_name);
-        if (name.size() == 13 && (pos = name.find("_")) != string::npos) {
-            string s;
-            string sDate = name.substr(0, 8);
-            string sTime = name.substr(9, 4);
+    std::string::size_type pos;
+    while ((dirp = readdir(dp)) != nullptr) {
+        std::string name(dirp->d_name);
+        if (name.size() == 13 && (pos = name.find("_")) != std::string::npos) {
+            std::string s;
+            std::string sDate = name.substr(0, 8);
+            std::string sTime = name.substr(9, 4);
 
             s     = sDate;
             sDate = s.substr(0, 4) + "-" + s.substr(4, 2) + "-" + s.substr(6, 2);
@@ -700,7 +706,7 @@ bool FlextraRun::getPredefInputPath(const string& rootPath, const MvDate& startD
 
 void FlextraRun::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "--------------FlextraRun::serve()--------------" << endl;
+    std::cout << "--------------FlextraRun::serve()--------------" << std::endl;
     in.print();
 
     std::string errTxt;
@@ -708,13 +714,13 @@ void FlextraRun::serve(MvRequest& in, MvRequest& out)
     //Find out flextra script path
     std::string flextraScript;
     char* mvbin = getenv("METVIEW_BIN");
-    if (mvbin == 0) {
+    if (mvbin == nullptr) {
         marslog(LOG_EROR, "No METVIEW_BIN env variable is defined. Cannot locate script mv_flextra_run!");
         setError(13);
         return;
     }
     else {
-        flextraScript = string(mvbin) + "/mv_flextra_run";
+        flextraScript = std::string(mvbin) + "/mv_flextra_run";
     }
 
 
@@ -734,43 +740,43 @@ void FlextraRun::serve(MvRequest& in, MvRequest& out)
     }
 
     //Genarate pathnames  file
-    string fPathnames  = tmpPath + "/pathnames";
-    string optionsPath = tmpPath;
-    string outPath     = tmpPath;
+    std::string fPathnames  = tmpPath + "/pathnames";
+    std::string optionsPath = tmpPath;
+    std::string outPath     = tmpPath;
     if (!generatePathnamesFile(fPathnames, in, optionsPath, outPath)) {
         return;
     }
 
     //Generate COMMAND file
-    string fCmd = tmpPath + "/COMMAND";
+    std::string fCmd = tmpPath + "/COMMAND";
     if (!generateCommandFile(fCmd, in)) {
         return;
     }
 
     //Get FLEXTRA RUN MODE
-    string trMode;
+    std::string trMode;
     in.getValueId("FLEXTRA_RUN_MODE", trMode, modeIds_);
 
     if (trMode == "1") {
-        string fStart = tmpPath + "/STARTPOINTS";
+        std::string fStart = tmpPath + "/STARTPOINTS";
         if (!generateStartPointsFile(fStart, in)) {
             return;
         }
     }
     else if (trMode == "2") {
-        string fStart = tmpPath + "/STARTCET";
+        std::string fStart = tmpPath + "/STARTCET";
         if (!generateStartCetFile(fStart, in)) {
             return;
         }
     }
     else if (trMode == "3") {
-        string fStart = tmpPath + "/STARTFLIGHT";
+        std::string fStart = tmpPath + "/STARTFLIGHT";
         if (!generateStartFlightFile(fStart, in)) {
             return;
         }
     }
 
-    string trModeName;
+    std::string trModeName;
     if (trMode == "1")
         trModeName = "NORMAL";
     if (trMode == "2")
@@ -778,23 +784,23 @@ void FlextraRun::serve(MvRequest& in, MvRequest& out)
     if (trMode == "3")
         trModeName = "FLIGHT";
 
-    string resFileName = "res.txt";
-    string logFileName = "log.txt";
+    std::string resFileName = "res.txt";
+    std::string logFileName = "log.txt";
 
     //Run the flextra script
-    string cmd = flextraScript + " \"" + tmpPath + "\" \"" + exe + "\" \"" + trModeName + "\" \"" + resFileName + "\" \"" + logFileName + "\"";
+    std::string cmd = flextraScript + " \"" + tmpPath + "\" \"" + exe + "\" \"" + trModeName + "\" \"" + resFileName + "\" \"" + logFileName + "\"";
 
     //marslog(LOG_INFO,"Execute command: %s",cmd.c_str());
-    cout << "Execute command: " << cmd << endl;
+    std::cout << "Execute command: " << cmd << std::endl;
 
     int ret = system(cmd.c_str());
 
     //If the script failed read log file and
     //write it into LOG_EROR
     if (ret == -1 || WEXITSTATUS(ret) != 0) {
-        string logFile = tmpPath + "/" + logFileName;
-        ifstream in(logFile.c_str());
-        string line;
+        std::string logFile = tmpPath + "/" + logFileName;
+        std::ifstream in(logFile.c_str());
+        std::string line;
 
         if (WEXITSTATUS(ret) == 255) {
             marslog(LOG_WARN, "Warnings generated during FLEXTRA run!");
@@ -824,7 +830,7 @@ void FlextraRun::serve(MvRequest& in, MvRequest& out)
         }
     }
 
-    string resFile = tmpPath + "/" + resFileName;
+    std::string resFile = tmpPath + "/" + resFileName;
 
     out         = MvRequest("FLEXTRA_FILE");
     out("PATH") = resFile.c_str();
