@@ -13,16 +13,13 @@
 
 #include <iostream>
 #include <stdexcept>
-#include <fstream>
-
-using namespace std;
 
 
 class Base : public MvService
 {
 protected:
     Base(const char* a) :
-        MvService(a){};
+        MvService(a) {}
 };
 
 
@@ -30,18 +27,18 @@ class FlextraVisualiser : public Base
 {
 public:
     FlextraVisualiser(const char* a) :
-        Base(a){};
+        Base(a) {}
     void serve(MvRequest&, MvRequest&);
 };
 
 void FlextraVisualiser::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "--------------FlextraVisualiser::serve()--------------" << endl;
+    std::cout << "--------------FlextraVisualiser::serve()--------------" << std::endl;
     in.print();
 
     MvRequest inR = in;
-    string inFile;
-    string verb = in.getVerb();
+    std::string inFile;
+    std::string verb = in.getVerb();
 
     //------------------------------------------
     // Find out the input filename
@@ -60,7 +57,7 @@ void FlextraVisualiser::serve(MvRequest& in, MvRequest& out)
             return;
         }
         else {
-            inFile = string(path);
+            inFile = std::string(path);
         }
     }
     else {
@@ -71,7 +68,7 @@ void FlextraVisualiser::serve(MvRequest& in, MvRequest& out)
             return;
         }
 
-        inFile = string(path);
+        inFile = std::string(path);
     }
 
 
@@ -108,7 +105,7 @@ void FlextraVisualiser::serve(MvRequest& in, MvRequest& out)
     // Select block
     //----------------------------------
 
-    MvFlextraBlock* data    = 0;
+    MvFlextraBlock* data    = nullptr;
     const char* blockIdChar = inR("FLEXTRA_GROUP_INDEX");
     if (blockIdChar) {
         int blockId = atoi(blockIdChar) - 1;
@@ -142,7 +139,7 @@ void FlextraVisualiser::serve(MvRequest& in, MvRequest& out)
     // Points file
     //----------------------------------
 
-    string outFilePoints(marstmp());
+    std::string outFilePoints(marstmp());
     int metaDataCntPoints = 0;
 
     //data->writeAll(outFilePoints,metaDataCntPoints);
@@ -194,7 +191,7 @@ void FlextraVisualiser::serve(MvRequest& in, MvRequest& out)
             out = out + vdef;
         }
         else if (strcmp(plot_mode, "LABEL") == 0) {
-            vector<string> labels;
+            std::vector<std::string> labels;
             data->writeLabels(outFilePoints, metaDataCntPoints, "6h", labels);
 
             MvRequest req("TABLE_GEO_POINTS");
@@ -229,8 +226,8 @@ void FlextraVisualiser::serve(MvRequest& in, MvRequest& out)
 			vdef("SYMBOL_ADVANCED_TABLE_MAX_VALUE") = trNum+1; //!!
 			vdef("SYMBOL_ADVANCED_TABLE_INTERVAL") = 1;*/
 
-            for (int i = 0; i < static_cast<int>(labels.size()); i++) {
-                vdef.addValue("SYMBOL_ADVANCED_TABLE_TEXT_LIST", labels[i].c_str());
+            for (auto& label : labels) {
+                vdef.addValue("SYMBOL_ADVANCED_TABLE_TEXT_LIST", label.c_str());
             }
 
             vdef("SYMBOL_ADVANCED_TABLE_TEXT_HEIGHT") = 0.3;
@@ -243,9 +240,9 @@ void FlextraVisualiser::serve(MvRequest& in, MvRequest& out)
             out = out + vdef;
 
             /*const char *period=inR("FLEXTRA_LABEL_PERIOD");
-	  		string periodStr(period);	
+	  		std::string periodStr(period);	
 		
-			string outFileLabels(marstmp());
+			std::string outFileLabels(marstmp());
 			int metaDataCnt=0;
 
 			data->writeLabels(outFileLabels,metaDataCnt,period);
@@ -291,7 +288,7 @@ void FlextraVisualiser::serve(MvRequest& in, MvRequest& out)
         if (strcmp(plot_mode, "TRAJECTORY") == 0) {
             data->writeAll(outFilePoints, metaDataCntPoints);
 
-            map<string, int> parId;
+            std::map<std::string, int> parId;
             parId["DATE"]       = 2;
             parId["LATITUDE"]   = 4;
             parId["LONGITUDE"]  = 5;
@@ -309,12 +306,12 @@ void FlextraVisualiser::serve(MvRequest& in, MvRequest& out)
             if (strcmp(x_var, "DATE") == 0) {
                 req("TABLE_X_TYPE") = "DATE";
             }
-            req("TABLE_X_VARIABLE") = parId[string(x_var)];
+            req("TABLE_X_VARIABLE") = parId[std::string(x_var)];
 
             if (strcmp(y_var, "DATE") == 0) {
                 req("TABLE_Y_TYPE") = "DATE";
             }
-            req("TABLE_Y_VARIABLE") = parId[string(y_var)];
+            req("TABLE_Y_VARIABLE") = parId[std::string(y_var)];
 
             req("TABLE_VALUE_VARIABLE")     = "1";
             req("TABLE_DELIMITER")          = ",";
@@ -367,9 +364,9 @@ void FlextraVisualiser::serve(MvRequest& in, MvRequest& out)
 	if(highlight && strcmp(highlight,"ON") == 0)
 	{  
 	  	const char *period=inR("FLEXTRA_SYMBOL_HIGHLIGHT_PERIOD");
-	  	string periodStr(period);	  	
+	  	std::string periodStr(period);	  	
 	 
-	  	string outFileHighlight(marstmp());
+	  	std::string outFileHighlight(marstmp());
 		int metaDataCnt=0;
 
 		data->writeHighlightPoints(outFileHighlight,metaDataCnt,periodStr);
