@@ -11,7 +11,6 @@
 #include <string>
 #include <vector>
 #include <iostream>
-#include <fstream>
 #include <stdio.h>
 #include <string.h>
 #include <assert.h>
@@ -21,7 +20,7 @@
 #include "MvFlexpart.h"
 #include "MvBinaryReader.h"
 #include "MvDate.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 //#define _GNU_SOURCE
 //#include <fenv.h>
@@ -32,7 +31,7 @@ class MvFlexpartGrid
 {
 public:
     MvFlexpartGrid(const std::string&, const std::string&, const std::string&, const std::string&, bool forward, int species);
-    ~MvFlexpartGrid() {}
+    ~MvFlexpartGrid() = default;
 
 protected:
     void convert();
@@ -94,7 +93,7 @@ void MvFlexpartGrid::convert()
 
     int paramId;
     double scaleFactor = pow(10., -12);
-    double* data       = 0;
+    double* data       = nullptr;
     std::string levType;
     int spec = species_;
 
@@ -192,12 +191,10 @@ void MvFlexpartGrid::convert()
             readField(&r, &data, dataSize, true, scaleFactor);
 
             double* dLev = data;
-            for (size_t lev = 0; lev < header_.levels.size(); lev++) {
-                double levVal = header_.levels[lev];
-
-                std::string outName = outPattern_ + metview::toString<double>(levVal) + "_" +
-                                      metview::toString<int>(ac) + "_" +
-                                      metview::toString<int>(specPoint) + " .grib";
+            for (double levVal : header_.levels) {
+                std::string outName = outPattern_ + std::to_string(levVal) + "_" +
+                                      std::to_string(ac) + "_" +
+                                      std::to_string(specPoint) + " .grib";
 
                 writeField(dLev, outName,
                            paramId, levType, levVal, step, specPoint, spec, ac);
@@ -217,7 +214,7 @@ void MvFlexpartGrid::convertFlux()
     if (!r.isValid())
         return;
 
-    double* data        = 0;
+    double* data        = nullptr;
     std::string levType = "heightAboveGround";
 
     r.skipRecMarker();
@@ -250,13 +247,12 @@ void MvFlexpartGrid::convertFlux()
                     readFluxField(&r, &data, dataSize);
 
                     double* dLev = data;
-                    for (size_t lev = 0; lev < header_.levels.size(); lev++) {
-                        double levVal       = header_.levels[lev];
-                        std::string outName = outPattern_ + metview::toString<int>(iFlux) + "_" +
-                                              metview::toString<double>(levVal) + "_" +
-                                              metview::toString<int>(ac) + "_" +
-                                              metview::toString<int>(specPoint) + "_" +
-                                              metview::toString<int>(spec + 1) + "_.grib";
+                    for (double levVal : header_.levels) {
+                        std::string outName = outPattern_ + std::to_string(iFlux) + "_" +
+                                              std::to_string(levVal) + "_" +
+                                              std::to_string(ac) + "_" +
+                                              std::to_string(specPoint) + "_" +
+                                              std::to_string(spec + 1) + "_.grib";
 
                         writeField(dLev, outName,
                                    paramIds[iFlux], levType, levVal, step, specPoint, spec, 0);
@@ -408,27 +404,27 @@ void MvFlexpartGrid::readFluxField(MvBinaryReader* r, double** data, size_t data
 void MvFlexpartGrid::writeField(double* data, const std::string& outFile, long paramId,
                                 const std::string& levType, double levVal, long stepInSec, int specPoint, int spec, int ageClass)
 {
-    grib_handle* gh = 0;
+    grib_handle* gh = nullptr;
 
     size_t size = header_.nx * header_.ny;
     size_t len  = 0;
 
     std::string sampleName("flexpart_1_grib2");
-    if ((gh = grib_handle_new_from_samples(0, sampleName.c_str())) == 0) {
+    if ((gh = grib_handle_new_from_samples(nullptr, sampleName.c_str())) == nullptr) {
         std::cerr << "Could not create grib from sample: " << sampleName << std::endl;
         exit(1);
         return;
     }
 
     //Pouplate Section 2
-    GRIB_CHECK(grib_set_long(gh, "flexpartVersion", 902), 0);
-    GRIB_CHECK(grib_set_long(gh, "speciesId", spec + 1), 0);
+    GRIB_CHECK(grib_set_long(gh, "flexpartVersion", 902), nullptr);
+    GRIB_CHECK(grib_set_long(gh, "speciesId", spec + 1), nullptr);
 
     //Species
     assert(spec >= 0 && spec < header_.specNum);
     std::string speciesName = header_.specNames[spec];
     len                     = speciesName.size();
-    GRIB_CHECK(grib_set_string(gh, "speciesName", speciesName.c_str(), &len), 0);
+    GRIB_CHECK(grib_set_string(gh, "speciesName", speciesName.c_str(), &len), nullptr);
 
     //Releases
 
@@ -436,22 +432,22 @@ void MvFlexpartGrid::writeField(double* data, const std::string& outFile, long p
     if (static_cast<int>(header_.release.size()) == header_.specPointNum) {
         int release = specPoint;
         assert(release >= 0 && release < static_cast<int>(header_.release.size()));
-        GRIB_CHECK(grib_set_long(gh, "numberOfReleases", header_.release.size()), 0);
-        GRIB_CHECK(grib_set_long(gh, "releaseNumber", release + 1), 0);
+        GRIB_CHECK(grib_set_long(gh, "numberOfReleases", header_.release.size()), nullptr);
+        GRIB_CHECK(grib_set_long(gh, "releaseNumber", release + 1), nullptr);
 
         std::string releaseName = header_.release[release].name;
         len                     = releaseName.size();
-        GRIB_CHECK(grib_set_string(gh, "releaseName", releaseName.c_str(), &len), 0);
+        GRIB_CHECK(grib_set_string(gh, "releaseName", releaseName.c_str(), &len), nullptr);
     }
     //releases are merged into a field
     else {
-        GRIB_CHECK(grib_set_long(gh, "numberOfReleases", header_.release.size()), 0);
-        GRIB_CHECK(grib_set_long(gh, "releaseNumber", 0), 0);
+        GRIB_CHECK(grib_set_long(gh, "numberOfReleases", header_.release.size()), nullptr);
+        GRIB_CHECK(grib_set_long(gh, "releaseNumber", 0), nullptr);
     }
 
     //Ageclasses
-    GRIB_CHECK(grib_set_long(gh, "numberOfAgeClasses", header_.ageClass.size()), 0);
-    GRIB_CHECK(grib_set_long(gh, "ageClass", ageClass + 1), 0);
+    GRIB_CHECK(grib_set_long(gh, "numberOfAgeClasses", header_.ageClass.size()), nullptr);
+    GRIB_CHECK(grib_set_long(gh, "ageClass", ageClass + 1), nullptr);
 
     long ageClassBegin = 0;
     long ageClassEnd   = header_.ageClass[ageClass];
@@ -460,48 +456,48 @@ void MvFlexpartGrid::writeField(double* data, const std::string& outFile, long p
         ageClassBegin = header_.ageClass[ageClass - 1];
     }
 
-    GRIB_CHECK(grib_set_long(gh, "ageClassEnd", ageClassBegin), 0);
-    GRIB_CHECK(grib_set_long(gh, "ageClassEnd", ageClassEnd), 0);
+    GRIB_CHECK(grib_set_long(gh, "ageClassEnd", ageClassBegin), nullptr);
+    GRIB_CHECK(grib_set_long(gh, "ageClassEnd", ageClassEnd), nullptr);
 
     //Grid
-    GRIB_CHECK(grib_set_double(gh, "longitudeOfFirstGridPointInDegrees", header_.west), 0);
-    GRIB_CHECK(grib_set_double(gh, "longitudeOfLastGridPointInDegrees", header_.east), 0);
-    GRIB_CHECK(grib_set_double(gh, "latitudeOfFirstGridPointInDegrees", header_.south), 0);
-    GRIB_CHECK(grib_set_double(gh, "latitudeOfLastGridPointInDegrees", header_.north), 0);
-    GRIB_CHECK(grib_set_long(gh, "Ni", header_.nx), 0);
-    GRIB_CHECK(grib_set_long(gh, "Nj", header_.ny), 0);
-    GRIB_CHECK(grib_set_double(gh, "iDirectionIncrementInDegrees", header_.dx), 0);
-    GRIB_CHECK(grib_set_double(gh, "jDirectionIncrementInDegrees", header_.dy), 0);
-    GRIB_CHECK(grib_set_long(gh, "jScansPositively", 1), 0);
+    GRIB_CHECK(grib_set_double(gh, "longitudeOfFirstGridPointInDegrees", header_.west), nullptr);
+    GRIB_CHECK(grib_set_double(gh, "longitudeOfLastGridPointInDegrees", header_.east), nullptr);
+    GRIB_CHECK(grib_set_double(gh, "latitudeOfFirstGridPointInDegrees", header_.south), nullptr);
+    GRIB_CHECK(grib_set_double(gh, "latitudeOfLastGridPointInDegrees", header_.north), nullptr);
+    GRIB_CHECK(grib_set_long(gh, "Ni", header_.nx), nullptr);
+    GRIB_CHECK(grib_set_long(gh, "Nj", header_.ny), nullptr);
+    GRIB_CHECK(grib_set_double(gh, "iDirectionIncrementInDegrees", header_.dx), nullptr);
+    GRIB_CHECK(grib_set_double(gh, "jDirectionIncrementInDegrees", header_.dy), nullptr);
+    GRIB_CHECK(grib_set_long(gh, "jScansPositively", 1), nullptr);
 
     //Level
     len = levType.size();
-    GRIB_CHECK(grib_set_string(gh, "typeOfLevel", levType.c_str(), &len), 0);
-    GRIB_CHECK(grib_set_double(gh, "level", levVal), 0);
+    GRIB_CHECK(grib_set_string(gh, "typeOfLevel", levType.c_str(), &len), nullptr);
+    GRIB_CHECK(grib_set_double(gh, "level", levVal), nullptr);
 
     //Param
-    GRIB_CHECK(grib_set_long(gh, "paramId", paramId), 0);
+    GRIB_CHECK(grib_set_long(gh, "paramId", paramId), nullptr);
 
     //Date
-    GRIB_CHECK(grib_set_long(gh, "dataDate", header_.runDate), 0);
-    GRIB_CHECK(grib_set_long(gh, "dataTime", header_.runTime / 100), 0);
+    GRIB_CHECK(grib_set_long(gh, "dataDate", header_.runDate), nullptr);
+    GRIB_CHECK(grib_set_long(gh, "dataTime", header_.runTime / 100), nullptr);
 
     if (stepInSec % 3600 == 0)
-        GRIB_CHECK(grib_set_long(gh, "step", stepInSec / 3600), 0);
+        GRIB_CHECK(grib_set_long(gh, "step", stepInSec / 3600), nullptr);
     else if (stepInSec % 60 == 0) {
         std::string stepUnits("m");
         len = stepUnits.size();
-        GRIB_CHECK(grib_set_string(gh, "stepUnits", stepUnits.c_str(), &len), 0);
-        GRIB_CHECK(grib_set_long(gh, "step", stepInSec / 60), 0);
+        GRIB_CHECK(grib_set_string(gh, "stepUnits", stepUnits.c_str(), &len), nullptr);
+        GRIB_CHECK(grib_set_long(gh, "step", stepInSec / 60), nullptr);
     }
     else {
         std::string stepUnits("s");
         len = stepUnits.size();
-        GRIB_CHECK(grib_set_string(gh, "stepUnits", stepUnits.c_str(), &len), 0);
-        GRIB_CHECK(grib_set_long(gh, "step", stepInSec), 0);
+        GRIB_CHECK(grib_set_string(gh, "stepUnits", stepUnits.c_str(), &len), nullptr);
+        GRIB_CHECK(grib_set_long(gh, "step", stepInSec), nullptr);
     }
 
-    GRIB_CHECK(grib_set_long(gh, "bitsPerValue", 24), 0);
+    GRIB_CHECK(grib_set_long(gh, "bitsPerValue", 24), nullptr);
 
     //for(int i=0; i < size; i++)
     //{
@@ -509,9 +505,9 @@ void MvFlexpartGrid::writeField(double* data, const std::string& outFile, long p
     //data[i]=0.;
     //}
 
-    GRIB_CHECK(grib_set_double_array(gh, "values", data, size), 0);
+    GRIB_CHECK(grib_set_double_array(gh, "values", data, size), nullptr);
 
-    GRIB_CHECK(grib_write_message(gh, outFile.c_str(), "w"), 0);
+    GRIB_CHECK(grib_write_message(gh, outFile.c_str(), "w"), nullptr);
 
     grib_handle_delete(gh);
 }
