@@ -7,19 +7,21 @@
 
  ***************************** LICENSE END *************************************/
 
-#include <string>
-#include <iostream>
-#include <fstream>
-#include <vector>
-#include <map>
-#include <cmath>
-#include <iomanip>
 #include <array>
+#include <cmath>
+#include <fstream>
+#include <iomanip>
+#include <iostream>
+#include <map>
+#include <string>
+#include <vector>
 
-#include <assert.h>
-#include <stdlib.h>
+#include "fstream_mars_fix.h"
 
-#include "MvMiscelaneous.h"
+#include <cassert>
+#include <cstdlib>
+
+#include "MvMiscellaneous.h"
 
 struct FxpCluster
 {
@@ -97,44 +99,44 @@ bool convert(const std::string& trFile, const std::string& outPattern)
     //Trajectory waypoints
 
     std::map<std::string, std::vector<FxpTraj> > trMap;
-    std::array<int,16> fieldWidthArr = {5, 8, 9, 9, 8, 8, 8, 8, 8, 8, 8, 8, 8, 6, 6, 6};
-    std::array<int, 5> clWidthArr = {8, 8, 7, 6, 8};
+    std::array<int, 16> fieldWidthArr = {5, 8, 9, 9, 8, 8, 8, 8, 8, 8, 8, 8, 8, 6, 6, 6};
+    std::array<int, 5> clWidthArr     = {8, 8, 7, 6, 8};
 
     while (getline(in, line)) {
         FxpTraj t;
         std::string str;
         int pos = 0;
-        for (size_t i = 0; i < fieldWidthArr.size(); i++) {
-            t.data.push_back(metview::simplified(line.substr(pos, fieldWidthArr[i])));
-            pos += fieldWidthArr[i];
+        for (int i : fieldWidthArr) {
+            t.data.push_back(metview::simplified(line.substr(pos, i)));
+            pos += i;
         }
 
         std::vector<FxpCluster> clVec;
-        while(pos < static_cast<int>(line.size())) {
+        while (pos < static_cast<int>(line.size())) {
             FxpCluster cl;
             cl.lon = metview::simplified(line.substr(pos, clWidthArr[0]));
             pos += clWidthArr[0];
-            if(pos >= static_cast<int>(line.size()))
+            if (pos >= static_cast<int>(line.size()))
                 return false;
 
             cl.lat = metview::simplified(line.substr(pos, clWidthArr[1]));
             pos += clWidthArr[1];
-            if(pos >= static_cast<int>(line.size()))
+            if (pos >= static_cast<int>(line.size()))
                 return false;
 
             cl.z = metview::simplified(line.substr(pos, clWidthArr[2]));
             pos += clWidthArr[2];
-            if(pos >= static_cast<int>(line.size()))
+            if (pos >= static_cast<int>(line.size()))
                 return false;
 
             cl.f = metview::simplified(line.substr(pos, clWidthArr[3]));
             pos += clWidthArr[3];
-            if(pos >= static_cast<int>(line.size()))
+            if (pos >= static_cast<int>(line.size()))
                 return false;
 
             cl.rms = metview::simplified(line.substr(pos, clWidthArr[4]));
             pos += clWidthArr[4];
-            if(pos > static_cast<int>(line.size()))
+            if (pos > static_cast<int>(line.size()))
                 return false;
 
             clVec.push_back(cl);
@@ -146,7 +148,7 @@ bool convert(const std::string& trFile, const std::string& outPattern)
         trMap[actId].push_back(t);
     }
 
-    for (std::map<std::string, std::vector<FxpTraj> >::const_iterator it = trMap.begin(); it != trMap.end(); ++it) {
+    for (auto it = trMap.begin(); it != trMap.end(); ++it) {
         if (!write(it->second, it->first, outPattern, runDate, runTime, relVec))
             return false;
     }
@@ -197,8 +199,8 @@ bool write(const std::vector<FxpTraj>& tr, const std::string& id, const std::str
         return false;
     }
 
-    for (std::map<std::string, std::string>::const_iterator it = relVec[relId].begin(); it != relVec[relId].end(); ++it) {
-        out << " " << it->first << "=" << it->second;
+    for (const auto& it : relVec[relId]) {
+        out << " " << it.first << "=" << it.second;
     }
 
     out << std::endl;
@@ -214,9 +216,7 @@ bool write(const std::vector<FxpTraj>& tr, const std::string& id, const std::str
     out << std::endl;
 
     //write data
-    for (size_t i = 0; i < tr.size(); i++) {
-        const FxpTraj& t = tr[i];
-
+    for (const auto& t : tr) {
         assert(t.data.size() == 16);
 
         for (size_t j = 1; j < t.data.size(); j++) {
