@@ -7,15 +7,11 @@
 
  ***************************** LICENSE END *************************************/
 
+#include "MvQHighlighter.h"
+
 #include <QStringList>
 #include <QRegularExpressionMatch>
 
-#include <iostream>
-#include <fstream>
-#include <sstream>
-#include "MvQHighlighter.h"
-
-using namespace std;
 
 MvQHighlighter::MvQHighlighter(QTextDocument* parent) :
     QSyntaxHighlighter(parent)
@@ -35,14 +31,14 @@ MvQHighlighter::MvQHighlighter(QTextDocument* parent) :
                     << "# OF POINTS";
 
     foreach (QString pattern, keywordPatterns) {
-        QString s    = pattern + "(?=:)";
+        QString s = pattern + "(?=:)";
 #if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
         rule.pattern = QRegularExpression(s);
         rule.pattern.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
 #else
         rule.pattern = QRegExp(s, Qt::CaseInsensitive);
 #endif
-        rule.format  = keywordFormat;
+        rule.format = keywordFormat;
         highlightingRules.append(rule);
     }
 
@@ -68,14 +64,14 @@ MvQHighlighter::MvQHighlighter(QTextDocument* parent) :
     foreach (QString pattern, dataKeyPatterns) {
         //rule.pattern = QRegExp(pattern,Qt::CaseInsensitive);
         //QString s=pattern + "(?==)";
-        QString s    = pattern;
+        QString s = pattern;
 #if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
         rule.pattern = QRegularExpression(s);
         rule.pattern.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
 #else
         rule.pattern = QRegExp(s, Qt::CaseInsensitive);
 #endif
-        rule.format  = dataKeyFormat;
+        rule.format = dataKeyFormat;
         highlightingRules.append(rule);
     }
 
@@ -104,10 +100,10 @@ void MvQHighlighter::highlightBlock(const QString& text)
         QRegularExpressionMatch rmatch;
         int index = text.indexOf(expression, 0, &rmatch);
         while (index >= 0) {
-             int length = rmatch.capturedLength();
-             setFormat(index, length, rule.format);
-             index = text.indexOf(expression, index + length, &rmatch);
-         }
+            int length = rmatch.capturedLength();
+            setFormat(index, length, rule.format);
+            index = text.indexOf(expression, index + length, &rmatch);
+        }
 #else
         QRegExp expression(rule.pattern);
         int index = text.indexOf(expression);
