@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQHighlighter_H
-#define MvQHighlighter_H
+#pragma once
 
 #include <QtGlobal>
 #include <QSyntaxHighlighter>
@@ -43,6 +42,3 @@ private:
 
     QVector<HighlightingRule> highlightingRules;
 };
-
-
-#endif
