@@ -7,8 +7,9 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef GeopExaminer_H
-#define GeopExaminer_H
+#pragma once
+
+#include <string>
 
 #include <QMainWindow>
 #include <QModelIndex>
@@ -27,7 +28,6 @@ class MvQTreeView;
 class MvQTreeViewSearchLine;
 class MvQLogPanel;
 
-using namespace std;
 
 class GeopExaminer : public MvQMainWindow
 {
@@ -36,7 +36,7 @@ class GeopExaminer : public MvQMainWindow
 public:
     GeopExaminer(QWidget* parent = 0);
     ~GeopExaminer();
-    bool initMetaData(const string&);
+    bool initMetaData(const std::string&);
     void updateFileInfoLabel();
 
 public slots:
@@ -71,5 +71,3 @@ private:
     MvQArrowSpinWidget* dataRowSpin_;
     QWidget* dataPanel_;
 };
-
-#endif
