@@ -16,7 +16,7 @@
 MvQGeoPointsDataModel::MvQGeoPointsDataModel(QObject* parent) :
     QAbstractItemModel(parent)
 {
-    data_ = 0;
+    data_ = nullptr;
 }
 
 void MvQGeoPointsDataModel::dataIsAboutToChange()
@@ -34,7 +34,7 @@ void MvQGeoPointsDataModel::setBaseData(MvGeoPoints* data)
 
 int MvQGeoPointsDataModel::columnCount(const QModelIndex&) const
 {
-    if (data_ != 0)
+    if (data_ != nullptr)
         return data_->totalcols() + 1;
 
     return 0;
@@ -47,7 +47,7 @@ int MvQGeoPointsDataModel::rowCount(const QModelIndex& parent) const
         return 0;
 
     //Root
-    if (data_ != 0)
+    if (data_ != nullptr)
         return data_->count();
 
     return 0;
@@ -104,10 +104,10 @@ QVariant MvQGeoPointsDataModel::headerData(const int section, const Qt::Orientat
 
 QModelIndex MvQGeoPointsDataModel::index(int row, int column, const QModelIndex&) const
 {
-    if (data_ == 0 || data_->count() <= 0 || column < 0)
+    if (data_ == nullptr || data_->count() <= 0 || column < 0)
         return QModelIndex();
 
-    return createIndex(row, column, (void*)0);
+    return createIndex(row, column, (void*)nullptr);
 }
 
 
