@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQGeoPointsModel_H
-#define MvQGeoPointsModel_H
+#pragma once
 
 #include <QAbstractItemModel>
 
@@ -34,5 +33,3 @@ public:
 private:
     MvGeoPoints* data_;
 };
-
-#endif
