@@ -22,13 +22,6 @@
 //
 //=====================================
 
-
-MvQGribMvDumpModel::MvQGribMvDumpModel(QObject* parent) :
-    QAbstractItemModel(parent)
-{
-    data_ = 0;
-}
-
 MvQGribMvDumpModel::~MvQGribMvDumpModel()
 {
     if (data_)
@@ -40,7 +33,7 @@ void MvQGribMvDumpModel::clear()
     if (data_) {
         beginResetModel();
         delete data_;
-        data_ = 0;
+        data_ = nullptr;
         endResetModel();
     }
 }
@@ -81,7 +74,7 @@ void MvQGribMvDumpModel::setFilter(QString txt)
 
 int MvQGribMvDumpModel::columnCount(const QModelIndex& /* parent */) const
 {
-    return 3;
+    return 4;
 }
 
 int MvQGribMvDumpModel::rowCount(const QModelIndex& parent) const
@@ -93,12 +86,9 @@ int MvQGribMvDumpModel::rowCount(const QModelIndex& parent) const
     if (!parent.isValid()) {
         return data_->itemNum();
     }
-    else {
-        return 0;
-    }
+    return 0;
 }
 
-
 QVariant MvQGribMvDumpModel::data(const QModelIndex& index, int role) const
 {
     if (!index.isValid() ||
@@ -111,7 +101,7 @@ QVariant MvQGribMvDumpModel::data(const QModelIndex& index, int role) const
             return QVariant();
 
         GribItem* item = data_->item().at(index.row());
-        QString name = QString::fromStdString(item->name());
+        QString name   = QString::fromStdString(item->name());
         if (gribNameSpace_ == "Default") {
             if (!filter_.isEmpty() && !name.contains(filter_, Qt::CaseInsensitive))
                 return QString::number(0);
@@ -146,24 +136,28 @@ QVariant MvQGribMvDumpModel::headerData(const int section, const Qt::Orientation
 
     if (role == Qt::DisplayRole) {
         switch (section) {
-            case 0:
+            case KeyColum:
                 return "Key";
-            case 1:
+            case TypeColumn:
                 return "Type";
-            case 2:
-                return "Value";
+            case ValueColumn:
+                return "Native value";
+            case StrValueColumn:
+                return "String value";
             default:
                 return QVariant();
         }
     }
     else if (role == Qt::ToolTipRole) {
         switch (section) {
-            case 0:
+            case KeyColum:
                 return "ecCodes key";
-            case 1:
+            case TypeColumn:
                 return "Key type";
-            case 2:
-                return "Key value";
+            case ValueColumn:
+                return "Native value";
+            case StrValueColumn:
+                return "Value accessed as string";
             default:
                 return QVariant();
         }
@@ -176,27 +170,34 @@ QVariant MvQGribMvDumpModel::headerData(const int section, const Qt::Orientation
 QString MvQGribMvDumpModel::label(GribItem* item, const int column) const
 {
     switch (column) {
-        case 0: {
-            return QString(item->name().c_str());
+        case KeyColum: {
+            return QString::fromStdString(item->name());
         }
-        case 1: {
-            return QString(item->type().c_str());
+        case TypeColumn: {
+            return QString::fromStdString(item->type());
         }
-        case 2: {
-            return QString(item->value().c_str());
+        case ValueColumn: {
+            auto v = item->value();
+            if (v.type() == MvVariant::LongType) {
+                return QString::number(v.toLong());
+            } else if (v.type() == MvVariant::DoubleType) {
+                return QString::number(v.toDouble());
+            }
+            return QString::fromStdString(v.toString());
+        }
+        case StrValueColumn: {
+            return QString::fromStdString(item->strValue());
         }
         default:
             return QString();
     }
 }
 
-
 QModelIndex MvQGribMvDumpModel::index(int row, int column, const QModelIndex& /*parent*/) const
 {
     return createIndex(row, column, (void*)0);
 }
 
-
 QModelIndex MvQGribMvDumpModel::parent(const QModelIndex& /*index*/) const
 {
     return QModelIndex();
@@ -219,14 +220,13 @@ Qt::DropActions MvQGribMvDumpModel::supportedDropActions() const
 
 QStringList MvQGribMvDumpModel::mimeTypes() const
 {
-    QStringList types;
-    types << "metview/mvkey";
+    QStringList types = {"metview/mvkey"};
     return types;
 }
 
 QMimeData* MvQGribMvDumpModel::mimeData(const QModelIndexList& indexes) const
 {
-    MvQKeyMimeData* mimeData = new MvQKeyMimeData(this);
+    auto* mimeData = new MvQKeyMimeData(this);
 
     QList<int> procRows;
 
@@ -234,7 +234,7 @@ QMimeData* MvQGribMvDumpModel::mimeData(const QModelIndexList& indexes) const
         if (index.isValid() &&
             procRows.indexOf(index.row()) == -1) {
             GribItem* item = data_->item().at(index.row());
-            MvKey* key     = new MvKey(item->name(), item->name());
+            auto* key      = new MvKey(item->name(), item->name());
             mimeData->addKey(key, index.row());
             procRows << index.row();
         }
@@ -255,11 +255,10 @@ bool MvQGribMvDumpModel::dropMimeData(const QMimeData* /*data*/,
 //
 //=====================================
 
-
-MvQGribWmoDumpModel::MvQGribWmoDumpModel(QObject* parent) :
-    QAbstractItemModel(parent),
-    data_(0)
+MvQGribWmoDumpModel::~MvQGribWmoDumpModel()
 {
+    if (data_)
+        delete data_;
 }
 
 void MvQGribWmoDumpModel::clear()
@@ -267,7 +266,7 @@ void MvQGribWmoDumpModel::clear()
     if (data_) {
         beginResetModel();
         delete data_;
-        data_ = 0;
+        data_ = nullptr;
         endResetModel();
     }
 }
@@ -365,11 +364,11 @@ QVariant MvQGribWmoDumpModel::headerData(const int section, const Qt::Orientatio
 
     if (role == Qt::DisplayRole) {
         switch (section) {
-            case 0:
+            case PositionColum:
                 return "Position";
-            case 1:
+            case KeyColumn:
                 return "Key";
-            case 2:
+            case ValueColumn:
                 return "Value";
             default:
                 return QVariant();
@@ -377,11 +376,11 @@ QVariant MvQGribWmoDumpModel::headerData(const int section, const Qt::Orientatio
     }
     else if (role == Qt::ToolTipRole) {
         switch (section) {
-            case 0:
+            case PositionColum:
                 return "Position within section";
-            case 1:
+            case KeyColumn:
                 return "ecCodes key";
-            case 2:
+            case ValueColumn:
                 return "Key value";
             default:
                 return QVariant();
@@ -394,26 +393,26 @@ QVariant MvQGribWmoDumpModel::headerData(const int section, const Qt::Orientatio
 
 QString MvQGribWmoDumpModel::label(GribSection* section, const int column) const
 {
-    switch (column) {
-        case 0: {
-            return QString(section->name().c_str());
-        }
-        default:
-            return QString();
-    }
+    return column == PositionColum ? QString(section->name().c_str()) : QString();
 }
 
 QString MvQGribWmoDumpModel::label(GribItem* item, const int column) const
 {
     switch (column) {
-        case 0: {
+        case PositionColum: {
             return QString(item->pos().c_str());
         }
-        case 1: {
+        case KeyColumn: {
             return QString(item->name().c_str());
         }
-        case 2: {
-            return QString(item->value().c_str());
+        case ValueColumn: {
+            auto v = item->value();
+            if (v.type() == MvVariant::LongType) {
+                return QString::number(v.toLong());
+            } else if (v.type() == MvVariant::DoubleType) {
+                return QString::number(v.toDouble());
+            }
+            return QString::fromStdString(v.toString());
         }
         default:
             return QString();
@@ -422,13 +421,7 @@ QString MvQGribWmoDumpModel::label(GribItem* item, const int column) const
 
 QString MvQGribWmoDumpModel::label(QString value, const int column) const
 {
-    switch (column) {
-        case 2: {
-            return value;
-        }
-        default:
-            return QString();
-    }
+    return column == ValueColumn ? value : QString();
 }
 
 QModelIndex MvQGribWmoDumpModel::index(int row, int column, const QModelIndex& parent) const
@@ -539,14 +532,13 @@ Qt::DropActions MvQGribWmoDumpModel::supportedDropActions() const
 
 QStringList MvQGribWmoDumpModel::mimeTypes() const
 {
-    QStringList types;
-    types << "metview/mvkey";
+    QStringList types = {"metview/mvkey"};
     return types;
 }
 
 QMimeData* MvQGribWmoDumpModel::mimeData(const QModelIndexList& indexes) const
 {
-    MvQKeyMimeData* mimeData = new MvQKeyMimeData(this);
+    auto* mimeData = new MvQKeyMimeData(this);
 
     QList<int> procRows;
 
@@ -557,8 +549,8 @@ QMimeData* MvQGribWmoDumpModel::mimeData(const QModelIndexList& indexes) const
             //Index to the second column!!!
             QModelIndex col = createIndex(index.row(), 1, id);
 
-            string keyName = data(col).toString().toStdString();
-            MvKey* key     = new MvKey(keyName, keyName);
+            std::string keyName = data(col).toString().toStdString();
+            auto* key           = new MvKey(keyName, keyName);
             mimeData->addKey(key, index.row());
             procRows << index.row();
         }
@@ -579,11 +571,6 @@ bool MvQGribWmoDumpModel::dropMimeData(const QMimeData* /*data*/,
 //
 //=====================================
 
-MvQGribStdDumpModel::MvQGribStdDumpModel(QObject* parent) :
-    QAbstractItemModel(parent)
-{
-    data_ = 0;
-}
 
 MvQGribStdDumpModel::~MvQGribStdDumpModel()
 {
@@ -596,7 +583,7 @@ void MvQGribStdDumpModel::clear()
     if (data_) {
         beginResetModel();
         delete data_;
-        data_ = 0;
+        data_ = nullptr;
         endResetModel();
     }
 }
@@ -655,9 +642,9 @@ QVariant MvQGribStdDumpModel::data(const QModelIndex& index, int role) const
         return label(item, index.column());
     }
     else if (idToLevel(id) == 1) {
-        int parentRow  = idToParentRow(id);
-        GribItem* item = data_->item().at(parentRow);
-        string value   = item->arrayData().at(index.row());
+        int parentRow     = idToParentRow(id);
+        GribItem* item    = data_->item().at(parentRow);
+        std::string value = item->arrayData().at(index.row());
         return label(value, index.column());
     }
 
@@ -672,11 +659,11 @@ QVariant MvQGribStdDumpModel::headerData(const int section, const Qt::Orientatio
 
     if (role == Qt::DisplayRole) {
         switch (section) {
-            case 0:
+            case KeyColum:
                 return "Key";
-            case 1:
+            case ValueColumn:
                 return "Value";
-            case 2:
+            case DescColumn:
                 return "Description";
             default:
                 return QVariant();
@@ -684,11 +671,11 @@ QVariant MvQGribStdDumpModel::headerData(const int section, const Qt::Orientatio
     }
     else if (role == Qt::ToolTipRole) {
         switch (section) {
-            case 0:
+            case KeyColum:
                 return "ecCodes Key";
-            case 1:
+            case ValueColumn:
                 return "Key value";
-            case 2:
+            case DescColumn:
                 return "Key description";
             default:
                 return QVariant();
@@ -701,13 +688,19 @@ QVariant MvQGribStdDumpModel::headerData(const int section, const Qt::Orientatio
 QString MvQGribStdDumpModel::label(GribItem* item, const int column) const
 {
     switch (column) {
-        case 0: {
+        case KeyColum: {
             return QString(item->name().c_str());
         }
-        case 1: {
-            return QString(item->value().c_str());
+        case ValueColumn: {
+            auto v = item->value();
+            if (v.type() == MvVariant::LongType) {
+                return QString::number(v.toLong());
+            } else if (v.type() == MvVariant::DoubleType) {
+                return QString::number(v.toDouble());
+            }
+            return QString::fromStdString(v.toString());
         }
-        case 2: {
+        case DescColumn: {
             return QString(item->description().c_str());
         }
 
@@ -716,16 +709,9 @@ QString MvQGribStdDumpModel::label(GribItem* item, const int column) const
     }
 }
 
-QString MvQGribStdDumpModel::label(string value, const int column) const
+QString MvQGribStdDumpModel::label(std::string value, const int column) const
 {
-    switch (column) {
-        case 0: {
-            return QString(value.c_str());
-        }
-
-        default:
-            return QString();
-    }
+    return column == KeyColum ? QString(value.c_str()) : QString();
 }
 
 QModelIndex MvQGribStdDumpModel::index(int row, int column, const QModelIndex& parent) const
@@ -804,7 +790,7 @@ QStringList MvQGribStdDumpModel::mimeTypes() const
 
 QMimeData* MvQGribStdDumpModel::mimeData(const QModelIndexList& indexes) const
 {
-    MvQKeyMimeData* mimeData = new MvQKeyMimeData(this);
+    auto* mimeData = new MvQKeyMimeData(this);
 
     QList<int> procRows;
 
@@ -812,8 +798,8 @@ QMimeData* MvQGribStdDumpModel::mimeData(const QModelIndexList& indexes) const
         int id = index.internalId();
         if (index.isValid() && idToLevel(id) == 0 &&
             procRows.indexOf(index.row()) == -1) {
-            string keyName = data(index).toString().toStdString();
-            MvKey* key     = new MvKey(keyName, keyName);
+            std::string keyName = data(index).toString().toStdString();
+            auto* key           = new MvKey(keyName, keyName);
             mimeData->addKey(key, index.row());
             procRows << index.row();
         }
@@ -835,13 +821,6 @@ bool MvQGribStdDumpModel::dropMimeData(const QMimeData* /*data*/,
 //
 //=====================================
 
-MvQGribValueDumpModel::MvQGribValueDumpModel(QObject* parent) :
-    QAbstractItemModel(parent),
-    data_(0),
-    minValAsDecimal_(0.001)
-{
-}
-
 MvQGribValueDumpModel::~MvQGribValueDumpModel()
 {
     if (data_)
@@ -853,7 +832,7 @@ void MvQGribValueDumpModel::clear()
     if (data_) {
         beginResetModel();
         delete data_;
-        data_ = 0;
+        data_ = nullptr;
         endResetModel();
     }
 }
