@@ -41,13 +41,13 @@ public:
     void setGribNameSpace(QString);
     void setFilter(QString);
 
-    Qt::ItemFlags flags(const QModelIndex&) const;
-    Qt::DropActions supportedDropActions() const;
-    QStringList mimeTypes() const;
-    QMimeData* mimeData(const QModelIndexList&) const;
+    Qt::ItemFlags flags(const QModelIndex&) const override;
+    Qt::DropActions supportedDropActions() const override;
+    QStringList mimeTypes() const override;
+    QMimeData* mimeData(const QModelIndexList&) const override;
     bool dropMimeData(const QMimeData* data,
                       Qt::DropAction action, int row, int column,
-                      const QModelIndex& parent);
+                      const QModelIndex& parent) override;
 
 private:
     enum Column {KeyColum=0, TypeColumn=1, ValueColumn=2, StrValueColumn=3};
@@ -77,13 +77,13 @@ public:
     bool hasData() const { return data_ != nullptr; }
     void clear();
 
-    Qt::ItemFlags flags(const QModelIndex&) const;
-    Qt::DropActions supportedDropActions() const;
-    QStringList mimeTypes() const;
-    QMimeData* mimeData(const QModelIndexList&) const;
+    Qt::ItemFlags flags(const QModelIndex&) const override;
+    Qt::DropActions supportedDropActions() const override;
+    QStringList mimeTypes() const override;
+    QMimeData* mimeData(const QModelIndexList&) const override;
     bool dropMimeData(const QMimeData* data,
                       Qt::DropAction action, int row, int column,
-                      const QModelIndex& parent);
+                      const QModelIndex& parent) override;
 
 private:
     QString label(GribSection*, const int) const;
@@ -117,13 +117,13 @@ public:
     bool hasData() const { return data_ != nullptr; }
     void clear();
 
-    Qt::ItemFlags flags(const QModelIndex&) const;
-    Qt::DropActions supportedDropActions() const;
-    QStringList mimeTypes() const;
-    QMimeData* mimeData(const QModelIndexList&) const;
+    Qt::ItemFlags flags(const QModelIndex&) const override;
+    Qt::DropActions supportedDropActions() const override;
+    QStringList mimeTypes() const override;
+    QMimeData* mimeData(const QModelIndexList&) const override;
     bool dropMimeData(const QMimeData* data,
                       Qt::DropAction action, int row, int column,
-                      const QModelIndex& parent);
+                      const QModelIndex& parent) override;
 
 private:
     QString label(GribItem*, const int) const;
