@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef HOVAREA_H
-#define HOVAREA_H
+#pragma once
 
 #include "Hovmoeller.h"
 #include "HovToolkit.h"
@@ -17,10 +16,10 @@ class HovAreaToolkit : public HovToolkit
 {
 public:
     HovAreaToolkit();
-    ~HovAreaToolkit(){};
+    ~HovAreaToolkit() = default;
 
     // Common functions
-    string GetTitle(ParamInfo*);
+    std::string GetTitle(ParamInfo*);
     const char* GetSecondCoordName();
     bool SecondAuxiliaryCoord() { return false; }
     const char* ApplicationType() { return "AREA_HOVM"; }
@@ -53,11 +52,11 @@ class AreaHovmoeller : public HovAreaToolkit, public Hovmoeller
 {
 public:
     AreaHovmoeller() :
-        Hovmoeller("AREA_HOVM"){};
+        Hovmoeller("AREA_HOVM") {}
     AreaHovmoeller(const char* kw) :
-        Hovmoeller(kw){};
+        Hovmoeller(kw) {}
 
-    ~AreaHovmoeller(){};
+    ~AreaHovmoeller() = default;
 
     // Entry point
     void serve(MvRequest& in, MvRequest& out);
@@ -71,11 +70,9 @@ class AreaHovmoellerM3 : public AreaHovmoeller
 {
 public:
     AreaHovmoellerM3() :
-        AreaHovmoeller("AREA_HOV"){};
-    ~AreaHovmoellerM3(){};
+        AreaHovmoeller("AREA_HOV") {}
+    ~AreaHovmoellerM3() = default;
 
     // Entry point
     void serve(MvRequest&, MvRequest&);
 };
-
-#endif
