@@ -78,6 +78,10 @@ public:
     void setExtrapolateMode(ExtrapolateMode m) {extrapolateMode_ = m;}
     bool extrapolateFixedSign() const {return extrapolateFixedSign_;}
     void setExtrapolateFixedSign(bool b) {extrapolateFixedSign_=b;}
+    void setUseFixedLnsp(bool b) {useFixedLnsp_=b;}
+    bool useFixedLnsp() const {return useFixedLnsp_;}
+    void setFixedLnsp(float v) {fixedLnsp_ = v;}
+    float fixedLnsp() const {return fixedLnsp_;}
 
 protected:
     int indexOfLevel(int level) const;
@@ -90,6 +94,8 @@ protected:
     bool extrapolateFixedSign_{true};
     std::vector<long> levels_;
     mutable std::map<std::string, VerticalDataItem> steps_;
+    bool useFixedLnsp_{false};
+    float fixedLnsp_{1013.25};
 };
 
 
@@ -175,7 +181,6 @@ double VerticalDataItem::extrapolateBottom(double targetYCoord, LevelInterpolato
 double VerticalDataItem::extrapolate(double targetYCoord, int level1, int level2, LevelInterpolator* inter) const
 {
      assert(yCoord_.size() == val_.size());
-     int level = 0;
      if (yCoord_.size() >= 2) {
          if (inter->extrapolateMode()  == LevelInterpolator::ConstantExtrapolation) {
              return MISSING_VALUE(val_[level1])?HMISSING_VALUE:val_[level1];
@@ -211,8 +216,11 @@ VerticalDataItem* LevelInterpolator::getStep(const std::string& key, bool addIfM
     auto it = steps_.find(key);
     if (it == steps_.end()) {
         if (addIfMissing) {
-            steps_[key] = VerticalDataItem(levelNum());
+            steps_[key] = VerticalDataItem(levelNum());           
             it = steps_.find(key);
+            if (useFixedLnsp_) {
+                steps_[key].lnsp_ = fixedLnsp_;
+            }
         } else {
             return nullptr;
         }
@@ -438,9 +446,9 @@ void HovHeightToolkit::collectVerticalData(MvField& field, const std::string& ti
         }
 
         if (inputLevelType_ == "ml" && outputLevelType_ == "pl") {
-            if(levHandler_->isEmpty()) {
+            if(!levHandler_->useFixedLnsp() && levHandler_->isEmpty()) {
                 throw MvException(moduleLabel_ +
-                          "No lnsp data was found! Cannot interpolate input model level data for pressure levels!");
+                    "No lnsp data was found! Cannot interpolate input model level data for pressure levels!");
             }
         } else if(vertAxisType_ != ParamLevelType && inputLevelType_ != outputLevelType_) {
             throw MvException(moduleLabel_ + "Input (=" + inputLevelType_ +
@@ -451,22 +459,24 @@ void HovHeightToolkit::collectVerticalData(MvField& field, const std::string& ti
 
     // Conversion from model level to pressure level is needed
     if (inputLevelType_ == "ml" && outputLevelType_ == "pl") {
-        assert(!levHandler_->isEmpty());
         int ml = static_cast<int>(ilevel);
-//        if (ml <= 0 || ml > mlevInter_->levelNum()) {
-//            throw MvException(moduleLabel_ + "Invalid model level (= " + std::to_string(ml) +
-//                              ") in input data! Expected range=[1," + std::to_string(mlevInter_->levelNum()) + "]");
-//        }
-        if (levHandler_->hasKey(timeKey)) {
-            auto lnsp = levHandler_->lnsp(timeKey);
-            if (!MISSING_VALUE(lnsp)) {
-                // compute pressue in hPa
-                auto p = field.meanML_to_Pressure_byLNSP(lnsp, ml) / 100.;
-                levHandler_->setVCoord(timeKey, ml-1, p);
-                levHandler_->setValue(timeKey, ml-1, computeValue(field));
-            }
+        if(levHandler_->useFixedLnsp()) {
+            auto p = field.meanML_to_Pressure_byLNSP(levHandler_->fixedLnsp(), ml) / 100.;
+            levHandler_->setVCoord(timeKey, ml-1, p);
+            levHandler_->setValue(timeKey, ml-1, computeValue(field));
         } else {
-            throw MvException(moduleLabel_ + "Invalid date/time in input data!");
+            assert(!levHandler_->isEmpty());
+            if (levHandler_->hasKey(timeKey)) {
+                auto lnsp = levHandler_->lnsp(timeKey);
+                if (!MISSING_VALUE(lnsp)) {
+                    // compute pressue in hPa
+                    auto p = field.meanML_to_Pressure_byLNSP(lnsp, ml) / 100.;
+                    levHandler_->setVCoord(timeKey, ml-1, p);
+                    levHandler_->setValue(timeKey, ml-1, computeValue(field));
+                }
+            } else {
+                throw MvException(moduleLabel_ + "Invalid date/time in input data!");
+            }
         }
     } else if (vertAxisType_ == ParamLevelType) {
 //        assert(!mlevInter_->isEmpty());
@@ -498,6 +508,10 @@ bool HovHeightToolkit::collectLnsp(MvRequest& data)
     // model level input with pressure vertical axis
     if (vertAxisType_ == PressureLevelType) {
 
+        if (levHandler_->useFixedLnsp()) {
+            return true;
+        }
+
         // Initialize fieldset
         MvFieldSet fs(data);
         MvFieldSetIterator iter(fs);
@@ -776,6 +790,19 @@ bool HovHeightToolkit::GetInputInfo(MvRequest& in)
 
     lnspParamId_ = (int)in("LNSP_PARAM");
 
+    if (const char* ch = in("USE_FIXED_SURFACE_PRESSURE")) {
+        levHandler_->setUseFixedLnsp((strcmp(ch, "ON") == 0));
+        if (levHandler_->useFixedLnsp()) {
+             if ((const char*)in("FIXED_SURFACE_PRESSURE")) {
+                 auto sp = (double)in("FIXED_SURFACE_PRESSURE");
+                 if (sp <= 1E-5) {
+                     throw MvException(moduleLabel_ + "invalid FIXED_SURFACE_PRESSURE specified!");
+                 }
+                 levHandler_->setFixedLnsp(std::log(sp*100.));
+             }
+        }
+    }
+
     // Set axis orientation
     verticalAxis_ = HOV_GEO;
 
