@@ -9,6 +9,7 @@
 
 #include "HovLine.h"
 
+#include <cmath>
 #include <sstream>
 
 #include "MvException.h"
@@ -19,7 +20,7 @@ const char* HovLineToolkit::GetSecondCoordName()
     // are the same. In this case, it is latitude.
     // In the NetCDF Visualiser request, parameter NETCDF_X_VARIABLE
     // can not have all the same values (Magics restriction).
-    if ((x2_ - x1_) > 0.00001) {
+    if (std::fabs(x2_ - x1_) > 0.00001) {
         glConvention_ = "lonlat";
         return HOV_VARLON.c_str();
     }
@@ -35,7 +36,7 @@ const char* HovLineToolkit::GetSecondAuxiliaryCoordName()
     // are the same. In this case, it is longitude..
     // In the NetCDF Visualiser request, parameter NETCDF_X_VARIABLE
     // can not have all the same values (Magics restriction).
-    if ((x2_ - x1_) > 0.00001)
+    if (std::fabs(x2_ - x1_) > 0.00001)
         return HOV_VARLAT.c_str();
     else
         return HOV_VARLON.c_str();
@@ -86,17 +87,15 @@ std::string HovLineToolkit::GetTitle(ParamInfo* par)
 bool HovLineToolkit::EvaluateNPoints()
 {
     if (y1_ > 90. || y1_ < -90. || y2_ > 90. || y2_ < -90.)
-        throw MvException("Hovmoeller-> Invalid input geographical coordinates");
+        throw MvException(moduleLabel_ + "Invalid input latitude coordinates");
 
-    double dellat = ABS(y2_ - y1_);
-    double dellon = ABS(x2_ - x1_);
+    double dellat = std::fabs(y2_ - y1_);
+    double dellon = std::fabs(x2_ - x1_);
     int np        = int(sqrt(dellon * dellon + dellat * dellat) / MAX(gridNS_, gridEW_));
     if (np <= 0) {
-        std::ostringstream oss;
-        oss << "Hovmoeller-> Computed number of points along the hovmoeller line is invalid: "
-            << np
-            << " . Check the input data";
-        throw MvException(oss.str());
+        throw MvException(moduleLabel_ +
+                          "Computed number of points along the hovmoeller line is invalid: " +
+                          std::to_string(np) + ". Check the input data grid geometry.");
     }
 
     nrPoints_ = MAX(np, 64);  //64->arbitrary minimum number of points
@@ -112,25 +111,6 @@ bool HovLineToolkit::GetInputInfo(MvRequest& in)
     y2_ = in("LINE", 2);
     x2_ = in("LINE", 3);
 
-    // Make sure the coordinates follow Mars rules (n/w/s/e)
-    //   bool swap = false;
-    if (x1_ > x2_) {
-        double W = x1_;
-        x1_      = x2_;
-        x2_      = W;
-        //      swap = true;
-    }
-    if (y2_ > y1_) {
-        double W = y1_;
-        y1_      = y2_;
-        y2_      = W;
-        //      swap = true;
-    }
-
-    // Send a warning message
-    //   if ( swap )
-    //      marslog(LOG_WARN,"WARNING: Input geographical coordinates do not follow MARS rules (n/w/s/e). Values have been swapped.");
-
     // Get swap axes flag
     swapAxes_ = ((const char*)in("SWAP_AXES") && strcmp(in("SWAP_AXES"), "YES") == 0) ? true : false;
 
@@ -189,13 +169,14 @@ bool HovLineToolkit::NcWriteSecondCoord()
 bool HovLineToolkit::consistencyCheck(MvRequest& req1, MvRequest& req2)
 {
     // Check input TYPE
-    if ((const char*)req1("TYPE") != (const char*)req2.getVerb()) {
-        std::ostringstream oss;
-        oss << "Hovmoeller-> TYPE parameter is not consistent: "
-            << (const char*)req1("TYPE")
-            << " and "
-            << (const char*)req2.getVerb();
-        throw MvException(oss.str());
+    const char* cType1 = (const char*)req1("TYPE");
+    const char* verb2 =  (const char*)req2.getVerb();
+    if (strcmp(cType1, verb2) != 0) {
+        std::string msg = moduleLabel_ + "TYPE parameter is not consistent";
+        if (cType1 && verb2) {
+            msg += ": " +  std::string(cType1) + " != " + std::string(verb2);
+        }
+        throw MvException(msg);
     }
 
     // Check coordinates
@@ -203,26 +184,28 @@ bool HovLineToolkit::consistencyCheck(MvRequest& req1, MvRequest& req2)
         (double)req1("LINE", 1) != (double)req2("LINE", 1) ||
         (double)req1("LINE", 2) != (double)req2("LINE", 2) ||
         (double)req1("LINE", 3) != (double)req2("LINE", 3))
-        throw MvException("Hovmoeller-> LINE coordinates are not consistent");
+        throw MvException(moduleLabel_ +  "LINE coordinates are not consistent");
 
     // Check SWAP AXES
-    if ((const char*)req1("SWAP_AXES") != (const char*)req2("SWAP_AXES")) {
-        std::ostringstream oss;
-        oss << "Hovmoeller-> SWAP_AXES parameter is not consistent: "
-            << (const char*)req1("SWAP_AXES")
-            << " and "
-            << (const char*)req2("SWAP_AXES");
-        throw MvException(oss.str());
+    const char* swapA1 = (const char*)req1("SWAP_AXES");
+    const char* swapA2 =(const char*)req2("SWAP_AXES");
+    if (strcmp(swapA1, swapA2) != 0) {
+        std::string msg = moduleLabel_ + "SWAP_AXES parameter is not consistent";
+        if (swapA1 && swapA2) {
+            msg += ": " + std::string(swapA1) + " != " + std::string(swapA2);
+        }
+        throw MvException(msg);
     }
 
     // Check RESOLUTION
-    if ((const char*)req1("RESOLUTION") != (const char*)req2("RESOLUTION")) {
-        std::ostringstream oss;
-        oss << "Hovmoeller-> RESOLUTION parameter is not consistent: "
-            << (const char*)req1("RESOLUTION")
-            << " and "
-            << (const char*)req2("RESOLUTION");
-        throw MvException(oss.str());
+    const char*  res1 = (const char*)req1("RESOLUTION");
+    const char*  res2 = (const char*)req2("RESOLUTION");
+    if (strcmp(res1, res2) != 0) {
+        std::string msg = moduleLabel_ + "RESOLUTION parameter is not consistent";
+        if (res1 && res2) {
+            msg += ": " + std::string(res1) + " != " + std::string(res2);
+        }
+        throw MvException(msg);
     }
 
     return true;
