@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef HOVLINE_H
-#define HOVLINE_H
+#pragma once
 
 #include "Hovmoeller.h"
 #include "HovToolkit.h"
@@ -21,7 +20,7 @@ public:
     bool GetInputInfo(MvNetCDF*);   //from the netCDF file
 
     // Common functions
-    string GetTitle(ParamInfo*);
+    std::string GetTitle(ParamInfo*);
     const char* GetSecondCoordName();
     const char* GetSecondAuxiliaryCoordName();
     bool SecondAuxiliaryCoord() { return true; }
@@ -52,11 +51,11 @@ class LineHovmoeller : public HovLineToolkit, public Hovmoeller
 {
 public:
     LineHovmoeller() :
-        Hovmoeller("LINE_HOVM"){};
+        Hovmoeller("LINE_HOVM") {}
     LineHovmoeller(const char* kw) :
-        Hovmoeller(kw){};
+        Hovmoeller(kw) {}
 
-    ~LineHovmoeller(){};
+    ~LineHovmoeller() = default;
 
     // Entry point
     void serve(MvRequest&, MvRequest&);
@@ -70,12 +69,10 @@ class LineHovmoellerM3 : public LineHovmoeller
 {
 public:
     LineHovmoellerM3() :
-        LineHovmoeller("LINE_HOV"){};
+        LineHovmoeller("LINE_HOV") {}
 
-    ~LineHovmoellerM3(){};
+    ~LineHovmoellerM3() = default;
 
     // Entry point
     void serve(MvRequest&, MvRequest&);
 };
-
-#endif
