@@ -45,11 +45,11 @@ void HovToolkit::ReleaseMemory()
     coord2_.clear();
     if (xint_) {
         delete[] xint_;
-        xint_ = 0;
+        xint_ = nullptr;
     }
     if (netcdf_) {
         delete netcdf_;
-        netcdf_ = 0;
+        netcdf_ = nullptr;
     }
 
     ExpandCloseNcFile();
@@ -255,7 +255,7 @@ bool HovToolkit::GetInputParameters(MvRequest& in)
     // Retrieve fieldset
     in.getValue(dataRequest_, "DATA");
     if (!in.countValues("DATA"))
-        throw MvException("Hovmoeller-> No Data file specified");
+        throw MvException(moduleLabel_ + "No Data file specified");
 
     // Get and save action mode. Default value is "prepare"
     std::string actionMode = (const char*)in("_ACTION") ? (const char*)in("_ACTION") : "prepare";
@@ -326,7 +326,7 @@ bool HovToolkit::GetInputCommonInfo(MvNetCDF* netcdf)
     nrIndexesIn_    = edges[0];
     MvNcAtt* tmpatt = var->getAttribute("reference_date");
     if (!tmpatt)
-        throw MvException("Hovmoeller-> Netcdf file: REFERENCE_DATE attribute not found");
+        throw MvException(moduleLabel_ + "Netcdf file: REFERENCE_DATE attribute not found");
 
     MvDate d1(tmpatt->as_string(0).c_str());
     refTime_ = d1.YyyyMmDd_r();
@@ -336,14 +336,14 @@ bool HovToolkit::GetInputCommonInfo(MvNetCDF* netcdf)
     edges     = var->edges();
     nrPoints_ = edges[0];
     if (nrIndexesIn_ <= 0 || nrPoints_ <= 0)
-        throw MvException("Hovmoeller-> Netcdf file: invalid dimension for variables TIME and/or GEOGRAPHICAL");
+        throw MvException(moduleLabel_ + "Netcdf file: invalid dimension for variables TIME and/or GEOGRAPHICAL");
 
     // Retrieve attributes values
     // Retrieve Grid values
     MvRequest req  = netcdf->getRequest();
     const char* cp = (const char*)req("grid");
     if (cp == nullptr)
-        throw MvException("Hovmoeller-> Netcdf file: GRID attribute not found");
+        throw MvException(moduleLabel_ + "Netcdf file: GRID attribute not found");
 
     std::string str = cp;
     gridEW_         = atof(strtok((char*)str.c_str(), "/"));
@@ -352,7 +352,7 @@ bool HovToolkit::GetInputCommonInfo(MvNetCDF* netcdf)
     // Retrieve Coordinates values
     cp = (const char*)req("coordinates");
     if (cp == nullptr)
-        throw MvException("Hovmoeller-> Netcdf file: COORDINATES attribute not found");
+        throw MvException(moduleLabel_ + "Netcdf file: COORDINATES attribute not found");
 
     str = cp;
     y1_ = atof(strtok((char*)str.c_str(), "/"));
@@ -372,6 +372,10 @@ bool HovToolkit::CreateParamInfo(MvRequest& data)
     // Clean param info structure
     this->ReleaseMemoryParam();
 
+    // For ML to PL conversion the LNSP should be
+    // collected before the data is processed
+    bool skipLnsp = collectLnsp(data);
+
     // Initialize fieldset
     MvFieldSet fs(data);
     MvFieldSetIterator iter(fs);
@@ -391,10 +395,10 @@ bool HovToolkit::CreateParamInfo(MvRequest& data)
     //   iter.sort("DATE");
     iter.sort("EXPVER");
     iter.sort("PARAM");
+
     while ((field = iter())) {
         // MvFieldExpander	x(field);
         MvRequest rq = field.getRequest();
-
         iparam         = rq("PARAM");
         level          = rq("LEVELIST", 0);
         expver         = rq("EXPVER");
@@ -403,38 +407,42 @@ bool HovToolkit::CreateParamInfo(MvRequest& data)
         // Save basic information
         GenerateKey(keystr, rq);
         GenerateTimeKey(timekey, rq);
-        UpdateLevelList(field, level);
 
-        MvDate dd = GetDate(field);
-        double d1 = dd.YyyyMmDd_r();
+        // LNSP may be handled separately from the rest of the data
+        if (!(skipLnsp && isParamLnsp(iparam))) {
+            collectVerticalData(field, timekey, level);
+            if (!isParamVertCoord(iparam)) {
+                MvDate dd = GetDate(field);
+                double d1 = dd.YyyyMmDd_r();
 
-        // compute min/max time values
-        if (dateMinD_ > d1)
-            dateMinD_ = d1;
-        if (dateMaxD_ < d1)
-            dateMaxD_ = d1;
+                // compute min/max time values
+                if (dateMinD_ > d1)
+                    dateMinD_ = d1;
+                if (dateMaxD_ < d1)
+                    dateMaxD_ = d1;
 
-        auto* par = new ParamInfo(iparam, d1, level, ev,
-                                  field.getGribKeyValueString("shortName"),
-                                  field.getGribKeyValueString("name"),
-                                  field.getGribKeyValueString("units"));
+                //TODO: This seems to be a memory leak
+                auto* par = new ParamInfo(iparam, d1, level, ev,
+                                          field.getGribKeyValueString("shortName"),
+                                          field.getGribKeyValueString("name"),
+                                          field.getGribKeyValueString("units"));
 
-        ParamInsertPair inserted = params_.insert(ParamPair(keystr, par));
-        ParamInfo* pp            = (*(inserted.first)).second;
-        pp->AddIndex(timekey);
+                ParamInsertPair inserted = params_.insert(ParamPair(keystr, par));
+                ParamInfo* pp            = (*(inserted.first)).second;
+                pp->AddIndex(timekey);
+            }
+         }
     }
 
     // Check if basic information was retrieved
     if (params_.size() == 0)
-        throw MvException("Hovmoeller-> GRIB file invalid, no parameters found");
+        throw MvException(moduleLabel_ + "GRIB file invalid, no parameters found");
 
     // Maybe this restriction should be removed in the future
     if (params_.size() > 1) {
-        std::ostringstream oss;
-        oss << "Hovmoeller-> Creation of Hovmoeller diagrams from multiple parameters or vertical levels is not yet supported. This data has "
-            << params_.size()
-            << " parameters or levels";
-        throw MvException(oss.str());
+        throw MvException(moduleLabel_ + "Creation of Hovmoeller diagrams from multiple parameters or vertical levels is not yet supported. This data has "
+            + std::to_string(params_.size()) + " parameters or levels");
+
     }
 
     return true;
@@ -607,7 +615,7 @@ bool HovToolkit::GenerateData(MvRequest& data)
 
         // Write out data, if it can be grouped together
         if (lastKey != keystr && lastKey != std::string("FIRSTFIELD")) {
-            if (!NcWriteData(lastField, lastKey))
+            if (!NcWriteData(lastKey))
                 return false;
             lastNrGenerated = currentGenerated;
         }
@@ -618,7 +626,7 @@ bool HovToolkit::GenerateData(MvRequest& data)
 
     // Write out the data in the netcdf file
     if (lastNrGenerated <= currentGenerated) {
-        if (!NcWriteData(lastField, lastKey))
+        if (!NcWriteData(lastKey))
             return false;
     }
     netcdf_->close();
@@ -703,7 +711,7 @@ bool HovToolkit::NcWriteTimeInfo()
 
 // We have all the values for one set of data
 // Call functions to write the values to netcdf file
-bool HovToolkit::NcWriteData(MvField&, const std::string& key)
+bool HovToolkit::NcWriteData(const std::string& key)
 {
     // Get parameter info
     ParamInfo* par = this->GetParamInfo(key);
@@ -842,9 +850,7 @@ ParamInfo* HovToolkit::GetParamInfo(const std::string& key)
     // Check if field is valid
     auto ii = params_.find(key);
     if (ii == params_.end()) {
-        std::ostringstream oss;
-        oss << "Hovmoeller-> GetParamInfo: Could not find the requested field " << key;
-        throw MvException(oss.str());
+        throw MvException(moduleLabel_ + "GetParamInfo: Could not find the requested field " + key);
     }
 
     // Get parameter info
@@ -970,7 +976,7 @@ bool HovToolkit::ExpandGetTimeInfo()
 
     // Check input file
     if (!netcdfIn_)
-        throw MvException("Hovmoeller-> Input NetCDF file not accessible");
+        throw MvException(moduleLabel_ + "Input NetCDF file not accessible");
 
     // Copy 'time' values from the input file
     std::vector<double> vals;
@@ -1002,3 +1008,13 @@ MvRequest HovToolkit::buildMacroConverterRequest()
 
     return oreq;
 }
+
+bool HovToolkit::isParamLnsp(int paramId) const
+{
+    return paramId == lnspParamId_;
+}
+
+bool HovToolkit::isParamVertCoord(int paramId) const
+{
+    return paramId == vertCoordParamId_;
+}
