@@ -32,7 +32,7 @@ private:
     friend class ParamInfo;
 
     IndexesInfo(double index) :
-        values_(0),
+        values_(nullptr),
         index_(index) {}
 
     double* values_;
