@@ -7,6 +7,8 @@
 
  ***************************** LICENSE END *************************************/
 
+#include <iostream>
+
 #include "macro.h"
 
 class ShellFunction : public Function
@@ -16,7 +18,8 @@ public:
         Function(n)  //,1,tstring)
     {
         info = "Execute a shell command";
-    };
+    }
+
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -39,9 +42,9 @@ Value ShellFunction::Execute(int arity, Value* arg)
         return Error("Cannot execute shell command: %s", shell_cmd);
 
     while (fgets(buf, sizeof(buf), f))
-        cout << buf;
+        std::cout << buf;
 
-    cout << flush;
+    std::cout << std::flush;
 
     if ((ret_code = pclose(f)) != 0) {
         marslog(LOG_INFO, "Warning : Shell command '%s' returned %d",
@@ -59,7 +62,8 @@ public:
         Function(n, 1, tstring)
     {
         info = "Return the value of a shell variable";
-    };
+    }
+
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -86,7 +90,8 @@ public:
         Function(n, 2, tstring, tnumber)
     {
         info = "Return the value of a shell variable";
-    };
+    }
+
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -126,12 +131,12 @@ public:
 
 Value PutenvFunction::Execute(int, Value* arg)
 {
-    const char *p = NULL, *q = NULL;
+    const char *p = nullptr, *q = nullptr;
 
     arg[0].GetValue(p);
     arg[1].GetValue(q);
     if (!p && !q)
-        return Value((char*)NULL);
+        return Value((char*)nullptr);
 
     char* buf = new char[strlen(p) + strlen(q) + 2];  //memory leak!!!
     sprintf(buf, "%s=%s", p, q);
@@ -147,7 +152,8 @@ public:
         Function(n, 1, tnumber)
     {
         info = "Sleep (number of seconds)";
-    };
+    }
+
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -166,7 +172,8 @@ public:
         Function(n, 1, tnumber)
     {
         info = "Nice (nice value)";
-    };
+    }
+
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -182,7 +189,7 @@ class PauseFunction : public Function
 {
 public:
     PauseFunction(const char* n) :
-        Function(n, 0){};
+        Function(n, 0) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -199,7 +206,8 @@ public:
         Function(n, 0)
     {
         info = "Return a unique filename for a temporary file.";
-    };
+    }
+
     virtual Value Execute(int arity, Value* arg);
 };
 
