@@ -172,8 +172,8 @@ Value ObjectFunction::Execute(int arity, Value* a)
 
 void Context::AddExtern(const char* nam, const char* cmd)
 {
-    Context* c        = new Context(nam, 0);
-    ExternFunction* f = new ExternFunction(nam, c);
+    auto* c = new Context(nam, 0);
+    auto* f = new ExternFunction(nam, c);
     AddContext(c);
     AddFunction(f);
     f->SetCommand(cmd, 0);
@@ -183,8 +183,8 @@ extern "C" {
 
 void update_branch(void* a, void* b)
 {
-    OpGoto* g = (OpGoto*)a;
-    Step* s   = (OpGoto*)b;
+    auto* g = (OpGoto*)a;
+    auto* s = (OpGoto*)b;
     g->SetBranch(s);
     Context::Current->NewStep(0);
     if (mars.debug)
@@ -194,7 +194,7 @@ void update_branch(void* a, void* b)
 
 void new_context(const char* name, int handler, int user, int oo)
 {
-    Context* c = new Context(name, oo);
+    auto* c = new Context(name, oo);
     Function* f;
 
     if (oo)
@@ -249,7 +249,7 @@ void end_global(char* s)
 }
 void argument_count(int n)
 {
-    UserFunction* f = (UserFunction*)Context::Current->Macro;
+    auto* f = (UserFunction*)Context::Current->Macro;
     if (n == 0)
         f->SetTypes(0, 0);
     if (mars.debug)
@@ -258,7 +258,7 @@ void argument_count(int n)
 
 void extern_command(char* s, char* p)
 {
-    ExternFunction* f = (ExternFunction*)Context::Current->Macro;
+    auto* f = (ExternFunction*)Context::Current->Macro;
     f->SetCommand(s, p);
     if (mars.debug)
         printf("---- extern_command %s %s\n", s, p);
@@ -267,7 +267,7 @@ void extern_command(char* s, char* p)
 void argument_type(char* s)
 {
     extern int zzerror(const char*);
-    UserFunction* f = (UserFunction*)Context::Current->Macro;
+    auto* f = (UserFunction*)Context::Current->Macro;
 
     vtype t = Value::NameType(s);
     if (t == tnone)
@@ -288,7 +288,7 @@ void end_context(char* s)
 
 void* new_code(int opcode, char* carg, int iarg, int line)
 {
-    Step* s=nullptr;
+    Step* s = nullptr;
 
     switch (opcode) {
         case OP_NOP:
