@@ -117,7 +117,7 @@ void CDate::ToString(const char*& x)
 
 void CDate::Dump2()
 {
-    cout << "date(" << date._julian() << "," << date._second() << ")";
+    std::cout << "date(" << date._julian() << "," << date._second() << ")";
 }
 
 //============================================================================
@@ -130,10 +130,10 @@ int Date::Julian()
 
 static request* pref()
 {
-    static request* p = 0;
+    static request* p = nullptr;
     static MvRequest r;  // declare locally to avoid the destructor removing it
 
-    if (p == 0) {
+    if (p == nullptr) {
         r = MvApplication::getPreferences();
         p = r;
     }
@@ -173,7 +173,7 @@ void Date::Print(void)
 {
     char buf[1024];
     Format(StringFormat(), buf);
-    cout << buf;
+    std::cout << buf;
 }
 
 
@@ -461,6 +461,9 @@ void Date::Format(const char* f, char* buf)
                         break;
                 }
                 break;
+
+            default:
+                break;
         }
 
         if (n < 0)
@@ -624,7 +627,7 @@ public:
         Function(n)
     {
         info = "Creates a date from a number or a string";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -636,7 +639,7 @@ public:
         Function(n)
     {
         info = "Returns the current date and time";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -648,7 +651,7 @@ public:
         Function(n, 2, tdate, tnumber)
     {
         info = "Adds a number to a date";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -656,18 +659,18 @@ class DateSubFunction : public Function
 {
 public:
     DateSubFunction(const char* n) :
-        Function(n, 2, tdate, tnumber | tdate){};
+        Function(n, 2, tdate, tnumber | tdate) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
 class DateCmpFunction : public Function
 {
-    typedef int (*cproc)(Date*, Date*);
+    using cproc = int (*)(Date*, Date*);
     cproc F_;
 
 public:
     DateCmpFunction(const char* n, cproc c) :
-        Function(n, 2, tdate, tdate) { F_ = c; };
+        Function(n, 2, tdate, tdate) { F_ = c; }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -725,6 +728,9 @@ Value DateFunction::Execute(int arity, Value* arg)
                 date = yy * 10000 + mm * 100 + dd +
                        HH / 24.0 + MM / 24.0 / 60.0 + SS / 24.0 / 60.0 / 60.0;
                 break;
+
+            default:
+                break;
         }
 
         Date x(date);
@@ -738,7 +744,7 @@ Value DateFunction::Execute(int arity, Value* arg)
     }
 }
 
-int DateNowFunction::ValidArguments(int arity, Value* arg)
+int DateNowFunction::ValidArguments(int arity, Value* /*arg*/)
 {
     if (arity == 0)
         return 1;
@@ -845,7 +851,7 @@ public:
         Function(n, 2, tdate, tnumber)
     {
         info = "Adds months to a date";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
