@@ -17,6 +17,8 @@
 //-- I have not spotted such a method)...
 //--
 
+#include <cstring>
+
 #include "macro.h"
 #include "grib_api.h"
 #include "arith.h"
@@ -74,14 +76,14 @@ class Image
     FILE* file;  //-- store file descr between Map() and Unmap()
 
 public:
-    int Count(void) { return count; };
-    int Nx(void) { return nx; };
-    int Ny(void) { return ny; };
+    int Count(void) { return count; }
+    int Nx(void) { return nx; }
+    int Ny(void) { return ny; }
 
     void Map(void);
     void Unmap(void);
-    unsigned char& operator[](int n) { return data[n]; };
-    unsigned char& operator()(int i, int j) { return data[i + nx * j]; };
+    unsigned char& operator[](int n) { return data[n]; }
+    unsigned char& operator()(int i, int j) { return data[i + nx * j]; }
 
     const char* Path() { return path; }
     void ToRequest(request*&);
@@ -189,13 +191,13 @@ Image::Image(Image* i)
     i->Map();
 
     /*
-	memcpy(buffer,i->buffer,length);
+       std::memcpy(buffer,i->buffer,length);
 	*/
 
-    memcpy(buffer, i->buffer, offset);
-    memcpy(buffer + offset + count,
-           i->buffer + offset + count,
-           length - offset - count);
+    std::memcpy(buffer, i->buffer, offset);
+    std::memcpy(buffer + offset + count,
+                i->buffer + offset + count,
+                length - offset - count);
     Unmap();
     i->Unmap();
 
@@ -341,7 +343,7 @@ Value ImageConvol::Execute(int, Value* arg)
     for (n = 0; n < 9; n++)
         a[n] /= d;
 
-    Image* q = new Image(p);
+    auto* q = new Image(p);
 
     p->Map();
     q->Map();
@@ -423,7 +425,7 @@ Value ImageLut::Execute(int, Value* arg)
         a[n] = (unsigned char)d;
     }
 
-    Image* q = new Image(p);
+    auto* q = new Image(p);
 
     p->Map();
     q->Map();
@@ -463,7 +465,7 @@ public:
 
 class ImageMulOp : public Function
 {
-    typedef double (*binproc)(double, double);
+    using binproc = double (*)(double, double);
     binproc F_;
 
 public:
@@ -555,7 +557,7 @@ Value ImageUnOp::Execute(int, Value* arg)
     Image* p;
     arg[0].GetValue(p);
 
-    Image* q = new Image(p);
+    auto* q = new Image(p);
 
     p->Map();
     q->Map();
