@@ -6,8 +6,7 @@
  an Intergovernmental Organization or submit itself to any jurisdiction.
 
  ***************************** LICENSE END *************************************/
-#ifndef ARITH_H__
-#define ARITH_H__
+#pragma once
 
 
 typedef double (*uniproc)(double);
@@ -36,4 +35,16 @@ extern binop BinOps[];
 extern mulop MulOps[];
 extern uniop UniOps[];
 
-#endif
+
+inline bool is_number_nan_d(double d)
+{
+    // one way to detect a NaN is to compare it with itself - it will be false
+    return (d != d);
+}
+
+inline bool is_number_nan_f(float d)
+{
+    // one way to detect a NaN is to compare it with itself - it will be false
+    return (d != d);
+}
+
