@@ -7,10 +7,8 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef _H_MACRO_
-#define _H_MACRO_
+#pragma once
 
-#include <inc_iostream.h>
 #include <stdio.h>
 #include <mars.h>
 
@@ -25,8 +23,8 @@ class Step : public Node
 public:
     Context* Owner() { return (Context*)Node::Owner(); }
     Step* Next() { return (Step*)Node::Next(); }
-    virtual Step* Execute(void) { return Next(); };
-    virtual int Ready(void) { return 1; };
+    virtual Step* Execute(void) { return Next(); }
+    virtual int Ready(void) { return 1; }
 
     int ref;
     int line;
@@ -131,12 +129,12 @@ class Context : public Node
     {
         l.Append(n);
         n->SetOwner(this);
-    };  // append to end of list
+    }  // append to end of list
     void InsertNode(List& l, Node* n)
     {
         l.Insert(n);
         n->SetOwner(this);
-    };  // insert at head of list
+    }  // insert at head of list
 
     static List DictionaryStack;
     static List DictionaryCache;
@@ -200,15 +198,15 @@ public:
 
     Context* FindContext(const char* name);
     static const char* FallBackHandler(const char* name);
-    int HasHandler(const char* nam, int arity = 0, Value* arg = NULL)
+    int HasHandler(const char* nam, int arity = 0, Value* arg = nullptr)
     {
-        return FindHandler(nam, arity, arg) != NULL;
-    };
+        return FindHandler(nam, arity, arg) != nullptr;
+    }
 
-    int Argc(void) { return argc; };
-    Value* Argv(void) { return argv; };
+    int Argc(void) { return argc; }
+    Value* Argv(void) { return argv; }
 
-    List* Dictionaries(void) { return &DictionaryStack; };
+    List* Dictionaries(void) { return &DictionaryStack; }
     Function* Macro;  // If the context is a user function
 
     void PushDictionary(const char* name);
@@ -234,7 +232,7 @@ public:
     Context* Owner() { return (Context*)Node::Owner(); }
 
 
-    virtual Value Run(const char* handler = NULL, int argc = 0, Value* argv = NULL);
+    virtual Value Run(const char* handler = nullptr, int argc = 0, Value* argv = nullptr);
 
     void Store(const char*, Value, int);
     Value& Fetch(const char*);
@@ -266,7 +264,7 @@ public:
     void AddLocal(Variable* v) { AddNode(Locals, v); }
     void AddGlobal(Variable* v) { AddNode(Globals, v); }
 
-    virtual void NewStep(Step*){};
+    virtual void NewStep(Step*) {}
     void AddStep(Step* s)
     {
         AddNode(Steps, s);
@@ -278,8 +276,8 @@ public:
 
     Value NextParameter(void);
 
-    Function* FirstFunction(void) { return (Function*)Functions.Head(); };
-    virtual Step* FirstStep(void) { return (Step*)Steps.Head(); };
+    Function* FirstFunction(void) { return (Function*)Functions.Head(); }
+    virtual Step* FirstStep(void) { return (Step*)Steps.Head(); }
 
     //===============================================================
     void* operator new(size_t s) { return fast_new(s, permanent_mem); }
@@ -307,7 +305,7 @@ class Linkage
         proc(c);
         if (next)
             next->Run(c);
-    };
+    }
 
 public:
     Linkage(cproc p)
@@ -315,8 +313,8 @@ public:
         proc  = p;
         next  = Links;
         Links = this;
-    };
-    Linkage* Next(void) { return next; };
+    }
+    Linkage* Next(void) { return next; }
 
     static void Install(Context* c) { Links->Run(c); }
 };
@@ -336,5 +334,3 @@ public:
     static void SetPlotter(const char* p);
     static void Init();
 };
-
-#endif
