@@ -7,14 +7,12 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef VALUE_H__
-#define VALUE_H__
+#pragma once
 
-//#pragma once
-
-#include <inc_iostream.h>
-#include <vector>
+#include <iostream>
 #include <map>
+#include <string>
+#include <vector>
 
 #include "date.h"
 #include "arith.h"
@@ -29,8 +27,6 @@ typedef int _vtype;
 
 class Value;
 
-using std::string;
-
 //=============================================================================
 
 class Notify
@@ -68,7 +64,7 @@ public:
             suicide();
     }
     void SetNotify(Notify* n) { notify = n; }
-    virtual ~Reference(){};
+    virtual ~Reference() = default;
 
     //============================================================================
     void* operator new(size_t s) { return fast_new(s, transient_mem); }
@@ -115,7 +111,7 @@ public:
     static int Error(const char* fmt, ...);
     static void Perl(request*);
 
-    virtual void Sync(Value*){};
+    virtual void Sync(Value*) {}
 
     Content(vtype t) :
         type(t) {}
@@ -127,118 +123,118 @@ public:
         if (n)
             *n = TypeName();
         return type;
-    };
-    //	virtual void Print(void)       { cout << form("<%s>",TypeName());};
-    virtual void Print(void) { cout << TypeName(); }
+    }
+    //	virtual void Print(void)       { std::cout << form("<%s>",TypeName());};
+    virtual void Print(void) { std::cout << TypeName(); }
     virtual Content* Clone(void)
     {
         Fail("Clone");
         return this;
-    };
+    }
 
     virtual void ToNumber(double& x)
     {
         Fail("double");
         x = 0;
-    };
+    }
     virtual void ToDate(Date& x)
     {
         Fail("date");
         x = 0.0;
-    };
+    }
     virtual void ToString(const char*& x)
     {
         Fail("string");
         x = 0;
-    };
+    }
     virtual void ToRequest(request*& x)
     {
         Fail("request");
         x = 0;
-    };
+    }
     virtual void ToFieldset(fieldset*& x)
     {
         Fail("fieldset");
         x = 0;
-    };
+    }
     virtual void ToList(CList*& x)
     {
         Fail("list");
         x = 0;
-    };
+    }
     virtual void ToGrib(CGrib*& x)
     {
         Fail("grib");
         x = 0;
-    };
+    }
     virtual void ToBufr(CBufr*& x)
     {
         Fail("bufr");
         x = 0;
-    };
+    }
     virtual void ToGeopts(CGeopts*& x)
     {
         Fail("geopoints");
         x = 0;
-    };
+    }
     virtual void ToGeoptSet(CGeoptSet*& x)
     {
         Fail("geopointset");
         x = 0;
-    };
+    }
     virtual void ToImage(Image*& x)
     {
         Fail("image");
         x = 0;
-    };
+    }
     virtual void ToMatrix(CMatrix*& x)
     {
         Fail("matrix");
         x = 0;
-    };
+    }
     virtual void ToVector(CVector*& x)
     {
         Fail("vector");
         x = 0;
-    };
+    }
     virtual void ToFile(CFile*& x)
     {
         Fail("file");
         x = 0;
-    };
+    }
     virtual void ToNetCDF(CNetCDF*& x)
     {
         Fail("netcdf");
         x = 0;
-    };
+    }
     virtual void ToTable(CTable*& x)
     {
         Fail("table");
         x = 0;
-    };
+    }
     virtual void ToObject(CObject*& x)
     {
         Fail("object");
         x = 0;
-    };
+    }
     virtual void ToError(CError*& x)
     {
         Fail("error");
         x = 0;
-    };
+    }
 #ifdef METVIEW_ODB
     virtual void ToOdb(COdb*& x)
     {
         Fail("odb");
         x = 0;
-    };
+    }
 #endif
     virtual void Dump(int);
     virtual void Dump1() { Print(); }
     virtual void Dump2() { Print(); }
 
     int Check(int, Value&, int, Value*, vtype, int, ...);
-    virtual void SetSubValue(Value&, int, Value*) { Fail("Index"); };
+    virtual void SetSubValue(Value&, int, Value*) { Fail("Index"); }
     //
 };
 
@@ -253,7 +249,7 @@ protected:
 
 public:
     InPool(vtype t, request* r);
-    InPool(vtype t, const char* n = NULL);
+    InPool(vtype t, const char* n = nullptr);
     ~InPool();
 
     //SetName(char *n);
@@ -270,17 +266,17 @@ class CNumber : public Content
     static long sDefaultPrec;
     virtual void ToRequest(request*&);
     virtual void ToString(const char*&);
-    virtual void ToNumber(double& x) { x = number; };
-    //	virtual void Print(void)  { cout << form("%g",number); };
-    virtual void Print(void);  //  { cout << number;            };
+    virtual void ToNumber(double& x) { x = number; }
+    //	virtual void Print(void)  { std::cout << form("%g",number); };
+    virtual void Print(void);  //  { std::cout << number;            };
     virtual int Write(FILE*);
 
 public:
     CNumber(double d) :
-        Content(tnumber) { number = d; };
-    static void SetPrecision(long p) { sPrec = p; };
-    static long GetPrecision() { return sPrec; };
-    static long GetDefaultPrecision() { return sDefaultPrec; };
+        Content(tnumber) { number = d; }
+    static void SetPrecision(long p) { sPrec = p; }
+    static long GetPrecision() { return sPrec; }
+    static long GetDefaultPrecision() { return sDefaultPrec; }
 };
 //=============================================================================
 class CDate : public Content
@@ -288,29 +284,29 @@ class CDate : public Content
     Date date;
     virtual void ToNumber(double&);
     virtual void ToString(const char*&);
-    virtual void ToDate(Date& x) { x = date; };
+    virtual void ToDate(Date& x) { x = date; }
     virtual void Dump2();
-    virtual void Print(void) { date.Print(); };
+    virtual void Print(void) { date.Print(); }
 
 public:
     CDate(Date d) :
-        Content(tdate) { date = d; };
+        Content(tdate) { date = d; }
 };
 //=============================================================================
 class CString : public Content
 {
     char* string;
     virtual void ToRequest(request*&);
-    virtual void ToString(const char*& x) { x = string; };
-    virtual void Print(void) { cout << string; };
+    virtual void ToString(const char*& x) { x = string; }
+    virtual void Print(void) { std::cout << string; }
     virtual void Dump1();
     virtual void Dump2();
     virtual int Write(FILE*);
 
 public:
     CString(const char* s) :
-        Content(tstring) { string = strcache(s); };
-    ~CString() { strfree(string); };
+        Content(tstring) { string = strcache(s); }
+    ~CString() { strfree(string); }
 };
 
 //=============================================================================
@@ -319,10 +315,10 @@ public:
 class CRequest : public Content
 {
     request* r;
-    virtual void ToRequest(request*& x) { x = r; };
+    virtual void ToRequest(request*& x) { x = r; }
     virtual void Print(void);
     virtual void Dump2(void);
-    virtual Content* Clone(void) { return new CRequest(r); };
+    virtual Content* Clone(void) { return new CRequest(r); }
     virtual void SetSubValue(Value&, int, Value*);
     virtual int Write(FILE*);
 
@@ -331,15 +327,15 @@ public:
     {
         free_all_requests(r);
         r = clone_all_requests(s);
-    };
-    request* GetRequest(void) { return r; };
+    }
+    request* GetRequest(void) { return r; }
     CRequest(request* s) :
-        Content(trequest) { r = clone_all_requests(s); };
-    ~CRequest() { free_all_requests(r); };
+        Content(trequest) { r = clone_all_requests(s); }
+    ~CRequest() { free_all_requests(r); }
 };
 
 // exposed for the Python interface
-void SetValue(request* r, const char* param, Value& val, bool attachData=true);
+void SetValue(request* r, const char* param, Value& val, bool attachData = true);
 
 //=============================================================================
 class CError : public Content
@@ -349,7 +345,7 @@ class CError : public Content
 
     virtual void Print(void);
     virtual void ToRequest(request*& x);
-    virtual void ToError(CError*& x) { x = this; };
+    virtual void ToError(CError*& x) { x = this; }
 
 public:
     CError(err e, const char* m) :
@@ -357,7 +353,7 @@ public:
     {
         error = e;
         msg   = strcache(m);
-    };
+    }
     ~CError() { strfree(msg); }
     const char* Message() { return msg; }
 };
@@ -365,12 +361,12 @@ public:
 //=============================================================================
 class CNil : public Content
 {
-    virtual void ToRequest(request*& x) { x = NULL; }
+    virtual void ToRequest(request*& x) { x = nullptr; }
     virtual void Dump2();
 
 public:
     CNil() :
-        Content(tnil){};
+        Content(tnil) {}
 };
 
 //=============================================================================
@@ -379,7 +375,7 @@ class CGrib : public InPool
 {
     fieldset* fs;
     hypercube* cube;
-    string path_;       // It stores an absolute path. This is important
+    std::string path_;  // It stores an absolute path. This is important
                         // specially if request parameter PATH contains
                         // a relative path.
     bool from_filter_;  // Indicates if the grib data was a result of a
@@ -414,11 +410,11 @@ public:
     fieldset* GetFieldset(void)
     {
         return fs;
-    };
+    }
 
     void SetFileTempFlag(boolean);
     hypercube* get_cube();
-    bool fromFilter() {return from_filter_;}
+    bool fromFilter() { return from_filter_; }
 };
 
 
@@ -440,7 +436,7 @@ class CImage : public InPool
     Image* image;
     virtual void ToRequest(request*&);
     //virtual void ToImage(CImage* &x)   { x = this; };
-    virtual void ToImage(Image*& x) { x = image; };
+    virtual void ToImage(Image*& x) { x = image; }
     virtual int Write(FILE*);
 
 public:
@@ -463,7 +459,7 @@ class ASync : public CRequest
 
     boolean Ready;
     virtual void Sync(Value*);
-    void Print(void) { cout << "<waiting>"; };
+    void Print(void) { std::cout << "<waiting>"; }
 
 public:
     static svc* Svc;
@@ -472,13 +468,13 @@ public:
     static char* Name;
 
     static void Connect(void);
-    static void IconStatus(const char*, const char*, const char* = NULL);
+    static void IconStatus(const char*, const char*, const char* = nullptr);
     static void Disconnect(void)
     {
         if (Svc)
             destroy_service(Svc);
-        Svc = NULL;
-    };
+        Svc = nullptr;
+    }
     static void Store(const char* name, request* r);
     static request* Fetch(const char* name);
 
@@ -486,10 +482,10 @@ public:
     ~ASync();
 
     request* Wait(void);
-    void SetAttachedContent(std::vector<Content*> v) { attachedContent = v; };
+    void SetAttachedContent(std::vector<Content*> v) { attachedContent = v; }
     void AvoidDuplication(Content* c);
 
-    virtual void ToRequest(request*& x) { x = Wait(); };
+    virtual void ToRequest(request*& x) { x = Wait(); }
 
 private:
     // asynchronous requests require a bit more effort for cleaning up any
@@ -529,7 +525,7 @@ class Value
             nil.Attach();
             nil.Attach();
         }  //ensure never deleted, even on termination
-    } *nilvalue;
+    } * nilvalue;
 
 public:
     Value()
@@ -581,16 +577,16 @@ public:
     void SetContent(Content* x);
     void SetContent(request* r);
     void SetContentRequest(request* r);
-    Content* GetContent(void) { return c; };
+    Content* GetContent(void) { return c; }
 
     void Write(void)
     {
         if (c->RefCount() > 1)
             SetContent(c->Clone());
-    };
+    }
 
     ~Value();
-    void Destroy() { delete this; };
+    void Destroy() { delete this; }
 
     void Sync() { _s(); }
 
@@ -600,53 +596,53 @@ public:
         Write();
         c->SetSubValue(a, b, v);
     }
-    vtype GetType(const char** name = NULL)
+    vtype GetType(const char** name = nullptr)
     {
         _s();
         return c->GetType(name);
-    };
+    }
 
     void GetValue(int& x)
     {
         double d;
         c->ToNumber(d);
         x = (int)d;
-    };
+    }
     void GetValue(long& x)
     {
         double d;
         c->ToNumber(d);
         x = (long)d;
-    };
-    void GetValue(double& x) { c->ToNumber(x); };
-    void GetValue(Date& x) { c->ToDate(x); };
-    void GetValue(const char*& x) { c->ToString(x); };
-    void GetValue(request*& x) { c->ToRequest(x); };
-    void GetValue(fieldset*& x) { c->ToFieldset(x); };
-    void GetValue(CList*& x) { c->ToList(x); };
-    void GetValue(CGrib*& x) { c->ToGrib(x); };
-    void GetValue(CBufr*& x) { c->ToBufr(x); };
-    void GetValue(CGeopts*& x) { c->ToGeopts(x); };
-    void GetValue(CGeoptSet*& x) { c->ToGeoptSet(x); };
-    void GetValue(CMatrix*& x) { c->ToMatrix(x); };
-    void GetValue(CNetCDF*& x) { c->ToNetCDF(x); };
-    void GetValue(CTable*& x) { c->ToTable(x); };
-    void GetValue(CObject*& x) { c->ToObject(x); };
-    void GetValue(CVector*& x) { c->ToVector(x); };
-    void GetValue(Image*& x) { c->ToImage(x); };
-    void GetValue(CFile*& x) { c->ToFile(x); };
-    void GetValue(CError*& x) { c->ToError(x); };
+    }
+    void GetValue(double& x) { c->ToNumber(x); }
+    void GetValue(Date& x) { c->ToDate(x); }
+    void GetValue(const char*& x) { c->ToString(x); }
+    void GetValue(request*& x) { c->ToRequest(x); }
+    void GetValue(fieldset*& x) { c->ToFieldset(x); }
+    void GetValue(CList*& x) { c->ToList(x); }
+    void GetValue(CGrib*& x) { c->ToGrib(x); }
+    void GetValue(CBufr*& x) { c->ToBufr(x); }
+    void GetValue(CGeopts*& x) { c->ToGeopts(x); }
+    void GetValue(CGeoptSet*& x) { c->ToGeoptSet(x); }
+    void GetValue(CMatrix*& x) { c->ToMatrix(x); }
+    void GetValue(CNetCDF*& x) { c->ToNetCDF(x); }
+    void GetValue(CTable*& x) { c->ToTable(x); }
+    void GetValue(CObject*& x) { c->ToObject(x); }
+    void GetValue(CVector*& x) { c->ToVector(x); }
+    void GetValue(Image*& x) { c->ToImage(x); }
+    void GetValue(CFile*& x) { c->ToFile(x); }
+    void GetValue(CError*& x) { c->ToError(x); }
 #ifdef METVIEW_ODB
     void GetValue(COdb*& x)
     {
         c->ToOdb(x);
-    };
+    }
 #endif
     void Print(void)
     {
         c->Print();
-    };
-    void Dump(int trace) { c->Dump(trace); };
+    }
+    void Dump(int trace) { c->Dump(trace); }
     int Write(FILE* f) { return c->Write(f); }
 
     static const char* TypeName(vtype);
@@ -665,8 +661,8 @@ class CList : public Content
     {
         delete[] values;
         values = nullptr;
-    };
-    virtual void ToList(CList*& x) { x = this; };
+    }
+    virtual void ToList(CList*& x) { x = this; }
     virtual void ToRequest(request*&);
     virtual int Write(FILE*);
     virtual Content* Clone(void);
@@ -692,12 +688,12 @@ public:
     CList(int n) :
         Content(tlist),
         count(n),
-        capacity(calcCapacity(n)) { values = new Value[capacity]; };
-    virtual ~CList() { CleanUp(); };
-    Value& operator[](int n) { return values[n]; };
+        capacity(calcCapacity(n)) { values = new Value[capacity]; }
+    virtual ~CList() { CleanUp(); }
+    Value& operator[](int n) { return values[n]; }
 
-    int Count(void) { return count; };
-    Value* Values(void) { return values; };
+    int Count(void) { return count; }
+    Value* Values(void) { return values; }
     void Add(const Value& v);
 
     void Print(void);
@@ -743,10 +739,10 @@ public:
     };
 
     CArray() :
-        size(0){};
+        size(0) {}
     CArray(ValuesType type) :
         size(0),
-        valtype(type){};
+        valtype(type) {}
     int count() { return size; }
     CArray::ValuesType type() { return valtype; }
     void copyValues(int targetIndex, CArray* source, int sourceIndex, int numValues);
@@ -787,18 +783,18 @@ class CArrayF64 : public CArray
 public:
     CArrayF64() :
         CArray(CArray::VALUES_F64),
-        values(NULL){};
+        values(nullptr) {}
 
     void allocateMemory(int numElements);
     void setValuesToConstant(double c);
     void memorycopy(int targetIndex, const double* srcVals, int numVals);
     void memorycopy(int targetIndex, const float* srcVals, int numVals);
-    double* asDoubles(int i) { return &(values[i]); };
-    float* asFloat32s(int i) { return NULL; };
+    double* asDoubles(int i) { return &(values[i]); }
+    float* asFloat32s(int) { return nullptr; }
     void setIndexedValue(int i, double v) { values[i] = v; }
     void setIndexedValueToMissing(int i) { values[i] = VECTOR_MISSING_VALUE; }
     bool isIndexedValueMissing(int i) { return (values[i] == VECTOR_MISSING_VALUE); }
-    double getIndexedValue(int i) { return values[i]; };
+    double getIndexedValue(int i) { return values[i]; }
     double getMissingValueIndicator() { return VECTOR_MISSING_VALUE; }
     size_t writeValuesToFile(FILE* fp);
     size_t readValuesFromFile(FILE* fp, int n);
@@ -818,18 +814,18 @@ class CArrayF32 : public CArray
 public:
     CArrayF32() :
         CArray(CArray::VALUES_F32),
-        values(NULL){};
+        values(nullptr) {}
 
     void allocateMemory(int numElements);
     void setValuesToConstant(double c);
     void memorycopy(int targetIndex, const double* srcVals, int numVals);
     void memorycopy(int targetIndex, const float* srcVals, int numVals);
-    double* asDoubles(int i) { return NULL; };
-    float* asFloat32s(int i) { return &(values[i]); };
-    void setIndexedValue(int i, double v) { values[i] = v; };
-    void setIndexedValueToMissing(int i) { values[i] = VECTOR_F32_MISSING_VALUE; };
-    bool isIndexedValueMissing(int i) { return (values[i] == VECTOR_F32_MISSING_VALUE); };
-    double getIndexedValue(int i) { return values[i]; };
+    double* asDoubles(int) { return nullptr; }
+    float* asFloat32s(int i) { return &(values[i]); }
+    void setIndexedValue(int i, double v) { values[i] = v; }
+    void setIndexedValueToMissing(int i) { values[i] = VECTOR_F32_MISSING_VALUE; }
+    bool isIndexedValueMissing(int i) { return (values[i] == VECTOR_F32_MISSING_VALUE); }
+    double getIndexedValue(int i) { return values[i]; }
     double getMissingValueIndicator() { return VECTOR_F32_MISSING_VALUE; }
     size_t writeValuesToFile(FILE* fp);
     size_t readValuesFromFile(FILE* fp, int n);
@@ -878,7 +874,7 @@ public:
     ~CVector() { CleanUp(); }
     CVector(const CVector& x) :
         Content(tvector),
-        values(0) { Copy(x); };
+        values(0) { Copy(x); }
     CVector& operator=(const CVector& x)
     {
         CleanUp();
@@ -922,10 +918,10 @@ class CMatrix : public Content
     double* values;
 
     void Copy(const CMatrix& x);
-    void CleanUp(void) { delete[] values; };
-    virtual void ToMatrix(CMatrix*& x) { x = this; };
+    void CleanUp(void) { delete[] values; }
+    virtual void ToMatrix(CMatrix*& x) { x = this; }
 
-    virtual Content* Clone(void) { return new CMatrix(*this); };
+    virtual Content* Clone(void) { return new CMatrix(*this); }
     virtual void SetSubValue(Value&, int, Value*);
 
 public:
@@ -933,14 +929,14 @@ public:
     virtual void Dump(int);
     CMatrix(int r, int c);
     CMatrix(const CMatrix& x) :
-        Content(tmatrix) { Copy(x); };
+        Content(tmatrix) { Copy(x); }
     CMatrix& operator=(const CMatrix& x)
     {
         CleanUp();
         Copy(x);
         return *this;
-    };
-    ~CMatrix() { CleanUp(); };
+    }
+    ~CMatrix() { CleanUp(); }
 
 #if 0
 	double&  operator()(int r,int c)    { return values[r+c*row]; };
@@ -961,13 +957,13 @@ public:
             abort();
         }
         return values[r + c * row];
-    };
+    }
 #endif
     int Row(void)
     {
         return row;
-    };
-    int Col(void) { return col; };
+    }
+    int Col(void) { return col; }
     virtual int Write(FILE*);
 };
 
@@ -1007,5 +1003,4 @@ public:
     void GetInheritance(Context**, int& count);
 };
 
-#endif
 //VALUE_H__
