@@ -14,14 +14,14 @@
 #include "MvDebugPrintControl.h"
 #include "MvPath.hpp"
 
-typedef struct data
+struct data
 {
     boolean serve;
     boolean module;
     char* name;
     char* script;
     char* args;
-} data;
+};
 
 static option opts[] = {
 
@@ -86,16 +86,16 @@ static void out_of_memory(void)
 
 // This class redirect cout to Script::PutMessage
 
-class sbuf : public streambuf
+class sbuf : public std::streambuf
 {  // 76830942
 
     char line[1024];
     int n;
 
 
-    // Oops, SUN says streambuf::seekoff(long,ios::seek_dir,int) undefined ????
+    // Oops, SUN says streambuf::seekoff(long,std::ios::seek_dir,int) undefined ????
     //#ifdef sun
-    //	virtual long seekoff(long,ios::seek_dir,int) { return 0;};
+    //	virtual long seekoff(long,std::ios::seek_dir,int) { return 0;};
     //#endif
 
     virtual int sync(void)
@@ -122,7 +122,7 @@ class sbuf : public streambuf
 
 public:
     sbuf() :
-        n(0){};
+        n(0) {}
 };
 
 
@@ -143,7 +143,7 @@ static Value* args_from_file(char* file, int& n)
     // Waring unlink file
     unlink(file);
 
-    Value* v = new Value[max];
+    auto* v = new Value[max];
     char line[1024];
 
     while (fgets(line, sizeof(line), f)) {
@@ -160,7 +160,7 @@ static Value* args_from_file(char* file, int& n)
 
         if (n == max) {
             max += n / 2;
-            Value* w = new Value[max];
+            auto* w = new Value[max];
             for (int i = 0; i < n; i++)
                 w[i] = v[i];
 
@@ -187,9 +187,9 @@ static void serve_macro(svcid* id, request* r, void* data)
     // send pid to caller process
     MvRequest reqPid("REGISTER_MACRO_PID");
     reqPid("PID") = getpid();
-    send_progress(id, NULL, reqPid);
+    send_progress(id, nullptr, reqPid);
 
-    request* param        = (request*)data;
+    auto* param           = (request*)data;
     const char* path      = get_value(r, "PATH", 0);
     const char* name      = get_value(r, "_NAME", 0);
     const char* action    = get_value(r, "_ACTION", 0);
@@ -241,7 +241,7 @@ static void serve_macro(svcid* id, request* r, void* data)
 
     start_timer();
 
-    Script* s = new Script(mbasename(name));
+    auto* s = new Script(mbasename(name));
 
     if (output)  //-- uPlot/PlotMod/MetZoom
     {
@@ -256,7 +256,7 @@ static void serve_macro(svcid* id, request* r, void* data)
 
 
     // store the current macro path - needs to be done *before* Compile(path)
-    string fullPath = MakeAbsolutePath(path);
+    std::string fullPath = MakeAbsolutePath(path);
     Script::MacroPath(fullPath.c_str());
     Script::MacroMainPath(fullPath.c_str());
 
@@ -297,9 +297,9 @@ static void serve_macro(svcid* id, request* r, void* data)
             w.Sync();
 
             if (print) {
-                cout << "# Macro returns: ";
+                std::cout << "# Macro returns: ";
                 w.Print();
-                cout << '\n';
+                std::cout << '\n';
             }
 
             w.GetValue(reply);
@@ -315,10 +315,10 @@ static void serve_macro(svcid* id, request* r, void* data)
 
         // Special case when setouput and metzoom commands are defined:
         // ignores setouput and calls uPlotManager instead of uPlotBatch
-        if ( reqdrive && req && 
-            (const char*)req("_MACRO_PLOT_COMMAND") && 
-            strcmp((const char*)req("_MACRO_PLOT_COMMAND"),"metzoom") == 0 )
-                PlotterFunction::SetPlotter("uPlotManager");
+        if (reqdrive && req &&
+            (const char*)req("_MACRO_PLOT_COMMAND") &&
+            strcmp((const char*)req("_MACRO_PLOT_COMMAND"), "metzoom") == 0)
+            PlotterFunction::SetPlotter("uPlotManager");
         else {
             // Concatenate Output Driver and Plot request
             MvRequest req_aux(reqdrive);
@@ -327,11 +327,11 @@ static void serve_macro(svcid* id, request* r, void* data)
             req = req + Script::PlotReq;
         }
 
-		// Important to indicate which visualiser will be called.
-		// The visualiser default is uPlot
-		// Module uPlotManager will be called
-		if (action && strcmp(action,"metzoom") == 0)
-			req("_ACTION") = "metzoom";
+        // Important to indicate which visualiser will be called.
+        // The visualiser default is uPlot
+        // Module uPlotManager will be called
+        if (action && strcmp(action, "metzoom") == 0)
+            req("_ACTION") = "metzoom";
 
         // Flush
         Value v(PlotterFunction::Plotter(), req);
@@ -358,7 +358,7 @@ static void serve_macro(svcid* id, request* r, void* data)
 
     // Add parameter _PATH
     if (!(const char*)get_value(reply, "_PATH", 0)) {
-        string fullPath = MakeAbsolutePath((const char*)get_value(reply, "PATH", 0), mdirname(Script::MacroMainPath()));
+        std::string fullPath = MakeAbsolutePath((const char*)get_value(reply, "PATH", 0), mdirname(Script::MacroMainPath()));
         set_value(reply, "_PATH", fullPath.c_str());
     }
 
@@ -537,8 +537,8 @@ int main(int argc, char** argv)
         // Send prints to caller
 
         sbuf buf;
-        ostream out(&buf);
-        cout.rdbuf(out.rdbuf());
+        std::ostream out(&buf);
+        std::cout.rdbuf(out.rdbuf());
 
         service = create_service("macro");  // progname());
         add_service_callback(service, "HELP", serve_help, 0);
