@@ -146,19 +146,19 @@ void CMatrix::Copy(const CMatrix& v)
 
 void CMatrix::Dump(int)
 {
-    cout << "matrix(" << row << ',' << col << ')';
+    std::cout << "matrix(" << row << ',' << col << ')';
 }
 
 void CMatrix::Print(void)
 {
     for (int i = 0; i < row; i++) {
-        cout << '|';
+        std::cout << '|';
         for (int j = 0; j < col; j++) {
-            cout << values[i + row * j];
+            std::cout << values[i + row * j];
             if (j != col - 1)
-                cout << ',';
+                std::cout << ',';
         }
-        cout << '|' << '\n';
+        std::cout << '|' << '\n';
     }
 }
 int CMatrix::Write(FILE* file)
@@ -205,7 +205,7 @@ class Matrix1Function : public Function
 {
 public:
     Matrix1Function(const char* n) :
-        Function(n){};
+        Function(n) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -244,7 +244,7 @@ public:
         Function(n, 2, tnumber, tnumber)
     {
         info = "Builds a new matrix given ist dimensions";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -265,7 +265,7 @@ public:
         Function(n, 2, tmatrix, tmatrix)
     {
         info = "Matrix multiplication";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -279,7 +279,7 @@ Value MatrixMulFunction::Execute(int, Value* arg)
         return Error("Cannot multiply a %d x %d matrix by a %d x %d matrix",
                      a->Row(), a->Col(), b->Row(), b->Col());
 
-    CMatrix* c = new CMatrix(a->Row(), b->Col());
+    auto* c = new CMatrix(a->Row(), b->Col());
 
     Multiply(*a, *b, *c);
 
@@ -295,7 +295,7 @@ public:
         Function(n, 2, tmatrix, tmatrix)
     {
         info = "Matrix addition";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -309,7 +309,7 @@ Value MatrixAddFunction::Execute(int, Value* arg)
         return Error("Cannot add a %d x %d matrix by a %d x %d matrix",
                      a->Row(), a->Col(), b->Row(), b->Col());
 
-    CMatrix* c = new CMatrix(a->Row(), a->Col());
+    auto* c = new CMatrix(a->Row(), a->Col());
 
     for (int i = 0; i < a->Row(); i++)
         for (int j = 0; j < a->Col(); j++)
@@ -327,7 +327,7 @@ public:
         Function(n, 2, tmatrix, tmatrix)
     {
         info = "Matrix addition";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -341,7 +341,7 @@ Value MatrixSubFunction::Execute(int, Value* arg)
         return Error("Cannot substract a %d x %d matrix by a %d x %d matrix",
                      a->Row(), a->Col(), b->Row(), b->Col());
 
-    CMatrix* c = new CMatrix(a->Row(), a->Col());
+    auto* c = new CMatrix(a->Row(), a->Col());
 
     for (int i = 0; i < a->Row(); i++)
         for (int j = 0; j < a->Col(); j++)
@@ -359,7 +359,7 @@ public:
         Function(n, 1, tmatrix)
     {
         info = "Matrix negation";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -368,7 +368,7 @@ Value MatrixNegFunction::Execute(int, Value* arg)
     CMatrix* a;
     arg[0].GetValue(a);
 
-    CMatrix* c = new CMatrix(a->Row(), a->Col());
+    auto* c = new CMatrix(a->Row(), a->Col());
 
     for (int i = 0; i < a->Row(); i++)
         for (int j = 0; j < a->Col(); j++)
@@ -386,7 +386,7 @@ public:
         Function(n, 1, tmatrix)
     {
         info = "Matrix invertion";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -400,7 +400,7 @@ Value MatrixInvFunction::Execute(int, Value* arg)
         return Error("Cannot inverse %d x %d matrix. Matrix must by square",
                      a->Row(), a->Col());
 
-    CMatrix* c = new CMatrix(a->Row(), a->Col());
+    auto* c = new CMatrix(a->Row(), a->Col());
 
     if (Invert(*a, *c)) {
         delete c;
@@ -419,7 +419,7 @@ public:
         Function(n, 1, tmatrix)
     {
         info = "Matrix determinant";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -445,7 +445,7 @@ public:
         Function(n, 1, tmatrix)
     {
         info = "Transpose a matrix";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -454,7 +454,7 @@ Value MatrixTransFunction::Execute(int, Value* arg)
     CMatrix* a;
     arg[0].GetValue(a);
 
-    CMatrix* b = new CMatrix(a->Col(), a->Row());
+    auto* b = new CMatrix(a->Col(), a->Row());
 
     for (int i = 0; i < a->Row(); i++)
         for (int j = 0; j < a->Col(); j++)
@@ -470,7 +470,7 @@ class MatrixGetElemFunction : public Function
 {
 public:
     MatrixGetElemFunction(const char* n) :
-        Function(n, 3, tmatrix, tnumber, tnumber){};
+        Function(n, 3, tmatrix, tnumber, tnumber) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
