@@ -8,6 +8,9 @@
  ***************************** LICENSE END *************************************/
 
 #include <algorithm>
+#include <fstream>
+
+#include "fstream_mars_fix.h"
 
 #include "MvPath.hpp"
 #include "macro.h"
@@ -49,20 +52,19 @@ CGeoptSet::CGeoptSet(const char* p, int temp) :
 }
 
 
-CGeoptSet::CGeoptSet(request* s): Content(tgptset)
+CGeoptSet::CGeoptSet(request* s) :
+    Content(tgptset)
 {
     r = clone_all_requests(s);
     load();
 }
 
 
-CGeoptSet::~CGeoptSet()
-{
-}
+CGeoptSet::~CGeoptSet() = default;
 
 void CGeoptSet::Print(void)
 {
-    cout << "geopointset " << '<' << Count() << " geopoints" << '>';
+    std::cout << "geopointset " << '<' << Count() << " geopoints" << '>';
 }
 
 int CGeoptSet::Write(FILE* f)
@@ -86,7 +88,7 @@ void CGeoptSet::load(void)
     if (r) {
         const char* path = get_value(r, "PATH", 0);
 
-        ifstream f(path);
+        std::ifstream f(path);
         if (!f) {
             marslog(LOG_EROR, "Could not open geopointset file: %s", path);
             return;  // false;
@@ -95,9 +97,9 @@ void CGeoptSet::load(void)
         // read each embedded geopoints file from the 'master file'
         bool readOk = true;
         while (readOk && !f.eof()) {
-            MvGeoPoints* gp = new MvGeoPoints();
-            readOk          = gp->load(f);
-            CGeopts* cgp    = new CGeopts(*gp);
+            auto* gp  = new MvGeoPoints();
+            readOk    = gp->load(f);
+            auto* cgp = new CGeopts(*gp);
             Add(*(new Value(cgp)));
         }
     }
@@ -175,7 +177,7 @@ class SubGeoSetFunction : public Function
 {
 public:
     SubGeoSetFunction(const char* n) :
-        Function(n, 2, tgptset, tnumber){};
+        Function(n, 2, tgptset, tnumber) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -205,7 +207,7 @@ public:
         Function(n)
     {
         info = "Creates a new geopoints_set";
-    };
+    }
     virtual int ValidArguments(int arity, Value* arg);
     virtual Value Execute(int arity, Value* arg);
 };
@@ -222,7 +224,7 @@ int CreateGeopointsSetFunction::ValidArguments(int arity, Value* arg)
 
 Value CreateGeopointsSetFunction::Execute(int arity, Value* arg)
 {
-    CGeoptSet* gs = new CGeoptSet();
+    auto* gs = new CGeoptSet();
 
     for (int i = 0; i < arity; i++) {
         CGeopts* gp;
@@ -237,7 +239,7 @@ class CountGeoSetFunction : public Function
 {
 public:
     CountGeoSetFunction(const char* n) :
-        Function(n, 1, tgptset){};
+        Function(n, 1, tgptset) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -256,7 +258,7 @@ class MergeGeopointSetFunction : public Function
 {
 public:
     MergeGeopointSetFunction(const char* n) :
-        Function(n){};
+        Function(n) {}
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -284,15 +286,15 @@ Value MergeGeopointSetFunction::Execute(int, Value* arg)
     if (arg[1].GetType() == tgeopts) {
         CGeopts* gp;
         arg[1].GetValue(gp);
-        CGeoptSet* newgpset = new CGeoptSet(geoset);
+        auto* newgpset = new CGeoptSet(geoset);
         newgpset->Add(*(new Value(gp)));
         return Value(newgpset);
     }
     else if (arg[1].GetType() == tgptset) {
         CGeoptSet* gset2;
         arg[1].GetValue(gset2);
-        CGeoptSet* newgpset = new CGeoptSet(geoset);
-        unsigned long n     = gset2->Count();
+        auto* newgpset  = new CGeoptSet(geoset);
+        unsigned long n = gset2->Count();
         for (unsigned long i = 1; i < n + 1; i++)
             newgpset->Add((*gset2)[i]);
         return Value(newgpset);
@@ -307,7 +309,7 @@ class FilterGeoSetFunction : public Function
 {
 public:
     FilterGeoSetFunction(const char* n) :
-        Function(n, 2, tgptset, trequest){};
+        Function(n, 2, tgptset, trequest) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -325,8 +327,8 @@ Value FilterGeoSetFunction::Execute(int, Value* arg)
     }
 
     // otherwise, do the filtering
-    CGeoptSet* result = new CGeoptSet();
-    unsigned long c   = gps->Count();
+    auto* result    = new CGeoptSet();
+    unsigned long c = gps->Count();
     for (unsigned long i = 1; i <= c; i++) {
         Value& val = (*gps)[i];
         CGeopts* gpi;
@@ -350,7 +352,7 @@ class GeoSetUnOp : public Function
     const char* fname_;
 
 public:
-    GeoSetUnOp(const char* n, uniproc f) :
+    GeoSetUnOp(const char* n, uniproc) :
         Function(n, 1, tgptset)
     {
         fname_ = strcache(n);
@@ -390,7 +392,7 @@ class ValueGeoSetBinOp : public Function
     const char* fname_;
 
 public:
-    ValueGeoSetBinOp(const char* n, binproc f) :
+    ValueGeoSetBinOp(const char* n, binproc) :
         Function(n) { fname_ = strcache(n); }
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
@@ -424,7 +426,7 @@ Value ValueGeoSetBinOp::Execute(int, Value* arg)
 
     unsigned long c = std::max(i1, i2);
 
-    CGeoptSet* p = new CGeoptSet();
+    auto* p = new CGeoptSet();
 
     // for each geopoints var, call this function on that gpt
     for (unsigned long i = 1; i < c + 1; i++)  // 1-based indexing
