@@ -7,12 +7,14 @@
 
  ***************************** LICENSE END *************************************/
 
+#include <iostream>
+
 #include <stdlib.h>
 #include <time.h>
 #include <MvRequest.h>
 #include <MvVersionInfo.h>
 #include <MvScanFileType.h>
-#include <MvMiscelaneous.h>
+#include <MvMiscellaneous.h>
 
 #if defined(METVIEW_ODB)
 #include <odc/api/odc.h>
@@ -108,11 +110,11 @@ class NilCountFunction : public Function
 {
 public:
     NilCountFunction(const char* n) :
-        Function(n, 1, tnil){};
+        Function(n, 1, tnil) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
-Value NilCountFunction::Execute(int, Value* arg)
+Value NilCountFunction::Execute(int, Value* /*arg*/)
 {
     int zero = 0;
     return Value(zero);
@@ -129,7 +131,7 @@ public:
         Function(n, 1, tany)
     {
         info = "Returns the type of an expression";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -213,7 +215,7 @@ class RandomFunction : public Function
 {
 public:
     RandomFunction(const char* n) :
-        Function(n, 0) { info = "Generat random"; };
+        Function(n, 0) { info = "Generat random"; }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -235,7 +237,7 @@ class PrintFunction : public Function
 {
 public:
     PrintFunction(const char* n) :
-        Function(n) { info = "Prints all its arguments"; };
+        Function(n) { info = "Prints all its arguments"; }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -246,7 +248,7 @@ public:
         PrintFunction(n)
     {
         info = "Prints all its arguments and stop in error";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -257,7 +259,7 @@ public:
         PrintFunction(n)
     {
         info = "Prints all its arguments and stop the macro";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -271,8 +273,8 @@ Value PrintFunction::Execute(int arity, Value* arg)
         arg[i].Sync();  // This will force sync
         arg[i].Print();
     }
-    cout << '\n'
-         << flush;
+    std::cout << '\n'
+              << std::flush;
     return Value(0.0);
 }
 
@@ -317,7 +319,7 @@ public:
         Function(n)
     {
         info = "Describes available function";
-    };
+    }
     virtual int ValidArguments(int arity, Value* arg);
     virtual Value Execute(int arity, Value* arg);
 };
@@ -361,7 +363,7 @@ Value DescribeFunction::Execute(int, Value* arg)
 
     List* l = (List*)c->Dictionaries()->Head();
     while (l) {
-        Function* n = (Function*)l->Head();
+        auto* n = (Function*)l->Head();
         while (n) {
             if (p == n->Name()) {
                 num_matches++;
@@ -471,13 +473,13 @@ Value FetchFunction::Execute(int, Value* arg)
 
     Content* content = v.GetContent();
 
-    if (content->GetType(NULL) == tgrib) {
-        CGrib* c = (CGrib*)content;
+    if (content->GetType(nullptr) == tgrib) {
+        auto* c = (CGrib*)content;
         c->IsIcon(true);  // so that InPool won't touch the data
         c->SetFileTempFlag(false);
     }
-    else if (content->GetType(NULL) == tbufr) {
-        CBufr* c = (CBufr*)content;
+    else if (content->GetType(nullptr) == tbufr) {
+        auto* c = (CBufr*)content;
         c->IsIcon(true);  // so that InPool won't touch the data
     }
 
@@ -566,7 +568,7 @@ public:
         Function(n, 0)
     {
         info = "Returns the list of the calling arguments of the current function";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -576,7 +578,7 @@ Value ArgsFunction::Execute(int, Value*)
     int n      = c->Argc();
     Value* v   = c->Argv();
 
-    CList* l = new CList(n);
+    auto* l = new CList(n);
 
     for (int i = 0; i < n; i++)
         (*l)[i] = v[i];
@@ -592,7 +594,7 @@ public:
         Function(n)
     {
         info = "Returns the list of all the documented functions";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -605,14 +607,14 @@ static int cmp(const void* a, const void* b)
 
 Value DictionaryFunction::Execute(int arity, Value*)
 {
-    typedef const char* charp;
-    Context* c = Context::Instruction->Owner();
-    int count = 0;
-    int all = arity > 0;
+    using charp = const char*;
+    Context* c  = Context::Instruction->Owner();
+    int count   = 0;
+    int all     = arity > 0;
 
     List* l = (List*)c->Dictionaries()->Head();
     while (l) {
-        Function* n = (Function*)l->Head();
+        auto* n = (Function*)l->Head();
         while (n) {
             if (all || n->Info())
                 count++;
@@ -632,12 +634,12 @@ Value DictionaryFunction::Execute(int arity, Value*)
         c = c->Owner();
     }
 
-    charp* names = new charp[count];
+    auto* names = new charp[count];
 
     count = 0;
     l     = (List*)c->Dictionaries()->Head();
     while (l) {
-        Function* n = (Function*)l->Head();
+        auto* n = (Function*)l->Head();
         while (n) {
             if (all || n->Info())
                 names[count++] = n->Name();
@@ -665,7 +667,7 @@ Value DictionaryFunction::Execute(int arity, Value*)
             names[++m] = names[i];
     count = m + 1;
 
-    CList* v = new CList(count);
+    auto* v = new CList(count);
     for (i = 0; i < count; i++)
         (*v)[i] = Value(names[i]);
     delete[] names;
@@ -674,10 +676,10 @@ Value DictionaryFunction::Execute(int arity, Value*)
     // add the names of the mvl functions
     char line[1024];
     std::string mlvFuncsFile(metview::mvlMacroDirFile("mvl_funcs.txt"));
-    FILE *fp = fopen(mlvFuncsFile.c_str(), "rt");
+    FILE* fp = fopen(mlvFuncsFile.c_str(), "rt");
 
     while (fgets(line, sizeof(line), fp)) {
-        line[strlen(line)-1] = '\0';
+        line[strlen(line) - 1] = '\0';
         v->Add(Value(line));
     }
     fclose(fp);
@@ -706,7 +708,9 @@ class MagMLFunction : public Function
 {
 public:
     MagMLFunction(const char* n) :
-        Function(n, 1, tstring){/*"Executes MagML code";*/};
+        Function(n, 1, tstring)
+    { /*"Executes MagML code";*/
+    }
 
     virtual Value Execute(int arity, Value* arg);
 };
@@ -745,7 +749,7 @@ public:
         Function(n)
     {
         info = "Actives an interactive data examiner window on the given data";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -829,10 +833,9 @@ Value ExamineFunction::Execute(int, Value* arg)
     // warning, but do not fail, as this could be part of an interactive Jupyter session
     std::string message("examine: this Metview installation has been built without user interface");
     marslog(LOG_WARN, message.c_str());
-    if (Context::IsPython())
-    {
+    if (Context::IsPython()) {
         std::string message2 = message + "; consider using methods ls() and describe() if using a Fieldset";
-        v = Value(message2.c_str());
+        v                    = Value(message2.c_str());
     }
     else
         v = Value(message.c_str());
@@ -849,12 +852,12 @@ public:
         Function(n)
     {
         info = "Activates an interactive editor window on the given file";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
 
-int EditFunction::ValidArguments(int arity, Value* arg)
+int EditFunction::ValidArguments(int /*arity*/, Value* /*arg*/)
 {
     return true;
 }
@@ -871,7 +874,7 @@ Value EditFunction::Execute(int, Value* arg)
 
     // if the argument is a string, assume it's a path to the file to be edited
     if (arg[0].GetType() == tstring) {
-        const char* path = NULL;
+        const char* path = nullptr;
         arg[0].GetValue(path);
         spath = std::string(path);
     }
@@ -944,7 +947,7 @@ Value PurgeMemFunction::Execute(int, Value*)
     // The mars-client purge_mem function releases the first unused block it finds
     // and then returns 1. If there are no unused blocks, it returns 0. Therefore
     // we must call it in a loop to free all unused memory.
-    while(purge_mem()) {
+    while (purge_mem()) {
     }
     return Value();
 }
@@ -988,7 +991,7 @@ public:
     virtual Value Execute(int arity, Value* arg);
 };
 
-Value CallArgsFunction::Execute(int arity, Value* argv)
+Value CallArgsFunction::Execute(int /*arity*/, Value* argv)
 {
     const char* name;
     argv[0].GetValue(name);
@@ -1018,7 +1021,7 @@ public:
         info = "Says Hello";
     }
     virtual Value Execute(int arity, Value* arg);
-    virtual int ValidArguments(int arity, Value*) { return true; }
+    virtual int ValidArguments(int /*arity*/, Value*) { return true; }
 };
 
 Value HelloWorldFunction::Execute(int arity, Value* argv)
@@ -1069,7 +1072,7 @@ public:
 };
 
 
-Value MetviewVersionFunction::Execute(int arity, Value* arg)
+Value MetviewVersionFunction::Execute(int /*arity*/, Value* /*arg*/)
 {
     request* r;
     long grib_api_version;
@@ -1077,7 +1080,7 @@ Value MetviewVersionFunction::Execute(int arity, Value* arg)
     MvVersionInfo mvInfo;  // the constructor populates the class with information
 
     // the return value will be a request whose elements we will populate below
-    r = empty_request(NULL);
+    r = empty_request(nullptr);
 
 
     if (mvInfo.infoFound()) {
@@ -1102,8 +1105,8 @@ Value MetviewVersionFunction::Execute(int arity, Value* arg)
     // extra code to take into account the possibility of
     // using either GRIB_API or ecCodes for GRIB handling
     std::string grib_package = QUOTE_PPP(GRIB_HANDLING_PACKAGE);
-    for (unsigned int i = 0; i < grib_package.length(); ++i)
-        grib_package[i] = tolower(grib_package[i]);
+    for (char& i : grib_package)
+        i = tolower(i);
     grib_package += "_version";
 
     grib_api_version = grib_get_api_version();
@@ -1116,8 +1119,8 @@ Value MetviewVersionFunction::Execute(int arity, Value* arg)
     const char* cinterp = getenv("MARS_PPROC_BACKEND");
     if (cinterp) {
         std::string interp(cinterp);
-        for (unsigned int i = 0; i < interp.length(); ++i)
-            interp[i] = tolower(interp[i]);
+        for (char& i : interp)
+            i = tolower(i);
         set_value(r, "default_interp", "%s", interp.c_str());
     }
 
@@ -1192,7 +1195,7 @@ Value FeatureAvailabilityFunction::Execute(int, Value* arg)
 #ifdef METVIEW_ODB
         return Value(1);
 #else
-        return Value(0.0);  // 0.0 to avoid ambiguity with NULL pointer
+        return Value(0.0);  // 0.0 to avoid ambiguity with nullptr
 #endif
     }
 
@@ -1200,7 +1203,14 @@ Value FeatureAvailabilityFunction::Execute(int, Value* arg)
 #ifdef ENABLE_PLOTTING
         return Value(1);
 #else
-        return Value(0.0);  // 0.0 to avoid ambiguity with NULL pointer
+        return Value(0.0);  // 0.0 to avoid ambiguity with nullptr
+#endif
+    }
+    else if (featureName == "stations_db") {
+#ifdef ENABLE_STATIONS_DB
+        return Value(1);
+#else
+        return Value(0.0);  // 0.0 to avoid ambiguity with nullptr
 #endif
     }
     else
