@@ -10,7 +10,10 @@
 #include "macro.h"
 #include "arith.h"
 #include "code.h"
-#include "inc_stl.h"
+
+#include <iostream>
+#include <utility>
+#include <vector>
 
 
 enum eListIndexType
@@ -95,7 +98,7 @@ void CList::Move(CList&& v)
 void CList::Add(const Value& v)
 {
     if (count == capacity) {
-        Value* new_values = new Value[capacity += CHUNK];
+        auto* new_values = new Value[capacity += CHUNK];
 
         for (int ii = 0; ii < count; ii++)  // copy the existing values across
             new_values[ii] = values[ii];
@@ -135,28 +138,28 @@ CList& CList::operator=(CList&& v)
 
 void CList::Print(void)
 {
-    cout << '[';
+    std::cout << '[';
     for (int i = 0; i < count; i++) {
         values[i].Print();
         if (i != count - 1)
-            cout << ',';
+            std::cout << ',';
     }
-    cout << ']';
+    std::cout << ']';
 }
 
 void CList::Dump2(void)
 {
-    cout << "[\n";
+    std::cout << "[\n";
     for (int i = 0; i < count; i++) {
         values[i].Dump(2);
-        cout << ",\n";
+        std::cout << ",\n";
     }
-    cout << "]\n";
+    std::cout << "]\n";
 }
 
 Content* CList::Clone(void)
 {
-    CList* list = new CList(*this);
+    auto* list = new CList(*this);
     return list;
 }
 
@@ -169,14 +172,14 @@ public:
         Function(n)
     {
         info = "Builds a list from its arguments";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
 
 Value ListFunction::Execute(int arity, Value* arg)
 {
-    CList* v = new CList(arity);
+    auto* v = new CList(arity);
 
     for (int i = 0; i < arity; i++)
         (*v)[i] = arg[i];
@@ -190,7 +193,7 @@ class ListCountFunction : public Function
 {
 public:
     ListCountFunction(const char* n) :
-        Function(n, 1, tlist){};
+        Function(n, 1, tlist) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -208,7 +211,7 @@ class ListElemFunction : public Function
 {
 public:
     ListElemFunction(const char* n) :
-        Function(n, 2, tlist, tnumber){};
+        Function(n, 2, tlist, tnumber) {}
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 
@@ -277,8 +280,8 @@ Value ListElemFunction::Execute(int arity, Value* arg)
             return (*v)[n - 1];
 
 
-        int c    = (m - n) / s + 1;
-        CList* l = new CList(c);
+        int c   = (m - n) / s + 1;
+        auto* l = new CList(c);
         int i, j;
 
         for (i = 0, j = n - 1; i < c; i++, j += s)
@@ -295,7 +298,7 @@ Value ListElemFunction::Execute(int arity, Value* arg)
         arg[1].GetValue(vi);
 
         // the result vector
-        CList* vnew = new CList(vi->Count());
+        auto* vnew = new CList(vi->Count());
         for (int i = 0; i < vi->Count(); i++) {
             int index = vi->getIndexedValue(i);
             if (index < 1 || index > v->Count())
@@ -314,7 +317,7 @@ class ListAddFunction : public Function
 {
 public:
     ListAddFunction(const char* n) :
-        Function(n, 2, tlist, tlist){};
+        Function(n, 2, tlist, tlist) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -328,7 +331,7 @@ Value ListAddFunction::Execute(int, Value* arg)
     arg[1].GetValue(v2);
 
 
-    CList* v = new CList(v1->Count() + v2->Count());
+    auto* v = new CList(v1->Count() + v2->Count());
 
     int i, n = 0;
 
@@ -350,7 +353,7 @@ public:
         Function(n, 2, tany, tlist)
     {
         info = "Test if a value is in a list";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -390,7 +393,7 @@ public:
         Function(n, 2, tany, tlist)
     {
         info = "Find where an item occurs in a list";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -429,7 +432,7 @@ Value ListFindFunction::Execute(int arity, Value* arg)
     arg[0].GetValue(v);
 
 
-    vector<int> results;  // only need a vector if we're looking for more than 1 result
+    std::vector<int> results;  // only need a vector if we're looking for more than 1 result
 
     int baseIndex = Context::BaseIndex();
     for (int i = 0; i < v->Count(); i++) {
@@ -457,7 +460,7 @@ Value ListFindFunction::Execute(int arity, Value* arg)
 
     if (findAll) {
         if (results.size() > 0) {
-            CList* outlist = new CList(results.size());
+            auto* outlist = new CList(results.size());
 
             for (unsigned int i = 0; i < results.size(); i++) {
                 (*outlist)[i] = results[i];
@@ -491,7 +494,7 @@ public:
         ReturnType(t)
     {
         info = "Sorts a list or indices (sort/sort_indices/sort_and_indices)";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -554,7 +557,7 @@ Value ListSortFunction::Execute(int arity, Value* arg)
 
     qsort(x, SortList->Count(), sizeof(int), Sort);
 
-    CList* c = new CList(SortList->Count());
+    auto* c = new CList(SortList->Count());
 
     int baseIndex = Context::BaseIndex();
     switch (ReturnType) {
@@ -570,9 +573,9 @@ Value ListSortFunction::Execute(int arity, Value* arg)
 
         case 3:  //-- 'sorted list and indices'
             for (i = 0; i < SortList->Count(); i++) {
-                CList* pair = new CList(2);  //- memory leak here!?
-                (*pair)[0]  = (*SortList)[x[i]];
-                (*pair)[1]  = x[i] + baseIndex;  //- indices from 1: 1,2,3,...
+                auto* pair = new CList(2);  //- memory leak here!?
+                (*pair)[0] = (*SortList)[x[i]];
+                (*pair)[1] = x[i] + baseIndex;  //- indices from 1: 1,2,3,...
 
                 (*c)[i] = Value(pair);
             }
@@ -594,12 +597,12 @@ public:
         Function(n, 1, tlist)
     {
         info = "Returns a list with all the unique items in the input list";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
 
-Value ListUniqueFunction::Execute(int arity, Value* arg)
+Value ListUniqueFunction::Execute(int /*arity*/, Value* arg)
 {
     CList* v;
     char* in = strcache("in");
@@ -608,7 +611,7 @@ Value ListUniqueFunction::Execute(int arity, Value* arg)
 
     arg[0].GetValue(v);
 
-    CList* list = new CList(0);  // start with an empty list and add one element at a time
+    auto* list = new CList(0);  // start with an empty list and add one element at a time
 
     Value list_as_value(list);
 
@@ -667,7 +670,7 @@ Value ListListBinOp::Execute(int, Value* arg)
         return Value();
     }
 
-    CList* p = new CList(v->Count());
+    auto* p = new CList(v->Count());
 
     int count = v->Count();
     for (int i = 0; i < count; i++) {
@@ -732,7 +735,7 @@ Value NumListBinOp::Execute(int, Value* arg)
             arg[0].GetValue(n);
         arg[1].GetValue(v);
 
-        CList* p = new CList(v->Count());
+        auto* p = new CList(v->Count());
 
         // for each point, compute
 
@@ -758,7 +761,7 @@ Value NumListBinOp::Execute(int, Value* arg)
         else
             arg[1].GetValue(n);
 
-        CList* p = new CList(v->Count());
+        auto* p = new CList(v->Count());
 
 
         // for each point, compute
