@@ -7,12 +7,12 @@
 
  ***************************** LICENSE END *************************************/
 
-#include "macro.h"
-#include <string>
 #include <ctype.h>
 #include <string.h>
 
-using std::string;
+#include <string>
+
+#include "macro.h"
 
 //=============================================================================
 
@@ -24,8 +24,8 @@ int CString::Write(FILE* f)
 
 void CString::ToRequest(request*& x)
 {
-    static request* r = 0;
-    if (r == 0)
+    static request* r = nullptr;
+    if (r == nullptr)
         r = empty_request("STRING");
     set_value(r, "VALUE", "%s", string);
     x = r;
@@ -35,7 +35,7 @@ class StringFunction : public Function
 {
 public:
     StringFunction(const char* n) :
-        Function(n, 1, tany){};
+        Function(n, 1, tany) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -47,18 +47,18 @@ void CString::Dump1()
     char* p = string;
     while (*p) {
         if (isprint(*p))
-            cout << *p;
+            std::cout << *p;
         else
-            cout << '<' << (int)*p << '>';
+            std::cout << '<' << (int)*p << '>';
         p++;
     }
 }
 
 void CString::Dump2()
 {
-    cout << "'";
+    std::cout << "'";
     Dump1();
-    cout << "'";
+    std::cout << "'";
 }
 
 
@@ -76,7 +76,7 @@ public:
         Function(n)
     {
         info = "Splits a string into tokens.";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -139,7 +139,7 @@ Value ParseFunction::Execute(int arity, Value* arg)
             return Error("the parse() function currently only accepts 'string' as its third argument. It was given '%s'", type);
     }
 
-    CList* l = 0;
+    CList* l = nullptr;
 
     if (*q == '\0')  //-- empty delimiter => split into single chars
     {
@@ -162,7 +162,7 @@ Value ParseFunction::Execute(int arity, Value* arg)
         int cnt = 0;
         while (strtok(t, q)) {
             cnt++;
-            t = 0;
+            t = nullptr;
         }
 
         t = s;
@@ -178,7 +178,7 @@ Value ParseFunction::Execute(int arity, Value* arg)
                 (*l)[i] = Value(atof(a));
             else
                 (*l)[i] = Value(a);
-            t = 0;
+            t = nullptr;
             i++;
         }
 
@@ -196,7 +196,7 @@ public:
         Function(n)
     {
         info = "Returns a substring.";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -215,7 +215,7 @@ int SubstringFunction::ValidArguments(int arity, Value* arg)
 
     return true;
 }
-Value SubstringFunction::Execute(int arity, Value* arg)
+Value SubstringFunction::Execute(int /*arity*/, Value* arg)
 {
     const char* s;
     arg[0].GetValue(s);  //-- original string
@@ -251,11 +251,11 @@ public:
         Function(n, 2, tstring, tstring)
     {
         info = "Search for a given substring.";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
-Value StringSearchFunction::Execute(int arity, Value* arg)
+Value StringSearchFunction::Execute(int /*arity*/, Value* arg)
 {
     const int cNotFound = -1;
 
@@ -290,7 +290,7 @@ class StringAddFunction : public Function
 public:
     StringAddFunction(const char* n) :
         Function(n, 2, tstring | tnumber | tdate,
-                 tstring | tnumber | tdate){};
+                 tstring | tnumber | tdate) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -299,10 +299,10 @@ Value StringAddFunction::Execute(int, Value* arg)
     const char* c;
 
     arg[0].GetValue(c);
-    string s = c;
+    std::string s = c;
 
     arg[1].GetValue(c);
-    string s2 = c;
+    std::string s2 = c;
 
     s = s + s2;
 
@@ -324,7 +324,7 @@ public:
 
 Value LengthFunction::Execute(int, Value* arg)
 {
-    const char* p = 0;
+    const char* p = nullptr;
     arg[0].GetValue(p);
     return Value(p ? strlen(p) : 0);
 }
@@ -406,7 +406,7 @@ public:
 
 Value NumberFunction::Execute(int, Value* arg)
 {
-    const char* p = 0;
+    const char* p = nullptr;
     arg[0].GetValue(p);
     double d = atof(p);
     return Value(d);
@@ -444,7 +444,7 @@ static int s_le(const char* a, const char* b)
 
 class StringCmpFunction : public Function
 {
-    typedef int (*cproc)(const char*, const char*);
+    using cproc = int (*)(const char*, const char*);
     cproc F_;
 
 public:
