@@ -7,13 +7,15 @@
 
  ***************************** LICENSE END *************************************/
 
+#include <map>
+#include <string>
+
 #include <math.h>
 #include <ctype.h>
 #include <float.h>
 #include <string.h>
 #include "macro.h"
 #include "arith.h"
-#include "inc_stl.h"
 #include "MvPath.hpp"
 #include "ctable.h"
 //#include "MvOdb.h"
@@ -37,7 +39,7 @@ CTable::CTable(request* s) :
         print_all_requests(r);
         /*
         const char* path = get_value(r,"PATH",0);
-        string s(path);
+        std::string s(path);
         table_.setPath(s);        */
     }
 }
@@ -54,7 +56,7 @@ CTable::CTable(const char* p, int temp) :
 
     if (r) {
         const char* path = get_value(r, "PATH", 0);
-        string s(path);
+        std::string s(path);
         table_.setPath(s);
         /*
         const char *delimiter = get_value(r,"DELIMITER",0);
@@ -139,14 +141,14 @@ int CTable::Write(FILE* /*f*/)
 
 /*CGeopts::CGeopts(long count) : InPool(tgeopts)
 {
-    r = NULL;
+    r = nullptr;
     gpts.newReservedSize (count);
 }*/
 
 
 /*CGeopts::CGeopts(CGeopts  *p) : InPool(tgeopts)
 {
-    r = NULL;
+    r = nullptr;
     p->load();
     gpts = p->gpts;
 }*/
@@ -357,7 +359,7 @@ Value TableReadWithParamsFunction::Execute(int arity, Value* arg)
     // find the file that we want to load
 
     //const char *p = get_value(request,"FILENAME",0);
-    CTable* table = new CTable(r);
+    auto* table = new CTable(r);
 
     if (!table->constructedOk()) {
         return Error("read_table: could not read table because of previous error");
@@ -374,7 +376,7 @@ class TableCountFunction : public Function
 {
 public:
     TableCountFunction(const char* n) :
-        Function(n, 1, ttable){};
+        Function(n, 1, ttable) {}
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -439,7 +441,7 @@ Value TableValuesFunction::Execute(int, Value* arg)
     if (fieldFromName_) {
         const char* colName;
         arg[1].GetValue(colName);  // second arg is the name of the desired column
-        string strColName(colName);
+        std::string strColName(colName);
         col = ctable->column(strColName);  // get the relevant column
 
         if (!col) {
@@ -474,15 +476,15 @@ Value TableValuesFunction::Execute(int, Value* arg)
     Content* c = 0;
 
     if (col->type() == MvTableColumn::COL_NUMBER) {
-        CVector* v = new CVector(col->count());  // vectors can only hold numbers
-        c          = v;
+        auto* v = new CVector(col->count());  // vectors can only hold numbers
+        c       = v;
         for (int i = 0; i < col->count(); i++) {
             v->setIndexedValue(i, col->dVals().at(i));
         }
     }
     else if (col->type() == MvTableColumn::COL_STRING) {
-        CList* v = new CList(col->count());  // we need a list to hold strings
-        c        = v;
+        auto* v = new CList(col->count());  // we need a list to hold strings
+        c       = v;
         for (int i = 0; i < col->count(); i++) {
             (*v)[i] = col->sVals().at(i).c_str();
         }
@@ -554,7 +556,7 @@ Value TableMetaDataKeysFunction::Execute(int, Value* arg)
     arg[0].GetValue(ctable);  // first arg is a table
     ctable->load();
 
-    map<string, string> metadata = ctable->userMetaData();
+    std::map<std::string, std::string> metadata = ctable->userMetaData();
 
 
     if (metadata.empty())  // no meta-data? return 'nil'
@@ -563,10 +565,10 @@ Value TableMetaDataKeysFunction::Execute(int, Value* arg)
 
     // now construct a list of keys from the meta-data
 
-    CList* v = new CList(metadata.size());  // we need a list to hold strings
+    auto* v = new CList(metadata.size());  // we need a list to hold strings
 
-    map<string, string>::iterator iter     = metadata.begin();
-    map<string, string>::iterator iter_end = metadata.end();
+    auto iter     = metadata.begin();
+    auto iter_end = metadata.end();
 
     int i = 0;
     while (iter != iter_end) {
@@ -582,7 +584,7 @@ Value TableMetaDataKeysFunction::Execute(int, Value* arg)
 
 class TableMetaDataValueFunction : public Function
 {
-    map<string, string> metadata_;
+    std::map<std::string, std::string> metadata_;
     enum eModeType
     {
         SINGLE,
@@ -632,10 +634,10 @@ int TableMetaDataValueFunction::ValidArguments(int arity, Value* arg)
 
 Value TableMetaDataValueFunction::GetMetaDataFromKey(const char* key)
 {
-    string value;
+    std::string value;
 
     if (metadata_.count(key)) {
-        value = metadata_[string(key)];
+        value = metadata_[std::string(key)];
         return Value(value.c_str());
     }
     else {
@@ -671,7 +673,7 @@ Value TableMetaDataValueFunction::Execute(int, Value* arg)
     {
         CList* keys;
         arg[1].GetValue(keys);
-        CList* values = new CList(keys->Count());
+        auto* values = new CList(keys->Count());
 
         for (int i = 0; i < keys->Count(); i++) {
             const char* key;
