@@ -204,6 +204,13 @@ static const char* low(const char* s, int under, int clean)
     return buf;
 }
 
+static void printCannotImport(FILE* f, const char* icon)
+{
+    fprintf(f, "# Warning: cannot import : %s\n", icon);
+    fprintf(f, "# Using the metview function, not available in batch\n\n");
+    fprintf(f, "%s = metview(\"%s\")\n\n", low(mbasename(icon), 1, 1), icon);
+}
+
 static void importing(FILE* f, const char* icon)
 {
     static char* tag = NULL;
@@ -503,7 +510,7 @@ static void import_values(FILE* f, request* r, parameter* p)
 
 static boolean import_simple_formula(FILE* f, const char* icon, request* r)
 {
-    request *lang;
+    request* lang;
     import_sub_objects(f, icon, r, NULL);
 
     lang = get_language(r->name);
@@ -854,6 +861,28 @@ boolean import_rttov_visualiser(FILE* f, const char* icon, request* r)
     return import_request(f, icon, r, NULL);
 }
 
+boolean import_weather_symbol(FILE* f, const char* icon, const char* className)
+{
+    char buf[1024];
+    request* r  = NULL;
+    boolean ret = false;
+    if (strcmp(className, "WS_COLLECTION") == 0) {
+        r = empty_request("WS_COLLECTION");
+        set_value(r, "PATH", icon);
+        ret = import_request(f, icon, r, NULL);
+    }
+    else {
+        const char* fTmp = marstmp();
+        sprintf(buf, "$METVIEW_BIN/MvWsToRequest \"%s\" %s", icon, fTmp);
+        if (system(buf) == 0) {
+            r   = read_request_file(fTmp);
+            ret = import_request(f, icon, r, NULL);
+        }
+    }
+    free_all_requests(r);
+    return ret;
+}
+
 const char* import(FILE* f, const char* name, const char* className)
 {
     char buf[1024];
@@ -875,6 +904,26 @@ const char* import(FILE* f, const char* name, const char* className)
     else
         sprintf(buf, "%s/%s", mvhome, icon);
 
+    if (className) {
+        strcpy(cname, className);
+        c = &cname[0];
+    }
+    //If the classname is not present we need to find out the iconclass from
+    //the folder-level dot file
+    else {
+        if (get_iconClass(buf, cname) == 0)
+            c = &cname[0];
+    }
+
+    /* We handle Weather Symbols (GeoJSON) first */
+    if (c && strncmp(c, "WS_", 3) == 0) {
+        if (!import_weather_symbol(f, buf, c)) {
+            importing(f, icon);
+            printCannotImport(f, icon);
+        }
+        return low(mbasename(icon), 1, 1);
+    }
+
     r = read_request_file(buf);
 
     /*We need to read the request again (into *u) otherwise mars cannot read the 
@@ -891,17 +940,6 @@ const char* import(FILE* f, const char* name, const char* className)
 
     u = read_request_file(buf);
 
-    if (className) {
-        strcpy(cname, className);
-        c = &cname[0];
-    }
-    //If the classname is not present we need to find out the iconclass from
-    //the folder-level dot file
-    else {
-        if (get_iconClass(buf, cname) == 0)
-            c = &cname[0];
-    }
-
     if (c) {
         if (strcmp(c, "NOTE") == 0)
             ok = import_note(f, icon, buf);
@@ -951,11 +989,12 @@ const char* import(FILE* f, const char* name, const char* className)
 
     if (!ok) {
         importing(f, icon);
-        fprintf(f, "# Warning: cannot import : %s\n", icon);
-        fprintf(f, "# Using the metview function, not available in batch\n\n");
-        fprintf(f, "%s = metview(\"%s\")\n\n", low(mbasename(icon), 1, 1), icon);
-        /* print_all_requests(r); */
-        /* print_all_requests(u); */
+        printCannotImport(f, icon);
+        //        fprintf(f, "# Warning: cannot import : %s\n", icon);
+        //        fprintf(f, "# Using the metview function, not available in batch\n\n");
+        //        fprintf(f, "%s = metview(\"%s\")\n\n", low(mbasename(icon), 1, 1), icon);
+        //        /* print_all_requests(r); */
+        //        /* print_all_requests(u); */
     }
 
     free_all_requests(r);
