@@ -99,7 +99,7 @@ CList* CNetCDF::Variables()
     load();
 
     int count = netCDF_->getNumberOfVariables();
-    CList* l  = new CList(count);
+    auto* l   = new CList(count);
 
     for (int i = 0; i < count; i++)
         (*l)[i] = netCDF_->getVariable(i)->name();
@@ -133,7 +133,7 @@ MvRequest CNetCDF::Attributes(bool global)
                     strncpy(shortened_att, s, NUM_CHARS_IN_ADD_VALUE - 1);
                     shortened_att[NUM_CHARS_IN_ADD_VALUE - 1] = '\0';
                     free(s);
-                    s                                         = &(shortened_att[0]);
+                    s = &(shortened_att[0]);
                 }
                 req.addValue(tmpatt->name(), s);
             }
@@ -170,7 +170,7 @@ public:
         Function(n, 2, tnetcdf, tany)
     {
         info = "Sets the variable number on which netcdf functions will operate.";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -224,7 +224,7 @@ public:
         Function(n, 1, tnetcdf)
     {
         info = "Returns a list of the names of the given netcdf file's variables.";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -244,7 +244,7 @@ public:
         Function(n, 1, tnetcdf)
     {
         info = "Returns the attributes of the current NetCDF variable";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -264,7 +264,7 @@ public:
         Function(n, 1, tnetcdf)
     {
         info = "Returns a definition variable holding the netcdf's global metadata.";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -286,7 +286,7 @@ public:
         Function(n)
     {
         info = "Returns a list containing all the values for the current netcdf variable.";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
     virtual int ValidArguments(int arity, Value* arg);
 };
@@ -343,7 +343,7 @@ Value CDFValuesFunction::Execute(int, Value* arg)
             char str[string_length + 1];
             str[string_length] = '\0';  //-- terminating NULL
 
-            CList* list = new CList(num_values);  //-- we need a list to hold strings
+            auto* list = new CList(num_values);  //-- we need a list to hold strings
 
             long elem = 0;
             for (long string = 0; string < num_values; ++string)  //-- for each string...
@@ -377,8 +377,8 @@ Value CDFValuesFunction::Execute(int, Value* arg)
             */
 
             if (listOfDims) {
-                vector<long> vPositionList;
-                vector<long> vCountList;
+                std::vector<long> vPositionList;
+                std::vector<long> vCountList;
                 CList* positions;  // user-supplied list of position indexes
                 arg[1].GetValue(positions);
 
@@ -430,8 +430,8 @@ Value CDFValuesFunction::Execute(int, Value* arg)
 
                 if (aVar->isTime() && aVar->options().translateTime())  // time-based variable to be translated to date?)
                 {
-                    CList* list = new CList(num_values);
-                    vector<MvDate> vd;  // output vector
+                    auto* list = new CList(num_values);
+                    std::vector<MvDate> vd;  // output vector
 
                     aVar->setCurrent(&(vPositionList[0]));
                     aVar->getDates(vd, &(vCountList[0]));
@@ -444,8 +444,8 @@ Value CDFValuesFunction::Execute(int, Value* arg)
 
                 else  // a vector of numbers
                 {
-                    CVector* vec = new CVector(num_values);  // output vector
-                    vector<double> vd;
+                    auto* vec = new CVector(num_values);  // output vector
+                    std::vector<double> vd;
 
                     aVar->setCurrent(&(vPositionList[0]));
                     aVar->get(vd, &(vCountList[0]));
@@ -464,7 +464,7 @@ Value CDFValuesFunction::Execute(int, Value* arg)
 
                 if (aVar->isTime() && aVar->options().translateTime())  // time-based variable to be translated to date?
                 {
-                    CList* list = new CList(num_values);
+                    auto* list = new CList(num_values);
 
                     for (long elem = 0; elem < num_values; ++elem) {
                         MvDate d = aVar->as_date(elem);
@@ -475,7 +475,7 @@ Value CDFValuesFunction::Execute(int, Value* arg)
                 }
                 else  // just a vector of numbers
                 {
-                    CVector* vec = new CVector(num_values);
+                    auto* vec = new CVector(num_values);
 
                     for (long elem = 0; elem < num_values; ++elem) {
                         double d = aVar->as_double(elem);
@@ -502,7 +502,7 @@ public:
         Function(n, 2, tnetcdf, tnumber)
     {
         info = "Returns the n:th value from the current netcdf variable.";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -578,7 +578,7 @@ public:
         Function(n, 1, tnetcdf)
     {
         info = "Returns a list of the netcdf's dimensions.";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -591,7 +591,7 @@ Value CDFDimFunction::Execute(int, Value* arg)
 
     long* edges = aVar->edges();
     int nrDims  = aVar->getNumberOfDimensions();
-    CList* l    = new CList(nrDims);
+    auto* l     = new CList(nrDims);
 
     for (int i = 0; i < nrDims; i++)
         (*l)[i] = edges[i];
@@ -606,7 +606,7 @@ public:
         Function(n, 1, tnetcdf)
     {
         info = "Returns a list of the netcdf's dimension names.";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -618,7 +618,7 @@ Value CDFDimNamesFunction::Execute(int, Value* arg)
     MvNcVar* aVar = a->GetVar();
 
     int nrDims = aVar->getNumberOfDimensions();
-    CList* l   = new CList(nrDims);
+    auto* l    = new CList(nrDims);
 
     for (int i = 0; i < nrDims; i++)
         (*l)[i] = aVar->getDimension(i)->name();
@@ -637,7 +637,7 @@ public:
         type(t)
     {
         info = "Sets the behaviour of netcdf value handling: 1=on, 0=off";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -698,7 +698,7 @@ Value CdfCdfBinOp::Execute(int, Value* arg)
     Path bPath(newName);
     aPath.copyData(bPath);  // ensure we copy the data and not just a link
 
-    CNetCDF* c = new CNetCDF(newName, 1, 'u');
+    auto* c = new CNetCDF(newName, 1, 'u');
     c->Current(a->Current());
 
     // Get the variables
@@ -706,7 +706,7 @@ Value CdfCdfBinOp::Execute(int, Value* arg)
     MvNcVar* bVar = b->GetVar();
     MvNcVar* cVar = c->GetVar();
 
-    vector<double> aValues, bValues;
+    std::vector<double> aValues, bValues;
 
     aVar->get(aValues, aVar->edges());
     bVar->get(bValues, aVar->edges());
@@ -714,7 +714,7 @@ Value CdfCdfBinOp::Execute(int, Value* arg)
     if (aValues.size() != bValues.size())
         return Error("Different dimensions on NetCDF variables");
 
-    double* cValues = new double[aValues.size()];
+    auto* cValues = new double[aValues.size()];
     for (unsigned int i = 0; i < aValues.size(); i++) {
         if (aValues[i] == NETCDF_MISSING_VALUE || bValues[i] == NETCDF_MISSING_VALUE)
             cValues[i] = NETCDF_MISSING_VALUE;
@@ -769,17 +769,17 @@ Value NumCdfBinOp::Execute(int, Value* arg)
     Path aPath(a->GetFileName());
     Path bPath(newName);
     aPath.copyData(bPath);  // ensure we copy the data and not just a link
-    CNetCDF* b = new CNetCDF(newName, 1, 'u');
+    auto* b = new CNetCDF(newName, 1, 'u');
     b->Current(a->Current());
 
     // Get the variables
     MvNcVar* aVar = a->GetVar();
     MvNcVar* bVar = b->GetVar();
 
-    vector<double> aValues;
+    std::vector<double> aValues;
     aVar->get(aValues, aVar->edges());
 
-    double* bValues = new double[aValues.size()];
+    auto* bValues = new double[aValues.size()];
 
     for (unsigned int i = 0; i < aValues.size(); i++) {
         if (aValues[i] == NETCDF_MISSING_VALUE) {
@@ -835,17 +835,17 @@ Value CdfUniOp::Execute(int, Value* arg)
     Path aPath(a->GetFileName());
     Path bPath(newName);
     aPath.copyData(bPath);  // ensure we copy the data and not just a link
-    CNetCDF* b = new CNetCDF(newName, 1, 'u');
+    auto* b = new CNetCDF(newName, 1, 'u');
     b->Current(a->Current());
 
     // Get the variables
     MvNcVar* aVar = a->GetVar();
     MvNcVar* bVar = b->GetVar();
 
-    vector<double> aValues;
+    std::vector<double> aValues;
     aVar->get(aValues, aVar->edges());
 
-    double* bValues = new double[aValues.size()];
+    auto* bValues = new double[aValues.size()];
 
     for (unsigned int i = 0; i < aValues.size(); i++) {
         if (aValues[i] == NETCDF_MISSING_VALUE)
