@@ -39,9 +39,9 @@ public:
 
 
 #ifdef METVIEW_ODB_NEW
-void init_odb(int argc, char **argv)
+void init_odb(int argc, char** argv)
 {
-        eckit::Main::initialise(argc, argv);
+    eckit::Main::initialise(argc, argv);
 }
 #endif
 
@@ -118,7 +118,7 @@ const char* p_call_function(const char* name, int arity)
 
     // if there was an error, we should return a CError value
     if (metviewPythonScript->GetError()) {
-        CError* ce          = new CError(1, "Error calling Metview function");
+        auto* ce            = new CError(1, "Error calling Metview function");
         metviewPythonResult = new Value(ce);
         return fname;
     }
@@ -134,7 +134,7 @@ const char* p_call_function(const char* name, int arity)
             // Special case if metzoom is defined: always call uPlotManager.
             // If setouput is also defined then ignore it.
             MvRequest req;
-            if (fname == strcache("metzoom") ) {
+            if (fname == strcache("metzoom")) {
                 req = Script::PlotReq;
                 PlotterFunction::SetPlotter("uPlotManager");
             }
@@ -156,7 +156,7 @@ const char* p_call_function(const char* name, int arity)
 
             // if there was an error, we should return a CError value
             if (metviewPythonScript->GetError()) {
-                CError* ce          = new CError(1, "Error calling Metview function");
+                auto* ce            = new CError(1, "Error calling Metview function");
                 metviewPythonResult = new Value(ce);
                 return fname;
             }
@@ -190,7 +190,7 @@ void p_push_request(void* req)
 
 void p_push_value(void* value)
 {
-    Value* val = (Value*)value;
+    auto* val = (Value*)value;
     metviewPythonScript->Push(*val);
 }
 
@@ -211,20 +211,20 @@ void p_push_datestring(const char* str)
 
 void p_push_list(void* lst)
 {
-    CList* l = (CList*)lst;
+    auto* l = (CList*)lst;
     metviewPythonScript->Push(l);
 }
 
 void p_push_vector_from_double_array(double* vals, int size, double numpy_missing_value)
 {
-    CVector* v = new CVector(vals, size, CArray::VALUES_F64);
+    auto* v = new CVector(vals, size, CArray::VALUES_F64);
     v->Replace(numpy_missing_value, VECTOR_MISSING_VALUE);  // convert missing values
     metviewPythonScript->Push(v);
 }
 
 void p_push_vector_from_float32_array(float* vals, int size, float numpy_missing_value)
 {
-    CVector* v = new CVector(vals, size, CArray::VALUES_F32);
+    auto* v = new CVector(vals, size, CArray::VALUES_F32);
     v->Replace(numpy_missing_value, VECTOR_F32_MISSING_VALUE);  // convert missing values
     metviewPythonScript->Push(v);
 }
@@ -399,7 +399,7 @@ Value* p_list_element_as_value(CList* lst, int i)
 CList* p_new_list(int size)
 {
     // XXX potential memory leak
-    CList* lst = new CList(size);
+    auto* lst = new CList(size);
     return lst;
 }
 
@@ -420,7 +420,7 @@ void p_add_value_from_pop_to_list(CList* lst, int i)
 
 MvRequest* p_new_request(const char* verb)
 {
-    MvRequest* req = new MvRequest(verb);
+    auto* req = new MvRequest(verb);
     return req;
 }
 
@@ -456,8 +456,8 @@ int p_get_req_num_params(Value* val)
     request* r;
     val->GetValue(r);
     if (r) {
-        MvRequest req(r, false, false);  // clone=false, free_req_on_destroy=false
-        return req.countParameters(false); //includeHidden=false
+        MvRequest req(r, false, false);     // clone=false, free_req_on_destroy=false
+        return req.countParameters(false);  //includeHidden=false
     }
     else
         return 0;  // NULL request pointer -> no parameters
@@ -502,7 +502,7 @@ void p_set_subvalue_from_arg_stack(Value* val)
 }
 
 
-void p_set_temporary(Value* val, int flag)
+void p_set_temporary(Value* /*val*/, int /*flag*/)
 {
     // implementation pending
 }
@@ -535,7 +535,7 @@ void p_destroy_value(Value* val)
 }
 }
 
-int main(int argc, char** argv)
+int main(int /*argc*/, char** /*argv*/)
 {
     /*
     p_init();
