@@ -134,7 +134,7 @@ SimpleNotify::~SimpleNotify()
 
 void SimpleNotify::trigger(void* data)
 {
-    Content* c = (Content*)data;
+    auto* c = (Content*)data;
 
     request* r = 0;
     request* s = empty_request(notify);
@@ -266,9 +266,9 @@ InPool::~InPool()
 
 //=============================================================================
 
-void CError::Print(void)
+void CError::Print()
 {
-    cout << "<error: " << msg << ">";
+    std::cout << "<error: " << msg << ">";
 }
 
 void CError::ToRequest(request*& x)
@@ -287,7 +287,7 @@ int ASync::RequestMax = 3;
 int ASync::RequestCnt = 0;
 char* ASync::Name     = 0;
 
-void ASync::Connect(void)
+void ASync::Connect()
 {
     if (Svc == 0) {
         Name = strcache(Context::UniqueName());
@@ -346,7 +346,7 @@ void ASync::Definition(svcid* id, request* s, void*)
 
 void ASync::Reply(svcid* id, request* s, void*)
 {
-    ASync* a = (ASync*)get_svc_ref(id);
+    auto* a = (ASync*)get_svc_ref(id);
 
     RequestCnt--;
 
@@ -395,11 +395,11 @@ void ASync::Reply(svcid* id, request* s, void*)
     }
 }
 
-request* ASync::Wait(void)
+request* ASync::Wait()
 {
     if (!Ready && Context::Trace())
-        cout << "# Line " << Context::CurrentLine()
-             << ": Waiting for asynchronious request" << endl;
+        std::cout << "# Line " << Context::CurrentLine()
+                  << ": Waiting for asynchronious request" << std::endl;
 
     while (!Ready && service_sync(Svc))
         ;
@@ -415,9 +415,9 @@ ASync::ASync(const char* n, request* s) :
 
     while (RequestCnt >= RequestMax) {
         if (Context::Trace())
-            cout << "# Line " << Context::CurrentLine()
-                 << ": " << RequestCnt << " request" << (RequestCnt > 1 ? "s " : " ")
-                 << "out. Maximum is " << RequestMax << ", waiting..." << endl;
+            std::cout << "# Line " << Context::CurrentLine()
+                      << ": " << RequestCnt << " request" << (RequestCnt > 1 ? "s " : " ")
+                      << "out. Maximum is " << RequestMax << ", waiting..." << std::endl;
         service_sync(Svc);
     }
 
@@ -440,14 +440,11 @@ ASync::ASync(const char* n, request* s) :
     Attach();  // 1 for the ref in call_service
 }
 
-ASync::~ASync()
-{
-    //   cout << "ASync Destructor " << endl;
-}
+ASync::~ASync() = default;
 
 //=============================================================================
 
-Value::NilValue *Value::nilvalue = 0;
+Value::NilValue* Value::nilvalue = 0;
 
 Value::Value(const char* name, request* r)
 {
@@ -459,7 +456,7 @@ Value::Value(const char* name, request* r, std::vector<Content*> attachedContent
 {
     c = new ASync(name, r);
     c->Attach();
-    ASync* async = (ASync*)c;
+    auto* async = (ASync*)c;
     async->SetAttachedContent(attachedContent);  // - see comments for attachedContent in value.h.
 }
 
@@ -495,8 +492,7 @@ void ASync::Sync(Value* v)
     // and we now want to release the input data)
     // - see comments for attachedContent in value.h.
 
-    for (vector<Value*>::size_type i = 0; i < attachedContent.size(); i++) {
-        Content* c = attachedContent[i];
+    for (auto c : attachedContent) {
         c->Detach();
     }
 
@@ -519,16 +515,14 @@ void ASync::AvoidDuplication(Content* c)
     // comes from the fact that the result fieldset is constructed from
     // a request, and knows nothing of other fieldsets or gribfiles.
 
-    if (c->GetType(NULL) == tgrib) {
+    if (c->GetType(nullptr) == tgrib) {
         // loop through all the attached content and only consider GRIBs
 
-        for (vector<Value*>::size_type i = 0; i < attachedContent.size(); i++) {
-            Content* a = attachedContent[i];
-
-            if ((a) && a->GetType(NULL) == tgrib)  // both are GRIB
+        for (auto a : attachedContent) {
+            if ((a) && a->GetType(nullptr) == tgrib)  // both are GRIB
             {
-                CGrib* cg1 = (CGrib*)c;  // the returned data
-                CGrib* cg2 = (CGrib*)a;  // the attached (input) data
+                auto* cg1 = (CGrib*)c;  // the returned data
+                auto* cg2 = (CGrib*)a;  // the attached (input) data
 
                 fieldset* fs1 = cg1->GetFieldset();
                 fieldset* fs2 = cg2->GetFieldset();
@@ -564,7 +558,7 @@ void ASync::AvoidDuplication(Content* c)
 }
 
 
-void Value::CleanUp(void)
+void Value::CleanUp()
 {
     c->Detach();
 }
@@ -587,9 +581,9 @@ Value::~Value()
 
 const char* Value::TypeName(vtype t)
 {
-    for (unsigned int i = 0; i < NUMBER(types); i++)
-        if (types[i].t == t)
-            return types[i].n;
+    for (auto& type : types)
+        if (type.t == t)
+            return type.n;
     return "unknown";
 }
 
@@ -597,9 +591,9 @@ vtype Value::NameType(const char* n)
 {
     if (n == 0)
         return tany;
-    for (unsigned int i = 0; i < NUMBER(types); i++)
-        if (strcmp(types[i].n, n) == 0)
-            return types[i].t;
+    for (auto& type : types)
+        if (strcmp(type.n, n) == 0)
+            return type.t;
     return tnone;
 }
 
@@ -633,11 +627,8 @@ void Value::SetContent(request* r)
         n++;
     };
 
-    Content* c;
-    CList* l = 0;
-
-    if (n != 1)
-        l = new CList(n);
+    Content* c = nullptr;
+    CList* l   = n != 1 ? new CList(n) : nullptr;
 
     int i = 0;
     while (r) {
@@ -709,22 +700,21 @@ void Value::SetContentRequest(request* r)
     }
 
     request* s = r;
-    int n = 0;
+    int n      = 0;
     while (s) {
         s = s->next;
         n++;
     };
 
-    Content* c;
-    CList* l = 0;
-    l = new CList(n);
+    Content* c = nullptr;
+    auto* l    = new CList(n);
 
     int i = 0;
     while (r) {
-        s = r->next;
+        s       = r->next;
         r->next = 0;
 
-        c = new CRequest(r);
+        c         = new CRequest(r);
         (*l)[i++] = Value(c);
 
         r->next = s;
@@ -735,7 +725,7 @@ void Value::SetContentRequest(request* r)
     SetContent(c);
 }
 
-const char* Content::TypeName(void)
+const char* Content::TypeName()
 {
     return Value::TypeName(type);
 }
@@ -751,47 +741,47 @@ void Content::Dump(int level)
 void Content::Perl(request* r)
 {
     request* s = r;
-    cout << "\n";
+    std::cout << "\n";
     if (r->next)
-        cout << "[\n";
+        std::cout << "[\n";
 
     while (s) {
         parameter* p = s->params;
-        cout << "bless({\n";
+        std::cout << "bless({\n";
         while (p) {
             if (*p->name != '_') {
-                cout << p->name << " => ";
+                std::cout << p->name << " => ";
 
 
                 value* v = p->values;
                 if (v && v->next)
-                    cout << '[';
+                    std::cout << '[';
                 value* w = v;
                 int vflg = 0;
 
                 while (w) {
                     if (vflg)
-                        cout << ',';
-                    cout << "'" << w->name << "'";
+                        std::cout << ',';
+                    std::cout << "'" << w->name << "'";
                     vflg++;
                     w = w->next;
                 }
 
                 if (v && v->next)
-                    cout << ']';
-                cout << ",\n";
+                    std::cout << ']';
+                std::cout << ",\n";
             }
             p = p->next;
         }
-        cout << "}, 'metview::" << s->name << "'),\n";
+        std::cout << "}, 'metview::" << s->name << "'),\n";
         s = s->next;
     }
     if (r->next)
-        cout << "\n]";
-    cout << "\n";
+        std::cout << "\n]";
+    std::cout << "\n";
 }
 
 void CNil::Dump2()
 {
-    cout << "undef";
+    std::cout << "undef";
 }
