@@ -28,10 +28,10 @@ static void info_cb(svcid* id, request* r, void* data)
     e->next = r->next;
     reply.SetContent(e);
 
-    e->next = 0;
+    e->next = nullptr;
     free_all_requests(e);
 
-    send_reply(id, 0);
+    send_reply(id, nullptr);
 }
 
 static void close_cb(svcid* id, request* r, void*)
@@ -39,7 +39,7 @@ static void close_cb(svcid* id, request* r, void*)
     print_all_requests(r);
     ready = true;
     reply = Value();  // Nil
-    send_reply(id, 0);
+    send_reply(id, nullptr);
 }
 
 //=============================================================================
@@ -51,7 +51,7 @@ public:
         Function(n, 1, trequest)
     {
         info = "Wait for user input";
-    };
+    }
     virtual Value Execute(int arity, Value* arg);
 };
 
@@ -64,7 +64,7 @@ Value InputFunction::Execute(int, Value* arg)
         add_service_callback(ASync::Svc, "CHANGE_WINDOW", info_cb, (void*)"change");
         //add_service_callback(ASync::Svc,"MOVE_CURSOR",   info_cb,0);
         //add_service_callback(ASync::Svc,"CONTENTS",      info_cb,0);
-        add_service_callback(ASync::Svc, "CLOSE_WINDOW", close_cb, 0);
+        add_service_callback(ASync::Svc, "CLOSE_WINDOW", close_cb, nullptr);
         first = 0;
     }
 
@@ -73,7 +73,7 @@ Value InputFunction::Execute(int, Value* arg)
 
     const char* id = get_value(r, "VISTOOL_ID", 0);
 
-    if (id == 0) {
+    if (id == nullptr) {
         request* e = empty_request("REGISTER");
 
 
