@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef CODEHELPERWIDGET_H
-#define CODEHELPERWIDGET_H
+#pragma once
 
 #include <QSettings>
 #include <QWidget>
@@ -27,7 +26,7 @@ class CodeHelperWidget : public QWidget
     Q_OBJECT
 
 public:
-    CodeHelperWidget(QWidget* parent=nullptr);
+    CodeHelperWidget(QWidget* parent = nullptr);
 
     bool canSupportLanguage() const;
     void setLanguage(LanguageHelper* language);
@@ -53,7 +52,11 @@ signals:
 private:
     void build();
 
-    enum HelpModeIndex {FunctionHelpIndex=0, ColourHelpIndex=1};
+    enum HelpModeIndex
+    {
+        FunctionHelpIndex = 0,
+        ColourHelpIndex   = 1
+    };
 
     bool built_;
     QStackedWidget* stackedW_;
@@ -64,5 +67,3 @@ private:
     EditorTheme* editorTheme_;
     QFont editorFont_;
 };
-
-#endif // CODEHELPERWIDGET_H
