@@ -20,7 +20,7 @@ CodeTemplateDialog::CodeTemplateDialog(QString& templateListFilePath, QWidget* p
     setupUi(this);  // this sets up GUI
 
 
-    QPushButton* insertButton = new QPushButton(tr("&Insert Template"));
+    auto* insertButton = new QPushButton(tr("&Insert Template"));
     insertButton->setDefault(true);
     buttonBox->addButton(insertButton, QDialogButtonBox::ActionRole);
 
@@ -137,11 +137,11 @@ void CodeTemplateDialog::reloadCodeTemplates(TabsSettings& tabSettings)
 // triggered when the selected item is changed
 // ---------------------------------------------------------------------------
 
-void CodeTemplateDialog::onItemChanged(QListWidgetItem* item, QListWidgetItem* previous)
+void CodeTemplateDialog::onItemChanged(QListWidgetItem* item, QListWidgetItem* /*previous*/)
 {
     //    emit insertFunctionName (item->text(0)); // emit a signal with the function name
     //    close();
-    if (item != NULL) {
+    if (item != nullptr) {
         int index = item->data(Qt::UserRole).toInt();
         previewPlainTextEdit->clear();
         previewPlainTextEdit->insertPlainText(templateCodeBodies_.at(index));
