@@ -13,7 +13,7 @@
 #include "FunctionListWidget.h"
 #include "FunctionInfoWidget.h"
 #include "VerbFunctionHelpWidget.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 #include <QStackedWidget>
 #include <QVBoxLayout>
@@ -23,48 +23,48 @@ FunctionHelpWidget::FunctionHelpWidget(QWidget* parent) :
     QWidget(parent),
     language_(nullptr)
 {
-    QVBoxLayout* vb = new QVBoxLayout(this);
-    vb->setContentsMargins(0,0,0,0);
+    auto* vb = new QVBoxLayout(this);
+    vb->setContentsMargins(0, 0, 0, 0);
     vb->setSpacing(0);
 
     stackedW_ = new QStackedWidget(this);
-    vb->addWidget(stackedW_,1);
+    vb->addWidget(stackedW_, 1);
 
     functionListW_ = new FunctionListWidget(this);
     stackedW_->addWidget(functionListW_);
-    Q_ASSERT(FunctionViewIndex == stackedW_->count()-1);
+    Q_ASSERT(FunctionViewIndex == stackedW_->count() - 1);
 
     verbHelper_ = new VerbFunctionHelpWidget(this);
     stackedW_->addWidget(verbHelper_);
-    Q_ASSERT(VerbHelpViewIndex == stackedW_->count()-1);
+    Q_ASSERT(VerbHelpViewIndex == stackedW_->count() - 1);
 
     functionInfoW_ = new FunctionInfoWidget(this);
     stackedW_->addWidget(functionInfoW_);
-    Q_ASSERT(FunctionInfoViewIndex == stackedW_->count()-1);
+    Q_ASSERT(FunctionInfoViewIndex == stackedW_->count() - 1);
 
-    connect(functionListW_,SIGNAL(helperRequested(VerbFunctionHelpFunction*,int)),
-            this, SLOT(showHelper(VerbFunctionHelpFunction*,int)));
+    connect(functionListW_, SIGNAL(helperRequested(VerbFunctionHelpFunction*, int)),
+            this, SLOT(showHelper(VerbFunctionHelpFunction*, int)));
 
-    connect(functionListW_,SIGNAL(webDocRequested(VerbFunctionHelpFunction*,int)),
-            this, SLOT(showWebDoc(VerbFunctionHelpFunction*,int)));
+    connect(functionListW_, SIGNAL(webDocRequested(VerbFunctionHelpFunction*, int)),
+            this, SLOT(showWebDoc(VerbFunctionHelpFunction*, int)));
 
-    connect(functionListW_,SIGNAL(insertRequested(QString)),
+    connect(functionListW_, SIGNAL(insertRequested(QString)),
             this, SIGNAL(insertRequested(QString)));
 
-    connect(verbHelper_,SIGNAL(functionListRequested()),
+    connect(verbHelper_, SIGNAL(functionListRequested()),
             this, SLOT(showFunctionList()));
 
-    connect(verbHelper_,SIGNAL(insertRequested(QString)),
+    connect(verbHelper_, SIGNAL(insertRequested(QString)),
             this, SIGNAL(insertRequested(QString)));
 
-    connect(functionInfoW_,SIGNAL(functionListRequested()),
+    connect(functionInfoW_, SIGNAL(functionListRequested()),
             this, SLOT(showFunctionList()));
 
-    connect(functionInfoW_,SIGNAL(insertRequested(QString)),
+    connect(functionInfoW_, SIGNAL(insertRequested(QString)),
             this, SIGNAL(insertRequested(QString)));
 
-    connect(functionInfoW_,SIGNAL(webDocRequested(VerbFunctionHelpFunction*,int)),
-            this, SLOT(showWebDoc(VerbFunctionHelpFunction*,int)));
+    connect(functionInfoW_, SIGNAL(webDocRequested(VerbFunctionHelpFunction*, int)),
+            this, SLOT(showWebDoc(VerbFunctionHelpFunction*, int)));
 }
 
 void FunctionHelpWidget::setLanguage(LanguageHelper* language)
@@ -89,15 +89,16 @@ void FunctionHelpWidget::setCodeEditorTheme(EditorTheme* theme, QFont font)
 
 bool FunctionHelpWidget::adjustContents(QString functionName, QString paramName)
 {
-    functionName = functionName.toLower();
-    paramName = paramName.toLower();
-    VerbFunctionHelpFunction *verb = nullptr;
-    VerbFunctionHelpParam* param = nullptr;
+    functionName                   = functionName.toLower();
+    paramName                      = paramName.toLower();
+    VerbFunctionHelpFunction* verb = nullptr;
+    VerbFunctionHelpParam* param   = nullptr;
 
 
     if (functionName.isEmpty()) {
         return false;
-    } else {
+    }
+    else {
         verb = verbHelper_->function(functionName);
     }
 
@@ -123,7 +124,8 @@ void FunctionHelpWidget::showHelper(VerbFunctionHelpFunction* fn, int descIndex)
     if (fn->iconClass()) {
         verbHelper_->showFunction(fn->name());
         stackedW_->setCurrentIndex(VerbHelpViewIndex);
-    } else {
+    }
+    else {
         functionListW_->selectFunction(fn, descIndex);
         functionInfoW_->showFunction(fn, descIndex);
         stackedW_->setCurrentIndex(FunctionInfoViewIndex);
@@ -138,11 +140,12 @@ void FunctionHelpWidget::showWebDoc(VerbFunctionHelpFunction* fn, int descIndex)
     QString web;
     if (fn->iconClass()) {
         web = language_->functionHelp()->iconUrl(fn);
-    } else if (descIndex >= 0) {
+    }
+    else if (descIndex >= 0) {
         QPair<QString, QString> desc = fn->descriptions()[descIndex];
-        QString webGroup = desc.first;
+        QString webGroup             = desc.first;
         if (!webGroup.isEmpty()) {
-            web = language_->functionHelp()->url(webGroup,fn->name());
+            web = language_->functionHelp()->url(webGroup, fn->name());
         }
     }
 
@@ -150,7 +153,7 @@ void FunctionHelpWidget::showWebDoc(VerbFunctionHelpFunction* fn, int descIndex)
         std::string err;
         if (!metview::openInBrowser(web.toStdString(), err)) {
             QMessageBox::warning(this, "Code editor - Metview",
-                             "Failed to show documentation in web browser!<br><br>" + QString::fromStdString(err));
+                                 "Failed to show documentation in web browser!<br><br>" + QString::fromStdString(err));
         }
     }
 }
