@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef FUNCTIONHELPWIDGET_H
-#define FUNCTIONHELPWIDGET_H
+#pragma once
 
 #include <QSettings>
 #include <QWidget>
@@ -45,12 +44,15 @@ public slots:
     void slotInsert();
 
 protected:
-    enum ViewIndex {FunctionViewIndex=0,VerbHelpViewIndex=1,FunctionInfoViewIndex=2};
+    enum ViewIndex
+    {
+        FunctionViewIndex     = 0,
+        VerbHelpViewIndex     = 1,
+        FunctionInfoViewIndex = 2
+    };
     LanguageHelper* language_;
     QStackedWidget* stackedW_;
     FunctionListWidget* functionListW_;
     VerbFunctionHelpWidget* verbHelper_;
     FunctionInfoWidget* functionInfoW_;
 };
-
-#endif // FUNCTIONHELPWIDGET_H
