@@ -33,7 +33,7 @@ FunctionInfoWidget::FunctionInfoWidget(QWidget* parent) :
 {
     ui_->setupUi(this);
 
-    connect(ui_->showFunctionListTb,SIGNAL(clicked()),
+    connect(ui_->showFunctionListTb, SIGNAL(clicked()),
             this, SIGNAL(functionListRequested()));
 
     ui_->macroLabel->setPixmap(QPixmap(":/macroEditor/macro.svg").scaledToHeight(20, Qt::SmoothTransformation));
@@ -41,23 +41,23 @@ FunctionInfoWidget::FunctionInfoWidget(QWidget* parent) :
 
     //Set css for the text formatting
     QString cssDoc =
-        "td {background: "+  MvQTheme::htmlTableBg().name() + "; color: " + MvQTheme::htmlTableText().name() +
+        "td {background: " + MvQTheme::htmlTableBg().name() + "; color: " + MvQTheme::htmlTableText().name() +
         "; padding-left: 4px; padding-right: 3px;}" +
-        "th {background: "+  MvQTheme::htmlTableBg().name() + "; color: " + MvQTheme::subText().name() +
-            "; padding-left: 4px; padding-right: 3px;}" ;
+        "th {background: " + MvQTheme::htmlTableBg().name() + "; color: " + MvQTheme::subText().name() +
+        "; padding-left: 4px; padding-right: 3px;}";
 
     ui_->descBrowser->setReadOnly(true);
     ui_->descBrowser->setWordWrapMode(QTextOption::WordWrap);
     ui_->descBrowser->document()->setDefaultStyleSheet(cssDoc);
 
-    connect(ui_->insertTb,SIGNAL(clicked()),
-        this, SLOT(slotInsert()));
+    connect(ui_->insertTb, SIGNAL(clicked()),
+            this, SLOT(slotInsert()));
 
-    connect(ui_->copyTb,SIGNAL(clicked()),
-        this, SLOT(slotCopy()));
+    connect(ui_->copyTb, SIGNAL(clicked()),
+            this, SLOT(slotCopy()));
 
-    connect(ui_->webDocTb,SIGNAL(clicked()),
-        this, SLOT(slotWebDoc()));
+    connect(ui_->webDocTb, SIGNAL(clicked()),
+            this, SLOT(slotWebDoc()));
 
     hideDescription();
 }
@@ -67,7 +67,7 @@ void FunctionInfoWidget::clear()
     ui_->functionNameLabel->setText("");
     ui_->descBrowser->clear();
     hideDescription();
-    fn_ = 0;
+    fn_ = nullptr;
 }
 
 void FunctionInfoWidget::hideDescription()
@@ -75,7 +75,7 @@ void FunctionInfoWidget::hideDescription()
     ui_->descBrowser->hide();
 }
 
-void FunctionInfoWidget::setLanguage(LanguageHelper *language)
+void FunctionInfoWidget::setLanguage(LanguageHelper* language)
 {
     clear();
     language_ = language;
@@ -90,18 +90,19 @@ void FunctionInfoWidget::showFunction(VerbFunctionHelpFunction* fn, int descInde
         return;
     }
 
-    fn_ = fn;
+    fn_        = fn;
     descIndex_ = descIndex;
-    Q_ASSERT(descIndex_ >=0);
+    Q_ASSERT(descIndex_ >= 0);
     ui_->functionNameLabel->setText("<b> " + fn_->name() + "()</b>");
 
     ui_->descBrowser->clear();
     QString txt = "<table width=\'100%\'>";
     txt += "<tr><th><b>Category</b></th><th><b>Description<b></th></tr>";
-    for (int i=0; i < fn->descriptions().size(); i++) {
+    for (int i = 0; i < fn->descriptions().size(); i++) {
         if (i != descIndex_) {
             txt += "<tr><td>" + fn->descriptions()[i].first + "</td><td>" + fn->descriptions()[i].second + "</td></tr>";
-        } else {
+        }
+        else {
             txt += "<tr><td>" + fn->descriptions()[i].first + "</td><td>" + fn->descriptions()[i].second + "</td></tr>";
         }
     }
@@ -116,12 +117,12 @@ void FunctionInfoWidget::showFunction(VerbFunctionHelpFunction* fn, int descInde
 bool FunctionInfoWidget::hasData() const
 {
     return (language_ && language_->hasVerbFunctionHelp() &&
-             !language_->functionHelp()->isEmpty());
+            !language_->functionHelp()->isEmpty());
 }
 
 void FunctionInfoWidget::slotInsert()
 {
-     if (fn_ && !fn_->name().isEmpty())
+    if (fn_ && !fn_->name().isEmpty())
         emit insertRequested(fn_->name() + "()");
 }
 
@@ -133,7 +134,7 @@ void FunctionInfoWidget::slotCopy()
 
 void FunctionInfoWidget::slotWebDoc()
 {
-    if(fn_)
+    if (fn_)
         emit webDocRequested(fn_, descIndex_);
 }
 
