@@ -30,16 +30,16 @@
 //
 //========================================================
 
-FunctionListDelegate::FunctionListDelegate(QWidget *parent) :
+FunctionListDelegate::FunctionListDelegate(QWidget* parent) :
     QStyledItemDelegate(parent)
 {
     borderPen_ = MvQTheme::pen("treeview", "border_pen");
 }
 
-void FunctionListDelegate::paint(QPainter *painter,const QStyleOptionViewItem &option,
-                   const QModelIndex& index) const
+void FunctionListDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option,
+                                 const QModelIndex& index) const
 {
-    QStyledItemDelegate::paint(painter,option,index);
+    QStyledItemDelegate::paint(painter, option, index);
 
     painter->save();
 
@@ -55,10 +55,10 @@ void FunctionListDelegate::paint(QPainter *painter,const QStyleOptionViewItem &o
     painter->restore();
 }
 
-QSize FunctionListDelegate::sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index ) const
+QSize FunctionListDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
-    QSize size=QStyledItemDelegate::sizeHint(option,index);
-    size+=QSize(0,2);
+    QSize size = QStyledItemDelegate::sizeHint(option, index);
+    size += QSize(0, 2);
     return size;
 }
 
@@ -98,26 +98,26 @@ QVariant FunctionListModel::data(const QModelIndex& index, int role) const
         return {};
     }
 
-    QPair<VerbFunctionHelpFunction*,int> item= data_->itemAtInTotal(index.row());
+    QPair<VerbFunctionHelpFunction*, int> item = data_->itemAtInTotal(index.row());
 
     //VerbFunctionHelpFunction *item = data_->itemAt(index.row());
     if (!item.first)
         return {};
 
     if (index.column() == 0) {
-        if (role ==  Qt::DecorationRole) {
-            if (IconClassHelp *ich = item.first->iconClass()) {
+        if (role == Qt::DecorationRole) {
+            if (IconClassHelp* ich = item.first->iconClass()) {
                 return QIcon(MvQTheme::icIconFile(ich->pixmap()));
             }
         }
-
-    } else if (index.column() == 1) {
+    }
+    else if (index.column() == 1) {
         if (role == Qt::DisplayRole)
             return item.first->name();
         else if (role == Qt::ToolTipRole)
             return item.first->descriptionAsRt(item.second);
-
-    } else if (index.column() == 2) {
+    }
+    else if (index.column() == 2) {
         if (role == Qt::DisplayRole)
             return item.first->descriptionAsStr(item.second);
         else if (role == Qt::ToolTipRole)
@@ -132,29 +132,30 @@ QVariant FunctionListModel::data(const QModelIndex& index, int role) const
 QVariant FunctionListModel::headerData(const int section, const Qt::Orientation orient,
                                        const int role) const
 {
-    if (orient  == Qt::Vertical)
+    if (orient == Qt::Vertical)
         return {};
 
     if (role == Qt::DisplayRole) {
         if (section == 0)
             return tr("I");
-        else if(section == 1)
+        else if (section == 1)
             return tr("Function");
-        else if(section == 2)
+        else if (section == 2)
             return tr("Description");
-    } else if (role == Qt::ToolTipRole) {
+    }
+    else if (role == Qt::ToolTipRole) {
         if (section == 0)
             return tr("Icon representation of icon functions");
-        else if(section == 1)
+        else if (section == 1)
             return tr("Name of the built-in function");
-        else if(section == 2)
+        else if (section == 2)
             return tr("Description of the built-in function");
     }
 
     return {};
 }
 
-Qt::ItemFlags FunctionListModel::flags(const QModelIndex &index) const
+Qt::ItemFlags FunctionListModel::flags(const QModelIndex& index) const
 {
     if (!index.isValid())
         return QAbstractItemModel::flags(index) | Qt::ItemIsDropEnabled;
@@ -177,7 +178,7 @@ QModelIndex FunctionListModel::parent(const QModelIndex&) const
     return QModelIndex();
 }
 
-void FunctionListModel::reload(VerbFunctionHelp *data)
+void FunctionListModel::reload(VerbFunctionHelp* data)
 {
     beginResetModel();
     data_ = data;
@@ -210,9 +211,9 @@ int FunctionListModel::functionDescriptionIndex(const QModelIndex& idx)
 QModelIndex FunctionListModel::functionToIndex(VerbFunctionHelpFunction* fn, int descIndex)
 {
     if (data_) {
-        int row=data_->totalIndexOf(fn, descIndex);
+        int row = data_->totalIndexOf(fn, descIndex);
         if (row >= 0) {
-            return createIndex(row,0);
+            return createIndex(row, 0);
         }
     }
     return {};
@@ -220,7 +221,7 @@ QModelIndex FunctionListModel::functionToIndex(VerbFunctionHelpFunction* fn, int
 
 QString FunctionListModel::scopePrefix() const
 {
-    return (data_)?(data_->scopePrefix()):QString();
+    return (data_) ? (data_->scopePrefix()) : QString();
 }
 
 //================================================
@@ -243,7 +244,7 @@ FunctionListWidget::FunctionListWidget(QWidget* parent) :
     ui_->tree->setRootIsDecorated(false);
     ui_->tree->setItemDelegate(new FunctionListDelegate(this));
 
-    model_ = new FunctionListModel(this);
+    model_     = new FunctionListModel(this);
     sortModel_ = new QSortFilterProxyModel(this);
     sortModel_->setDynamicSortFilter(true);
     sortModel_->setFilterKeyColumn(1);
@@ -263,7 +264,7 @@ FunctionListWidget::FunctionListWidget(QWidget* parent) :
     // context menu
     ui_->tree->addAction(ui_->actionInsert);
     ui_->tree->addAction(ui_->actionCopy);
-    QAction *sep = new QAction(this);
+    auto* sep = new QAction(this);
     sep->setSeparator(true);
     ui_->tree->addAction(sep);
     ui_->tree->addAction(ui_->actionIconParam);
@@ -293,14 +294,14 @@ FunctionListWidget::FunctionListWidget(QWidget* parent) :
     connect(ui_->actionFontSizeUp, SIGNAL(triggered()),
             this, SLOT(slotFontSizeUp()));
 
-    connect(ui_->tree->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-            this, SLOT(slotCurrentChanged(QModelIndex,QModelIndex)));
+    connect(ui_->tree->selectionModel(), SIGNAL(currentChanged(QModelIndex, QModelIndex)),
+            this, SLOT(slotCurrentChanged(QModelIndex, QModelIndex)));
 
     connect(ui_->tree, SIGNAL(doubleClicked(QModelIndex)),
             this, SLOT(slotDoubleClicked(QModelIndex)));
 
-    connect(ui_->actionInsert,SIGNAL(triggered()),
-        this, SLOT(slotInsert()));
+    connect(ui_->actionInsert, SIGNAL(triggered()),
+            this, SLOT(slotInsert()));
 
     connect(ui_->actionCopy, SIGNAL(triggered()),
             this, SLOT(slotCopy()));
@@ -340,7 +341,7 @@ void FunctionListWidget::showIconParams(const QModelIndex& idx)
 {
     checkButtonState();
     if (idx.isValid()) {
-        if (VerbFunctionHelpFunction *fn = model_->functionObj(sortModel_->mapToSource(idx)))
+        if (VerbFunctionHelpFunction* fn = model_->functionObj(sortModel_->mapToSource(idx)))
             emit helperRequested(fn,
                                  model_->functionDescriptionIndex(sortModel_->mapToSource(idx)));
     }
@@ -350,7 +351,7 @@ void FunctionListWidget::showWebDoc(const QModelIndex& idx)
 {
     checkButtonState();
     if (idx.isValid()) {
-        if (VerbFunctionHelpFunction *fn = model_->functionObj(sortModel_->mapToSource(idx)))
+        if (VerbFunctionHelpFunction* fn = model_->functionObj(sortModel_->mapToSource(idx)))
             emit webDocRequested(fn,
                                  model_->functionDescriptionIndex(sortModel_->mapToSource(idx)));
     }
@@ -376,7 +377,7 @@ void FunctionListWidget::slotIconParam()
 void FunctionListWidget::slotInsert()
 {
     QModelIndex idx = sortModel_->mapToSource(ui_->tree->currentIndex());
-    if(VerbFunctionHelpFunction* fn = model_->functionObj(idx)) {
+    if (VerbFunctionHelpFunction* fn = model_->functionObj(idx)) {
         QString v = fn->name();
         if (!v.isEmpty())
             emit insertRequested(model_->scopePrefix() + v + "()");
@@ -391,7 +392,7 @@ void FunctionListWidget::slotFilter(QString txt)
 void FunctionListWidget::slotCopy()
 {
     QModelIndex idx = sortModel_->mapToSource(ui_->tree->currentIndex());
-    if(VerbFunctionHelpFunction* fn = model_->functionObj(idx)) {
+    if (VerbFunctionHelpFunction* fn = model_->functionObj(idx)) {
         QString v = fn->name();
         if (!v.isEmpty())
             MvQ::toClipboard(model_->scopePrefix() + v + "()");
@@ -400,12 +401,12 @@ void FunctionListWidget::slotCopy()
 
 void FunctionListWidget::slotFontSizeDown()
 {
-    MvQ::changeFontSize(ui_->tree,-1);
+    MvQ::changeFontSize(ui_->tree, -1);
 }
 
 void FunctionListWidget::slotFontSizeUp()
 {
-    MvQ::changeFontSize(ui_->tree,1);
+    MvQ::changeFontSize(ui_->tree, 1);
 }
 
 void FunctionListWidget::selectFunction(VerbFunctionHelpFunction* fn, int descIndex)
@@ -436,8 +437,8 @@ void FunctionListWidget::checkButtonState()
 void FunctionListWidget::readSettins(QSettings& settings)
 {
     settings.beginGroup("FunctionListWidget");
-    MvQ::initTreeColumnWidth(settings, "treeWidth", ui_->tree);    
-    MvQ::setFontSize(ui_->tree,settings.value("fontSize").toInt());
+    MvQ::initTreeColumnWidth(settings, "treeWidth", ui_->tree);
+    MvQ::setFontSize(ui_->tree, settings.value("fontSize").toInt());
     settings.endGroup();
 }
 
@@ -445,7 +446,6 @@ void FunctionListWidget::writeSettings(QSettings& settings)
 {
     settings.beginGroup("FunctionListWidget");
     MvQ::saveTreeColumnWidth(settings, "treeWidth", ui_->tree);
-    settings.setValue("fontSize",ui_->tree->font().pointSize());
+    settings.setValue("fontSize", ui_->tree->font().pointSize());
     settings.endGroup();
 }
-
