@@ -66,8 +66,8 @@ MacroRunTask::MacroRunTask(MacroEdit* editor, QString macro, MacroRunOptions opt
     // to enable communication to the editor, we need to use
     // signals and slots.
 
-    connect(this, SIGNAL(sendMessageToLog(const string&)),
-            editor_, SLOT(logMessage(const string&)));
+    connect(this, SIGNAL(sendMessageToLog(const std::string&)),
+            editor_, SLOT(logMessage(const std::string&)));
 
     connect(this, SIGNAL(sendMacroFinishedMsg(int)),
             editor_, SLOT(macroFinished(int)));
@@ -155,7 +155,8 @@ void MacroRunTask::start()
             QFileInfo fInfo(macro_);
             proc_->setWorkingDirectory(fInfo.dir().path());
             proc_->start("python3", QStringList() << macro_);
-        } else {
+        }
+        else {
             QString command = editor_->languageHelper()->serviceName();
             command.replace("%s", macro_);
             proc_->start("/bin/sh", QStringList() << "-c" << command);
@@ -214,7 +215,7 @@ void MacroRunTask::progress(const MvRequest&)
 // Here, we just pass the given message string to the editor's message log.
 // ---------------------------------------------------------------------------
 
-void MacroRunTask::message(const string& msg)
+void MacroRunTask::message(const std::string& msg)
 {
     // Macro can encode special messages which only the Macro Editor will interpret
     // They start with 'MACROEDITOR:' and are followed by a command and possibly
@@ -247,7 +248,7 @@ void MacroRunTask::slotProcStdOutput()
         return;
 
     auto s = proc_->readAllStandardOutput();
-//    qDebug() << "stdout" << s;
+    //    qDebug() << "stdout" << s;
     message(s.toStdString());
 }
 
@@ -256,7 +257,8 @@ void MacroRunTask::slotProcFinished(int exitCode, QProcess::ExitStatus exitStatu
     if (!proc_)
         return;
 #ifdef MACROEDIT_DEBUG__
-    qDebug() << "slotProcFinished" << "exitCode=" << exitCode << "exitStatus" << exitStatus;
+    qDebug() << "slotProcFinished"
+             << "exitCode=" << exitCode << "exitStatus" << exitStatus;
 #endif
     // get remaining stdout (it is merged with stderr)
     QString stdOutTxt(proc_->readAllStandardOutput());
@@ -282,7 +284,7 @@ void MacroRunTask::slotProcFinished(int exitCode, QProcess::ExitStatus exitStatu
     emit sendMacroFinishedMsg((exitCode > 0) ? exitCode : 1);
 }
 
-void MacroRunTask::print(ostream&) const
+void MacroRunTask::print(std::ostream&) const
 {
     /*     s << "MacroRunTask[" 
       << action_.name() 
@@ -306,7 +308,7 @@ class ReplyHandler : public MvReply
 
 void ReplyHandler::callback(MvRequest& in)
 {
-    ReplyObserverH* s = (ReplyObserverH*)getReference();
+    auto* s = (ReplyObserverH*)getReference();
     if (s == 0)
         return;
 
@@ -329,7 +331,7 @@ class ProgressHandler : public MvProgress
 
 void ProgressHandler::callback(MvRequest& in)
 {
-    ReplyObserverH* s = (ReplyObserverH*)getReference();
+    auto* s = (ReplyObserverH*)getReference();
     if (s == 0)
         return;
 
@@ -365,11 +367,9 @@ ReplyObserver::ReplyObserver(QObject* parent) :
     static ReplyHandler replyHandler;
 }
 
-ReplyObserver::~ReplyObserver()
-{
-}
+ReplyObserver::~ReplyObserver() = default;
 
-void ReplyObserver::callService(const string& service, const MvRequest& r)
+void ReplyObserver::callService(const std::string& service, const MvRequest& r)
 {
     MvApplication::callService(service.c_str(), r, new ReplyObserverH(this));
 }
@@ -391,7 +391,7 @@ MacroEdit::MacroEdit(QString appName, QWidget* parent, QString* fileToLoad) :
     findDialog_(0),
     gotoLineDialog_(0),
     tabsDialog_(0),
-    runDialog_(0), 
+    runDialog_(0),
     codeTemplateDialog_(0),
     rowColLabel_(0),
     messageLabel_(0),
@@ -411,10 +411,10 @@ MacroEdit::MacroEdit(QString appName, QWidget* parent, QString* fileToLoad) :
     MvQ::showShortcutInContextMenu(this);
 
     // This code causes a crash on MacOS Big Sur with Qt6.0.2 so it is commented out!
-//#ifdef __APPLE__
-//    // Set this to false if you want non-native menus on Mac OS X (i.e. menus are the same as under Linux)
-//    menuBar()->setNativeMenuBar(false);
-//#endif
+    //#ifdef __APPLE__
+    //    // Set this to false if you want non-native menus on Mac OS X (i.e. menus are the same as under Linux)
+    //    menuBar()->setNativeMenuBar(false);
+    //#endif
 
     //setupHelpMenu();
     setupEditor();
@@ -423,7 +423,7 @@ MacroEdit::MacroEdit(QString appName, QWidget* parent, QString* fileToLoad) :
     readSettings();
 
     // load the text file if specified
-    if (fileToLoad != NULL) {
+    if (fileToLoad != nullptr) {
         fileName_ = *fileToLoad;
         loadTextFile(fileName_);
     }
@@ -616,12 +616,12 @@ void MacroEdit::setupEditor()
 
     // get a list of all the available programming languages
 
-    vector<LanguageHelper*> languageHelpers = languageHelperFactory_.languageHelpers();
+    std::vector<LanguageHelper*> languageHelpers = languageHelperFactory_.languageHelpers();
 
-    for (size_t i = 0; i < languageHelpers.size(); i++) {
-        QAction* actionLang = new QAction(this);
-        actionLang->setObjectName("action_" + languageHelpers[i]->name());
-        actionLang->setText(languageHelpers[i]->name());
+    for (auto& languageHelper : languageHelpers) {
+        auto* actionLang = new QAction(this);
+        actionLang->setObjectName("action_" + languageHelper->name());
+        actionLang->setText(languageHelper->name());
         actionLang->setCheckable(true);
         menu_Language->addAction(actionLang);
         languageActions_.push_back(actionLang);
@@ -635,8 +635,8 @@ void MacroEdit::setupEditor()
 
 
     // the Help menu
-    connect(actionAbout,SIGNAL(triggered()),
-            this,SLOT(slotShowAboutBox()));
+    connect(actionAbout, SIGNAL(triggered()),
+            this, SLOT(slotShowAboutBox()));
 
     actionFunctionList->setEnabled(false);
     actionCodeHelper->setEnabled(false);
@@ -702,20 +702,20 @@ void MacroEdit::setupEditor()
     actionSideBar->setChecked(false);
     actionSideBar->setEnabled(false);
 
-    connect(actionSideBar,SIGNAL(toggled(bool)),
-            codeHelperW,SLOT(setVisible(bool)));
+    connect(actionSideBar, SIGNAL(toggled(bool)),
+            codeHelperW, SLOT(setVisible(bool)));
 
-    connect(codeHelperW,SIGNAL(showRequested(bool)),
-            actionSideBar,SLOT(setChecked(bool)));
+    connect(codeHelperW, SIGNAL(showRequested(bool)),
+            actionSideBar, SLOT(setChecked(bool)));
 
-    connect(codeHelperW,SIGNAL(insertRequested(QString)),
-            this,SLOT(insertText(QString)));
+    connect(codeHelperW, SIGNAL(insertRequested(QString)),
+            this, SLOT(insertText(QString)));
 }
 
 
 // we shoud call it after a language is set
 void MacroEdit::adjustSideBarForLanguage()
-{    
+{
     codeHelperW->setLanguage(languageHelper_);
 
     bool st = codeHelperW->canSupportLanguage();
@@ -915,12 +915,11 @@ QString MacroEdit::currentFunctionUnderCursor()
 bool MacroEdit::AskToSave()
 {
     if (textEditor->document()->isModified()) {
-        int ret = QMessageBox::warning(this, appName_,
+        auto ret = QMessageBox::warning(this, appName_,
                                        tr("The document has been modified.\n"
                                           "Do you want to save your changes?"),
-                                       QMessageBox::Yes | QMessageBox::Default,
-                                       QMessageBox::No,
-                                       QMessageBox::Cancel | QMessageBox::Escape);
+                                       QMessageBox::Cancel | QMessageBox::No | QMessageBox::Yes,
+                                       QMessageBox::Yes);
         if (ret == QMessageBox::Yes)
             return save();
         else if (ret == QMessageBox::Cancel)
@@ -955,7 +954,7 @@ bool MacroEdit::save()
 // - returns true if it happens, false if the user cancels the operation.
 // ---------------------------------------------------------------------------
 
-bool MacroEdit::saveAs(void)
+bool MacroEdit::saveAs()
 {
     QString fileName = QFileDialog::getSaveFileName(this);
     if (fileName.isEmpty())
@@ -972,7 +971,7 @@ bool MacroEdit::saveAs(void)
 // - returns true if it happens ok.
 // ---------------------------------------------------------------------------
 
-bool MacroEdit::reload(void)
+bool MacroEdit::reload()
 {
     QTextCursor cursor = textEditor->textCursor();  // note the current text cursor position
     int pos            = cursor.position();         // note the current text cursor position
@@ -1213,7 +1212,7 @@ void MacroEdit::findString(const QString& s, QTextDocument::FindFlags flags, boo
 //   's' is the string to search for, 'r' is the string to replace it with
 // ---------------------------------------------------------------------------
 
-void MacroEdit::replaceString(const QString& s, const QString& r, QTextDocument::FindFlags flags)
+void MacroEdit::replaceString(const QString& /*s*/, const QString& r, QTextDocument::FindFlags /*flags*/)
 {
     // perform the 'replace'
     textEditor->insertPlainText(r);
@@ -1665,7 +1664,7 @@ void MacroEdit::codeTemplateDialog()
 
     // if created, set it up and display it
 
-    if (codeTemplateDialog_) {        
+    if (codeTemplateDialog_) {
         codeTemplateDialog_->reloadCodeTemplates(textEditor->tabsSettings());
         codeTemplateDialog_->show();
         codeTemplateDialog_->raise();
@@ -1843,7 +1842,7 @@ void MacroEdit::slotColourHelper()
 void MacroEdit::insertLicenceText()
 {
     if (licenceText_.isEmpty()) {
-        string licenceTextPath = MakeSystemEtcPath("licence_for_macros.txt");
+        std::string licenceTextPath = MakeSystemEtcPath("licence_for_macros.txt");
 
         QFile file(licenceTextPath.c_str());
         if (file.open(QIODevice::ReadOnly)) {
@@ -1916,7 +1915,7 @@ void MacroEdit::insertLicenceText()
 // triggered when the user clicks 'Run'
 // ---------------------------------------------------------------------------
 
-void MacroEdit::run(void)
+void MacroEdit::run()
 {
     runMacro(runOptions_);
 }
@@ -1935,7 +1934,7 @@ void MacroEdit::debug(void)
 }
 */
 
-void MacroEdit::stop(void)
+void MacroEdit::stop()
 {
     Q_ASSERT(actionRun->isEnabled() == false);
 
@@ -1951,10 +1950,10 @@ void MacroEdit::stop(void)
 // ---------------------------------------------------------------------------
 
 
-void MacroEdit::monitor(void)
+void MacroEdit::monitor()
 {
     MvRequest r;
-    MvApplication::callService("MvMonitor", r, NULL);  //Qt-based monitor
+    MvApplication::callService("MvMonitor", r, nullptr);  //Qt-based monitor
 }
 
 
@@ -1963,7 +1962,7 @@ void MacroEdit::monitor(void)
 // called when the user clicks to open the file in an external editor
 // ---------------------------------------------------------------------------
 
-void MacroEdit::external(void)
+void MacroEdit::external()
 {
     QString command = getenv("METVIEW_EDITOR");
     QString quote   = "\"";
@@ -2120,7 +2119,7 @@ void MacroEdit::stopAttemptFailed(int pid)
 // contains an error message and will be printed differently if it does.
 // ---------------------------------------------------------------------------
 
-void MacroEdit::logMessage(const string& s)
+void MacroEdit::logMessage(const std::string& s)
 {
     static const QString cr("\n");
 
@@ -2164,7 +2163,7 @@ void MacroEdit::stepLineNumber(const int line)
 // Parses the given string to see whether it is an error message or not.
 // ---------------------------------------------------------------------------
 
-bool MacroEdit::checkForErrorMessage(const string& s)
+bool MacroEdit::checkForErrorMessage(const std::string& s)
 {
     int len = s.length();
 
@@ -2272,12 +2271,12 @@ void MacroEdit::statusMessage(const QString& msg, int)
 // Provides a print dialog and lets the user print the document.
 // ---------------------------------------------------------------------------
 
-void MacroEdit::print(void)
+void MacroEdit::print()
 {
     // let the user select a printer
 
     QPrinter printer;
-    QPrintDialog* dialog = new QPrintDialog(&printer, this);
+    auto* dialog = new QPrintDialog(&printer, this);
 
     dialog->setWindowTitle(tr("Print Document"));
 
@@ -2304,7 +2303,7 @@ void MacroEdit::print(void)
 // for more information.
 // ---------------------------------------------------------------------------
 
-void MacroEdit::check_syntax(void)
+void MacroEdit::check_syntax()
 {
     // save the document first?
 
@@ -2366,12 +2365,11 @@ void MacroEdit::onFocusRegained()
 
         if (dt > lastSaveTime_) {
             // yes - ask the user if they want to reload the document from disk
-            int ret = QMessageBox::warning(this, appName_,
+            auto ret = QMessageBox::warning(this, appName_,
                                            tr("The document has been externally modified (%1).\n"
                                               "Do you want to reload from disk?\n")
                                                .arg(dt.toString(QLocale::system().dateTimeFormat(QLocale::ShortFormat))),
-                                           QMessageBox::Yes | QMessageBox::Default,
-                                           QMessageBox::No | QMessageBox::Escape);
+                                           QMessageBox::No | QMessageBox::Yes, QMessageBox::Yes);
 
             if (ret == QMessageBox::Yes) {
                 reload();  // reload the file
@@ -2680,9 +2678,9 @@ void MacroEdit::setLanguageMenuCheckedStatus()
     // - uncheck the ones that are not the current language
     // - check the one that is
 
-    for (size_t i = 0; i < languageActions_.size(); i++) {
-        QString language = languageActions_[i]->iconText();
-        languageActions_[i]->setChecked(languageHelper_->isLanguageName(language));
+    for (auto& languageAction : languageActions_) {
+        QString language = languageAction->iconText();
+        languageAction->setChecked(languageHelper_->isLanguageName(language));
     }
 }
 
@@ -2815,7 +2813,6 @@ void MacroEdit::writeSettings()
     settings.endGroup();
 
     codeHelperW->writeSettings();
-
 }
 
 
@@ -2851,14 +2848,15 @@ void MacroEdit::readSettings()
     else {
         Q_ASSERT(sidebarSplitter->count() == 2);
         if (sidebarSplitter->count() == 2) {
-            int w = size().width();
+            int w           = size().width();
             QList<int> sLst = sidebarSplitter->sizes();
             if (w > 500) {
                 sLst[1] = 220;
-                sLst[0] = w-220;
-            } else {
-                sLst[1] = w/3;
-                sLst[0] = w-w/3;
+                sLst[0] = w - 220;
+            }
+            else {
+                sLst[1] = w / 3;
+                sLst[0] = w - w / 3;
             }
             sidebarSplitter->setSizes(sLst);
         }
