@@ -7,18 +7,11 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MacroEdit_H
-#define MacroEdit_H
+#pragma once
 
-#include <iostream>
-#include "MvRequest.h"
-#include "MvQDragDrop.h"
-#include "ui_MacroEdit.h"
-#include "Highlighter.h"
-#include "LanguageHelper.h"
-#include "LanguageHelperFactory.h"
-#include "MacroRunOptions.h"
-#include "TabsSettings.h"
+#include <ostream>
+#include <string>
+#include <vector>
 
 #include <QElapsedTimer>
 #include <QStandardItemModel>
@@ -32,7 +25,14 @@
 #include <QProcess>
 #include <QString>
 
-using namespace std;
+#include "MvRequest.h"
+#include "MvQDragDrop.h"
+#include "ui_MacroEdit.h"
+#include "Highlighter.h"
+#include "LanguageHelper.h"
+#include "LanguageHelperFactory.h"
+#include "MacroRunOptions.h"
+#include "TabsSettings.h"
 
 class FindTextDialog;
 class GotoLineDialog;
@@ -98,14 +98,14 @@ public:
 
     virtual void reply(const MvRequest&, int) = 0;
     virtual void progress(const MvRequest&)   = 0;
-    virtual void message(const string&)       = 0;
+    virtual void message(const std::string&)  = 0;
     void attach();  //ir
     void detach();  //ir
     int macroPid() const { return macroPid_; }
     void setMacroPid(int v) { macroPid_ = v; }
 
 protected:
-    void callService(const string&, const MvRequest&);
+    void callService(const std::string&, const MvRequest&);
 
     int macroPid_;
 
@@ -143,14 +143,14 @@ protected slots:
 
 
 signals:
-    void sendMessageToLog(const string& s);
+    void sendMessageToLog(const std::string& s);
     void sendMacroFinishedMsg(int err);
     void sendCurrentLineNumber(int line);
     void finished();
     void stopAttempFailed(int);
 
 protected:
-    void print(ostream&) const;  // Change to virtual if base class
+    void print(std::ostream&) const;  // Change to virtual if base class
 
 private:
     // No copy allowed
@@ -168,7 +168,7 @@ private:
     // From ReplyObserver
     virtual void reply(const MvRequest&, int);
     virtual void progress(const MvRequest&);
-    virtual void message(const string&);
+    virtual void message(const std::string&);
 };
 
 
@@ -190,7 +190,7 @@ class MacroEdit : public QMainWindow, private Ui::MainWindow
     Q_OBJECT
 
 public:
-    MacroEdit(QString appName, QWidget* parent = 0, QString* fileToLoad = NULL);
+    MacroEdit(QString appName, QWidget* parent = 0, QString* fileToLoad = nullptr);
     ~MacroEdit();
     void metview_dnd();
     void loadTextFile(const QString& fileToLoad);
@@ -247,7 +247,7 @@ public slots:
     void cursorPositionWasChanged();
     void updateRowColLabel();
     void updateMessageLog();
-    void logMessage(const string& s);
+    void logMessage(const std::string& s);
     void macroFinished(int errorCode);
     void stepLineNumber(int line);
     void enlargeFont();
@@ -287,7 +287,7 @@ private:
     QString currentFunctionUnderCursor();
     void runMacro(MacroRunOptions options);
     void statusMessage(const QString& msg, int timeToDisplay = 0);
-    bool checkForErrorMessage(const string& s);
+    bool checkForErrorMessage(const std::string& s);
     void enableRunActions(bool enable);
     void changeFontSize(int amount);
     void setFontSize(int newSize);
@@ -336,7 +336,7 @@ private:
     QTimer logTimer_;
     QTimer buttonTimer_;
     QElapsedTimer time_;
-    vector<QAction*> languageActions_;
+    std::vector<QAction*> languageActions_;
     QString licenceText_;
     QActionGroup* autoInsertLicenceGroup_;
     QActionGroup* themeAg_;
@@ -344,5 +344,3 @@ private:
     //VerbFunctionHelpWidget* verbHelper_;
     //QComboBox *sidebarCombo_;
 };
-
-#endif
