@@ -72,7 +72,7 @@ int main(int argc, char** argv)
 
     //Create the qt application. The appname must be unique!
     std::string appName = MvApplication::buildAppName("MacroEditor");
-    MvQApplication app(argc, argv, appName.c_str(), {"MacroEdit", "window"});
+    MvQApplication app(argc, argv, appName.c_str(), {"MacroEdit", "window", "editor"});
 
     // set the application icon
     QPixmap winPix(MvQ::iconPixmapPath(language));
