@@ -20,7 +20,8 @@
 class PlainTextHighlighter : public Highlighter
 {
 public:
-    PlainTextHighlighter(QTextDocument* parent = 0) : Highlighter(parent) {}
+    PlainTextHighlighter(QTextDocument* parent = nullptr) :
+        Highlighter(parent) {}
 };
 
 
@@ -37,9 +38,9 @@ public:
 PlainTextHelper::PlainTextHelper()
 {
     languageName_ = "Plain Text";
-    className_ = "NOTE";
-    serviceName_ = "none";
-    iconName_ = "NOTE";
+    className_    = "NOTE";
+    serviceName_  = "none";
+    iconName_     = "NOTE";
 }
 
 
@@ -48,9 +49,7 @@ PlainTextHelper::PlainTextHelper()
 // destructor
 // ---------------------------------------------------------------------------
 
-PlainTextHelper::~PlainTextHelper()
-{
-}
+PlainTextHelper::~PlainTextHelper() = default;
 
 
 // ---------------------------------------------------------------------------
