@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef RunDialog_H
-#define RunDialog_H
+#pragma once
 
 #include "ui_RunDialog.h"
 #include "MacroRunOptions.h"
@@ -34,5 +33,3 @@ public slots:
     //void setButtonStatus();
     //void onUseSpacesChanged();
 };
-
-#endif
