@@ -7,6 +7,13 @@
 
  ***************************** LICENSE END *************************************/
 
+#include "VerbFunctionHelp.h"
+
+#include <fstream>
+#include <iostream>
+
+#include "fstream_mars_fix.h"
+
 #include <QDebug>
 #include <QFile>
 #include <QTextStream>
@@ -14,9 +21,6 @@
 #include <QXmlStreamReader>
 #include <QImageReader>
 
-#include <iostream>
-
-#include "VerbFunctionHelp.h"
 #include "IconClassHelp.h"
 #include "LanguageHelper.h"
 #include "MvIconLanguage.h"
@@ -33,7 +37,7 @@
 //
 //========================================================
 
-VerbFunctionHelpParam::VerbFunctionHelpParam(const MvIconParameter& param):
+VerbFunctionHelpParam::VerbFunctionHelpParam(const MvIconParameter& param) :
     param_(param)
 {
     param_.scan(*this);
@@ -44,7 +48,7 @@ void VerbFunctionHelpParam::next(const MvIconParameter&, const char* first, cons
     if (!first)
         return;
 
-    values_ <<  ((second) ? QString(second).toLower() : QString(first).toLower());
+    values_ << ((second) ? QString(second).toLower() : QString(first).toLower());
 }
 
 QString VerbFunctionHelpParam::name() const
@@ -55,7 +59,7 @@ QString VerbFunctionHelpParam::name() const
 QStringList VerbFunctionHelpParam::defaultValues() const
 {
     QStringList lst;
-    for(auto it: param_.defaults()) {
+    for (auto it : param_.defaults()) {
         lst << QString::fromStdString(it).toLower();
     }
     return lst;
@@ -71,8 +75,8 @@ QString VerbFunctionHelpParam::interfaceFunction() const
     if (QString(param_.interface()).toLower() == "icon") {
         Request r = param_.interfaceRequest();
         if (r) {
-            const vector<string>& cls = r.get("class");
-            for(auto clsName: cls) {
+            const std::vector<std::string>& cls = r.get("class");
+            for (auto clsName : cls) {
                 if (IconClassHelp* clsH = IconClassHelp::find(clsName)) {
                     if (QString::fromStdString(clsH->name()).toLower().startsWith("m")) {
                         return QString::fromStdString(clsH->macroFunction());
@@ -103,16 +107,16 @@ QString VerbFunctionHelpParam::valueName(int i) const
 void VerbFunctionHelpParam::toYaml(std::ofstream& out)
 {
     out << "- " << name().toLower().toStdString() << ":" << std::endl;
-    auto dv = defaultValues();
+    auto dv             = defaultValues();
     std::string parType = interface().toStdString();
 
     if (dv.count() > 0) {
         auto s = dv[0].simplified().toStdString();
-        out << "   default: \'" << s  << "\'" << std::endl;
+        out << "   default: \'" << s << "\'" << std::endl;
     }
 
     QStringList lst;
-    for (int i=0; i < numValues(); i++) {
+    for (int i = 0; i < numValues(); i++) {
         lst << valueName(i);
     }
     if (lst.count() > 0) {
@@ -126,16 +130,19 @@ void VerbFunctionHelpParam::toYaml(std::ofstream& out)
 
         if (parType == "combo" && lst[0] == "solid") {
             parType = "line_style";
-        } else if (v == "*" && name().endsWith("_thickness")) {
+        }
+        else if (v == "*" && name().endsWith("_thickness")) {
             parType = "line_width";
-        } else if (parType == "string" && v == "*") {
+        }
+        else if (parType == "string" && v == "*") {
             parType = "number";
         }
 
         if ((parType == "string" || parType == "text") && lst.contains("/")) {
-            if(lst.size() == 2 && lst.contains("*")) {
+            if (lst.size() == 2 && lst.contains("*")) {
                 parType = "number_list";
-            } else {
+            }
+            else {
                 parType = "list";
             }
         }
@@ -146,13 +153,13 @@ void VerbFunctionHelpParam::toYaml(std::ofstream& out)
 
         if (parType == "colour") {
             QStringList pseudoCols;
-            foreach(QString cName, lst) {
+            foreach (QString cName, lst) {
                 if (MvQPalette::isPseudo(cName.toUpper().toStdString())) {
                     pseudoCols << cName;
                 }
             }
             if (!pseudoCols.isEmpty()) {
-               out << "   values: " << pseudoCols.join("/").toStdString() << std::endl;
+                out << "   values: " << pseudoCols.join("/").toStdString() << std::endl;
             }
         }
 
@@ -169,7 +176,7 @@ void VerbFunctionHelpParam::toYaml(std::ofstream& out)
 //
 //========================================================
 
-VerbFunctionHelpFunction::VerbFunctionHelpFunction(QString name, IconClassHelp* iconClass):
+VerbFunctionHelpFunction::VerbFunctionHelpFunction(QString name, IconClassHelp* iconClass) :
     name_(name),
     iconClass_(iconClass),
     paramsLoaded_(false)
@@ -180,7 +187,7 @@ VerbFunctionHelpFunction::VerbFunctionHelpFunction(QString name, IconClassHelp*
 
 VerbFunctionHelpFunction::~VerbFunctionHelpFunction()
 {
-    for(auto p: params_)
+    for (auto p : params_)
         delete p;
 }
 
@@ -195,9 +202,9 @@ void VerbFunctionHelpFunction::loadParams()
 void VerbFunctionHelpFunction::next(const MvIconParameter& p)
 {
     bool visible = true;
-    Request r = p.interfaceRequest();
+    Request r    = p.interfaceRequest();
     if (r) {
-        if (const char *vs = r("visible")) {
+        if (const char* vs = r("visible")) {
             if (strcmp(vs, "false") == 0)
                 visible = false;
         }
@@ -220,23 +227,23 @@ QIcon VerbFunctionHelpFunction::icon() const
 
 VerbFunctionHelpParam* VerbFunctionHelpFunction::paramFromName(QString name) const
 {
-    if(name.isEmpty())
+    if (name.isEmpty())
         return nullptr;
 
     auto it = paramMap_.find(name);
-    return (it != paramMap_.end())?(it->second):nullptr;
+    return (it != paramMap_.end()) ? (it->second) : nullptr;
 }
 
 VerbFunctionHelpParam* VerbFunctionHelpFunction::param(int i) const
 {
-    return (i>=0 && i < static_cast<int>(params_.size()))?params_[i]:nullptr;
+    return (i >= 0 && i < static_cast<int>(params_.size())) ? params_[i] : nullptr;
 }
 
 int VerbFunctionHelpFunction::indexOfParam(VerbFunctionHelpParam* param) const
 {
-    for(size_t i=0; i < params_.size(); i++)
+    for (size_t i = 0; i < params_.size(); i++)
         if (params_[i] == param)
-        return i;
+            return i;
 
     return -1;
 }
@@ -260,7 +267,6 @@ QString VerbFunctionHelpFunction::descriptionAsStr(int idx) const
     }
     return s;
 #endif
-
 }
 
 QString VerbFunctionHelpFunction::descriptionAsRt(int idx) const
@@ -296,7 +302,8 @@ void VerbFunctionHelpFunction::adjustDescriptions()
     if (descriptions_.isEmpty()) {
         if (iconClass_) {
             descriptions_ << qMakePair(QString(), QString::fromStdString(iconClass_->defaultName()));
-        } else {
+        }
+        else {
             descriptions_ << qMakePair(QString(), QString());
         }
     }
@@ -320,7 +327,7 @@ VerbFunctionHelp::~VerbFunctionHelp()
 
 void VerbFunctionHelp::clear()
 {
-    foreach(VerbFunctionHelpFunction *v, functions_)
+    foreach (VerbFunctionHelpFunction* v, functions_)
         delete v;
 
     functions_.clear();
@@ -331,16 +338,16 @@ void VerbFunctionHelp::init()
 {
     clear();
 
-    if(!language_)
+    if (!language_)
         return;
 
     if (functions_.size() > 0)
         return;
 
-    for(auto it : IconClassHelp::items()) {
+    for (auto it : IconClassHelp::items()) {
         QString fname = QString::fromStdString(it.second->macroFunction()).simplified().toLower();
         if (!it.second->isObsolete() && !fname.isEmpty() && it.second->type() != "File") {
-            functionMap_[fname] = new VerbFunctionHelpFunction(fname, it.second);           
+            functionMap_[fname] = new VerbFunctionHelpFunction(fname, it.second);
         }
     }
 
@@ -352,10 +359,10 @@ void VerbFunctionHelp::init()
         QString line;
 
         while (!file.atEnd() && !line.startsWith("-----")) {
-            line = file.readLine().simplified();
+            line    = file.readLine().simplified();
             int pos = line.indexOf(":");
-            if ( pos != -1)
-                webIds_[line.left(pos).simplified()] =  line.mid(pos+1).simplified();
+            if (pos != -1)
+                webIds_[line.left(pos).simplified()] = line.mid(pos + 1).simplified();
         }
 
         VerbFunctionHelpFunction* currentFn = nullptr;
@@ -373,76 +380,75 @@ void VerbFunctionHelp::init()
         //  when the type is icon the desc: item(s) is missing
 
         while (!file.atEnd())  // each line in the file is a function name to add to the list
-        {   
-            QString  item = file.readLine().simplified();
+        {
+            QString item = file.readLine().simplified();
 
             // skip comment lines
             if (item.startsWith("#"))
                 continue;
 
             if (item.startsWith("type:") && !currentName.isEmpty()) {
-               currentFn = nullptr;
-               QStringList lst = item.split("type:");
-               if (lst.count() == 2) {
-                   if (lst[1].simplified() == "script") {
-                       // it must be a non-iconclass functions!!
-                       if ( IconClassHelp::findByMacroFunction(currentName.toStdString()) == nullptr) {
-                           VerbFunctionHelpFunction* fn = new VerbFunctionHelpFunction(currentName);
-                           currentFn = fn;
-                           functionMap_[currentName] = fn;
-                       }
-                   }
-               }
-
-
-            } else if (item.startsWith("desc:") && currentFn) {
+                currentFn       = nullptr;
+                QStringList lst = item.split("type:");
+                if (lst.count() == 2) {
+                    if (lst[1].simplified() == "script") {
+                        // it must be a non-iconclass functions!!
+                        if (IconClassHelp::findByMacroFunction(currentName.toStdString()) == nullptr) {
+                            auto* fn                  = new VerbFunctionHelpFunction(currentName);
+                            currentFn                 = fn;
+                            functionMap_[currentName] = fn;
+                        }
+                    }
+                }
+            }
+            else if (item.startsWith("desc:") && currentFn) {
                 QStringList lst = item.split("desc:");
                 if (lst.count() == 2) {
                     QString ds = lst[1].simplified();
-                    int p1 = ds.indexOf("[");
-                    int p2 = ds.indexOf("]");
-                    if (p1 >=0 && p2 > p1) {
-                        QString group = ds.mid(p1+1,p2-p1-1);
-                        currentFn->setDescription(group, ds.mid(p2+1).simplified());
+                    int p1     = ds.indexOf("[");
+                    int p2     = ds.indexOf("]");
+                    if (p1 >= 0 && p2 > p1) {
+                        QString group = ds.mid(p1 + 1, p2 - p1 - 1);
+                        currentFn->setDescription(group, ds.mid(p2 + 1).simplified());
                     }
                 }
-
-            } else {
+            }
+            else {
                 currentName = item;
-                currentFn = nullptr;
+                currentFn   = nullptr;
             }
         }
     }
 
-    for(auto it : functionMap_) {
+    for (auto it : functionMap_) {
         functions_ << it.second;
         it.second->adjustDescriptions();
     }
 
     Q_ASSERT(totalFunctionIndex_.count() == 0);
-    for (int i=0; i < functions_.count(); i++) {
+    for (int i = 0; i < functions_.count(); i++) {
         Q_ASSERT(functions_[i]->descriptions().count() > 0);
-        for (int j=0; j < functions_[i]->descriptions().count(); j++) {
-           totalFunctionIndex_ << qMakePair(i,j);
+        for (int j = 0; j < functions_[i]->descriptions().count(); j++) {
+            totalFunctionIndex_ << qMakePair(i, j);
         }
     }
 
 
 #ifdef GENERATE_ICONCLASS_YAML
-    std::string outDir = "/tmp/" + std::string(getenv("USER")) + "/icon_class";
+    std::string outDir  = "/tmp/" + std::string(getenv("USER")) + "/icon_class";
     std::string outFile = outDir + "/index.yaml";
 
     std::ofstream out;
     out.open(outFile.c_str());
 
-    for (auto it:IconClassHelp::items()) {
+    for (auto it : IconClassHelp::items()) {
         IconClassHelp* kind = it.second;
         if (!kind->isObsolete() && !kind->isFamilyMember() &&
-             QString(kind->type().c_str()).toLower() != "folder")  {
-
-            Path pixPath = kind->pixmap();
+            QString(kind->type().c_str()).toLower() != "folder") {
+            auto icFile = MvQTheme::icIconFile(kind->pixmap());
+            Path pixPath(icFile.toStdString());
+//            qDebug() << " fname" << QString::fromStdString(pixPath.str());
             if (pixPath.exists()) {
-
                 out << "- icon: " << kind->name() << std::endl;
                 out << "  web: " << kind->defaultName() << std::endl;
 
@@ -454,11 +460,11 @@ void VerbFunctionHelp::init()
                 std::string pixName, pixSuffix;
                 pixPath.nameAndSuffix(pixName, pixSuffix);
 
-                QIcon icon(pixPath.str().c_str());
+//                QIcon icon(pixPath.str().c_str());
                 pixName += ".png";
                 out << "  pixmap: " << pixName << std::endl;
 
-                int pixSize=48;
+                int pixSize = 48;
                 QImageReader imgR(pixPath.str().c_str());
                 if (imgR.canRead()) {
                     imgR.setScaledSize(QSize(pixSize, pixSize));
@@ -472,13 +478,12 @@ void VerbFunctionHelp::init()
 
 #ifdef GENERATE_ICONDEF_YAML
     std::string outDir = "/tmp/" + std::string(getenv("USER")) + "/icon_def";
-    for (auto it:IconClassHelp::items()) {
+    for (auto it : IconClassHelp::items()) {
         IconClassHelp* kind = it.second;
         if (!kind->isObsolete() && !kind->isFamilyMember() &&
-           QString(kind->type().c_str()).toLower() != "folder" &&
-           kind->definitionFile().exists()) {
-
-            QString fname = QString::fromStdString(kind->macroFunction()).simplified().toLower();
+            QString(kind->type().c_str()).toLower() != "folder" &&
+            kind->definitionFile().exists()) {
+            QString fname       = QString::fromStdString(kind->macroFunction()).simplified().toLower();
             std::string outFile = outDir + "/" + fname.toStdString() + "_def.yaml";
             std::ofstream out;
             out.open(outFile.c_str());
@@ -487,15 +492,14 @@ void VerbFunctionHelp::init()
             fn->loadParams();
             out << "class: " << fname.toStdString() << std::endl;
             out << "params:" << std::endl;
-            for (int i=0; i < fn->numParams(); i++) {
+            for (int i = 0; i < fn->numParams(); i++) {
                 auto p = fn->param(i);
                 p->toYaml(out);
             }
             out.close();
-      }
+        }
     }
 #endif
-
 }
 
 bool VerbFunctionHelp::isHelpAvailableForFunction(QString functionName)
@@ -506,7 +510,7 @@ bool VerbFunctionHelp::isHelpAvailableForFunction(QString functionName)
 VerbFunctionHelpFunction* VerbFunctionHelp::function(QString functionName)
 {
     auto it = functionMap_.find(functionName);
-    return (it != functionMap_.end())?(it->second):nullptr;
+    return (it != functionMap_.end()) ? (it->second) : nullptr;
 }
 
 VerbFunctionHelpFunction* VerbFunctionHelp::itemAt(int i) const
@@ -514,10 +518,10 @@ VerbFunctionHelpFunction* VerbFunctionHelp::itemAt(int i) const
     return functions_[i];
 }
 
-QPair<VerbFunctionHelpFunction*,int> VerbFunctionHelp::itemAtInTotal(int i) const
+QPair<VerbFunctionHelpFunction*, int> VerbFunctionHelp::itemAtInTotal(int i) const
 {
     return qMakePair(functions_[totalFunctionIndex_[i].first],
-              totalFunctionIndex_[i].second);
+                     totalFunctionIndex_[i].second);
 }
 
 int VerbFunctionHelp::totalIndexOf(VerbFunctionHelpFunction* fn, int descIndex)
@@ -527,12 +531,12 @@ int VerbFunctionHelp::totalIndexOf(VerbFunctionHelpFunction* fn, int descIndex)
     }
 
     int idx = functions_.indexOf(fn);
-    if (idx >=0) {
-        for(int i=0; i < totalFunctionIndex_.count(); i++) {
+    if (idx >= 0) {
+        for (int i = 0; i < totalFunctionIndex_.count(); i++) {
             if (totalFunctionIndex_[i].first == idx) {
                 return i + descIndex;
             }
-       }
+        }
     }
 
     return -1;
@@ -548,9 +552,9 @@ QString VerbFunctionHelp::url(QString webGroup, QString fnName)
         if (fnName.isEmpty())
             return base + webIds_.value(webGroup);
         else {
-            QString page = webIds_.value(webGroup);
+            QString page       = webIds_.value(webGroup);
             QString pageAnchor = page;
-            return base + page + "#" + pageAnchor.replace("+","") + "-" + fnName;
+            return base + page + "#" + pageAnchor.replace("+", "") + "-" + fnName;
         }
     }
 
@@ -559,12 +563,12 @@ QString VerbFunctionHelp::url(QString webGroup, QString fnName)
 
 QString VerbFunctionHelp::iconUrl(VerbFunctionHelpFunction* fn)
 {
-    if(fn) {
+    if (fn) {
         QString base = webIds_.value("url");
         if (!base.isEmpty()) {
-            if(IconClassHelp* ic = fn->iconClass()) {
-               QString page = QString::fromStdString(ic->helpPage());
-               return base + page;
+            if (IconClassHelp* ic = fn->iconClass()) {
+                QString page = QString::fromStdString(ic->helpPage());
+                return base + page;
             }
         }
     }
@@ -574,5 +578,5 @@ QString VerbFunctionHelp::iconUrl(VerbFunctionHelpFunction* fn)
 
 QString VerbFunctionHelp::scopePrefix() const
 {
-    return (language_)?(language_->scopePrefix()):QString();
+    return (language_) ? (language_->scopePrefix()) : QString();
 }
