@@ -7,16 +7,19 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef VerbFunctionHelp_H
-#define VerbFunctionHelp_H
+#pragma once
+
+#include <fstream>
+#include <map>
+#include <vector>
+
+#include "fstream_mars_fix.h"
 
 #include <QIcon>
+#include <QMap>
+#include <QPair>
 #include <QString>
 #include <QStringList>
-#include <QPair>
-
-#include <vector>
-#include <map>
 
 #include "MvIconParameter.h"
 #include "MvIconLanguage.h"
@@ -54,7 +57,7 @@ public:
     int numValues() const;
     QString valueName(int i) const;
     void toYaml(std::ofstream&);
-    const MvIconParameter& iconParam() const {return param_;}
+    const MvIconParameter& iconParam() const { return param_; }
 
 protected:
     void next(const MvIconParameter&, const char* first, const char* second);
@@ -78,7 +81,7 @@ public:
     VerbFunctionHelpFunction(QString name, IconClassHelp* iconClass = nullptr);
     ~VerbFunctionHelpFunction();
 
-    QString name() const {return name_;}
+    QString name() const { return name_; }
     QIcon icon() const;
     int numParams() const { return static_cast<int>(params_.size()); }
     QString paramName(int i) const { return params_[i]->name(); }
@@ -86,12 +89,12 @@ public:
     VerbFunctionHelpParam* paramFromName(QString name) const;
     VerbFunctionHelpParam* param(int i) const;
     int indexOfParam(VerbFunctionHelpParam*) const;
-    IconClassHelp* iconClass() const {return iconClass_;}
+    IconClassHelp* iconClass() const { return iconClass_; }
     void loadParams();
 
     QString descriptionAsStr(int idx) const;
     QString descriptionAsRt(int idx) const;
-    QList<QPair<QString, QString> > descriptions() const {return descriptions_;}
+    QList<QPair<QString, QString> > descriptions() const { return descriptions_; }
     void setDescription(QString group, QString desc);
 
 protected:
@@ -122,14 +125,14 @@ public:
     ~VerbFunctionHelp();
 
     void init();
-    bool isEmpty() const {return functionNum() == 0;}
+    bool isEmpty() const { return functionNum() == 0; }
     int functionNum() const { return static_cast<int>(functions_.size()); }
     int totalFunctionNum() const { return totalFunctionIndex_.count(); }
     bool isHelpAvailableForFunction(QString functionName);
     VerbFunctionHelpFunction* function(QString functionName);
-    QList<VerbFunctionHelpFunction*> const functions() {return functions_;}
+    QList<VerbFunctionHelpFunction*> const functions() { return functions_; }
     VerbFunctionHelpFunction* itemAt(int i) const;
-    QPair<VerbFunctionHelpFunction*,int> itemAtInTotal(int i) const;
+    QPair<VerbFunctionHelpFunction*, int> itemAtInTotal(int i) const;
     int totalIndexOf(VerbFunctionHelpFunction* fn, int descIndex);
     QString url(QString webGroup, QString fnName);
     QString iconUrl(VerbFunctionHelpFunction*);
@@ -141,8 +144,6 @@ private:
     LanguageHelper* language_;
     std::map<QString, VerbFunctionHelpFunction*> functionMap_;
     QList<VerbFunctionHelpFunction*> functions_;
-    QList<QPair<int,int> > totalFunctionIndex_;
+    QList<QPair<int, int> > totalFunctionIndex_;
     QMap<QString, QString> webIds_;
 };
-
-#endif
