@@ -17,7 +17,7 @@
 #include "MvQMethods.h"
 #include "MvQTheme.h"
 #include "MvQTreeView.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 #include <QtGlobal>
 #include <QItemSelectionModel>
@@ -52,11 +52,11 @@ void ParamValueEditor::broadcastChange()
 //
 //================================================
 
-ParamColourValueEditor::ParamColourValueEditor(QString id, int index,QWidget* parent) :
+ParamColourValueEditor::ParamColourValueEditor(QString id, int index, QWidget* parent) :
     ParamValueEditor(id, index, parent)
 {
     // selector area
-    QVBoxLayout* vb = new QVBoxLayout();
+    auto* vb = new QVBoxLayout();
     parent->setLayout(vb);
 
     colW_ = new MvQColourWidget(parent);
@@ -64,7 +64,7 @@ ParamColourValueEditor::ParamColourValueEditor(QString id, int index,QWidget* pa
     vb->addStretch(1);
 
     connect(colW_, SIGNAL(valueChanged(QString)),
-            this,SIGNAL(valueChanged(QString)));
+            this, SIGNAL(valueChanged(QString)));
 }
 
 QWidget* ParamColourValueEditor::realWidget()
@@ -82,7 +82,7 @@ void ParamColourValueEditor::setParam(VerbFunctionHelpParam* param)
 {
     param_ = param;
 
-    if(param_) {
+    if (param_) {
         colW_->show();
         QStringList lst = param_->defaultValues();
         if (!lst.isEmpty())
@@ -92,7 +92,7 @@ void ParamColourValueEditor::setParam(VerbFunctionHelpParam* param)
 
 QString ParamColourValueEditor::value()
 {
-    if(param_) {;
+    if (param_) {
         return colW_->currentValue();
     }
 
@@ -105,7 +105,7 @@ QString ParamColourValueEditor::value()
 //
 //================================================
 
-ParamListValueEditor::ParamListValueEditor(QString id, int index,QWidget* parent) :
+ParamListValueEditor::ParamListValueEditor(QString id, int index, QWidget* parent) :
     ParamValueEditor(id, index, parent)
 {
     // selector area
@@ -118,7 +118,7 @@ ParamListValueEditor::ParamListValueEditor(QString id, int index,QWidget* parent
     valueTree_->setModel(valueModel_);
 
     connect(valueTree_, SIGNAL(clicked(QModelIndex)),
-            this,SLOT(slotValueSelected(QModelIndex)));
+            this, SLOT(slotValueSelected(QModelIndex)));
 }
 
 QWidget* ParamListValueEditor::realWidget()
@@ -137,14 +137,14 @@ void ParamListValueEditor::setParam(VerbFunctionHelpParam* param)
     valueModel_->clear();
     param_ = param;
 
-    if(param_) {
-            valueModel_->setHelpData(param_);
+    if (param_) {
+        valueModel_->setHelpData(param_);
     }
 }
 
 QString ParamListValueEditor::value()
 {
-    if(param_) {
+    if (param_) {
         QModelIndex idx = valueTree_->currentIndex();
         if (idx.isValid()) {
             return param_->valueName(idx.row());
@@ -215,8 +215,9 @@ QVariant VerbFunctionHelpParamModel::data(const QModelIndex& index, int role) co
         if (p) {
             // for icon parameters we display the iconclass macro function name
             if (p->interface() == "icon") {
-                QString f=p->interfaceFunction();
-                if (!f.isEmpty()) f +="()";
+                QString f = p->interfaceFunction();
+                if (!f.isEmpty())
+                    f += "()";
                 return f;
             }
 
@@ -233,11 +234,10 @@ QVariant VerbFunctionHelpParamModel::data(const QModelIndex& index, int role) co
 }
 
 QVariant VerbFunctionHelpParamModel::headerData(const int section, const Qt::Orientation orient,
-                                         const int role) const
+                                                const int role) const
 {
-    if ( role == Qt::DisplayRole && orient == Qt::Horizontal) {
-
-        if ( section == 0)
+    if (role == Qt::DisplayRole && orient == Qt::Horizontal) {
+        if (section == 0)
             return tr("Icon parameter");
         else if (section == 1)
             return tr("Default");
@@ -246,7 +246,7 @@ QVariant VerbFunctionHelpParamModel::headerData(const int section, const Qt::Ori
     return QVariant();
 }
 
-Qt::ItemFlags VerbFunctionHelpParamModel::flags(const QModelIndex &index) const
+Qt::ItemFlags VerbFunctionHelpParamModel::flags(const QModelIndex& index) const
 {
     if (!index.isValid())
         return QAbstractItemModel::flags(index) | Qt::ItemIsDropEnabled;
@@ -336,12 +336,12 @@ QVariant VerbFunctionHelpValueModel::data(const QModelIndex& index, int role) co
 }
 
 QVariant VerbFunctionHelpValueModel::headerData(const int /*section*/, const Qt::Orientation /*orient*/,
-                                         const int /*role*/) const
+                                                const int /*role*/) const
 {
     return QVariant();
 }
 
-Qt::ItemFlags VerbFunctionHelpValueModel::flags(const QModelIndex &index) const
+Qt::ItemFlags VerbFunctionHelpValueModel::flags(const QModelIndex& index) const
 {
     if (!index.isValid())
         return QAbstractItemModel::flags(index) | Qt::ItemIsDropEnabled;
@@ -394,17 +394,17 @@ VerbFunctionHelpWidget::VerbFunctionHelpWidget(QWidget* parent) :
 {
     ui_->setupUi(this);
 
-    connect(ui_->showFunctionListTb,SIGNAL(clicked()),
+    connect(ui_->showFunctionListTb, SIGNAL(clicked()),
             this, SIGNAL(functionListRequested()));
 
     ui_->descriptionLabel->setWordWrap(true);
     ui_->descriptionLabel->setProperty("type", "info");
 
     connect(ui_->fontSizeDownTb, SIGNAL(clicked()),
-        this, SLOT(slotFontSizeDown()));
+            this, SLOT(slotFontSizeDown()));
 
     connect(ui_->fontSizeUpTb, SIGNAL(clicked()),
-        this, SLOT(slotFontSizeUp()));
+            this, SLOT(slotFontSizeUp()));
 
     //-------------------------------
     // Param list tab
@@ -421,44 +421,44 @@ VerbFunctionHelpWidget::VerbFunctionHelpWidget(QWidget* parent) :
     ui_->paramTree->setModel(paramModel_);
     ui_->paramTree->setAlternatingRowColors(true);
 
-    connect(ui_->paramTree->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-            this,SLOT(slotParamSelected(QModelIndex, QModelIndex)));
+    connect(ui_->paramTree->selectionModel(), SIGNAL(currentChanged(QModelIndex, QModelIndex)),
+            this, SLOT(slotParamSelected(QModelIndex, QModelIndex)));
 
     //-----------------------------------
     // value selector/editor area
     //-----------------------------------
 
-    int cnt=0;
-    ParamValueEditor *e;
-    e = new ParamListValueEditor("list", cnt, this);
+    int cnt = 0;
+    ParamValueEditor* e;
+    e                = new ParamListValueEditor("list", cnt, this);
     editors_["list"] = e;
     ui_->editorStackW->addWidget(e->realWidget());
     cnt++;
 
-    e = new ParamColourValueEditor("colour", cnt, this);
+    e                  = new ParamColourValueEditor("colour", cnt, this);
     editors_["colour"] = e;
     ui_->editorStackW->addWidget(e->realWidget());
     cnt++;
 
-    foreach(ParamValueEditor *e, editors_) {
-        connect(e,SIGNAL(valueChanged(QString)),
-                this,SLOT(slotEditorValueChanged(QString)));
+    foreach (ParamValueEditor* e, editors_) {
+        connect(e, SIGNAL(valueChanged(QString)),
+                this, SLOT(slotEditorValueChanged(QString)));
     }
 
 
-    connect(ui_->extendSelectionCheckBox,SIGNAL(stateChanged(int)),
+    connect(ui_->extendSelectionCheckBox, SIGNAL(stateChanged(int)),
             this, SLOT(slotExtendSelection(int)));
 
     extendSelection_ = true;
     ui_->extendSelectionCheckBox->setChecked(extendSelection_);
 
-    connect(ui_->insertPb,SIGNAL(clicked()),
+    connect(ui_->insertPb, SIGNAL(clicked()),
             this, SLOT(slotInsert()));
 
-    connect(ui_->copyPb,SIGNAL(clicked()),
+    connect(ui_->copyPb, SIGNAL(clicked()),
             this, SLOT(slotCopy()));
 
-    connect(ui_->webDocPb,SIGNAL(clicked()),
+    connect(ui_->webDocPb, SIGNAL(clicked()),
             this, SLOT(slotWebDoc()));
 
     updateButtonStatus();
@@ -471,20 +471,20 @@ VerbFunctionHelpWidget::VerbFunctionHelpWidget(QWidget* parent) :
     ui_->paramTree->setColumnWidth(0, MvQ::textWidth(fm, "grib_interpolation_method_missing_fill_count"));
 }
 
-void VerbFunctionHelpWidget::setLanguage(LanguageHelper *language)
-{    
+void VerbFunctionHelpWidget::setLanguage(LanguageHelper* language)
+{
     Q_ASSERT(language);
 
     language_ = language;
     paramModel_->clear();
 }
 
-void VerbFunctionHelpWidget::setCodeEditorTheme(EditorTheme *theme,QFont editorFont)
+void VerbFunctionHelpWidget::setCodeEditorTheme(EditorTheme* theme, QFont editorFont)
 {
     editorTheme_ = theme;
     if (editorTheme_) {
         QString sh = "QLabel{background: " + editorTheme_->colour("background").name() +
-                "; color: " + editorTheme_->colour("text").name() + ";}";
+                     "; color: " + editorTheme_->colour("text").name() + ";}";
         QFont f(editorFont.family());
         //f.setPointSize(f.pointSize()+1);
         f.setFixedPitch(true);
@@ -496,12 +496,12 @@ void VerbFunctionHelpWidget::setCodeEditorTheme(EditorTheme *theme,QFont editorF
 
 VerbFunctionHelpFunction* VerbFunctionHelpWidget::function(QString name) const
 {
-    return (language_)?language_->functionHelp()->function(name):nullptr;
+    return (language_) ? language_->functionHelp()->function(name) : nullptr;
 }
 
 bool VerbFunctionHelpWidget::showFunction(QString functionName)
 {
-    if(!hasData())
+    if (!hasData())
         return false;
 
 
@@ -509,7 +509,7 @@ bool VerbFunctionHelpWidget::showFunction(QString functionName)
     if (fn && fn->iconClass()) {
         showFunction(language_->functionHelp()->function(functionName));
         if (fn->numParams() > 0) {
-            ui_->paramTree->setCurrentIndex(paramModel_->index(0,0));
+            ui_->paramTree->setCurrentIndex(paramModel_->index(0, 0));
         }
         return true;
     }
@@ -536,12 +536,12 @@ void VerbFunctionHelpWidget::slotParamSelected(const QModelIndex& idx, const QMo
         return;
     }
 
-    if(VerbFunctionHelpFunction* function = paramModel_->helpData())
+    if (VerbFunctionHelpFunction* function = paramModel_->helpData())
         showParamCore(function, function->param(idx.row()));
 }
 
 void VerbFunctionHelpWidget::showParam(VerbFunctionHelpFunction* function,
-                                       VerbFunctionHelpParam *param)
+                                       VerbFunctionHelpParam* param)
 {
     if (function && param) {
         if (function != paramModel_->helpData()) {
@@ -554,7 +554,7 @@ void VerbFunctionHelpWidget::showParam(VerbFunctionHelpFunction* function,
 }
 
 void VerbFunctionHelpWidget::showParamCore(VerbFunctionHelpFunction* function,
-                                       VerbFunctionHelpParam *param)
+                                           VerbFunctionHelpParam* param)
 {
     ui_->selectionLabel->clear();
     if (currentEditor_)
@@ -569,14 +569,13 @@ void VerbFunctionHelpWidget::showParamCore(VerbFunctionHelpFunction* function,
 
     Q_ASSERT(function == paramModel_->helpData());
 
-    if(param) {
-
+    if (param) {
         QString editorType = param->interface();
-        if ( editorType == "menu" || editorType == "option_menu" || editorType == "on_off")
+        if (editorType == "menu" || editorType == "option_menu" || editorType == "on_off")
             editorType = "list";
 
-        if(!editorType.isEmpty()) {
-            ParamValueEditor *e = editors_.value(editorType, nullptr);
+        if (!editorType.isEmpty()) {
+            ParamValueEditor* e = editors_.value(editorType, nullptr);
             if (!e) {
                 if (currentEditor_)
                     currentEditor_->clear();
@@ -584,8 +583,8 @@ void VerbFunctionHelpWidget::showParamCore(VerbFunctionHelpFunction* function,
                 currentEditor_ = nullptr;
                 ui_->valuesLabel->hide();
                 ui_->editorStackW->hide();
-
-            } else {
+            }
+            else {
                 if (currentEditor_ != e) {
                     currentEditor_ = e;
                     ui_->editorStackW->setCurrentWidget(e->realWidget());
@@ -594,8 +593,8 @@ void VerbFunctionHelpWidget::showParamCore(VerbFunctionHelpFunction* function,
                 }
                 currentEditor_->setParam(param);
             }
-
-        } else {
+        }
+        else {
             if (currentEditor_) {
                 currentEditor_->clear();
                 currentEditor_ = nullptr;
@@ -624,18 +623,19 @@ QString VerbFunctionHelpWidget::selection(bool highlightValue) const
         return s;
 
     bool hasVal = false;
-    if(VerbFunctionHelpFunction* function = paramModel_->helpData()) {
+    if (VerbFunctionHelpFunction* function = paramModel_->helpData()) {
         QModelIndex idx = ui_->paramTree->currentIndex();
-        if(VerbFunctionHelpParam* param=function->param(idx.row())) {
-            s+=param->name() + " " + language_->functionParameterAssignChar() + " ";
+        if (VerbFunctionHelpParam* param = function->param(idx.row())) {
+            s += param->name() + " " + language_->functionParameterAssignChar() + " ";
             if (currentEditor_) {
                 QString val = currentEditor_->value();
                 if (!val.isEmpty()) {
                     if (highlightValue) {
-                        s+="<font color=\'" + editorTheme_->colour("string").name() +
-                           "\'>\'" + val + "\'<font>";
-                    } else {
-                        s+="\'" + val + "\'";
+                        s += "<font color=\'" + editorTheme_->colour("string").name() +
+                             "\'>\'" + val + "\'<font>";
+                    }
+                    else {
+                        s += "\'" + val + "\'";
                     }
                     hasVal = true;
                 }
@@ -658,18 +658,19 @@ void VerbFunctionHelpWidget::updateSelectionLabel()
 void VerbFunctionHelpWidget::updateFunctionLabel(VerbFunctionHelpFunction* fn)
 {
     if (fn) {
-        ui_->functionIconLabel->setPixmap(fn->icon().pixmap(20,20));
+        ui_->functionIconLabel->setPixmap(fn->icon().pixmap(20, 20));
         ui_->functionNameLabel->setText("<b>" + fn->name() + "()</b>");
 
-        if (IconClassHelp *ic = fn->iconClass()) {
+        if (IconClassHelp* ic = fn->iconClass()) {
             ui_->descriptionLabel->show();
             ui_->descriptionLabel->setText(QString::fromStdString(ic->defaultName()));
-        } else {
+        }
+        else {
             ui_->descriptionLabel->clear();
             ui_->descriptionLabel->hide();
         }
-
-    } else {
+    }
+    else {
         ui_->functionIconLabel->setPixmap(QPixmap());
         ui_->functionNameLabel->setText("");
         ui_->descriptionLabel->clear();
@@ -679,7 +680,7 @@ void VerbFunctionHelpWidget::updateFunctionLabel(VerbFunctionHelpFunction* fn)
 
 bool VerbFunctionHelpWidget::hasData() const
 {
-     return (language_ && language_->hasVerbFunctionHelp() && !language_->functionHelp()->isEmpty());
+    return (language_ && language_->hasVerbFunctionHelp() && !language_->functionHelp()->isEmpty());
 }
 
 void VerbFunctionHelpWidget::slotExtendSelection(int st)
@@ -691,12 +692,12 @@ void VerbFunctionHelpWidget::slotExtendSelection(int st)
 
 void VerbFunctionHelpWidget::slotInsert()
 {
-     QString s = selection();
-     /*if (extendSelection_) {
+    QString s = selection();
+    /*if (extendSelection_) {
         s += QChar(QChar::LineSeparator);
         s += QChar(QChar::Tabulation);
      }*/
-     emit insertRequested(s);
+    emit insertRequested(s);
 }
 
 void VerbFunctionHelpWidget::slotCopy()
@@ -721,23 +722,23 @@ void VerbFunctionHelpWidget::updateButtonStatus()
 
 void VerbFunctionHelpWidget::slotWebDoc()
 {
-    if(VerbFunctionHelpFunction* fn = paramModel_->helpData()) {
+    if (VerbFunctionHelpFunction* fn = paramModel_->helpData()) {
         QString web = language_->functionHelp()->iconUrl(fn);
         std::string err;
         if (!metview::openInBrowser(web.toStdString(), err)) {
             QMessageBox::warning(this, "Code editor - Metview",
-                             "Failed to show documentation in web browser!<br><br>" + QString::fromStdString(err));
+                                 "Failed to show documentation in web browser!<br><br>" + QString::fromStdString(err));
         }
     }
 }
 
 void VerbFunctionHelpWidget::slotFontSizeDown()
 {
-    MvQ::changeFontSize(ui_->paramTree,-1);
+    MvQ::changeFontSize(ui_->paramTree, -1);
 
     int fs = ui_->paramTree->font().pointSize();
     MvQ::setFontSize(ui_->selectionLabel, fs);
-    foreach(ParamValueEditor* e, editors_.values()) {
+    foreach (ParamValueEditor* e, editors_.values()) {
         if (e)
             MvQ::setFontSize(e->realWidget(), fs);
     }
@@ -749,7 +750,7 @@ void VerbFunctionHelpWidget::slotFontSizeUp()
 
     int fs = ui_->paramTree->font().pointSize();
     MvQ::setFontSize(ui_->selectionLabel, fs);
-    foreach(ParamValueEditor* e, editors_.values()) {
+    foreach (ParamValueEditor* e, editors_.values()) {
         if (e)
             MvQ::setFontSize(e->realWidget(), fs);
     }
@@ -764,7 +765,7 @@ void VerbFunctionHelpWidget::writeSettings(QSettings& settings)
 {
     settings.beginGroup("VerbFunctionHelpWidget");
     MvQ::saveTreeColumnWidth(settings, "paramTreeWidth", ui_->paramTree);
-    settings.setValue("fontSize",ui_->paramTree->font().pointSize());
+    settings.setValue("fontSize", ui_->paramTree->font().pointSize());
     settings.endGroup();
 }
 
@@ -778,7 +779,7 @@ void VerbFunctionHelpWidget::readSettings(QSettings& settings)
 
     fs = ui_->paramTree->font().pointSize();
     MvQ::setFontSize(ui_->selectionLabel, fs);
-    foreach(ParamValueEditor* e, editors_.values()) {
+    foreach (ParamValueEditor* e, editors_.values()) {
         if (e)
             MvQ::setFontSize(e->realWidget(), fs);
     }
