@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef VERFUNCTIONHELPWIDGET_H
-#define VERFUNCTIONHELPWIDGET_H
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QSettings>
@@ -32,12 +31,12 @@ class ParamValueEditor : public QObject
     Q_OBJECT
 public:
     ParamValueEditor(QString id, int index, QWidget* parent);
-    virtual QString value()=0;
-    virtual void setParam(VerbFunctionHelpParam*)=0;
-    virtual QWidget* realWidget()=0;
-    virtual void clear() = 0;
-    virtual void fontSizeUp() = 0;
-    virtual void fontSizeDown() = 0;
+    virtual QString value()                       = 0;
+    virtual void setParam(VerbFunctionHelpParam*) = 0;
+    virtual QWidget* realWidget()                 = 0;
+    virtual void clear()                          = 0;
+    virtual void fontSizeUp()                     = 0;
+    virtual void fontSizeDown()                   = 0;
 
 signals:
     void valueChanged(QString);
@@ -94,11 +93,11 @@ public:
     int rowCount(const QModelIndex& parent = QModelIndex()) const;
     QVariant data(const QModelIndex&, int role = Qt::DisplayRole) const;
     QVariant headerData(int, Qt::Orientation, int role = Qt::DisplayRole) const;
-    Qt::ItemFlags flags(const QModelIndex &index) const;
+    Qt::ItemFlags flags(const QModelIndex& index) const;
     QModelIndex index(int, int, const QModelIndex& parent = QModelIndex()) const;
     QModelIndex parent(const QModelIndex&) const;
 
-    VerbFunctionHelpFunction* helpData() const {return data_;}
+    VerbFunctionHelpFunction* helpData() const { return data_; }
     void setHelpData(VerbFunctionHelpFunction*);
     QModelIndex paramToIndex(VerbFunctionHelpParam* param) const;
     void clear();
@@ -118,7 +117,7 @@ public:
     int rowCount(const QModelIndex& parent = QModelIndex()) const;
     QVariant data(const QModelIndex&, int role = Qt::DisplayRole) const;
     QVariant headerData(int, Qt::Orientation, int role = Qt::DisplayRole) const;
-    Qt::ItemFlags flags(const QModelIndex &index) const;
+    Qt::ItemFlags flags(const QModelIndex& index) const;
     QModelIndex index(int, int, const QModelIndex& parent = QModelIndex()) const;
     QModelIndex parent(const QModelIndex&) const;
 
@@ -132,8 +131,9 @@ private:
 };
 
 
-namespace Ui {
-    class VerbFunctionHelpWidget;
+namespace Ui
+{
+class VerbFunctionHelpWidget;
 }
 
 class VerbFunctionHelpWidget : public QWidget
@@ -151,9 +151,9 @@ public:
     void showFunction(VerbFunctionHelpFunction* function);
     void showParam(QString functionName);
     void showParam(VerbFunctionHelpFunction* function,
-                   VerbFunctionHelpParam *param);
+                   VerbFunctionHelpParam* param);
 
-    QString selection(bool highlightValue=false) const;
+    QString selection(bool highlightValue = false) const;
     bool hasData() const;
 
     void writeSettings(QSettings&);
@@ -176,10 +176,10 @@ protected slots:
 
 private:
     void showParamCore(VerbFunctionHelpFunction* function,
-                   VerbFunctionHelpParam *param);
+                       VerbFunctionHelpParam* param);
     void updateSelectionLabel();
     void updateFunctionLabel(VerbFunctionHelpFunction* function);
-    void updateButtonStatus();   
+    void updateButtonStatus();
     int currentTreeFontSize() const;
 
     Ui::VerbFunctionHelpWidget* ui_;
@@ -191,5 +191,3 @@ private:
     ParamValueEditor* currentEditor_;
     bool extendSelection_;
 };
-
-#endif // VERFUNCTIONHELPWIDGET_H
