@@ -20,9 +20,7 @@ LogEdit::LogEdit(QWidget* parent) :
 }
 
 
-LogEdit::~LogEdit()
-{
-}
+LogEdit::~LogEdit() = default;
 
 
 //Set the colour scheme
