@@ -24,7 +24,6 @@
 #include <QHBoxLayout>
 
 #include "MvQDragDrop.h"
-
 #include "MvQMethods.h"
 #include "EditorTheme.h"
 #include "LanguageHelper.h"
@@ -54,9 +53,7 @@ MvPlainTextEdit::MvPlainTextEdit(QWidget* parent) :
 }
 
 
-MvPlainTextEdit::~MvPlainTextEdit()
-{
-}
+MvPlainTextEdit::~MvPlainTextEdit() = default;
 
 
 // ---------------------------------------------------------------------------
@@ -93,7 +90,7 @@ void MvPlainTextEdit::keyPressEvent(QKeyEvent* e)
 // 'blindly' be added.
 // ---------------------------------------------------------------------------
 
-void MvPlainTextEdit::insertTextIndent(QTextCursor& cursor, bool intelligentIndent)
+void MvPlainTextEdit::insertTextIndent(QTextCursor& cursor, bool /*intelligentIndent*/)
 {
     if (useSpacesForTabs()) {
         // we want to insert enough spaces to bring us to the next 'tab stop'
@@ -147,7 +144,7 @@ void MvPlainTextEdit::cursorRowCol(int* row, int* col)
 QChar MvPlainTextEdit::characterBehindCursor(QTextCursor* cursor)
 {
     QTextCursor docTextCursor = textCursor();
-    QTextCursor* theCursor    = (cursor == 0) ? &docTextCursor : cursor;
+    QTextCursor* theCursor    = (cursor == nullptr) ? &docTextCursor : cursor;
     return document()->characterAt(theCursor->position() - 1);
 }
 
@@ -334,31 +331,31 @@ void MvPlainTextEdit::mouseDoubleClickEvent(QMouseEvent* e)
     //we try to handle the double-click selection for colour here!!
     if (languageHelper_ && languageHelper_->hasVerbFunctionHelp()) {
         QTextCursor cursor = textCursor();
-        QString t = cursor.block().text();
+        QString t          = cursor.block().text();
 
-        if(!t.contains("RGB(",Qt::CaseInsensitive) && !t.contains("RGBA(",Qt::CaseInsensitive)) {
+        if (!t.contains("RGB(", Qt::CaseInsensitive) && !t.contains("RGBA(", Qt::CaseInsensitive)) {
             return QPlainTextEdit::mouseDoubleClickEvent(e);
         }
 
         int cursorPosInLine = cursor.positionInBlock();
-        int startPos = 0;
-        int endPos = t.size();
+        int startPos        = 0;
+        int endPos          = t.size();
 
         QRegularExpression rx("(RGB\\(.+\\)|RGBA\\(.+\\))");
         rx.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
-        int pos = 0;
+        int pos    = 0;
         bool found = false;
 
         auto rmatch = rx.match(t, pos);
         while (rmatch.hasMatch()) {
             QString capText = rmatch.captured(1);
-            int capPos = rmatch.capturedStart(1);
+            int capPos      = rmatch.capturedStart(1);
 
             // the cursor must be inside the captured text
-            if (cursorPosInLine >=  capPos  && cursorPosInLine <= capPos + capText.length() ) {
+            if (cursorPosInLine >= capPos && cursorPosInLine <= capPos + capText.length()) {
                 startPos = capPos;
-                endPos = capPos + capText.length();
-                found = true;
+                endPos   = capPos + capText.length();
+                found    = true;
                 break;
             }
             pos += rmatch.capturedLength(1);
@@ -371,13 +368,14 @@ void MvPlainTextEdit::mouseDoubleClickEvent(QMouseEvent* e)
             cursor.setPosition(endPos + dPos, QTextCursor::KeepAnchor);
             setTextCursor(cursor);
             e->accept();
-        } else {
+        }
+        else {
             QPlainTextEdit::mouseDoubleClickEvent(e);
         }
-    } else {
+    }
+    else {
         QPlainTextEdit::mouseDoubleClickEvent(e);
     }
-
 }
 
 // ---------------------------------------------------------------------------
@@ -450,7 +448,7 @@ void MvPlainTextEdit::dragEnterEvent(QDragEnterEvent* event)
     if ((event->proposedAction() == Qt::CopyAction ||
          event->proposedAction() == Qt::MoveAction)) {
         // move the text cursor to show where the text will be inserted
-        QPoint p(event->pos());
+        QPoint p(MvQ::eventPos(event));
         QTextCursor tempCursor(cursorForPosition(p));
         setTextCursor(tempCursor);
         //setFocus(Qt::MouseFocusReason);
@@ -463,7 +461,7 @@ void MvPlainTextEdit::dragMoveEvent(QDragMoveEvent* event)
     if ((event->proposedAction() == Qt::CopyAction ||
          event->proposedAction() == Qt::MoveAction)) {
         // move the text cursor to show where the text will be inserted
-        QPoint p(event->pos());
+        QPoint p(MvQ::eventPos(event));
         QTextCursor tempCursor(cursorForPosition(p));
         setTextCursor(tempCursor);
         event->accept();
@@ -482,7 +480,7 @@ void MvPlainTextEdit::dropEvent(QDropEvent* event)
 
         // we know where the drop occurred, so get a new text cursor at that location
         // so that the generated text will be inserted there
-        QPoint p(event->pos());
+        QPoint p(MvQ::eventPos(event));
         QTextCursor tempCursor(cursorForPosition(p));
         setTextCursor(tempCursor);
 
@@ -566,14 +564,14 @@ QStringList MvPlainTextEdit::textBeforeCursor(int maxLineNum) const
     Q_ASSERT(maxLineNum > 0);
 
     QTextCursor cursor = textCursor();
-    QTextBlock block = cursor.block();
+    QTextBlock block   = cursor.block();
     QStringList res;
-    QString t= block.text();    
-    t = t.left(cursor.positionInBlock());
+    QString t = block.text();
+    t         = t.left(cursor.positionInBlock());
     res << t;
 
     block = block.previous();
-    while ( block.isValid() ) {
+    while (block.isValid()) {
         res << block.text();
 
         if (res.count() >= maxLineNum)
@@ -585,22 +583,22 @@ QStringList MvPlainTextEdit::textBeforeCursor(int maxLineNum) const
     return res;
 }
 
-void MvPlainTextEdit::textBeforeCursorLine(int maxLineNum, QStringList &lines, int& cursorPos) const
+void MvPlainTextEdit::textBeforeCursorLine(int maxLineNum, QStringList& lines, int& cursorPos) const
 {
     Q_ASSERT(maxLineNum > 0);
     lines.clear();
 
     QTextCursor cursor = textCursor();
-    cursorPos = cursor.positionInBlock();
+    cursorPos          = cursor.positionInBlock();
 
     QString sel = cursor.selectedText();
     if (!sel.isEmpty() && cursor.position() == cursor.selectionEnd()) {
-              cursorPos--;
+        cursorPos--;
     }
 
     // we suppose that one block is one line
     QTextBlock block = cursor.block();
-    while ( block.isValid() ) {
+    while (block.isValid()) {
         lines << block.text();
 
         if (lines.count() >= maxLineNum)
