@@ -10,7 +10,7 @@
 #include "Metview.h"
 #include "MvPath.hpp"
 #include "MvDate.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "Tokenizer.h"
 
 #include <iostream>
@@ -50,20 +50,20 @@ void MvMacroCallerService::registerCallbacks()
                        replyCb, (void*)this);
 }
 
-void MvMacroCallerService::progressCb(svcid* id, request* r, void* obj)
+void MvMacroCallerService::progressCb(svcid* /*id*/, request* r, void* obj)
 {
     //std::cout << "PROG callback: " << std::endl;
     MvRequest in(r);
-    if (MvMacroCallerService* b = static_cast<MvMacroCallerService*>(obj))
+    if (auto* b = static_cast<MvMacroCallerService*>(obj))
         b->progress(in);
 }
 
-void MvMacroCallerService::replyCb(svcid* id, request* r, void* obj)
+void MvMacroCallerService::replyCb(svcid* /*id*/, request* r, void* obj)
 {
     //std::cout << "REPLY: " << std::endl;
     //print_all_requests(r);
     MvRequest in(r);
-    if (MvMacroCallerService* b = static_cast<MvMacroCallerService*>(obj))
+    if (auto* b = static_cast<MvMacroCallerService*>(obj))
         b->reply(in);
 }
 
@@ -319,8 +319,8 @@ void Met3DPrep::serve(MvRequest& in, MvRequest& out)
     req("_EXTENDMESSAGE") = "1";
 
     //Define argument list for the macro!
-    for (std::vector<std::string>::iterator it = param.begin(); it != param.end(); it++) {
-        req.addValue("_ARGUMENTS", (*it).c_str());
+    for (auto& it : param) {
+        req.addValue("_ARGUMENTS", it.c_str());
     }
 
     //const char *cdir=getenv("PWD");
@@ -344,7 +344,7 @@ void Met3DPrep::serve(MvRequest& in, MvRequest& out)
 
     if (const char* v = replyReq_.getVerb()) {
         if (strcmp(v, "ERROR") == 0) {
-            string err = "Met3DPrepare-> Failed to run MET3D input preparation! Macro failed!";
+            std::string err = "Met3DPrepare-> Failed to run MET3D input preparation! Macro failed!";
             if (const char* cc = replyReq_("MESSAGE")) {
                 err += "Message: ";
                 err += cc;
@@ -355,7 +355,7 @@ void Met3DPrep::serve(MvRequest& in, MvRequest& out)
         else if (strcmp(v, "NUMBER") == 0) {
             if (const char* numCh = replyReq_("VALUE")) {
                 if (strcmp(numCh, "0") != 0) {
-                    string err = "Met3DPrepare-> Failed to run MET3D input preparation. Macro exited with code ";
+                    std::string err = "Met3DPrepare-> Failed to run MET3D input preparation. Macro exited with code ";
                     err += numCh;
                     setError(1, err.c_str());
                     return;
