@@ -252,7 +252,7 @@ void Meteogram::handle_remote(MvRequest &in, MvRequest &out)
     // 1) can we get different expvers?
 
 
-    std::string restUrl = "https://apps.ecmwf.int/webapps/opencharts-api/v1/products/opencharts_meteogram/";
+    std::string restUrl = "https://charts.ecmwf.int/opencharts-api/v1/products/opencharts_meteogram/";
 
     // allow to override the base URL so that if this changes, users don't need to move to a new
     // version of Metview in order to use it
@@ -274,18 +274,13 @@ void Meteogram::handle_remote(MvRequest &in, MvRequest &out)
     std::string dataSelectionType = (const char*)in("DATA_SELECTION_TYPE");
 
     if (dataSelectionType == "DATE") {
-        // get the date as a full string
+        // get the date and tias a full string
+        int time = in("FORECAST_RUN_TIME");
         MvDate date = in("DATE");
+        date += (double)time/24.0;
         std::ostringstream date_option;
         date_option << date.ISO8601();
         restUrl += "&base_time=" + date_option.str();
-
-
-        // get the time as a full string
-        int time = in("FORECAST_RUN_TIME");
-        std::ostringstream time_option;
-        time_option << std::setw(4) << std::setfill('0') << time * 100;
-        restUrl += "&base_time=" + date_option.str();
     }
 
     else if (dataSelectionType == "LATEST") {
