@@ -14,9 +14,11 @@ ECMWF Oct-93
 
 */
 
+#include <iostream>
+
 #include "Metview.h"
 #include "MvPath.hpp"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 #include <stdlib.h>
 
@@ -28,6 +30,7 @@ public:
     Retrieve(const char* c);
     void serve(MvRequest&, MvRequest&);
     virtual void marsServe(MvRequest&, MvRequest&);
+
 private:
     bool forcePrintLog_;
 };
@@ -123,7 +126,7 @@ void Retrieve::marsServe(MvRequest& in, MvRequest& out)
         // removes the first and last characters from the string!
         const char* filter = in("FILTER");
         if (filter) {
-            string fstr(filter);
+            std::string fstr(filter);
             if (fstr.size() > 0) {
                 if (fstr.substr(0, 1) != "\"")
                     fstr.insert(0, "\"");
@@ -148,7 +151,7 @@ void Retrieve::marsServe(MvRequest& in, MvRequest& out)
         // If size of the target file is 0
         // then there is no data retrieved
         if (!FileHasValidSize(in("TARGET"))) {
-            request* field = NULL;
+            request* field = nullptr;
             out            = field;
         }
         else {
@@ -171,7 +174,7 @@ void Retrieve::marsServe(MvRequest& in, MvRequest& out)
         // If size of the target file is 0
         // then there is no data retrieved
         if (!FileHasValidSize(in("TARGET"))) {
-            request* field = NULL;
+            request* field = nullptr;
             out            = field;
         }
         else {
@@ -190,7 +193,7 @@ void Retrieve::marsServe(MvRequest& in, MvRequest& out)
         }
 
         variable* v = find_variable((const char*)in("FIELDSET"));
-        if (v == NULL) {
+        if (v == nullptr) {
             setError(1, "Retrieve-> Parameter FIELDSET not found");
             return;
         }
@@ -295,8 +298,7 @@ void Read::marsServe(MvRequest& in, MvRequest& out)
         // b) if a temporary file was created
         out("FIELDSET_FROM_FILTER") = 1;
         if (grib && (const char*)grib("FIELDSET_FROM_FILTER") &&
-            (int)grib("FIELDSET_FROM_FILTER") == 1)
-        {
+            (int)grib("FIELDSET_FROM_FILTER") == 1) {
             const char* outpath = out("PATH");
             if (out.isEmpty() || (outpath && strcmp(outpath, path))) {
                 // 1) if a new file was created from the filtering (as can happen if
@@ -324,11 +326,11 @@ void Retrieve::serve(MvRequest& in, MvRequest& out)
 {
     // Make sure the request is clean...
 
-    cout << "--> Retrieve::serve in -->" << endl;
-    cout << "MARS HOME:           " << mars.mars_home << endl;
-    cout << "MARS LANGUAGE FILE:  " << mars.langfile << endl;
-    cout << "MARS RULES FILE:     " << mars.testfile << endl;
-    cout << endl;
+    std::cout << "--> Retrieve::serve in -->" << std::endl;
+    std::cout << "MARS HOME:           " << mars.mars_home << std::endl;
+    std::cout << "MARS LANGUAGE FILE:  " << mars.langfile << std::endl;
+    std::cout << "MARS RULES FILE:     " << mars.testfile << std::endl;
+    std::cout << std::endl;
     in.print(forcePrintLog_);
 
     reset_language(mars_language());
@@ -347,8 +349,8 @@ void Retrieve::serve(MvRequest& in, MvRequest& out)
     // Do the real job there
     marsServe(clean, out);
 
-    cout << "--> Retrieve::serve out -->" << endl;
-    ;
+    std::cout << "--> Retrieve::serve out -->" << std::endl;
+
     out.print();
 }
 
@@ -359,7 +361,7 @@ int main(int argc, char** argv)
 {
     // from the environment, check whether we're in 'standard', 'MIR' or 'TIGGE' mode
 
-    char* marsmode    = getenv("MV_MARS_MODE");
+    char* marsmode          = getenv("MV_MARS_MODE");
     const char* servicename = "mars";
 
     if (marsmode && strcmp(marsmode, "MIR") == 0) {
