@@ -9,15 +9,17 @@
 
 // geo_to_grib.cc, 010309/vk   (Q&D hack of tomatrix.cc)
 
+#include <algorithm>
+#include <cstring>
+#include <list>
+#include <sstream>
 #include <string>
-#include "inc_iostream.h"
-#include "inc_stl.h"
+#include <vector>
 
 #include "Metview.h"
 #include "LLMatrixToGRIB.h"
 #include "MvGeoPoints.h"
 #include "MvStopWatch.h"
-#include "min_max_macros.h"
 
 
 #ifndef MISSING_DATA
@@ -56,8 +58,8 @@ class ToMatrix
     int Parameter;
     int Table2;
     double* Matrix;
-    vector<list<size_t> > LatListVec; // will store indexes
-    MvField* templateField;  // template field - defines the output grid
+    std::vector<std::list<size_t> > LatListVec;  // will store indexes
+    MvField* templateField;                      // template field - defines the output grid
 
 public:
     enum GribDefinitionMode
@@ -68,7 +70,7 @@ public:
 
     ToMatrix(MvRequest&);
     int load(const char*);
-    int save(string&);
+    int save(std::string&);
     bool estimate();
     bool estimateToUserGrid();
     bool estimateToTemplateGrid();
@@ -77,8 +79,8 @@ public:
     bool convertUserToTemplateGrid();
     double value(float lat, float lon);
     void sortPoints();
-    string& errorMessage() { return errorMessage_; };
-    GribDefinitionMode mode() { return gribDefMode; };
+    std::string& errorMessage() { return errorMessage_; }
+    GribDefinitionMode mode() { return gribDefMode; }
 
 protected:
     GribDefinitionMode gribDefMode;
@@ -87,7 +89,7 @@ protected:
     float long360(float x) { return x < 0 ? x + 360 : x; }
     float minDistance(float x1, float x2);
     int latBand(float lat);
-    string errorMessage_;
+    std::string errorMessage_;
 };
 
 //_____________________________________________________________________
@@ -96,15 +98,15 @@ class GeoToGRIB : public MvService
 {
 public:
     GeoToGRIB() :
-        MvService("GEO_TO_GRIB"){};
+        MvService("GEO_TO_GRIB") {}
     void serve(MvRequest&, MvRequest&);
 };
 //_____________________________________________________________________
 
 double makeDateNumber(long date, long time)
 {
-    double myDate = date;
-    double myTime = (double)time;
+    auto myDate = double(date);
+    auto myTime = double(time);
 
     if (myDate < 470620)  //-- must be relative => no time
         return myDate;
@@ -131,7 +133,7 @@ double makeDateNumber(long date, long time)
 
 ToMatrix::ToMatrix(MvRequest& def)
 {
-    string mode = (const char*)def("GRID_DEFINITION_MODE");
+    std::string mode = (const char*)def("GRID_DEFINITION_MODE");
 
     if (mode == "USER") {
         gribDefMode = User;
@@ -170,10 +172,10 @@ ToMatrix::ToMatrix(MvRequest& def)
     }
 
 
-    Tolerance = def("TOLERANCE");
-    Parameter = def("PARAMETER");
-    Table2    = def("GRIB_TABLE2_VERSION");
-    string st = (const char*)def("INTERPOLATION_METHOD");
+    Tolerance      = def("TOLERANCE");
+    Parameter      = def("PARAMETER");
+    Table2         = def("GRIB_TABLE2_VERSION");
+    std::string st = (const char*)def("INTERPOLATION_METHOD");
 
     if (st == "RECIPROCAL")
         Weight_ = G2G_RECIPROCAL;
@@ -196,7 +198,7 @@ ToMatrix::ToMatrix(MvRequest& def)
     GPoints.load(path);
     Date = makeDateNumber(GPoints.date(0), GPoints.time(0));
 
-    list<size_t> emptyList;
+    std::list<size_t> emptyList;
     LatListVec.assign(cLatBandCount + 1, emptyList);
 }
 //_____________________________________________________________________
@@ -207,24 +209,22 @@ double ToMatrix::value(float lat, float lon)
     double dist, coef;
     double sigma = 0;
 
-    int band1 = latBand(min((int)((lat + Tolerance) + 0.5), 90));
-    int band2 = latBand(max((int)((lat - Tolerance) - 0.5), -90));
+    int band1 = latBand(std::min((int)((lat + Tolerance) + 0.5), 90));
+    int band2 = latBand(std::max((int)((lat - Tolerance) - 0.5), -90));
 
     for (int b = band1; b >= band2; --b) {
-        for (list<size_t>::iterator gp_iter = LatListVec[b].begin();
-             gp_iter != LatListVec[b].end();
-             ++gp_iter) {
-            float pi_lat = GPoints.lat_y(*gp_iter);
+        for (const auto& gp_iter : LatListVec[b]) {
+            float pi_lat = GPoints.lat_y(gp_iter);
 
             if ((fabs(lat - pi_lat)) > Tolerance)
                 continue;
 
-            float pi_lon = GPoints.lon_x(*gp_iter);
+            float pi_lon = GPoints.lon_x(gp_iter);
             if (minDistance(pi_lon, lon) > Tolerance)
                 continue;
 
             //-- Here we have found a point inside the Interval;
-            if (!GPoints.value_missing(*gp_iter, 0)) {
+            if (!GPoints.value_missing(gp_iter, 0)) {
                 double x = minDistance(lon, pi_lon);
                 double y = lat - pi_lat;
                 dist     = (x * x) + (y * y);
@@ -232,7 +232,7 @@ double ToMatrix::value(float lat, float lon)
                 // Compute weight
                 if (Weight_ == G2G_RECIPROCAL) {
                     if (dist == 0)
-                        return GPoints.value(*gp_iter);  //-- Here the point is on the Grid
+                        return GPoints.value(gp_iter);  //-- Here the point is on the Grid
                     dist = 1 / dist;
                 }
                 else  // exponential
@@ -244,7 +244,7 @@ double ToMatrix::value(float lat, float lon)
                 }
 
                 sigma += dist;
-                coef = dist * GPoints.value(*gp_iter);
+                coef = dist * GPoints.value(gp_iter);
 
                 if (val == MISSING_DATA)
                     val = coef;
@@ -287,7 +287,7 @@ int ToMatrix::latBand(float lat)
 
 void ToMatrix::sortPoints()
 {
-    ostringstream oss;
+    std::ostringstream oss;
     oss << "ToMatrix::sortPoints(): Lat Band Size & Count: "
         << cLatBandSize
         << ", "
@@ -492,13 +492,13 @@ bool ToMatrix::convertUserToTemplateGrid()
 
     setupUserMatrix(true);
 
-    string llmatrixpath;
+    std::string llmatrixpath;
     if (save(llmatrixpath)) {
         marslog(LOG_INFO, "geo_to_grib: can not write matrix into file %s", llmatrixpath.c_str());
         return false;
     }
 
-    string tmpGribFile = marstmp();
+    std::string tmpGribFile = marstmp();
 
     if (LLMatrixToGRIB(llmatrixpath.c_str(), tmpGribFile.c_str())) {
         marslog(LOG_INFO, "geo_to_grib: conversion from geo/LLMatrix to GRIB failed");
@@ -519,14 +519,14 @@ bool ToMatrix::convertUserToTemplateGrid()
 
 //_____________________________________________________________________
 
-int ToMatrix::save(string& path)  // returns path to caller
+int ToMatrix::save(std::string& path)  // returns path to caller
 {
     if (gribDefMode == User) {
         // create an LLMatrix text file to be later converted to GRIB
 
         path    = marstmp();
         FILE* f = fopen(path.c_str(), "w");
-        if (f == NULL)
+        if (f == nullptr)
             return 1;
 
         fprintf(f, "#LLMATRIX\n");
@@ -557,7 +557,7 @@ int ToMatrix::save(string& path)  // returns path to caller
         // clone the template GRIB field and copy the computed values to it
 
         field* z = copy_field(templateField->libmars_field(), false);
-        memcpy(z->values, Matrix, numValsInTemplateGrib * sizeof(double));
+        std::memcpy(z->values, Matrix, numValsInTemplateGrib * sizeof(double));
 
         // there could be missing values in the generated GRIB
         z->bitmap = true;
@@ -595,12 +595,12 @@ void GeoToGRIB::serve(MvRequest& in, MvRequest& out)
     timer.lapTime("estimate");
 
 
-    string tmpGribFile;
+    std::string tmpGribFile;
 
     if (matrix.mode() == ToMatrix::User) {
         // create an intermediate LLMatrix file, then convert to GRIB
 
-        string path;
+        std::string path;
 
         if (matrix.save(path)) {
             setError(1, "GeoToGRIB-> can not write matrix into file %s", path.c_str());
