@@ -10,7 +10,7 @@
 #include "NcExaminer.h"
 
 #include "LogHandler.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "MvNetCDF.h"
 #include "MvQAbout.h"
 #include "MvQFileInfoLabel.h"
@@ -49,11 +49,11 @@ NcExaminer::NcExaminer(QWidget* parent) :
     setCentralWidget(mainSplitter_);
 
     // The main layout (the upper part of mainSplitter)
-    QVBoxLayout* mainLayout = new QVBoxLayout;
+    auto* mainLayout = new QVBoxLayout;
     mainLayout->setObjectName(QString::fromUtf8("vboxLayout"));
     mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->setSpacing(1);
-    QWidget* w = new QWidget;
+    auto* w = new QWidget;
     w->setLayout(mainLayout);
     mainSplitter_->addWidget(w);
 
@@ -146,7 +146,7 @@ void NcExaminer::setupViewActions()
 void NcExaminer::setupHelpActions()
 {
     // About
-    QAction* actionAbout = new QAction(this);
+    auto* actionAbout = new QAction(this);
     actionAbout->setObjectName(QString::fromUtf8("actionAbout"));
     actionAbout->setText(tr("&About NetCDF Examiner"));
 
@@ -159,9 +159,9 @@ void NcExaminer::setupHelpActions()
 void NcExaminer::setupParamBox()
 {
     // Build a box layout
-    QVBoxLayout* textRepLayout = new QVBoxLayout;
+    auto* textRepLayout = new QVBoxLayout;
     textRepLayout->setContentsMargins(0, 0, 0, 0);
-    QWidget* textRepPanel = new QWidget(this);
+    auto* textRepPanel = new QWidget(this);
     textRepPanel->setLayout(textRepLayout);
     metaTab_->addTab(textRepPanel, tr("Meta data"));
 
@@ -177,15 +177,15 @@ void NcExaminer::setupParamBox()
     treeParam_->setHeaderLabels(headerTexts);
 
     // Build the three main leaves
-    QTreeWidgetItem* top1 = new QTreeWidgetItem(treeParam_);
+    auto* top1 = new QTreeWidgetItem(treeParam_);
     top1->setText(0, tr("Variables"));
     top1->setExpanded(true);
 
-    QTreeWidgetItem* top2 = new QTreeWidgetItem(treeParam_);
+    auto* top2 = new QTreeWidgetItem(treeParam_);
     top2->setText(0, tr("Dimensions"));
     top2->setExpanded(true);
 
-    QTreeWidgetItem* top3 = new QTreeWidgetItem(treeParam_);
+    auto* top3 = new QTreeWidgetItem(treeParam_);
     top3->setText(0, tr("Global Attributes"));
     top3->setExpanded(true);
 }
@@ -193,9 +193,9 @@ void NcExaminer::setupParamBox()
 void NcExaminer::setupDumpBox()
 {
     // Build a box layout
-    QVBoxLayout* dumpLayout = new QVBoxLayout;
+    auto* dumpLayout = new QVBoxLayout;
     dumpLayout->setContentsMargins(0, 0, 0, 0);
-    QWidget* dumpPanel = new QWidget(this);
+    auto* dumpPanel = new QWidget(this);
     dumpPanel->setLayout(dumpLayout);
     metaTab_->addTab(dumpPanel, tr("Ncdump"));
 
@@ -204,7 +204,7 @@ void NcExaminer::setupDumpBox()
     dumpLayout->addWidget(dumpText_);
 }
 
-bool NcExaminer::initMetaData(const string& filename)
+bool NcExaminer::initMetaData(const std::string& filename)
 {
     // Clean metadata if already exists
     if (data_) {
@@ -246,8 +246,8 @@ bool NcExaminer::initMetaData(const string& filename)
     MvNcDim* dim;
     QTreeWidgetItem* item = treeParam_->topLevelItem(1);
     for (i = 0; i < data_->getNumberOfDimensions(); i++) {
-        dim                  = data_->getDimension(i);
-        QTreeWidgetItem* sub = new QTreeWidgetItem(item);
+        dim       = data_->getDimension(i);
+        auto* sub = new QTreeWidgetItem(item);
         sub->setText(0, QString(dim->name()));
         sub->setText(1, QString::number(dim->size()));
     }
@@ -257,12 +257,12 @@ bool NcExaminer::initMetaData(const string& filename)
     if (data_->getNumberOfAttributes() == 0)
         item->setDisabled(true);
     else {
-        string values;
+        std::string values;
         MvNcAtt* att;
         for (i = 0; i < data_->getNumberOfAttributes(); i++) {
             att = data_->getAttribute(i);
             att->getValues(values);
-            QTreeWidgetItem* sub = new QTreeWidgetItem(item);
+            auto* sub = new QTreeWidgetItem(item);
             sub->setText(0, QString(att->name()));
             sub->setText(1, QString::fromStdString(values));
         }
@@ -275,9 +275,9 @@ bool NcExaminer::initMetaData(const string& filename)
 
 void NcExaminer::showDumpBox()
 {
-    stringstream in, err;
+    std::stringstream in, err;
 
-    string buf = "ncdump '" + data_->path() + "'";
+    std::string buf = "ncdump '" + data_->path() + "'";
 
     // Send initial info to the log area
     GuiLog().task() << "Calling netCDF ncdump command" << GuiLog().commandKey() << buf;
@@ -321,11 +321,11 @@ void NcExaminer::showVariables()
         var = data_->getVariable(i);  // variable information
 
         // Get variable's type
-        string str;
+        std::string str;
         var->getStringType(str);
 
         // Add variable name to the interface
-        QTreeWidgetItem* sub = new QTreeWidgetItem(item);
+        auto* sub = new QTreeWidgetItem(item);
         sub->setText(0, QString::fromStdString(var->name()));
         sub->setData(0, Qt::UserRole, i);
         sub->setExpanded(false);
@@ -340,21 +340,21 @@ void NcExaminer::showVariables()
             else
                 qstr += dim->name() + (QString) ", ";
         }
-        QTreeWidgetItem* sub1 = new QTreeWidgetItem(sub);
+        auto* sub1 = new QTreeWidgetItem(sub);
         sub1->setText(0, QString("Type"));
         sub1->setText(1, QString::fromStdString(str));
-        QTreeWidgetItem* sub2 = new QTreeWidgetItem(sub);
+        auto* sub2 = new QTreeWidgetItem(sub);
         sub2->setText(0, QString("Dimensions"));
         sub2->setText(1, qstr);
 
         // Add variable attributes
         if (var->getNumberOfAttributes()) {
-            QTreeWidgetItem* subat = new QTreeWidgetItem(sub);
+            auto* subat = new QTreeWidgetItem(sub);
             subat->setText(0, QString("Attributes"));
             for (j = 0; j < var->getNumberOfAttributes(); j++) {
                 MvNcAtt* att = var->getAttribute(j);
                 att->getValues(str);
-                QTreeWidgetItem* sub1 = new QTreeWidgetItem(subat);
+                auto* sub1 = new QTreeWidgetItem(subat);
                 sub1->setText(0, QString(att->name()));
                 sub1->setText(1, QString::fromStdString(str));
             }
@@ -365,15 +365,15 @@ void NcExaminer::showVariables()
         long maxvals = 20;                    // number of values to be printed
         QStringList strvals;
         getDataValues(var, strvals, maxvals);  // get values
-        QTreeWidgetItem* sub3 = new QTreeWidgetItem(sub);
+        auto* sub3 = new QTreeWidgetItem(sub);
         sub3->setText(0, "Data values");
         for (j = 0; j < maxvals; j++) {
-            QTreeWidgetItem* sub1 = new QTreeWidgetItem(sub3);
+            auto* sub1 = new QTreeWidgetItem(sub3);
             sub1->setText(1, strvals[j]);
         }
         if (maxvals < nvals) {
-            QTreeWidgetItem* sub1 = new QTreeWidgetItem(sub3);
-            qstr                  = "  ... " + QString::number(nvals - maxvals) + " more values";
+            auto* sub1 = new QTreeWidgetItem(sub3);
+            qstr       = "  ... " + QString::number(nvals - maxvals) + " more values";
             sub1->setText(1, qstr);
         }
     }
@@ -384,32 +384,32 @@ void NcExaminer::getDataValues(MvNcVar* var, QStringList& sdata, long& nvals)
     // Get data
     long* edges = var->edges();
     if (var->type() == ncChar) {
-        vector<Cached> datavec;
+        std::vector<Cached> datavec;
         var->get(datavec, edges, nvals);
         print_data(datavec, sdata, nvals);
     }
     else if (var->type() == ncFloat) {
-        vector<float> datavec;
+        std::vector<float> datavec;
         var->get(datavec, edges, nvals);
         print_data(datavec, sdata, nvals);
     }
     else if (var->type() == ncDouble) {
-        vector<double> datavec;
+        std::vector<double> datavec;
         var->get(datavec, edges, nvals);
         print_data(datavec, sdata, nvals);
     }
     else if (var->type() == ncByte) {
-        vector<ncbyte> datavec;
+        std::vector<ncbyte> datavec;
         var->get(datavec, edges, nvals);
         print_data(datavec, sdata, nvals);
     }
     else if (var->type() == ncShort) {
-        vector<short> datavec;
+        std::vector<short> datavec;
         var->get(datavec, edges, nvals);
         print_data(datavec, sdata, nvals);
     }
     else if (var->type() == ncLong) {
-        vector<nclong> datavec;
+        std::vector<nclong> datavec;
         var->get(datavec, edges, nvals);
         print_data(datavec, sdata, nvals);
     }
@@ -420,11 +420,11 @@ void NcExaminer::getDataValues(MvNcVar* var, QStringList& sdata, long& nvals)
 
 // Template function to write values to Re widget
 template <class T>
-void NcExaminer::print_data(vector<T>& datavec, QStringList& sdata, long nvals)
+void NcExaminer::print_data(std::vector<T>& datavec, QStringList& sdata, long nvals)
 {
     long num = (datavec.size() < (unsigned)nvals) ? datavec.size() : nvals;
     for (long j = 0; j < num; j++) {
-        stringstream oss;
+        std::stringstream oss;
         oss << datavec[j];
         sdata.append(QString::fromStdString(oss.str()));
     }
