@@ -15,7 +15,7 @@
 #include "MvObs.h"
 #include "MvException.h"
 #include "MvKeyProfile.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "MvEccBufr.h"
 
 #include "BufrFilterDef.h"
@@ -25,14 +25,14 @@ class BufrFilter : public MvService
 {
 public:
     BufrFilter();
-    ~BufrFilter() {}
+    ~BufrFilter() = default;
+
+    BufrFilter(const BufrFilter&) = delete;
+    void operator=(const BufrFilter&) = delete;
 
     void serve(MvRequest&, MvRequest&);
 
 private:
-    BufrFilter(const BufrFilter&);
-    void operator=(const BufrFilter&);
-
     void getParam(MvRequest& in, const std::string& param);
     void getParamVec(MvRequest& in, const std::string& param, const std::string& separator = "/");
 
@@ -76,7 +76,7 @@ void BufrFilter::getParam(MvRequest& in, const std::string& param)
 
 void BufrFilter::getParamVec(MvRequest& in, const std::string& param, const std::string& separator)
 {
-    std::vector<string> vals;
+    std::vector<std::string> vals;
     if (in.getValue(param, vals)) {
         def_.add(param, metview::merge(vals, separator));
     }
@@ -84,7 +84,7 @@ void BufrFilter::getParamVec(MvRequest& in, const std::string& param, const std:
 
 void BufrFilter::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "BufrFilter::serve() in" << endl;
+    std::cout << "BufrFilter::serve() in" << std::endl;
     in.print();
 
     getParam(in, "OUTPUT");
@@ -101,9 +101,10 @@ void BufrFilter::serve(MvRequest& in, MvRequest& out)
         return;
     }
 
-    if (outFormat ==  "BUFR") {
+    if (outFormat == "BUFR") {
         def_.add("EXTRACT", "OFF");
-    } else {
+    }
+    else {
         def_.add("EXTRACT", "ON");
     }
 
@@ -116,7 +117,7 @@ void BufrFilter::serve(MvRequest& in, MvRequest& out)
     if (!cntVal.empty()) {
         int cnt = metview::fromString<int>(cntVal);
         for (int i = 0; i < cnt; i++) {
-            std::string numStr = metview::toString(i + 1);
+            std::string numStr = std::to_string(i + 1);
             getParam(in, "PARAMETER_" + numStr);
             getParam(in, "PARAMETER_RANK_" + numStr);
             getParam(in, "PARAMETER_OPERATOR_" + numStr);
@@ -129,7 +130,7 @@ void BufrFilter::serve(MvRequest& in, MvRequest& out)
     if (!cntVal.empty()) {
         int cnt = metview::fromString<int>(cntVal);
         for (int i = 0; i < cnt; i++) {
-            std::string numStr = metview::toString(i + 1);
+            std::string numStr = std::to_string(i + 1);
             getParam(in, "COORDINATE_" + numStr);
             getParamVec(in, "COORDINATE_RANK_" + numStr);
             getParam(in, "COORDINATE_OPERATOR_" + numStr);
@@ -172,7 +173,7 @@ void BufrFilter::serve(MvRequest& in, MvRequest& out)
     if (!cntVal.empty()) {
         int cnt = metview::fromString<int>(cntVal);
         for (int i = 0; i < cnt; i++) {
-            std::string numStr = metview::toString(i + 1);
+            std::string numStr = std::to_string(i + 1);
             getParam(in, "CUSTOM_KEY_" + numStr);
             getParam(in, "CUSTOM_RANK_" + numStr);
             getParam(in, "CUSTOM_OPERATOR_" + numStr);
@@ -183,7 +184,7 @@ void BufrFilter::serve(MvRequest& in, MvRequest& out)
     BufrFilterEngine filter(bufrFile, BufrFilterEngine::IconMode, 0);
 
     //The object to store the extracted values
-    MvKeyProfile* extractedProf = new MvKeyProfile("result");
+    auto* extractedProf = new MvKeyProfile("result");
 
     //The output file
     std::string resFile(marstmp());
@@ -191,7 +192,8 @@ void BufrFilter::serve(MvRequest& in, MvRequest& out)
 
     if (outFormat == "CSV") {
         x = MvRequest("TABLE");  //CSV represented by TABLE in metview
-    } else if (outFormat == "BUFR") {
+    }
+    else if (outFormat == "BUFR") {
         x = MvRequest("BUFR");
     }
     else {
@@ -201,17 +203,17 @@ void BufrFilter::serve(MvRequest& in, MvRequest& out)
     x("PATH")      = resFile.c_str();
 
 #if 0
-    outfile_.open( fileName, ios::out );if(def_.value("OUTPUT") == "CSV")
+    outfile_.open( fileName, std::ios::out );if(def_.value("OUTPUT") == "CSV")
 
-    outfile_ << "#GEO" << endl;
+    outfile_ << "#GEO" << std::endl;
 
     if( geoVectorType_ > 0 )
-       outfile_ << "#FORMAT " << geoVectorName_[geoVectorType_] << endl;
+       outfile_ << "#FORMAT " << geoVectorName_[geoVectorType_] << std::endl;
 
     if ( geoVectorType_ > 0 )
-       outfile_ << "PARAMETER = " << param_ << mySeparator << param2_ << endl;
+       outfile_ << "PARAMETER = " << param_ << mySeparator << param2_ << std::endl;
     else
-       outfile_ << "PARAMETER = " << param_ << endl;
+       outfile_ << "PARAMETER = " << param_ << std::endl;
 
     outfile_ << "#lat" << mySeparator << "long" << mySeparator
              << "level" << mySeparator << "date" << mySeparator
@@ -219,7 +221,7 @@ void BufrFilter::serve(MvRequest& in, MvRequest& out)
 #endif
 
     //the USE_PREFILTER option is only used for test purposes at the moment
-    MvEccBufr* bd = NULL;
+    MvEccBufr* bd = nullptr;
     if (const char* val = in("USE_PREFILTER")) {
         if (strcmp(val, "1") == 0) {
             bd = new MvEccBufr(bufrFile);
@@ -250,7 +252,7 @@ void BufrFilter::serve(MvRequest& in, MvRequest& out)
 
     out = x;
 
-    cout << "BufrFilter::serve() out" << endl;
+    std::cout << "BufrFilter::serve() out" << std::endl;
     out.print();
 }
 
