@@ -26,14 +26,14 @@
 class BufrPicker : public MvService
 {
 private:
-    BufrPicker(const BufrPicker&);
-    void operator=(const BufrPicker&);
-
     bool failOnError_;
 
 public:
     BufrPicker();
-    ~BufrPicker(){};
+    ~BufrPicker() = default;
+
+    BufrPicker(const BufrPicker&) = delete;
+    void operator=(const BufrPicker&) = delete;
 
     void serve(MvRequest&, MvRequest&);
 
@@ -60,7 +60,7 @@ void BufrPicker::getInputParams(MvRequest& in, MvRequest& out)
 
     //Get parameter values
     MvObs obs;
-    string aux;
+    std::string aux;
     if ((const char*)in("PARAMETER"))
         aux = (const char*)in("PARAMETER");
 
@@ -71,12 +71,12 @@ void BufrPicker::getInputParams(MvRequest& in, MvRequest& out)
     out("PARAMETER_COUNT") = nparams;
     for (int i = 0; i < nparams; i++) {
         // Convert descriptor to key
-        string spar1 = (const char*)in("PARAMETER", i);
-        string spar2 = obs.keyC(spar1);
+        std::string spar1 = (const char*)in("PARAMETER", i);
+        std::string spar2 = obs.keyC(spar1);
 
         // Add parameter to the request
-        ostringstream sparam;
-        sparam << "PARAMETER_" << i + 1 << ends;
+        std::ostringstream sparam;
+        sparam << "PARAMETER_" << i + 1 << std::ends;
         out.setValue(sparam.str().c_str(), spar2.c_str());
     }
 
@@ -104,21 +104,21 @@ void BufrPicker::getInputParams(MvRequest& in, MvRequest& out)
     out("COORDINATE_COUNT") = ncoords;
     for (int i = 0; i < ncoords; i++) {
         // Convert descriptor to key
-        string spar1 = (const char*)in("COORDINATE_DESCRIPTORS", i);
-        string spar2 = obs.keyC(spar1);
+        std::string spar1 = (const char*)in("COORDINATE_DESCRIPTORS", i);
+        std::string spar2 = obs.keyC(spar1);
 
         // Add descriptor to the request
-        ostringstream sparam;
-        sparam << "COORDINATE_" << i + 1 << ends;
+        std::ostringstream sparam;
+        sparam << "COORDINATE_" << i + 1 << std::ends;
         out.setValue(sparam.str().c_str(), spar2.c_str());
 
         // Check for value ALL
-        string coordValStr = (const char*)in("COORDINATE_VALUES", i);
+        std::string coordValStr = (const char*)in("COORDINATE_VALUES", i);
         if (coordValStr == "ALL")
             extractAll = true;
         else {
-            ostringstream sparam1;
-            sparam1 << "COORDINATE_VALUE_" << i + 1 << ends;
+            std::ostringstream sparam1;
+            sparam1 << "COORDINATE_VALUE_" << i + 1 << std::ends;
             out(sparam1.str().c_str()) = (const char*)in("COORDINATE_VALUES", i);
         }
     }
