@@ -7,14 +7,20 @@
 
  ***************************** LICENSE END *************************************/
 
-#include "inc_iostream.h"
-#include <time.h>
+#include <fstream>
+#include <iostream>
+#include <sstream>
+#include <string>
 #include <vector>
 
+#include "fstream_mars_fix.h"
+
+#include <time.h>
+
 #include "Metview.h"
 #include "MvObs.h"
 #include "MvException.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "MvGeoPoints.h"
 
 const char cTab   = 9;  // ascii code for 'tab'
@@ -42,34 +48,34 @@ enum eOutput
     eCSV,
     eNCOLS
 };
-string outTypeStr[] = {"BUFR", "GEOPOINTS", "POLAR_VECTOR", "XY_VECTOR", "CSV", "NCOLS"};
+
+std::string outTypeStr[] = {"BUFR", "GEOPOINTS", "POLAR_VECTOR", "XY_VECTOR", "CSV", "NCOLS"};
 
 //__________________________________________________________ ObsFilter
 
 class ObsFilter : public MvService
 {
-private:
-    ObsFilter(const ObsFilter& anOther);
-    void operator=(const ObsFilter& anOther);
-
 public:
     ObsFilter();
     ~ObsFilter();
 
+    ObsFilter(const ObsFilter& anOther) = delete;
+    void operator=(const ObsFilter& anOther) = delete;
+
     void serve(MvRequest&, MvRequest&);
 
 protected:
-    void getParams(void);
-    void getData(void);
-    void getParameterSpecifiers(void);
-    void getTypes(void);
-    void getTimes(void);
-    void getWmoIds(void);
-    void getLocation(void);
-    void getCustom(void);
+    void getParams();
+    void getData();
+    void getParameterSpecifiers();
+    void getTypes();
+    void getTimes();
+    void getWmoIds();
+    void getLocation();
+    void getCustom();
     MvRequest createRequest();
     void add();
-    void close(void);
+    void close();
     float surfaceValue(long parInd);
     float pressureLevelValue(float level, long parInd);
     float layerValue(float level1, float level2, long parInd);
@@ -86,17 +92,17 @@ private:
     MvObsSetIterator* _iter{nullptr};
     eOutput outType_;
     MvObsSet* _outBufr{nullptr};
-    ofstream _outFile;
+    std::ofstream _outFile;
     eLevel _level{LVL_Surface};
     float _firstLevel{0.};
     float _secondLevel{0.};
     long _occurrenceIndex{0};
-    vector<std::string> param_;
+    std::vector<std::string> param_;
     ENextReturn _obsOrMsg{NR_returnMsg};  //-- for multisubset msgs (filtering also with subset data?)
     bool _includeMissingValues{false};
     float _missingValue{GEOPOINTS_MISSING_VALUE};
     bool failOnError_{true};
-    bool failOnEmptyOutput_{false}; //-- this breaks backwards compatibility
+    bool failOnEmptyOutput_{false};  //-- this breaks backwards compatibility
     std::string _coordLevelDescriptor;
     bool hasAttributeCondition_{false};
 };
@@ -118,7 +124,7 @@ ObsFilter::~ObsFilter()
     obs_.clear();
 }
 //_________________________________________________________
-void ObsFilter ::getData(void)
+void ObsFilter ::getData()
 {
     //-- D A T A --
     _in.getValue(_data, "DATA");
@@ -140,7 +146,7 @@ void ObsFilter ::getData(void)
         failOnEmptyOutput_ = false;  // default value
 }
 //_________________________________________________________
-void ObsFilter ::getParameterSpecifiers(void)
+void ObsFilter ::getParameterSpecifiers()
 {
     //-- P A R A M E T E R --
     int nrParams = _in.countValues("PARAMETER");
@@ -166,8 +172,8 @@ void ObsFilter ::getParameterSpecifiers(void)
     }
 
     //Check if there are attributes in params
-    for (size_t i = 0; i < param_.size(); i++) {
-        if (param_[i].find("->") != std::string::npos) {
+    for (auto& i : param_) {
+        if (i.find("->") != std::string::npos) {
             hasAttributeCondition_ = true;
             break;
         }
@@ -215,7 +221,7 @@ void ObsFilter ::getParameterSpecifiers(void)
     }
 }
 //_________________________________________________________
-void ObsFilter ::getTypes(void)
+void ObsFilter ::getTypes()
 {
     int i;
 
@@ -240,7 +246,7 @@ void ObsFilter ::getTypes(void)
     }
 }
 //_________________________________________________________
-void ObsFilter ::getTimes(void)
+void ObsFilter ::getTimes()
 {
     const char* obsTimeStr = _in("DATE_AND_TIME_FROM");
     if (obsTimeStr && strcmp(obsTimeStr, "DATA") == 0)
@@ -275,7 +281,7 @@ void ObsFilter ::getTimes(void)
     }
 }
 //_________________________________________________________
-void ObsFilter ::getWmoIds(void)
+void ObsFilter ::getWmoIds()
 {
     int i;
 
@@ -305,7 +311,7 @@ void ObsFilter ::getWmoIds(void)
     }
 }
 //_________________________________________________________
-void ObsFilter ::getLocation(void)
+void ObsFilter ::getLocation()
 {
     const char* locFilterStr = _in("LOCATION_FILTER");
     if (locFilterStr && strcmp(locFilterStr, "AREA") == 0) {
@@ -347,7 +353,7 @@ void ObsFilter ::getLocation(void)
     }
 }
 //_________________________________________________________
-void ObsFilter ::getCustom(void)
+void ObsFilter ::getCustom()
 {
     const char* customFilterStr  = _in("CUSTOM_FILTER");
     std::string customDescriptor = "";
@@ -392,7 +398,7 @@ void ObsFilter ::getCustom(void)
     }
 }
 //_________________________________________________________
-void ObsFilter ::getParams(void)
+void ObsFilter ::getParams()
 {
     _obsOrMsg = NR_returnMsg;  //-- set msg level as default
 
@@ -439,14 +445,14 @@ ObsFilter ::createRequest()
             x("TEMPORARY") = 1;
             x("PATH")      = fileName;
 
-            _outFile.open(fileName, ios::out);
+            _outFile.open(fileName, std::ios::out);
             //-- construct CSV header line
             for (unsigned int p = 0; p < param_.size(); ++p) {
                 if (p > 0)
                     _outFile << cComma;
                 _outFile << "'" << param_[p] << "'";
             }
-            _outFile << endl;
+            _outFile << std::endl;
 
             return x;
         }
@@ -460,17 +466,17 @@ ObsFilter ::createRequest()
             x("TEMPORARY") = 1;
             x("PATH")      = fileName;
 
-            _outFile.open(fileName, ios::out);
+            _outFile.open(fileName, std::ios::out);
 
-            _outFile << "#GEO" << endl;  //-- construct GEOPOINTS header
+            _outFile << "#GEO" << std::endl;  //-- construct GEOPOINTS header
 
             if (outType_ == ePOLAR_VECTOR || outType_ == eXY_VECTOR)
-                _outFile << "#FORMAT " << outTypeStr[outType_] << endl;
+                _outFile << "#FORMAT " << outTypeStr[outType_] << std::endl;
 
             if (outType_ == eGEOPOINTS)
-                _outFile << "PARAMETER = " << param_[0] << endl;
+                _outFile << "PARAMETER = " << param_[0] << std::endl;
             else
-                _outFile << "PARAMETER = " << param_[0] << cTab << param_[1] << endl;
+                _outFile << "PARAMETER = " << param_[0] << cTab << param_[1] << std::endl;
 
             _outFile << "#lat" << cTab << "long" << cTab
                      << "level" << cTab << "date" << cTab
@@ -479,9 +485,9 @@ ObsFilter ::createRequest()
                 _outFile << "value";
             else
                 _outFile << "speed|u" << cTab << "direction|v";
-            _outFile << endl;
+            _outFile << std::endl;
 
-            _outFile << "#DATA" << endl;
+            _outFile << "#DATA" << std::endl;
 
             return x;
         }
@@ -493,22 +499,22 @@ ObsFilter ::createRequest()
             x("TEMPORARY") = 1;
             x("PATH")      = fileName;
 
-            _outFile.open(fileName, ios::out);
+            _outFile.open(fileName, std::ios::out);
 
-            _outFile << "#GEO" << endl;
-            _outFile << "#FORMAT NCOLS" << endl;
+            _outFile << "#GEO" << std::endl;
+            _outFile << "#FORMAT NCOLS" << std::endl;
 
-            _outFile << "#COLUMNS " << endl
+            _outFile << "#COLUMNS " << std::endl
                      << "stnid" << cTab << "latitude" << cTab << "longitude" << cTab
                      << "level" << cTab << "date" << cTab
                      << "time" << cTab;
 
-            for (size_t p = 0; p < param_.size(); p++) {
-                _outFile << param_[p] << cTab;
+            for (auto& p : param_) {
+                _outFile << p << cTab;
             }
 
-            _outFile << endl
-                     << "#DATA" << endl;
+            _outFile << std::endl
+                     << "#DATA" << std::endl;
 
             return x;
         }
@@ -543,7 +549,7 @@ float ObsFilter::coordinateLevelValue(const std::string& coordDesc, float level,
     return obs_.valueByLevelC(coordDesc, level, param_[parInd]);
 }
 //_________________________________________________________
-float ObsFilter::coordinateRangeValue(const string& coordDesc, float level1, float level2, int parInd)
+float ObsFilter::coordinateRangeValue(const std::string& coordDesc, float level1, float level2, int parInd)
 {
     return obs_.valueByLevelRangeC(coordDesc, level1, level2, param_[parInd]);
 }
@@ -581,7 +587,7 @@ void ObsFilter ::add()
     }
     else if (outType_ == eCSV)  //-- CSV
     {
-        ostringstream os;
+        std::ostringstream os;
         bool abortOnMissing = false;
         for (unsigned int p = 0; p < param_.size(); ++p) {
             if (p > 0)
@@ -631,7 +637,7 @@ void ObsFilter ::add()
         }
 
         if (!abortOnMissing) {
-            _outFile << os.str() << endl;
+            _outFile << os.str() << std::endl;
             _counter++;
         }
     }
@@ -686,12 +692,14 @@ void ObsFilter ::add()
             MvLocation myLoc = obs_.location();
             if (myLoc.latitude() != kBufrMissingValue) {
                 _outFile << myLoc.latitude() << cTab;
-            } else {
+            }
+            else {
                 _outFile << _missingValue << cTab;
             }
             if (myLoc.longitude() != kBufrMissingValue) {
                 _outFile << myLoc.longitude() << cTab;
-            } else {
+            }
+            else {
                 _outFile << _missingValue << cTab;
             }
 
@@ -727,7 +735,7 @@ void ObsFilter ::add()
                     _outFile << cTab << myDirec;  //-- should we check against missing value?
             }
 
-            _outFile << endl;
+            _outFile << std::endl;
 
             _counter++;
         }
@@ -768,20 +776,22 @@ void ObsFilter ::add()
                 return;
         }
 
-        MvLocation myLoc = obs_.location();
+        MvLocation myLoc   = obs_.location();
         TStaticTime myTime = obs_.obsTime();
-        std::string ident =  obs_.headerIdent();
-        ident = metview::stationIdForWritingToFile(ident);
+        std::string ident  = obs_.headerIdent();
+        ident              = metview::stationIdForWritingToFile(ident);
 
         _outFile << ident << cTab;
         if (myLoc.latitude() != kBufrMissingValue) {
             _outFile << myLoc.latitude() << cTab;
-        } else {
+        }
+        else {
             _outFile << _missingValue << cTab;
         }
         if (myLoc.longitude() != kBufrMissingValue) {
             _outFile << myLoc.longitude() << cTab;
-        } else {
+        }
+        else {
             _outFile << _missingValue << cTab;
         }
 
@@ -818,7 +828,7 @@ void ObsFilter ::add()
                 _outFile << cTab;
         }
 
-        _outFile << endl;
+        _outFile << std::endl;
         _counter++;
     }
 
@@ -826,7 +836,7 @@ void ObsFilter ::add()
 }
 
 //_________________________________________________________
-void ObsFilter ::close(void)
+void ObsFilter ::close()
 {
     if (outType_ == eBUFR)
         _outBufr->close();
@@ -837,7 +847,7 @@ void ObsFilter ::close(void)
 //_________________________________________________________
 void ObsFilter ::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "ObsFilter::serve() in" << endl;
+    std::cout << "ObsFilter::serve() in" << std::endl;
     in.print();
 
     time_t myStartTime;
@@ -864,7 +874,7 @@ void ObsFilter ::serve(MvRequest& in, MvRequest& out)
         obs_.clear();  //-- initialise MvObs (serve function may be call iteractively
     }
     catch (MvException& e) {
-        string err = "ObsFilter-> Failed: ";
+        std::string err = "ObsFilter-> Failed: ";
         err += e.what();
         if (failOnError_)
             throw MvException(err.c_str());
@@ -881,17 +891,17 @@ void ObsFilter ::serve(MvRequest& in, MvRequest& out)
     sendProgress("ObsFilter-> Filtered %d observations (out of %d) into a %s file in %d secs (cpu %d secs)", _counter, _inSet->obsCount(), outTypeStr[(int)outType_].c_str(), (int)wallClockTime, (int)cpuTime);
 
     delete _iter;
-    _iter = 0;
+    _iter = nullptr;
 
     delete _inSet;
-    _inSet = 0;
+    _inSet = nullptr;
 
     if (_counter == 0 && failOnEmptyOutput_)
         throw MvException("ObsFilter-> Abort: Fail-On-Empty-Output requested!");
 
     out = x;
 
-    cout << "ObsFilter::serve() out" << endl;
+    std::cout << "ObsFilter::serve() out" << std::endl;
     out.print();
 }
 //_________________________________________________________
