@@ -21,15 +21,13 @@
 
 #include <eckit/exception/Exceptions.h>
 
-using namespace std;
 
-
-void messageToLog(const string& msg, int severity, const char* useLogWindow, MvRequest& out)
+void messageToLog(const std::string& msg, int severity, const char* useLogWindow, MvRequest& out)
 {
     if (useLogWindow) {
         MvRequest reqst("USER_MESSAGE");
         reqst("INFO") = msg.c_str();
-        send_message(MvApplication::instance().getService(), (request*)reqst);
+        send_message(MvApplication::getService(), (request*)reqst);
     }
 
     out                    = MvRequest("REPLY");
@@ -43,10 +41,10 @@ void messageToLog(const string& msg, int severity, const char* useLogWindow, MvR
 }
 
 
-void getStringLines(string ibuff, vector<string>& obuff)
+void getStringLines(std::string ibuff, std::vector<std::string>& obuff)
 {
-    string::size_type pos = 0, pos_prev = 0;
-    while ((pos = ibuff.find("\n", pos_prev)) != string::npos) {
+    std::string::size_type pos = 0, pos_prev = 0;
+    while ((pos = ibuff.find("\n", pos_prev)) != std::string::npos) {
         obuff.push_back(ibuff.substr(pos_prev, pos - pos_prev));
         pos_prev = pos + 1;
     }
@@ -55,21 +53,21 @@ void getStringLines(string ibuff, vector<string>& obuff)
     }
 }
 
-void getShellArgument(string ibuff, string& obuff)
+void getShellArgument(std::string ibuff, std::string& obuff)
 {
-    string::size_type pos = 0;
-    obuff                 = ibuff;
+    std::string::size_type pos = 0;
+    obuff                      = ibuff;
 
     //Replace linebrake with whitespace
     pos = 0;
-    while ((pos = obuff.find("\n", pos)) != string::npos) {
+    while ((pos = obuff.find("\n", pos)) != std::string::npos) {
         obuff.replace(pos, 1, " ");
         pos++;
     }
 
     //Replace linebrake with whitespace
     pos = 0;
-    while ((pos = obuff.find("$", pos)) != string::npos) {
+    while ((pos = obuff.find("$", pos)) != std::string::npos) {
         obuff.replace(pos, 1, "\\$");
         pos += 2;
     }
@@ -77,7 +75,7 @@ void getShellArgument(string ibuff, string& obuff)
 
     // "(" -> "/("
     /*pos=0;
-	while((pos=obuff.find("(",pos)) != string::npos)
+	while((pos=obuff.find("(",pos)) !=std::string::npos)
 	{
 		obuff.replace(pos,1,"\\(");
 		pos+=3;
@@ -85,7 +83,7 @@ void getShellArgument(string ibuff, string& obuff)
 
 	// ")" -> "/)" 
 	pos=0;
-	while((pos=obuff.find(")",pos)) != string::npos)
+	while((pos=obuff.find(")",pos)) !=std::string::npos)
 	{
 		obuff.replace(pos,1,"\\)");
 		pos+=3;
@@ -96,30 +94,30 @@ class Base : public MvService
 {
 protected:
     Base(const char* a) :
-        MvService(a){};
+        MvService(a) {}
 };
 
 class OdbFilter : public Base
 {
 public:
     OdbFilter() :
-        Base("ODB_FILTER"){};
+        Base("ODB_FILTER") {}
     void serve(MvRequest&, MvRequest&);
 };
 
 
 void OdbFilter::serve(MvRequest& in, MvRequest& out)
 {
-    //    cout << "---OdbFilter::serve() IN---" << endl;
+    //    std::cout << "---OdbFilter::serve() IN---" << std::endl;
     in.print();
 
     // Get prefix
-    string verb = in.getVerb();
+    std::string verb         = in.getVerb();
     const char* useLogWindow = (const char*)in("_USELOGWINDOW");
     const char* dataPath;
 
     MvRequest dataR = in("ODB_DATA");
-    if (dataR != 0) {
+    if (dataR != nullptr) {
         const char* dc = dataR("PATH");
         dataPath       = dc;
     }
@@ -127,19 +125,19 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
         dataPath = in("ODB_FILENAME");
     }
 
-    if (dataR == 0 &&
-        (dataPath == 0 || strcmp(dataPath, "OFF") == 0 || strlen(dataPath) == 0)) {
+    if (dataR == nullptr &&
+        (dataPath == nullptr || strcmp(dataPath, "OFF") == 0 || strlen(dataPath) == 0)) {
         messageToLog("No ODB file is specified!", LOG_EROR, useLogWindow, out);
         setError(13);
         return;
     }
 
-    if (static_cast<const char*>(in("ODB_QUERY")) == 0) {
+    if (static_cast<const char*>(in("ODB_QUERY")) == nullptr) {
         messageToLog("No ODB/SQL query is specified!", LOG_EROR, useLogWindow, out);
         setError(13);
         return;
     }
-    string query(in("ODB_QUERY"));
+    std::string query(in("ODB_QUERY"));
 
     /*if(static_cast<const char*>(in("ODB_OUTPUT")) == 0)
   	{
@@ -147,21 +145,21 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
 		setError(13);
 		return;			
   	}
-	string outputFormat(in("ODB_OUTPUT"));*/
-    string outputFormat("ODB");
+	std::string outputFormat(in("ODB_OUTPUT"));*/
+    std::string outputFormat("ODB");
 
 
-    if (static_cast<const char*>(in("ODB_NB_ROWS")) == 0) {
+    if (static_cast<const char*>(in("ODB_NB_ROWS")) == nullptr) {
         messageToLog("No number of rows is specified!", LOG_EROR, useLogWindow, out);
         setError(13);
         return;
     }
-    string nb_rows(in("ODB_NB_ROWS"));
+    std::string nb_rows(in("ODB_NB_ROWS"));
 
     //Find out and check odb format
-    string odbType = MvOdbType(dataPath, true);
+    std::string odbType = MvOdbType(dataPath, true);
     if (odbType != "ODB_NEW" && odbType != "ODB_OLD") {
-        stringstream err_s;
+        std::stringstream err_s;
         err_s << "Wrong data type: " << odbType << "! Only ODB_DB is accepted!";
         messageToLog(err_s.str(), LOG_EROR, useLogWindow, out);
         setError(13);
@@ -205,20 +203,20 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
     }
 
     //Outfile name
-    string outFile = marstmp();
+    std::string outFile = marstmp();
 
     //Odbsql script
-    string odbsqlScript;
+    std::string odbsqlScript;
     if (odbType == "ODB_OLD") {
         char* mvbin = getenv("METVIEW_BIN");
-        if (mvbin == 0) {
+        if (mvbin == nullptr) {
             messageToLog("No METVIEW_BIN env variable is defined. Cannot locate mv_odbsql script to run query for ODB-1 databases!",
                          LOG_EROR, useLogWindow, out);
             setError(13);
             return;
         }
         else {
-            odbsqlScript = string(mvbin) + "/mv_odbsql";
+            odbsqlScript = std::string(mvbin) + "/mv_odbsql";
         }
     }
 
@@ -226,7 +224,7 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
     // Performs filter
     //-------------------------
 
-    //string cmd="odbsql -q '" <<  query << "' -o " << outFile << " ";
+    //std::string cmd="odbsql -q '" <<  query << "' -o " << outFile << " ";
 
     if (outputFormat == "ODB") {
         if (odbType == "ODB_NEW") {
@@ -238,7 +236,7 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
             catch (eckit::Exception e)
 
             {
-                stringstream err_s;
+                std::stringstream err_s;
                 err_s << "Failed to perform retrieval: " << e.what();
                 messageToLog(err_s.str(), LOG_EROR, useLogWindow, out);
                 setError(13);
@@ -253,12 +251,12 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
         }
         else {
 #ifdef METVIEW_ODB_OLD
-            string queryForShell, dataPathForShell;
+            std::string queryForShell, dataPathForShell;
             getShellArgument(query, queryForShell);
             getShellArgument(dataPath, dataPathForShell);
 
-            string cmd = odbsqlScript + " -q \"" + queryForShell + "\" -o " + outFile +
-                         " -i " + "\"" + dataPathForShell + "\"" + " -f newodb";
+            std::string cmd = odbsqlScript + " -q \"" + queryForShell + "\" -o " + outFile +
+                              " -i " + "\"" + dataPathForShell + "\"" + " -f newodb";
 
             if (nb_rows != "-1") {
                 cmd += " -m " + nb_rows;
@@ -269,7 +267,7 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
             int ret = system(cmd.c_str());
 
             if (ret == -1 || WEXITSTATUS(ret) != 0) {
-                stringstream err_s;
+                std::stringstream err_s;
                 err_s << "Failed to perform retrieval: odbsql exited with value of " << WEXITSTATUS(ret);
                 messageToLog(err_s.str(), LOG_EROR, useLogWindow, out);
                 setError(13);
@@ -297,7 +295,7 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
              outputFormat == "GEO_XY_VECTOR" ||
              outputFormat == "GEO_POLAR_VECTOR") {
         if (odbType == "ODB_NEW") {
-            string tmpFile = marstmp();
+            std::string tmpFile = marstmp();
 
             try {
                 MvOdb::retrieveToFile(query, dataPath, tmpFile);
@@ -309,9 +307,8 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
                     return;
                 }
             }
-            catch (eckit::Exception e)
-            {
-                stringstream err_s;
+            catch (eckit::Exception e) {
+                std::stringstream err_s;
                 err_s << "Failed to perform retrieval: " << e.what();
                 messageToLog(err_s.str(), LOG_EROR, useLogWindow, out);
                 setError(13);
@@ -320,12 +317,12 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
         }
         else {
 #ifdef METVIEW_ODB_OLD
-            string queryForShell;
+            std::string queryForShell;
             getShellArgument(query, queryForShell);
 
-            string tmpFile = marstmp();
-            string cmd     = odbsqlScript + " -q \"" + queryForShell + "\" -o " + tmpFile +
-                         " -i " + dataPath + " -f newodb ";
+            std::string tmpFile = marstmp();
+            std::string cmd     = odbsqlScript + " -q \"" + queryForShell + "\" -o " + tmpFile +
+                              " -i " + dataPath + " -f newodb ";
 
             if (nb_rows != "-1") {
                 cmd += " -m " + nb_rows;
@@ -334,7 +331,7 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
             int ret = system(cmd.c_str());
 
             if (ret == -1 || WEXITSTATUS(ret) != 0) {
-                stringstream err_s;
+                std::stringstream err_s;
                 err_s << "Failed to perform retrieval: odbsql exited with value of " << WEXITSTATUS(ret);
                 messageToLog(err_s.str(), LOG_EROR, useLogWindow, out);
                 setError(13);
@@ -351,9 +348,8 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
                     return;
                 }
             }
-            catch (eckit::Exception e)
-            {
-                stringstream err_s;
+            catch (eckit::Exception e) {
+                std::stringstream err_s;
                 err_s << "Failed to convert retrieval result into geopoints: " << e.what();
                 messageToLog(err_s.str(), LOG_EROR, useLogWindow, out);
                 setError(13);
@@ -369,7 +365,7 @@ void OdbFilter::serve(MvRequest& in, MvRequest& out)
         out = rdata;
     }
 
-    cout << "---OdbFilter::serve() OUT---" << endl;
+    std::cout << "---OdbFilter::serve() OUT---" << std::endl;
     out.print();
 }
 
