@@ -25,7 +25,7 @@ class Base : public MvService
 {
 protected:
     Base(const char* a) :
-        MvService(a){};
+        MvService(a) {}
 };
 
 class OdbVisualiser : public Base
@@ -33,26 +33,26 @@ class OdbVisualiser : public Base
 public:
     OdbVisualiser(const char* a) :
         Base(a),
-        failOnEmpty_(true){};
+        failOnEmpty_(true) {}
     void serve(MvRequest&, MvRequest&);
 
 protected:
-    bool getParamValue(vector<string>&, MvRequest&, string);
+    bool getParamValue(std::vector<std::string>&, MvRequest&, std::string);
     bool isTextContained(const char* txt);
-    bool columnsHaveExpression(MvAbstractOdb*, const vector<const char*>&);
-    void buildColumnList(const vector<const char*>&, const string&, vector<string>&);
-    string buildQuery(const vector<string>&);
-    string buildQuery(const vector<string>& columns,
-                      const char* vars, const char* uniqueby,
-                      const char* from, const char* where, const char* orderby, bool);
-    bool callFilter(string path, string query, string& resPath);
+    bool columnsHaveExpression(MvAbstractOdb*, const std::vector<const char*>&);
+    void buildColumnList(const std::vector<const char*>&, const std::string&, std::vector<std::string>&);
+    std::string buildQuery(const std::vector<std::string>&);
+    std::string buildQuery(const std::vector<std::string>& columns,
+                           const char* vars, const char* uniqueby,
+                           const char* from, const char* where, const char* orderby, bool);
+    bool callFilter(std::string path, std::string query, std::string& resPath);
     bool updateRequest(MvRequest&, const char*, MvAbstractOdb*, int&);
 
     bool failOnEmpty_;
 };
 
 
-bool OdbVisualiser::getParamValue(vector<string>& value, MvRequest& in, string parName)
+bool OdbVisualiser::getParamValue(std::vector<std::string>& value, MvRequest& in, std::string parName)
 {
     value.clear();
 
@@ -61,15 +61,15 @@ bool OdbVisualiser::getParamValue(vector<string>& value, MvRequest& in, string p
     if (cnt == 1) {
         const char* cval = in(parName.c_str());
         if (cval) {
-            value.push_back(string(cval));
+            value.push_back(std::string(cval));
         }
     }
     else {
-        string val;
+        std::string val;
         for (int i = 0; i < cnt; i++) {
             const char* cval = in(parName.c_str(), i);
             if (cval) {
-                value.push_back(string(cval));
+                value.push_back(std::string(cval));
             }
         }
     }
@@ -81,19 +81,19 @@ bool OdbVisualiser::isTextContained(const char* txt)
 {
     if (!txt)
         return false;
-    string str(txt);
+    std::string str(txt);
 
-    return (str.find_last_not_of(" \n\t") != string::npos);
+    return (str.find_last_not_of(" \n\t") != std::string::npos);
 }
 
-bool OdbVisualiser::columnsHaveExpression(MvAbstractOdb* db, const vector<const char*>& cols)
+bool OdbVisualiser::columnsHaveExpression(MvAbstractOdb* db, const std::vector<const char*>& cols)
 {
     if (!db)
         return true;
 
-    for (unsigned int i = 0; i < cols.size(); i++) {
-        if (cols[i]) {
-            string s(cols[i]);
+    for (auto col : cols) {
+        if (col) {
+            std::string s(col);
             if (!db->hasColumn(s))
                 return true;
         }
@@ -103,11 +103,11 @@ bool OdbVisualiser::columnsHaveExpression(MvAbstractOdb* db, const vector<const
 }
 
 
-void OdbVisualiser::buildColumnList(const vector<const char*>& cols, const string& metadata, vector<string>& lst)
+void OdbVisualiser::buildColumnList(const std::vector<const char*>& cols, const std::string& metadata, std::vector<std::string>& lst)
 {
-    for (unsigned int i = 0; i < cols.size(); i++) {
-        if (cols[i]) {
-            string s(cols[i]);
+    for (auto col : cols) {
+        if (col) {
+            std::string s(col);
             lst.push_back(s);
         }
     }
@@ -116,7 +116,7 @@ void OdbVisualiser::buildColumnList(const vector<const char*>& cols, const strin
         lst.push_back(metadata);
 
     /*Tokenizer parse(",");
-	vector<string> vs;
+	std::vector<std::string> vs;
 		
 	parse(metadata,vs);
 	
@@ -127,19 +127,19 @@ void OdbVisualiser::buildColumnList(const vector<const char*>& cols, const strin
 	}*/
 }
 
-string OdbVisualiser::buildQuery(const vector<string>& columns)
+std::string OdbVisualiser::buildQuery(const std::vector<std::string>& columns)
 {
-    string query("SELECT");
+    std::string query("SELECT");
 
     bool empty = true;
-    for (unsigned int i = 0; i < columns.size(); i++) {
-        if (!columns[i].empty()) {
+    for (const auto& column : columns) {
+        if (!column.empty()) {
             if (!empty)
                 query.append(",\n");
             else
                 query.append("\n");
 
-            query.append("\t" + columns[i]);
+            query.append("\t" + column);
 
             if (empty)
                 empty = false;
@@ -152,11 +152,11 @@ string OdbVisualiser::buildQuery(const vector<string>& columns)
 }
 
 
-string OdbVisualiser::buildQuery(const vector<string>& columns,
-                                 const char* vars, const char* uniqueby, const char* from, const char* where, const char* orderby,
-                                 bool probablyNeedAQuery)
+std::string OdbVisualiser::buildQuery(const std::vector<std::string>& columns,
+                                      const char* vars, const char* uniqueby, const char* from, const char* where, const char* orderby,
+                                      bool probablyNeedAQuery)
 {
-    string query;
+    std::string query;
 
     //If the columns do not contain any expressions, we check if there is
     //any need for having a query
@@ -176,14 +176,14 @@ string OdbVisualiser::buildQuery(const vector<string>& columns,
 
     bool empty = true;
 
-    for (unsigned int i = 0; i < columns.size(); i++) {
-        if (!columns[i].empty()) {
+    for (const auto& column : columns) {
+        if (!column.empty()) {
             if (!empty)
                 query.append(",\n");
             else
                 query.append("\n");
 
-            query.append("\t" + columns[i]);
+            query.append("\t" + column);
 
             if (empty)
                 empty = false;
@@ -193,22 +193,22 @@ string OdbVisualiser::buildQuery(const vector<string>& columns,
     query.append("\n");
 
     if (from && isTextContained(from))
-        query.append("FROM \n" + string(from) + "\n");
+        query.append("FROM \n" + std::string(from) + "\n");
 
     if (uniqueby && isTextContained(uniqueby))
-        query.append("UNIQUEBY \n" + string(uniqueby) + "\n");
+        query.append("UNIQUEBY \n" + std::string(uniqueby) + "\n");
 
     if (where && isTextContained(where))
-        query.append("WHERE \n" + string(where) + "\n");
+        query.append("WHERE \n" + std::string(where) + "\n");
 
     if (orderby && isTextContained(orderby))
-        query.append("ORDER BY \n" + string(orderby) + "\n");
+        query.append("ORDER BY \n" + std::string(orderby) + "\n");
 
 
     return query;
 }
 
-bool OdbVisualiser::callFilter(string path, string query, string& resPath)
+bool OdbVisualiser::callFilter(std::string path, std::string query, std::string& resPath)
 {
     MvRequest r("ODB_FILTER");
 
@@ -226,9 +226,9 @@ bool OdbVisualiser::callFilter(string path, string query, string& resPath)
     MvRequest result = MvApplication::waitService("OdbFilter", r, error);
 
     const char* rPath = result("PATH");
-    if (error != 0 || !rPath || string(rPath).empty()) {
+    if (error != 0 || !rPath || std::string(rPath).empty()) {
         if (failOnEmpty_) {
-            string err         = "OdbVisualiser-> Calling ODB Filter failed. ";
+            std::string err    = "OdbVisualiser-> Calling ODB Filter failed. ";
             const char* errmsg = result("_FILTER_MESSAGE");
             if (errmsg)
                 err += errmsg;
@@ -238,7 +238,7 @@ bool OdbVisualiser::callFilter(string path, string query, string& resPath)
         return false;
     }
 
-    resPath = string(rPath);
+    resPath = std::string(rPath);
 
     struct stat st;
     if (stat(resPath.c_str(), &st) != 0 || st.st_size == 0) {
@@ -265,7 +265,7 @@ bool OdbVisualiser::updateRequest(MvRequest& req, const char* par, MvAbstractOdb
 
 void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "OdbVisualiser::serve in" << endl;
+    std::cout << "OdbVisualiser::serve in" << std::endl;
     in.print();
 
 #ifndef METVIEW_ODB_PLOT
@@ -275,7 +275,7 @@ void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
 
 
     // Get prefix
-    string verb = in.getVerb();
+    std::string verb = in.getVerb();
 
     const char* type = in("ODB_PLOT_TYPE");
 
@@ -284,8 +284,8 @@ void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
         return;
     }
 
-    vector<const char*> cols;
-    string outReqName;
+    std::vector<const char*> cols;
+    std::string outReqName;
 
     if (strcmp(type, "GEO_POINTS") == 0) {
         outReqName = "ODB_GEO_POINTS";
@@ -374,21 +374,21 @@ void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
     const char* orderby  = in("ODB_ORDERBY");
 
     //Get metadata columns
-    string metadata;
+    std::string metadata;
     const char* metadataC = in("ODB_METADATA_VARIABLES");
     if (metadataC)
-        metadata = string(metadataC);
+        metadata = std::string(metadataC);
 
     //Build the final column list
-    vector<string> columns;
+    std::vector<std::string> columns;
     buildColumnList(cols, metadata, columns);
 
     //-------------------------
     // Check input ODB format
     //------------------------
 
-    string odbPath;
-    string odbType;
+    std::string odbPath;
+    std::string odbType;
 
     MvRequest dataR      = in("ODB_DATA");
     const char* iconType = dataR.getVerb();
@@ -410,7 +410,7 @@ void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
             }
         }
 
-        odbPath = string(path);
+        odbPath = std::string(path);
     }
     //The icon type can only be "ODB_DB"
     else if (strcmp(iconType, "ODB_DB") != 0) {
@@ -425,7 +425,7 @@ void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
             return;
         }
         odbType = MvOdbType(path, false);
-        odbPath = string(path);
+        odbPath = std::string(path);
     }
 
     // check the FAIL ON EMPTY parameter set by the user
@@ -448,7 +448,7 @@ void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
     bool queryWasRun = false;
 
     //For ODB-1 we always need the filter!!
-    string query;
+    std::string query;
     if (odbType == "ODB_OLD") {
         //Build the query
         query = buildQuery(columns, vars, uniqueby, from, where, orderby, true);
@@ -456,7 +456,7 @@ void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
         MvRequest r;
         tmpR("ODB_DATA") = r;
 
-        string res;
+        std::string res;
         if (!callFilter(odbPath, query, res)) {
             out = r;
             return;
@@ -484,7 +484,7 @@ void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
             delete db;
 
         //Get the query
-        query = buildQuery(columns, vars, uniqueby, 0, where, orderby, needAQuery);
+        query = buildQuery(columns, vars, uniqueby, nullptr, where, orderby, needAQuery);
 
         //The query is empty if the columns do not contain any expressions
         //and there are no SET, WHERE, ORDERBY, UNIQUEBY statments specified
@@ -492,7 +492,7 @@ void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
             MvRequest r;
             tmpR("ODB_DATA") = r;
 
-            string res;
+            std::string res;
             if (!callFilter(odbPath, query, res)) {
                 out = r;
                 return;
@@ -516,9 +516,9 @@ void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
 
     if (queryWasRun == true) {
         const char* pR = tmpR("ODB_FILENAME");
-        string outPath;
+        std::string outPath;
         if (pR)
-            outPath = string(pR);
+            outPath = std::string(pR);
 
         //Get odb object to access metadata
         MvAbstractOdb* db = MvOdbFactory::make(outPath);
@@ -568,7 +568,7 @@ void OdbVisualiser::serve(MvRequest& in, MvRequest& out)
 
     out = tmpR;
 
-    cout << "OdbVisualiser::serve out" << endl;
+    std::cout << "OdbVisualiser::serve out" << std::endl;
     out.print();
 
     return;
