@@ -82,7 +82,7 @@ OdbExaminer::OdbExaminer(QWidget* parent) :
     // The main layout (the upper part of mainSplitter)
     //-----------------------------------------------------
 
-    QVBoxLayout* mainLayout = new QVBoxLayout;
+    auto* mainLayout = new QVBoxLayout;
     mainLayout->setObjectName(QString::fromUtf8("vboxLayout"));
     mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->setSpacing(1);
@@ -187,7 +187,7 @@ OdbExaminer::~OdbExaminer()
 	if(dataModel_) delete dataModel_;
 	if(bitmapModel_) delete bitmapModel_;
 
-	for(vector<QStandardItemModel*>::iterator it=secModel_.begin(); it != secModel_.end(); it++)
+	for(std::vector<QStandardItemModel*>::iterator it=secModel_.begin(); it != secModel_.end(); it++)
 	{
 		delete *it;
 	}*/
@@ -216,7 +216,7 @@ void OdbExaminer::setupEditActions()
 
 void OdbExaminer::setupViewActions()
 {
-    QAction* actionFileInfo = new QAction(this);
+    auto* actionFileInfo = new QAction(this);
     actionFileInfo->setObjectName(QString::fromUtf8("actionFileInfo"));
     actionFileInfo->setText(tr("File info"));
     actionFileInfo->setCheckable(true);
@@ -249,7 +249,7 @@ void OdbExaminer::setupSettingsActions()
 void OdbExaminer::setupHelpActions()
 {
     // About
-    QAction* actionAbout = new QAction(this);
+    auto* actionAbout = new QAction(this);
     actionAbout->setObjectName(QString::fromUtf8("actionAbout"));
     actionAbout->setText(tr("&About ODB Examiner"));
 
@@ -265,8 +265,8 @@ void OdbExaminer::setupTableBox()
     // Message tree (key profile)
     //--------------------------------
 
-    tablePanel_              = new QWidget;
-    QVBoxLayout* tableLayout = new QVBoxLayout;
+    tablePanel_       = new QWidget;
+    auto* tableLayout = new QVBoxLayout;
     tableLayout->setContentsMargins(0, 0, 0, 0);
     tablePanel_->setLayout(tableLayout);
 
@@ -310,8 +310,8 @@ void OdbExaminer::setupColumnBox()
     // Message tree (key profile)
     //--------------------------------
 
-    columnPanel_              = new QWidget(this);
-    QVBoxLayout* columnLayout = new QVBoxLayout;
+    columnPanel_       = new QWidget(this);
+    auto* columnLayout = new QVBoxLayout;
     columnLayout->setContentsMargins(0, 0, 0, 0);
     columnPanel_->setLayout(columnLayout);
 
@@ -337,8 +337,8 @@ void OdbExaminer::setupVarBox()
     // Message tree (key profile)
     //--------------------------------
 
-    varPanel_              = new QWidget;
-    QVBoxLayout* varLayout = new QVBoxLayout;
+    varPanel_       = new QWidget;
+    auto* varLayout = new QVBoxLayout;
     varLayout->setContentsMargins(0, 0, 0, 0);
     varPanel_->setLayout(varLayout);
 
