@@ -12,6 +12,13 @@
 #include <QDebug>
 #include <QPair>
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QtCore5Compat/QRegExp>
+#else
+#include <QRegExp>
+#endif
+
+
 int MvQGetMapRequest::maxFrame_ = 128;
 
 /*
