@@ -11,9 +11,10 @@
 
 #include "MvQOgcParam.h"
 
-MvQOgcTreeModel::MvQOgcTreeModel(QObject* parent) : QAbstractItemModel(parent)
+MvQOgcTreeModel::MvQOgcTreeModel(QObject* parent) :
+    QAbstractItemModel(parent)
 {
-    root_ = 0;
+    root_ = nullptr;
 }
 
 void MvQOgcTreeModel::dataIsAboutToChange()
@@ -79,12 +80,7 @@ QVariant MvQOgcTreeModel::headerData(const int section, const Qt::Orientation or
     if (orient != Qt::Horizontal || role != Qt::DisplayRole)
         return QAbstractItemModel::headerData(section, orient, role);
 
-    switch (section) {
-        case 0:
-            return "Layer title";
-    }
-
-    return QVariant();
+    return section == 0 ? "Layer title" : QVariant();
 }
 
 QModelIndex MvQOgcTreeModel::index(int row, int column, const QModelIndex& parent) const
@@ -132,7 +128,7 @@ QModelIndex MvQOgcTreeModel::parent(const QModelIndex& child) const
 
 QModelIndex MvQOgcTreeModel::indexFromNode(MvQOgcNode* node) const
 {
-    if (node != 0 && node->parent() != 0) {
+    if (node != nullptr && node->parent() != nullptr) {
         int row = node->parent()->children().indexOf(node);
         if (row != -1) {
             return createIndex(row, 0, node);
