@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQOgcTreeModel_H
-#define MvQOgcTreeModel_H
+#pragma once
 
 #include <QAbstractItemModel>
 
@@ -36,5 +35,3 @@ public:
 protected:
     MvQOgcNode* root_;
 };
-
-#endif
