@@ -37,19 +37,21 @@ public:
     static QDomElement findElement(const QDomElement& elem, QString path);
     static QDomElement findElementByCondition(const QDomElement& elem, const QString& tag, const QString& key, const QString& value);
     static QList<QDomElement> findDirectChildren(const QDomElement& elem, const QString& tag);
-    static void attributes(const QDomElement& elem, QMap<QString, QString>& att) ;
+    static void attributes(const QDomElement& elem, QMap<QString, QString>& att);
+
 private:
     static QDomElement find(const QDomElement& elem, QStringList pathLst);
 };
 
 
-QDomElement DomFinder::findElement(const QDomElement& elem,QString path)
+QDomElement DomFinder::findElement(const QDomElement& elem, QString path)
 {
     auto pathLst = path.split("/");
     if (!pathLst.isEmpty()) {
         if (elem.nodeName() == pathLst[0]) {
             return find(elem, pathLst);
-        } else {
+        }
+        else {
             auto s = elem.namedItem(pathLst[0]);
             if (s.isElement()) {
                 return find(s.toElement(), pathLst);
@@ -67,7 +69,8 @@ QDomElement DomFinder::find(const QDomElement& elem, QStringList pathLst)
             pathLst.removeFirst();
             if (pathLst.isEmpty()) {
                 return elem;
-            } else {
+            }
+            else {
                 QDomNode n = elem.firstChild();
                 while (!n.isNull()) {
                     auto v = find(n.toElement(), pathLst);
@@ -75,7 +78,7 @@ QDomElement DomFinder::find(const QDomElement& elem, QStringList pathLst)
                         return v;
                     }
                     n = n.nextSibling();
-               }
+                }
             }
         }
     }
@@ -101,7 +104,7 @@ QDomElement DomFinder::findElementByCondition(const QDomElement& elem, const QSt
                 }
             }
             n = n.nextSibling();
-         }
+        }
     }
 
     return {};
@@ -114,8 +117,8 @@ QList<QDomElement> DomFinder::findDirectChildren(const QDomElement& elem, const
     while (!n.isNull()) {
         if (n.isElement() && n.toElement().tagName() == tag) {
             lst << n.toElement();
-         }
-         n = n.nextSibling();
+        }
+        n = n.nextSibling();
     }
     return lst;
 }
@@ -123,14 +126,13 @@ QList<QDomElement> DomFinder::findDirectChildren(const QDomElement& elem, const
 void DomFinder::attributes(const QDomElement& elem, QMap<QString, QString>& att)
 {
     auto a = elem.attributes();
-    for (int i=0; i < a.count(); i++) {
-        auto item = a.item(i);
+    for (int i = 0; i < a.count(); i++) {
+        auto item                 = a.item(i);
         att[item.toAttr().name()] = item.toAttr().value().simplified();
     }
 }
 
 
-
 //==============================
 //
 // MvQProjInfo
@@ -187,11 +189,11 @@ void MvQProjInfo::parseRequest(const MvRequest& inReq)
     //Expand the request
     char* shareDir = getenv("METVIEW_DIR_SHARE");
     if (shareDir) {
-        string path(shareDir);
+        std::string path(shareDir);
         path.append("/etc/");
 
-        string defFileName   = path + "GeoViewDef";
-        string rulesFileName = path + "GeoViewRules";
+        std::string defFileName   = path + "GeoViewDef";
+        std::string rulesFileName = path + "GeoViewRules";
 
         MvLanguage langMetview(defFileName.c_str(),
                                rulesFileName.c_str(),
@@ -281,12 +283,12 @@ MvQWmsClientBase::MvQWmsClientBase()
     supportedCrs_ << "EPSG:4326"
                   << "CRS:84";
 
-//    queryMsgHandler_ = new MvQWmsMessageHandler;
+    //    queryMsgHandler_ = new MvQWmsMessageHandler;
 }
 
 MvQWmsClientBase::~MvQWmsClientBase()
 {
-//    delete queryMsgHandler_;
+    //    delete queryMsgHandler_;
 }
 
 QString MvQWmsClientBase::getMimeType(QByteArray ba)
@@ -786,17 +788,17 @@ void MvQWmsGetClient::slotReplyLogo(QNetworkReply* reply)
 //
 //=================================
 
-MvQWmsUiClient::MvQWmsUiClient(string& iconFile, MvRequest& req) :
+MvQWmsUiClient::MvQWmsUiClient(std::string& iconFile, MvRequest& req) :
     iconFile_(QString::fromStdString(iconFile)),
     reqInfo_(req)
 {
     char* shareDir = getenv("METVIEW_DIR_SHARE");
     if (shareDir) {
-        string path(shareDir);
+        std::string path(shareDir);
         path.append("/etc/");
 
-        string defFileName   = path + "WmsClientDef";
-        string rulesFileName = path + "WmsClientRules";
+        std::string defFileName   = path + "WmsClientDef";
+        std::string rulesFileName = path + "WmsClientRules";
 
         MvLanguage langMetview(defFileName.c_str(),
                                rulesFileName.c_str(),
@@ -1250,11 +1252,11 @@ void MvQWmsUiClient::slotSaveInfo()
 
     char* shareDir = getenv("METVIEW_DIR_SHARE");
     if (shareDir) {
-        string path(shareDir);
+        std::string path(shareDir);
         path.append("/etc/");
 
-        string defFileName   = path + "WmsClientDef";
-        string rulesFileName = path + "WmsClientRules";
+        std::string defFileName   = path + "WmsClientDef";
+        std::string rulesFileName = path + "WmsClientRules";
 
         MvLanguage langMetview(defFileName.c_str(),
                                rulesFileName.c_str(),
@@ -1322,7 +1324,7 @@ void MvQWmsUiClient::slotReplyGetCap(QNetworkReply* reply)
         }
         else {
             capability_ = QString(ba);
-            dom_ = QDomDocument();
+            dom_        = QDomDocument();
             dom_.setContent(capability_);
 
             //Uncomment these lines to load a getCapabilities file from the disk
@@ -1396,11 +1398,11 @@ void MvQWmsUiClient::updateAfterLayerLoaded()
 
     //readLayerAbstract();
     readLayerProperties();
-//    readStyle();
-//    readBoundingBox();  //bounding box should be called before crs!!!!!
-//    readCrs();
-//    readGeographicBoundingBox();
-//    readDimension();
+    //    readStyle();
+    //    readBoundingBox();  //bounding box should be called before crs!!!!!
+    //    readCrs();
+    //    readGeographicBoundingBox();
+    //    readDimension();
     //readAttribution();
 
     val = lastGetMapRequest_->item(style_->requestName());
@@ -1674,28 +1676,29 @@ QString MvQWmsUiClient::readVersion()
 {
     QString result;
 
-//    QByteArray ba = capability_.toUtf8();
-//    QBuffer buffer(&ba);  // This is a QIODevice.
-//    buffer.open(QIODevice::ReadOnly);
+    //    QByteArray ba = capability_.toUtf8();
+    //    QBuffer buffer(&ba);  // This is a QIODevice.
+    //    buffer.open(QIODevice::ReadOnly);
 
-//    defaultNsDeclaration_ = "declare default element namespace \"http://www.opengis.net/wms\";";
+    //    defaultNsDeclaration_ = "declare default element namespace \"http://www.opengis.net/wms\";";
     defaultNsDeclaration_ = "http://www.opengis.net/wms";
-//    auto doc = QDomDocument("getcap");
-//    doc.setContent(ba);
+    //    auto doc = QDomDocument("getcap");
+    //    doc.setContent(ba);
     QDomElement docElem = dom_.documentElement();
-//    qDebug() << "root" << docElem.text() << docElem.tagName();
+    //    qDebug() << "root" << docElem.text() << docElem.tagName();
     if (docElem.tagName() == "WMS_Capabilities") {
         auto attr = docElem.attributes();
-        result = attr.namedItem("version").toAttr().value();
+        result    = attr.namedItem("version").toAttr().value();
         qDebug() << "VERSION" << result;
-    } else {
+    }
+    else {
         //auto lst = docElem.elementsByTagNameNS(defaultNsDeclaration_, "WMS_Capabilities");
         auto lst = docElem.elementsByTagName("WMS_Capabilities");
         qDebug() << "readVersion";
         if (lst.count() > 0) {
             auto node = lst.item(0);
             auto attr = node.attributes();
-            result = attr.namedItem("version").toAttr().value();
+            result    = attr.namedItem("version").toAttr().value();
             qDebug() << "VERSION NODE:" << node.nodeName();
         }
     }
@@ -1722,43 +1725,43 @@ void MvQWmsUiClient::readService()
     serviceMeta_.clear();
 
     QDomElement docElem = dom_.documentElement();
-    QDomNode n = docElem.firstChild();
-    while(!n.isNull()) {
-          if (n.nodeName() == "Service") {
-//              qDebug() << "SERVICE found";
-              QStringList tags;
-              tags << "Title"
-                   << "Abstract"
-                   << "Name"
-                   << "ContactPerson"
-                   << "ContactOrganization"
-                   << "ContactPosition"
-                   << "AddressType"
-                   << "Address"
-                   << "City"
-                   << "StateOrProvince"
-                   << "PostCode"
-                   << "Country"
-                   << "ContactVoiceTelephone"
-                   << "ContactFacsimileTelephone"
-                   << "ContactElectronicMailAddress";
+    QDomNode n          = docElem.firstChild();
+    while (!n.isNull()) {
+        if (n.nodeName() == "Service") {
+            //              qDebug() << "SERVICE found";
+            QStringList tags;
+            tags << "Title"
+                 << "Abstract"
+                 << "Name"
+                 << "ContactPerson"
+                 << "ContactOrganization"
+                 << "ContactPosition"
+                 << "AddressType"
+                 << "Address"
+                 << "City"
+                 << "StateOrProvince"
+                 << "PostCode"
+                 << "Country"
+                 << "ContactVoiceTelephone"
+                 << "ContactFacsimileTelephone"
+                 << "ContactElectronicMailAddress";
 
-              auto elem = n.toElement();
-              if (!elem.isNull())  {
-//                qDebug() << "SERVICE not null";
-                for(auto name: tags) {
-//                    qDebug() << "tag" << name;
+            auto elem = n.toElement();
+            if (!elem.isNull()) {
+                //                qDebug() << "SERVICE not null";
+                for (auto name : tags) {
+                    //                    qDebug() << "tag" << name;
                     auto lst = elem.elementsByTagName(name);
-//                    qDebug() << " count" << lst.count();
+                    //                    qDebug() << " count" << lst.count();
                     if (lst.count() > 0 && lst.item(0).isElement()) {
-//                        qDebug() << lst.item(0).isElement() << lst.item(0).isText() << " val:" << lst.item(0).toElement().text();
+                        //                        qDebug() << lst.item(0).isElement() << lst.item(0).isText() << " val:" << lst.item(0).toElement().text();
                         serviceMeta_[name] = lst.item(0).toElement().text().simplified();
                     }
-                 }
-              }
-              break;
-          }
-          n = n.nextSibling();
+                }
+            }
+            break;
+        }
+        n = n.nextSibling();
     }
 
 #if OLD_XML
@@ -1832,13 +1835,13 @@ void MvQWmsUiClient::readFormat()
         path = "Capability/Request/GetMap";
     }
     else {
-        path= "Capability/Request/Map";
+        path = "Capability/Request/Map";
     }
 
     auto elem = DomFinder::findElement(dom_.documentElement(), path);
     if (elem.isElement() && !elem.isNull()) {
         auto lst = elem.elementsByTagName("Format");
-        for (int i=0; i < lst.count(); i++) {
+        for (int i = 0; i < lst.count(); i++) {
             if (lst.item(i).isElement()) {
                 formats << lst.item(i).toElement().text().simplified();
             }
@@ -1897,7 +1900,7 @@ void MvQWmsUiClient::readLayer(QDomElement& docElem, MvQOgcNode* parent)
         QDomElement dElem = dNode.toElement();
         if (!dElem.isNull()) {
             if (dElem.tagName() == "Layer") {
-                MvQOgcNode* layer = new MvQOgcNode;
+                auto* layer = new MvQOgcNode;
                 parent->addChild(layer);
 
                 QDomNode title = dNode.namedItem("Title");
@@ -1967,14 +1970,13 @@ void MvQWmsUiClient::readLayerProperties()
 }
 
 
-
 void MvQWmsUiClient::readStyle(const QList<QDomElement>& layers)
 {
-     QStringList nameLst, titleLst, abstractLst, legendLst;
-     for (auto layer: layers) {
+    QStringList nameLst, titleLst, abstractLst, legendLst;
+    for (auto layer : layers) {
         // collect styles values along the ancestors down from the root layer node
         auto styleElems = DomFinder::findDirectChildren(layer, "Style");
-        for (int i=0; i < styleElems.count(); i++) {
+        for (int i = 0; i < styleElems.count(); i++) {
             nameLst << styleElems[i].namedItem("Name").toElement().text().simplified();
             titleLst << styleElems[i].namedItem("Title").toElement().text().simplified();
             abstractLst << styleElems[i].namedItem("Abstract").toElement().text().simplified();
@@ -2054,10 +2056,10 @@ void MvQWmsUiClient::readCrs(const QList<QDomElement>& layers)
         crsName = "SRS";
     }
 
-    for (auto layer: layers) {
+    for (auto layer : layers) {
         // collect crs values along the ancestors up to the root layer node
         auto crsElems = DomFinder::findDirectChildren(layer, crsName);
-        for (int i=0; i < crsElems.count(); i++) {
+        for (int i = 0; i < crsElems.count(); i++) {
             lst << crsElems[i].text().simplified();
         }
     }
@@ -2068,13 +2070,15 @@ void MvQWmsUiClient::readCrs(const QList<QDomElement>& layers)
         foreach (QString s, lstOri) {
             lst << s.split(" ");
         }
-    } else if (repliedVersion_ >= "1.3.0") {
+    }
+    else if (repliedVersion_ >= "1.3.0") {
         QStringList lstOri = lst;
         lst.clear();
         foreach (QString s, lstOri) {
             if (s == "EPSG:4326" || s == "CRS:84") {
                 lst << s;
-            } else {
+            }
+            else {
                 foreach (MvQOgcBoundingBox* bb, bbox_) {
                     if (s == bb->crs()) {
                         lst << s;
@@ -2153,13 +2157,13 @@ void MvQWmsUiClient::readCrs(const QList<QDomElement>& layers)
 
 void MvQWmsUiClient::readBoundingBox(const QList<QDomElement>& layers)
 {
-    for (auto layer: layers) {
+    for (auto layer : layers) {
         // collect bbox values along the ancestors down from the root layer node
         auto bbElems = DomFinder::findDirectChildren(layer, "BoundingBox");
-        for (int i=0; i < bbElems.count(); i++) {
+        for (int i = 0; i < bbElems.count(); i++) {
             QMap<QString, QString> att;
             DomFinder::attributes(bbElems[i], att);
-            MvQOgcBoundingBox* bb = new MvQOgcBoundingBox(att);
+            auto* bb = new MvQOgcBoundingBox(att);
             //Remove all previously defined (in the ancestors) bboxes
             foreach (MvQOgcBoundingBox* bitem, bbox_) {
                 if (bitem->crs() == bb->crs()) {
@@ -2169,7 +2173,7 @@ void MvQWmsUiClient::readBoundingBox(const QList<QDomElement>& layers)
                 }
             }
             bbox_.push_back(bb);
-         }
+        }
     }
 
 #if OLD_XML
@@ -2217,23 +2221,27 @@ void MvQWmsUiClient::readBoundingBox(const QList<QDomElement>& layers)
 void MvQWmsUiClient::readGeographicBoundingBox(const QList<QDomElement>& layers)
 {
     // get first bounding box from ancestors
-    for (auto layer: layers) {
+    for (auto layer : layers) {
         if (repliedVersion_ >= "1.3.0") {
             auto bb = layer.namedItem("EX_GeographicBoundingBox").toElement();
             if (!bb.isNull()) {
                 QStringList names;
-                names << "westBoundLongitude" << "eastBoundLongitude" << "southBoundLatitude" << "northBoundLatitude";
+                names << "westBoundLongitude"
+                      << "eastBoundLongitude"
+                      << "southBoundLatitude"
+                      << "northBoundLatitude";
                 QMap<QString, QString> att;
-                for (auto name: names) {
+                for (auto name : names) {
                     att[name] = bb.namedItem(name).toElement().text().simplified();
                 }
                 if (geographicBbox_) {
                     delete geographicBbox_;
-                 }
+                }
                 geographicBbox_ = new MvQOgcGeoBoundingBox(att);  //new MvQXmlElementNode(query,item);
                 return;
-             }
-        } else {
+            }
+        }
+        else {
             auto bb = layer.namedItem("LatLonBoundingBox").toElement();
             if (!bb.isNull()) {
                 QMap<QString, QString> att;
@@ -2245,7 +2253,7 @@ void MvQWmsUiClient::readGeographicBoundingBox(const QList<QDomElement>& layers)
                 return;
             }
         }
-   }
+    }
 
 #if OLD_XML
     QStringList str;
@@ -2323,13 +2331,13 @@ void MvQWmsUiClient::readGeographicBoundingBox(const QList<QDomElement>& layers)
 
 void MvQWmsUiClient::readDimension(const QList<QDomElement>& layers)
 {
-    for (auto layer: layers) {
+    for (auto layer : layers) {
         // collect bbox values along the ancestors down from the root layer node
         auto dimElems = DomFinder::findDirectChildren(layer, "Dimension");
-        for (int i=0; i < dimElems.count(); i++) {
+        for (int i = 0; i < dimElems.count(); i++) {
             QMap<QString, QString> att;
             DomFinder::attributes(dimElems[i], att);
-            MvQOgcDimension* dim = new MvQOgcDimension(att, dimElems[i].text());
+            auto* dim = new MvQOgcDimension(att, dimElems[i].text());
             for (int i = 0; i < dimension_.count(); i++) {
                 if (dim->name().compare(dimension_[i]->name(), Qt::CaseInsensitive) == 0) {
                     MvQOgcDimension* item = dimension_[i];
@@ -2361,10 +2369,10 @@ void MvQWmsUiClient::readDimension(const QList<QDomElement>& layers)
     }
 
     if (repliedVersion_ < "1.3.0") {
-        for (auto layer: layers) {
+        for (auto layer : layers) {
             // collect bbox values along the ancestors down from the root layer node
             auto dimElems = DomFinder::findDirectChildren(layer, "Extent");
-            for (int i=0; i < dimElems.count(); i++) {
+            for (int i = 0; i < dimElems.count(); i++) {
                 QMap<QString, QString> att;
                 DomFinder::attributes(dimElems[i], att);
                 QString value = dimElems[i].text();
@@ -2469,10 +2477,10 @@ void MvQWmsUiClient::readAttribution(const QList<QDomElement>& layers)
     if (!layerNode)
         return;
 
-    for (auto layer: layers) {
+    for (auto layer : layers) {
         // collect attribution values along the ancestors down from the root layer node
         auto aElems = DomFinder::findDirectChildren(layer, "Attribution");
-        for (int i=0; i < aElems.count(); i++) {
+        for (int i = 0; i < aElems.count(); i++) {
             auto logoElem = DomFinder::findElement(aElems[i], "LogoURL/OnlineResource");
             if (!logoElem.isNull()) {
                 layerNode->setLogo(logoElem.attribute("xlink:href").simplified());
@@ -2527,7 +2535,7 @@ void MvQWmsUiClient::readException(QByteArray ba, QString& msg)
     auto elem = DomFinder::findElement(doc.documentElement(), "ServiceExceptionReport");
     if (!elem.isNull()) {
         auto items = elem.elementsByTagName("ServiceException");
-        for (int i=0; i < items.count(); i++) {
+        for (int i = 0; i < items.count(); i++) {
             auto exElem = items.item(i).toElement();
             if (!exElem.isNull()) {
                 msg += "Exception: ";
@@ -2545,7 +2553,6 @@ void MvQWmsUiClient::readException(QByteArray ba, QString& msg)
     }
 
 
-
 #if OLD_XML
     QXmlResultItems result;
 
