@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQWmsClient_H
-#define MvQWmsClient_H
+#pragma once
 
 //#include <QAbstractMessageHandler>
 #include <QDomDocument>
@@ -72,7 +71,7 @@ protected:
     QString getMimeType(QByteArray);
     QString getRequestedMimeType(QString);
 
-//    MvQWmsMessageHandler* queryMsgHandler_;
+    //    MvQWmsMessageHandler* queryMsgHandler_;
 };
 
 
@@ -137,7 +136,7 @@ class MvQWmsUiClient : public MvQWmsClientBase
     Q_OBJECT
 
 public:
-    MvQWmsUiClient(string&, MvRequest&);
+    MvQWmsUiClient(std::string&, MvRequest&);
     ~MvQWmsUiClient();
 
     enum ClientMode
@@ -207,7 +206,7 @@ public:
     QString layerAbstract() { return layer_->currentDescription(); }
 
     QString iconFile() { return iconFile_; }
-    void setFileNameInfo(string& name) { iconFile_ = QString::fromStdString(name); }
+    void setFileNameInfo(std::string& name) { iconFile_ = QString::fromStdString(name); }
     void setRequestInfo(MvRequest& req) { reqInfo_ = req; }
 
     void downloadPreview(QSize s = QSize(512, 256));
@@ -338,5 +337,3 @@ protected:
 
     QDomDocument dom_;
 };
-
-#endif
