@@ -236,8 +236,8 @@ MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent)
 
     //Main layout
     mainLayout_ = new QVBoxLayout;
-    mainLayout_->setContentsMargins(1,1,1,1);
-    QWidget* w  = new QWidget(this);
+    mainLayout_->setContentsMargins(1, 1, 1, 1);
+    auto* w = new QWidget(this);
     w->setLayout(mainLayout_);
     setCentralWidget(w);
 
@@ -256,9 +256,9 @@ MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent)
     mainSplitter_->addWidget(requestSplitter_);
 
     //Request left layout
-    layerPanel_                    = new QWidget(this);
-    QVBoxLayout* requestLeftLayout = new QVBoxLayout;
-    requestLeftLayout->setContentsMargins(1,1,1,1);
+    layerPanel_             = new QWidget(this);
+    auto* requestLeftLayout = new QVBoxLayout;
+    requestLeftLayout->setContentsMargins(1, 1, 1, 1);
     requestLeftLayout->setSpacing(1);
     layerPanel_->setLayout(requestLeftLayout);
     requestSplitter_->addWidget(layerPanel_);
@@ -284,11 +284,11 @@ MvQWmsClientEditor::MvQWmsClientEditor(MvQWmsUiClient* client, QWidget* parent)
     //---------------------------------------
 
     //Buttons
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     mainLayout_->addLayout(hb);
 
-    QLabel* labelMode = new QLabel(tr("Mode:"), this);
-    clientModeCombo_  = new QComboBox(this);
+    auto* labelMode  = new QLabel(tr("Mode:"), this);
+    clientModeCombo_ = new QComboBox(this);
     clientModeCombo_->addItem("Plain");
     clientModeCombo_->addItem("Interactive");
     hb->addWidget(labelMode);
@@ -387,7 +387,7 @@ MvQWmsClientEditor::~MvQWmsClientEditor()
 
 void MvQWmsClientEditor::setupFileActions()
 {
-    QAction* actionImport = new QAction(this);
+    auto* actionImport = new QAction(this);
     actionImport->setObjectName(QString::fromUtf8("actionImport"));
     actionImport->setText(tr("&Import"));
     actionImport->setToolTip(tr("Import request"));
@@ -424,7 +424,7 @@ void MvQWmsClientEditor::setupViewActions()
     //Log is hidden by default!!!
     actionLog_->setChecked(false);
 
-    QAction* actionSeparator = new QAction(this);
+    auto* actionSeparator = new QAction(this);
     actionSeparator->setSeparator(true);
 
     actionCapability_ = new QAction(this);
@@ -456,7 +456,7 @@ void MvQWmsClientEditor::setupViewActions()
     advancedModeOnlyWidgets_ << urlCombo_;
 
     //Server version combo
-    QLabel* labelVersion = new QLabel(tr(" Version:"), this);
+    auto* labelVersion = new QLabel(tr(" Version:"), this);
     advancedModeOnlyWidgets_ << labelVersion;
     versionCombo_ = new QComboBox(this);
     advancedModeOnlyWidgets_ << versionCombo_;
@@ -510,17 +510,17 @@ void MvQWmsClientEditor::setupSettingsActions()
     // Second toolbar row
     //--------------------
 
-    QLabel* labelFormat = new QLabel(tr("Format:"), this);
-    formatCombo_        = new QComboBox(this);
+    auto* labelFormat = new QLabel(tr("Format:"), this);
+    formatCombo_      = new QComboBox(this);
     formatCombo_->setSizeAdjustPolicy(QComboBox::AdjustToContents);
 
     //Extra getcap
-    QLabel* labelGetCap = new QLabel(tr(" Extra getCap param:"),this);
-    extraGetCapEdit_    = new QLineEdit("", this);
+    auto* labelGetCap = new QLabel(tr(" Extra getCap param:"), this);
+    extraGetCapEdit_  = new QLineEdit("", this);
 
     //Extra getmap
-    QLabel* labelGetMap = new QLabel(tr(" Extra getMap param:"),this);
-    extraGetMapEdit_    = new QLineEdit("",this);
+    auto* labelGetMap = new QLabel(tr(" Extra getMap param:"), this);
+    extraGetMapEdit_  = new QLineEdit("", this);
 
     QString mName = "Format";
 
@@ -586,10 +586,10 @@ void MvQWmsClientEditor::setupLayerPanel(QVBoxLayout* layout)
     // Param gui
     //-------------------
 
-    QScrollArea* scroll = new QScrollArea(this);
+    auto* scroll = new QScrollArea(this);
     layerTab_->addTab(scroll, tr("Layer settings"));
 
-    QWidget* w = new QWidget(this);
+    auto* w    = new QWidget(this);
     layerGrid_ = new QGridLayout;
     layerGrid_->setSizeConstraint(QLayout::SetMinAndMaxSize);
     w->setLayout(layerGrid_);
@@ -638,7 +638,7 @@ void MvQWmsClientEditor::setupLayerInfoTab()
     //--------------------------
     // Layer preview tab
     //--------------------------
-    w = new QWidget(this);
+    w                  = new QWidget(this);
     auto previewLayout = new QVBoxLayout(w);
     previewLayout->setContentsMargins(0, 2, 0, 0);
     previewLayout->setSpacing(0);
@@ -670,8 +670,8 @@ void MvQWmsClientEditor::setupLayerInfoTab()
     reqSplitter_ = new QSplitter(this);
     layerInfoTab_->addTab(reqSplitter_, tr("GetMap request"));
 
-    reqEditPanel_              = new QWidget(this);
-    QVBoxLayout* reqEditLayout = new QVBoxLayout;
+    reqEditPanel_       = new QWidget(this);
+    auto* reqEditLayout = new QVBoxLayout;
     reqEditPanel_->setLayout(reqEditLayout);
     reqSplitter_->addWidget(reqEditPanel_);
 
@@ -689,7 +689,7 @@ void MvQWmsClientEditor::setupLayerInfoTab()
     // --> Request display
     //---------------------------------------
 
-    w                          = new QWidget(this);
+    w                  = new QWidget(this);
     auto mapInfoLayout = new QVBoxLayout;
     mapInfoLayout->setContentsMargins(0, 2, 0, 0);
     mapInfoLayout->setSpacing(0);
@@ -708,7 +708,7 @@ void MvQWmsClientEditor::setupLayerInfoTab()
     //reqSplitter_->addWidget(reqGrid_);
     mapInfoLayout->addWidget(getMapInfoSplit_, 1);
 
-    new DocHighlighter(getMapInfoSplit_->document(),"getMap");
+    new DocHighlighter(getMapInfoSplit_->document(), "getMap");
 
     //---------------------------------------
     // --> Load preview (plain mode only)
@@ -717,7 +717,7 @@ void MvQWmsClientEditor::setupLayerInfoTab()
     plainPreviewPanel_ = new QWidget(this);
     plainPreviewPanel_->setMinimumHeight(128);
 
-    QVBoxLayout* plainPreLayout = new QVBoxLayout;
+    auto* plainPreLayout = new QVBoxLayout;
     plainPreLayout->setContentsMargins(0, 0, 0, 0);
     plainPreviewPanel_->setLayout(plainPreLayout);
     mapInfoLayout->addWidget(plainPreviewPanel_);
@@ -768,13 +768,13 @@ void MvQWmsClientEditor::setupLayerInfoTab()
     getCapInfo_->editor()->setLineWrapMode(QPlainTextEdit::NoWrap);
     getCapLayout->addWidget(getCapInfo_);
 
-    new DocHighlighter(getCapInfo_->editor()->document(),"getCapabilities");
+    new DocHighlighter(getCapInfo_->editor()->document(), "getCapabilities");
 
     //--------------------------
     // Service meta-data  tab
     //--------------------------
 
-    w = new QWidget(this);
+    w                  = new QWidget(this);
     auto serviceLayout = new QVBoxLayout;
     serviceLayout->setContentsMargins(0, 2, 0, 0);
     serviceLayout->setSpacing(0);
@@ -793,8 +793,8 @@ void MvQWmsClientEditor::setupReqEditPanel()
     if (reqEditSa_->widget())
         return;
 
-    QWidget* w           = new QWidget(this);
-    QGridLayout* reqGrid = new QGridLayout;
+    auto* w       = new QWidget(this);
+    auto* reqGrid = new QGridLayout;
     reqGrid->setSizeConstraint(QLayout::SetMinAndMaxSize);
     w->setLayout(reqGrid);
 
@@ -803,7 +803,7 @@ void MvQWmsClientEditor::setupReqEditPanel()
     QLabel* label;
     QLineEdit* le;
     QTextEdit* te;
-    QSignalMapper* sigMapper = new QSignalMapper(this);
+    auto* sigMapper = new QSignalMapper(this);
     QStringList labelText, key;
 
     labelText << tr("URL:") << tr("Version:") << tr("Layer:") << tr("Style:")
