@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQWmsClientEditor_H
-#define MvQWmsClientEditor_H
+#pragma once
 
 #include <QGridLayout>
 #include <QLineEdit>
@@ -187,7 +186,7 @@ protected:
     QTextBrowser* serviceInfo_;
     QTextBrowser* layerPreview_;
     QTextBrowser* getMapInfoSplit_;
-//    MvQHighlighter* highlighterSplit_;
+    //    MvQHighlighter* highlighterSplit_;
     QPushButton* plainPreviewPb_;
     QLabel* plainPreviewLabel_;
     QWidget* plainPreviewPanel_;
@@ -198,7 +197,7 @@ protected:
     MvQTextEditSearchLine* getCapSearch_;
 #endif
 
-//    MvQWmsGetCapHighlighter* highlighterGetCap_;
+    //    MvQWmsGetCapHighlighter* highlighterGetCap_;
 
     QProgressBar* loadProgress_;
 
@@ -213,6 +212,3 @@ protected:
     QPushButton* okPb_;
     QPushButton* cancelPb_;
 };
-
-
-#endif
