@@ -22,7 +22,6 @@
 #include "Metview.h"
 #include "MvQApplication.h"
 
-using namespace std;
 
 //class MvWmsClient : public MvQService
 //{
@@ -31,7 +30,7 @@ using namespace std;
 //        MvQService("WMSCLIENT") {}
 //    void serve(MvRequest&, MvRequest&);
 ////    void processUiMode(MvRequest&, MvRequest&);
-//    void processGetMode(MvRequest&, MvRequest&, const string&);
+//    void processGetMode(MvRequest&, MvRequest&, const std::string&);
 //};
 
 int main(int argc, char** argv)
@@ -44,26 +43,27 @@ int main(int argc, char** argv)
     MvRequest in, out;
     in.read(argv[1], false, true);
 
-    marslog(LOG_INFO,"Request:");
+    marslog(LOG_INFO, "Request:");
     in.print();
 
     std::string outPath;
     if (const char* outPathCh = in("_OUT_REQ_FILE")) {
         outPath = std::string(outPathCh);
-    } else {
+    }
+    else {
         marslog(LOG_EROR, "No output request specified in _OUT_REQ_FILE!");
         exit(1);
     }
 
     // Get user action mode
     std::string mode;
-    if(const char* modeC = (const char*)in("_ACTION")) {
+    if (const char* modeC = (const char*)in("_ACTION")) {
         mode = std::string(modeC);
     }
 
     bool doProcess = false;
     if (mode.empty()) {
-        if(const char* appl = (const char*)in("_APPL")) {
+        if (const char* appl = (const char*)in("_APPL")) {
             if (strcmp(appl, "macro") == 0 || strcmp(appl, "Python") == 0) {
                 doProcess = true;
             }
@@ -85,7 +85,7 @@ int main(int argc, char** argv)
     std::string appName = MvApplication::buildAppName("WmsClient");
     MvQApplication app(argc, argv, appName.c_str());
 
-    MvQWmsGetClient* client = new MvQWmsGetClient(in);
+    auto* client = new MvQWmsGetClient(in);
     if (mode == "update" && client->requestChanged() == false) {
         out.save(outPath.c_str());
         exit(0);
@@ -133,7 +133,7 @@ int main(int argc, char** argv)
     }
 
 
-    req("LAYERS") = gmr->layers().toStdString().c_str();
+    req("LAYERS")  = gmr->layers().toStdString().c_str();
     req("SERVICE") = "WMS";
 
     const char* layerTitle = static_cast<const char*>(in("LAYER_TITLE"));
@@ -218,7 +218,7 @@ int main(int argc, char** argv)
 
             reqFrame("DIM_NAME")  = dimName.join("/").toStdString().c_str();
             reqFrame("DIM_VALUE") = dimValue.join("/").toStdString().c_str();
-            reqLoop = reqLoop + reqFrame;
+            reqLoop               = reqLoop + reqFrame;
         }
 
         out.setVerb("PRASTERLOOP");
@@ -241,8 +241,8 @@ int main(int argc, char** argv)
 
     //
     MvRequest current = in.justOneRequest();
-    while (current != NULL) {
-        string verb = current.getVerb();
+    while (current != nullptr) {
+        std::string verb = current.getVerb();
         if (verb == "WMSCLIENT") {
             current("REQUEST")        = gmr->request().toStdString().c_str();
             out("WMS_CLIENT_REQUEST") = current;
