@@ -8,8 +8,11 @@
  ***************************** LICENSE END *************************************/
 
 #include "Percentile.h"
-#include "mars.h"
 
+#include <algorithm>
+#include <iostream>
+
+#include "mars.h"
 
 
 /*
@@ -18,23 +21,21 @@
     field will be replicated to fit.
 */
 
-static fieldset *copy_and_extend_fieldset(fieldset *x,int count,boolean copydata)
+static fieldset* copy_and_extend_fieldset(fieldset* x, int count, boolean copydata)
 {
-    fieldset *v = new_fieldset(count);
+    fieldset* v = new_fieldset(count);
 
-    if( count != 0 )
-    {
+    if (count != 0) {
         int i;
-        for(i=0;i<count;i++)
-        {
+        for (i = 0; i < count; i++) {
             int source_index;
             if (i < x->count)
                 source_index = i;
             else
-                source_index = x->count-1;
+                source_index = x->count - 1;
 
-            field *gx = get_field(x,source_index,expand_mem);
-            v->fields[i] = copy_field(gx,copydata);
+            field* gx    = get_field(x, source_index, expand_mem);
+            v->fields[i] = copy_field(gx, copydata);
             v->fields[i]->refcnt++;
             release_field(gx);
         }
@@ -49,14 +50,11 @@ Percentile::Percentile(const char* kw) :
     //empty
 }
 
-Percentile::~Percentile()
-{
-    //empty
-}
+Percentile::~Percentile() = default;
 
 void Percentile::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "Percentile::serve in" << endl;
+    std::cout << "Percentile::serve in" << std::endl;
     in.print();
 
     // Get information from the user interface
@@ -67,7 +65,7 @@ void Percentile::serve(MvRequest& in, MvRequest& out)
     if (!ComputePercentile(out))
         return;
 
-    cout << "Percentile::serve out" << endl;
+    std::cout << "Percentile::serve out" << std::endl;
     out.print();
 
     return;
@@ -79,7 +77,7 @@ bool Percentile::GetInputInfo(MvRequest& in)
     int i;           // auxiliary variables
 
     // Get data information from UI
-    string str;
+    std::string str;
     if ((const char*)in("SOURCE") && (strcmp((const char*)in("SOURCE"), "OFF") && strcmp((const char*)in("SOURCE"), "off"))) {
         str = (const char*)in("SOURCE");
         dataRequest_.setVerb("GRIB");
@@ -109,10 +107,10 @@ bool Percentile::GetInputInfo(MvRequest& in)
 
     // Get interpolation method
     const char* caux1 = in("INTERPOLATION");
-    interp_          = (strcmp(caux1, "NEAREST_NEIGHBOUR") == 0) ? PERC_NN : PERC_LI;
+    interp_           = (strcmp(caux1, "NEAREST_NEIGHBOUR") == 0) ? PERC_NN : PERC_LI;
 
     // Get missing value strategy
-    const char* caux2    = in("COMPUTE_IF_MISSING_PRESENT");
+    const char* caux2   = in("COMPUTE_IF_MISSING_PRESENT");
     computeWithMissing_ = (strcmp(caux2, "OFF") == 0) ? false : true;
 
     return true;
@@ -139,7 +137,7 @@ double Percentile::ComputeRank(double percentile, int numInputFields)
     If there are grid points with missing values, then a new rank will be computed for that
     grid point.
 */
-void Percentile::ComputeRankForAllPercentiles(vector<double>& percRanks, int numInputFields)
+void Percentile::ComputeRankForAllPercentiles(std::vector<double>& percRanks, int numInputFields)
 {
     for (size_t i = 0; i < percRanks.size(); i++) {
         percRanks[i] = ComputeRank(percList_[i], numInputFields);
@@ -147,7 +145,6 @@ void Percentile::ComputeRankForAllPercentiles(vector<double>& percRanks, int num
 }
 
 
-
 /*  -----------------------------------------------------------------------------------------
     NOTE: we use the basic MARS fieldset here instead of the MvFieldSet. This is because this
 	is a highly memory-intensive module, and we want to be able to get rid of the GRIB
@@ -156,7 +153,7 @@ void Percentile::ComputeRankForAllPercentiles(vector<double>& percRanks, int num
 
 bool Percentile::ComputePercentile(MvRequest& out)
 {
-    size_t numGridPoints = 0;
+    size_t numGridPoints  = 0;
     size_t numPercentiles = percList_.size();
 
     std::vector<std::vector<double> > fsValues;  // vector of vector of values - a vector for each field's values
@@ -168,7 +165,7 @@ bool Percentile::ComputePercentile(MvRequest& out)
 
 
     // Compute rank of percentiles
-    vector<double> percRanks(percList_.size());
+    std::vector<double> percRanks(percList_.size());
     ComputeRankForAllPercentiles(percRanks, numInputFields);
 
 
@@ -203,10 +200,10 @@ bool Percentile::ComputePercentile(MvRequest& out)
 
     // Main loop - get fieldset values for each grid point
 
-    vector<double> gvals(numInputFields, 0);  // values for one grid point across all fields
+    std::vector<double> gvals(numInputFields, 0);  // values for one grid point across all fields
     for (size_t gp = 0; gp < numGridPoints; gp++) {
-        bool returnMissing = false;
-        bool missingPresent = false;
+        bool returnMissing       = false;
+        bool missingPresent      = false;
         size_t numValsForCompute = numInputFields;
 
         // get values for the current grid point across all fields
@@ -226,7 +223,7 @@ bool Percentile::ComputePercentile(MvRequest& out)
             missingPresent = true;
             if (computeWithMissing_) {
                 auto firstMissing = std::find_if(gvals.rbegin(), gvals.rend(),
-                                    [](double d) { return !(MISSING_VALUE(d)); });
+                                                 [](double d) { return !(MISSING_VALUE(d)); });
                 numValsForCompute = gvals.rend() - firstMissing;
             }
             else {
@@ -235,16 +232,13 @@ bool Percentile::ComputePercentile(MvRequest& out)
         }
 
 
-
         // update output fieldset for each percentile value
         for (size_t i = 0; i < numPercentiles; i++) {
             double rank = (missingPresent)
-                          ? ComputeRank(percList_[i], numValsForCompute)
-                          : percRanks[i];
+                              ? ComputeRank(percList_[i], numValsForCompute)
+                              : percRanks[i];
 
-            gs->fields[i]->values[gp] = (returnMissing) ? 
-                                        mars.grib_missing_value :
-                                        GetValue(rank, gvals, numValsForCompute);
+            gs->fields[i]->values[gp] = (returnMissing) ? mars.grib_missing_value : GetValue(rank, gvals, numValsForCompute);
         }
     }
 
@@ -265,12 +259,12 @@ bool Percentile::ComputePercentile(MvRequest& out)
     return true;
 }
 
-double Percentile::GetValue(double rank, vector<double>& gvals, size_t numVals)
+double Percentile::GetValue(double rank, std::vector<double>& gvals, size_t numVals)
 {
     if (interp_ == PERC_NN)  //Nearest neighbour interpolation
         return gvals[int(rank + 0.5)];
     else {  //Linear interpolation
-        size_t ir    = size_t(rank);
+        auto ir   = size_t(rank);
         double fr = rank - double(ir);
 
         // Test boundary
