@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef PERCENTILE_H
-#define PERCENTILE_H
+#pragma once
 
 /**************
   Application Percentile.
@@ -44,20 +43,18 @@ public:
     double ComputeRank(double percentile, int nfsin);
 
     // Compute rank of percentiles
-    void ComputeRankForAllPercentiles(vector<double>& vrank, int nfsin);
+    void ComputeRankForAllPercentiles(std::vector<double>& vrank, int nfsin);
 
     // Compute percentiles
     bool ComputePercentile(MvRequest&);
 
     // Get values
-    double GetValue(double rank, vector<double>& gvals, size_t numVals);
+    double GetValue(double rank, std::vector<double>& gvals, size_t numVals);
 
 protected:
     // variables
-    MvRequest dataRequest_;    // input data request
-    vector<double> percList_;  // percentiles input values
-    int interp_;               // interporlation method
-    bool computeWithMissing_;  // if missing values present, do we still compute?
+    MvRequest dataRequest_;         // input data request
+    std::vector<double> percList_;  // percentiles input values
+    int interp_;                    // interporlation method
+    bool computeWithMissing_;       // if missing values present, do we still compute?
 };
-
-#endif
