@@ -10,10 +10,10 @@
 #include <Metview.h>
 #include <signal.h>
 
-typedef struct data
+struct optvals_t
 {
     int python_pid;
-} optvals_t;
+};
 
 
 static option opts[] = {
@@ -29,7 +29,7 @@ class PythonServe : public MvService
 {
 public:
     PythonServe(const char* name) :
-        MvService(name){};
+        MvService(name) {}
     void serve(MvRequest&, MvRequest&);
 
 private:
@@ -61,12 +61,12 @@ void PythonServe::checkCallingPythonProcess()
     marsexit(0);
 }
 
-void PythonServe::serve(MvRequest& in, MvRequest& /*out*/)
+void PythonServe::serve(MvRequest& /*in*/, MvRequest& /*out*/)
 {
-    //cout << "--------------PythonServe::serve() start --------------" << endl;
+    //cout << "--------------PythonServe::serve() start --------------" << std::endl;
     //in.print();
     checkCallingPythonProcess();
-    //cout << "--------------PythonServe::serve() end --------------" << endl;
+    //cout << "--------------PythonServe::serve() end --------------" << std::endl;
 }
 
 
@@ -76,7 +76,7 @@ int main(int argc, char** argv)
     PythonServe ps("PYTHONCHECK");
     MvRequest rin("PYTHONCHECK");
     MvRequest rout;
-    MvApplication::callService("PythonServe", rin, NULL);
+    MvApplication::callService("PythonServe", rin, nullptr);
     theApp.run();
     return 0;
 }
