@@ -152,7 +152,7 @@ class JobWrapper final : public mir::api::MIRJob
 public:
     const std::string& source() const { return source_; }
     const std::string& target() const { return target_; }
-    const int target_is_temporary() const { return target_is_temporary_; }
+    int target_is_temporary() const { return target_is_temporary_; }
     void source(const std::string& path) { source_ = path; }
     void target(const std::string& path) { target_ = path; }
     void target_is_temporary(int temp) { target_is_temporary_ = temp; }
