@@ -35,9 +35,7 @@ void MvRelhum::init()
     refDataLength = -1;
 }
 
-MvRelhum::~MvRelhum()
-{
-}
+MvRelhum::~MvRelhum() = default;
 
 
 MvRequest MvRelhum::compute(int n, MvField& f_LNSP,
@@ -109,12 +107,12 @@ MvRequest MvRelhum::compute(int n, MvField& f_LNSP,
 #if RELHUM_TESTPRINT
             //-- in 1.5/1.5 grid, gridpoint 9821 is: (30N,30W)
             if (jl == 9821)
-                cout << "  " << level
-                     << "\t" << pres
-                     << "\t  " << f_t[jl]
-                     << "\t  " << q_before
-                     << "\t  " << f_q[jl]
-                     << endl;
+                std::cout << "  " << level
+                          << "\t" << pres
+                          << "\t  " << f_t[jl]
+                          << "\t  " << q_before
+                          << "\t  " << f_q[jl]
+                          << std::endl;
 #endif
         }
         f_q.setGribKeyValueLong("paramId", 157);  //-- Relative humidity
