@@ -10,7 +10,11 @@
 
 #include <stdio.h>
 #include <math.h>
+
+#include <iostream>
+
 #include "Metview.h"
+
 #include "MvRelhum.h"
 #include "MvException.h"
 
@@ -19,18 +23,18 @@ class Relhum : public MvService
 {
 protected:
     Relhum(char* kw) :
-        MvService(kw){};
+        MvService(kw) {}
 
 public:
     Relhum() :
-        MvService("RELHUM2"){};
+        MvService("RELHUM2") {}
     void serve(MvRequest&, MvRequest&);
 };
 
 
 void Relhum::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "Relhum in" << endl;
+    std::cout << "Relhum in" << std::endl;
     in.print();
 
     mars.computeflg = 0;  //-- for a nicer plot title (no "**" in front of param name)
@@ -38,7 +42,7 @@ void Relhum::serve(MvRequest& in, MvRequest& out)
     MvField field;
     MvRequest grib;
 
-    MvRelhum* mvrh = new MvRelhum();
+    auto* mvrh = new MvRelhum();
 
     in.getValue(grib, "DATA");
 
@@ -91,7 +95,7 @@ void Relhum::serve(MvRequest& in, MvRequest& out)
     }
 
     //-- for checking field format consistency --//
-    MvFieldExpander* fe = new MvFieldExpander(field);
+    auto* fe = new MvFieldExpander(field);
     mvrh->setRefDataLength(field.countValues());
     int repres = field.dataRepres();
     if (repres == 50) {
@@ -129,7 +133,7 @@ void Relhum::serve(MvRequest& in, MvRequest& out)
         return;
     }
 
-    cout << "Relhum out" << endl;
+    std::cout << "Relhum out" << std::endl;
     out.print();
 
     delete mvrh;
