@@ -16,7 +16,7 @@
 #include "MvException.h"
 #include <PaperPoint.h>
 
-ReprojectService::ReprojectService(string in, string out, double rx, double ry, double x1, double x2, double y1, double y2) :
+ReprojectService::ReprojectService(std::string in, std::string out, double rx, double ry, double /*x1*/, double /*x2*/, double /*y1*/, double /*y2*/) :
     gribIn_(in),
     gribOut_(out),
     resX_(rx),
@@ -37,7 +37,7 @@ bool ReprojectService::execute()
 
     //     magics::ImagePlotting tool;
     grib.file_name_ = gribIn_;
-    grib.open(NULL);  // it's not clear what purpose the NULL has here - it should be a grib handle, but it seems to be unused
+    grib.open(nullptr);  // it's not clear what purpose the NULL has here - it should be a grib handle, but it seems to be unused
     magics::GribSatelliteInterpretor gribInterpreter;
     //     magics::GeoRectangularProjection transformation;
     //     magics::RasterData rdin;  //input data
@@ -55,7 +55,7 @@ bool ReprojectService::execute()
     gribInterpreter.interpretAsMatrix(grib);
     Matrix* matrix = grib.u();
     if (!matrix) {
-        string err = "Reprojection-> InterpretAsMatrix failed on file ";
+        std::string err = "Reprojection-> InterpretAsMatrix failed on file ";
         err += gribIn_;
         throw MvException(err.c_str());
     }
@@ -90,7 +90,7 @@ int ReprojectService::gribit(magics::Matrix& matrix, magics::GribDecoder& source
     {
         grib_handle* h;
 
-        h = grib_handle_new_from_samples(0, "GRIB1");
+        h = grib_handle_new_from_samples(nullptr, "GRIB1");
         if (!h)
             throw MvException("Reprojection-> Unable to create grib handle");
 
