@@ -7,32 +7,27 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef REPROJECTSERVICE_H
-#define REPROJECTSERVICE_H
+#pragma once
+
+#include <string>
 
-#include <iostream>
 #include <UserPoint.h>
 #include <RasterData.h>
 #include <GribDecoder.h>
 #include <Matrix.h>
 
-using namespace std;
-using namespace magics;
-
 
 class ReprojectService
 {
 public:
     ReprojectService() {}
-    ReprojectService(string in, string out, double rx, double ry, double x1, double x2, double y1, double y2);
+    ReprojectService(std::string in, std::string out, double rx, double ry, double x1, double x2, double y1, double y2);
 
     bool execute();
     int gribit(magics::Matrix& matrix, magics::GribDecoder& sourceGrib);
 
 private:
-    string gribIn_;
-    string gribOut_;
-    double resX_, resY_;        //resolution
+    std::string gribIn_;
+    std::string gribOut_;
+    double resX_, resY_;  //resolution
 };
-
-#endif
