@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef REPROJECTION_H
-#define REPROJECTION_H
+#pragma once
 
 /**************
   Application Reprojection.
@@ -44,7 +43,7 @@ public:
     bool ComputeReprojection(MvRequest&);
 
     // Get values
-    //	fortfloat GetValue(float rank, vector<fortfloat>& gvals);
+    //	fortfloat GetValue(float rank, std::vector<fortfloat>& gvals);
 
 protected:
     // variables
@@ -52,7 +51,5 @@ protected:
     fortint interp_;               // interporlation method
     fortfloat x1_, x2_, y1_, y2_;  // geographical coordinates
     fortfloat xres_, yres_;        // x/y resolution
-    string projectionOut_;         // output projection
+    std::string projectionOut_;    // output projection
 };
-
-#endif
