@@ -7,7 +7,12 @@
 
  ***************************** LICENSE END *************************************/
 
-#include "inc_iostream.h"
+#include <fstream>
+#include <iostream>
+#include <sstream>
+#include <string>
+#include "fstream_mars_fix.h"
+
 #include "Metview.h"
 
 #include <fcntl.h>
@@ -18,31 +23,27 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#include <sstream>
-
 #include "MvScm.h"
 
-using namespace std;
-
 
 class Base : public MvService
 {
 protected:
     Base(const char* a) :
-        MvService(a){};
+        MvService(a) {}
 };
 
 class RttovRun : public Base
 {
 public:
     RttovRun() :
-        Base("RTTOV_RUN"){};
+        Base("RTTOV_RUN") {}
     void serve(MvRequest&, MvRequest&);
 };
 
 void RttovRun::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "--------------RttovRun::serve() in--------------" << endl;
+    std::cout << "--------------RttovRun::serve() in--------------" << std::endl;
     in.print();
 
     std::string errTxt;
@@ -50,25 +51,25 @@ void RttovRun::serve(MvRequest& in, MvRequest& out)
     //Find out rttov script path
     std::string rttovScript;
     char* mvbin = getenv("METVIEW_BIN");
-    if (mvbin == 0) {
+    if (mvbin == nullptr) {
         setError(1, "RttovRun-> No METVIEW_BIN env variable is defined. Cannot locate script mv_rttov_run!");
         return;
     }
     else {
-        rttovScript = string(mvbin) + "/mv_rttov_run";
+        rttovScript = std::string(mvbin) + "/mv_rttov_run";
     }
 
 
     //Create  tmp dir for the flextra run
     std::string tmpPath;
     if (!metview::createWorkDir("rttov", tmpPath, errTxt)) {
-        string err = "RttovRun-> " + errTxt;
+        std::string err = "RttovRun-> " + errTxt;
         setError(1, err.c_str());
         return;
     }
 
     //RttovRun exe
-    string exe;
+    std::string exe;
     if (!in.getPath("RTTOV_EXE_PATH", exe, true)) {
         setError(1, "RttovRun-> Error parameter RTTOV_EXE_PATH");
         return;
@@ -81,9 +82,9 @@ void RttovRun::serve(MvRequest& in, MvRequest& out)
     // Input data
     //---------------------------------------
 
-    string data;
+    std::string data;
     if (!in.getPath("RTTOV_INPUT_DATA", "RTTOV_INPUT_DATA_PATH", data, false, errTxt)) {
-        string err = "RttovRun-> " + errTxt;
+        std::string err = "RttovRun-> " + errTxt;
         setError(1, err.c_str());
         return;
     }
@@ -98,9 +99,9 @@ void RttovRun::serve(MvRequest& in, MvRequest& out)
         return;
     }
 
-    stringstream sst;
+    std::stringstream sst;
     sst << levelNum;
-    string nlev = sst.str();
+    std::string nlev = sst.str();
 
     //--------------------------------------
     // Sensor (channels + coefficients)
@@ -108,19 +109,19 @@ void RttovRun::serve(MvRequest& in, MvRequest& out)
 
     const char* sensor = in("RTTOV_SENSOR");
 
-    string ch    = "_UNDEF_";
-    string coeff = "_UNDEF_";
+    std::string ch    = "_UNDEF_";
+    std::string coeff = "_UNDEF_";
     if (sensor && strcmp(sensor, "CUSTOM") == 0) {
         //Channels file
         if (!in.getPath("RTTOV_CHANNELS", "RTTOV_CHANNELS_PATH", ch, true, errTxt)) {
-            string err = "RttovRun-> " + errTxt;
+            std::string err = "RttovRun-> " + errTxt;
             setError(1, err.c_str());
             return;
         }
 
         //Coeff file
         if (!in.getPath("RTTOV_COEFFICIENTS", "RTTOV_COEFFICIENTS_PATH", coeff, true, errTxt)) {
-            string err = "RttovRun-> " + errTxt;
+            std::string err = "RttovRun-> " + errTxt;
             setError(1, err.c_str());
             return;
         }
@@ -141,10 +142,10 @@ void RttovRun::serve(MvRequest& in, MvRequest& out)
     // Prepare input file
     //---------------------------
 
-    string inFile = tmpPath + "/rttov_in.txt";
-    bool useOzone = (sensor && strcmp(sensor, "IASI") == 0) ? true : false;
+    std::string inFile = tmpPath + "/rttov_in.txt";
+    bool useOzone      = (sensor && strcmp(sensor, "IASI") == 0) ? true : false;
     if (MvScm::createRttovInput(data, inFile, sat_z, sat_az, solar_z, solar_az, useOzone, errTxt) == false) {
-        string err = "RttovRun-> Could not generate RTTOV input file! " + errTxt;
+        std::string err = "RttovRun-> Could not generate RTTOV input file! " + errTxt;
         setError(1, err.c_str());
         return;
     }
@@ -153,14 +154,14 @@ void RttovRun::serve(MvRequest& in, MvRequest& out)
     // Run the model
     //-------------------------
 
-    string resFileName = "rttov_out.txt";
-    string resFile     = tmpPath + "/" + resFileName;
+    std::string resFileName = "rttov_out.txt";
+    std::string resFile     = tmpPath + "/" + resFileName;
 
-    string logFileName = "log.txt";
-    string logFile     = tmpPath + "/" + logFileName;
+    std::string logFileName = "log.txt";
+    std::string logFile     = tmpPath + "/" + logFileName;
 
     //Run the scm script
-    string cmd = rttovScript + " \"" + tmpPath + "\" \"" + exe + "\" \"" + inFile + "\" \"" + nlev + "\" \"" + sensor + "\" \"" + ch + "\" \"" + coeff + "\" \"" + logFileName + "\" \"" + resFileName + "\"";
+    std::string cmd = rttovScript + " \"" + tmpPath + "\" \"" + exe + "\" \"" + inFile + "\" \"" + nlev + "\" \"" + sensor + "\" \"" + ch + "\" \"" + coeff + "\" \"" + logFileName + "\" \"" + resFileName + "\"";
 
     //marslog(LOG_INFO,"Execute command: %s",cmd.c_str());
 
@@ -171,8 +172,8 @@ void RttovRun::serve(MvRequest& in, MvRequest& out)
     //If the script failed read log file and
     //write it into LOG_EROR
     if (ret == -1 || WEXITSTATUS(ret) != 0) {
-        ifstream in(logFile.c_str());
-        string line;
+        std::ifstream in(logFile.c_str());
+        std::string line;
 
         if (WEXITSTATUS(ret) == 255) {
             setError(0, "RttovRun-> Warnings were generated during RTTOV run!");
@@ -193,7 +194,7 @@ void RttovRun::serve(MvRequest& in, MvRequest& out)
         marslog(LOG_EROR, "Log files are available at:");
         marslog(LOG_EROR, "---------------------------");
         marslog(LOG_EROR, " (STDOUT)  %s", logFile.c_str());
-        string msg = tmpPath + "/fort.20";
+        std::string msg = tmpPath + "/fort.20";
         marslog(LOG_EROR, " (fort.20) %s", msg.c_str());
 
         return;
@@ -202,7 +203,7 @@ void RttovRun::serve(MvRequest& in, MvRequest& out)
         marslog(LOG_INFO, "Log files are available at:");
         marslog(LOG_INFO, "---------------------------");
         marslog(LOG_INFO, " (STDOUT)  %s", logFile.c_str());
-        string msg = tmpPath + "/fort.20";
+        std::string msg = tmpPath + "/fort.20";
         marslog(LOG_INFO, " (fort.20) %s", msg.c_str());
     }
 
@@ -213,10 +214,10 @@ void RttovRun::serve(MvRequest& in, MvRequest& out)
     /*if(!userResFile.empty())
 	{
 	  	const char *dn=dirname(userResFile.c_str());
-	  	cmd="mkdir -p " + string(dn) + "; cp -f " + resFile + " " +  userResFile;
+	  	cmd="mkdir -p " + std::string(dn) + "; cp -f " + resFile + " " +  userResFile;
 			
-	  	stringstream outStream;
-		stringstream errStream;
+	  	std::stringstream outStream;
+		std::stringstream errStream;
 		shellCommand(cmd,outStream,errStream);
 		
 		if(!errStream.str().empty())
@@ -238,7 +239,7 @@ void RttovRun::serve(MvRequest& in, MvRequest& out)
     out         = MvRequest("RTTOV_OUTPUT_FILE");
     out("PATH") = resFile.c_str();
 
-    cout << "--------------RttovRun::serve() out--------------" << endl;
+    std::cout << "--------------RttovRun::serve() out--------------" << std::endl;
     out.print();
 }
 
