@@ -12,27 +12,26 @@
 
 #include <iostream>
 #include <stdexcept>
-#include <fstream>
 
 
 class Base : public MvService
 {
 protected:
     Base(const char* a) :
-        MvService(a){};
+        MvService(a) {}
 };
 
 class ScmVisualiser : public Base
 {
 public:
     ScmVisualiser() :
-        Base("SCM_VISUALISER"){};
+        Base("SCM_VISUALISER") {}
     void serve(MvRequest&, MvRequest&);
 
 private:
-    bool getDataPath(MvRequest& in, const char* dataParamName, const char* dataPathParamName, string& result);
-    string getList(MvRequest& in, const char* parameter, string& separator, int& numElements);
-    string getString(MvRequest& in, const char* parameter, const char* defaultVal);
+    bool getDataPath(MvRequest& in, const char* dataParamName, const char* dataPathParamName, std::string& result);
+    std::string getList(MvRequest& in, const char* parameter, std::string& separator, int& numElements);
+    std::string getString(MvRequest& in, const char* parameter, const char* defaultVal);
 };
 
 
@@ -43,18 +42,18 @@ private:
 // in the 'result' string.
 // Returns true if it found a path, otherwise false.
 
-bool ScmVisualiser::getDataPath(MvRequest& in, const char* dataParamName, const char* dataPathParamName, string& result)
+bool ScmVisualiser::getDataPath(MvRequest& in, const char* dataParamName, const char* dataPathParamName, std::string& result)
 {
     MvRequest dataR      = in(dataParamName);
     const char* dataPath = dataR("PATH");
 
     if (dataPath) {
-        result = string(dataPath);
+        result = std::string(dataPath);
     }
     else {
         const char* cval = in(dataPathParamName);
         if (cval) {
-            result = string(cval);
+            result = std::string(cval);
             if (result == "OFF")
                 result.clear();
         }
@@ -73,22 +72,22 @@ bool ScmVisualiser::getDataPath(MvRequest& in, const char* dataParamName, const
 // Parses a list-type variable from a request and returns it
 // as a separated string. Also returns the number of elements found.
 
-string ScmVisualiser::getList(MvRequest& in, const char* parameter, string& separator, int& numElements)
+std::string ScmVisualiser::getList(MvRequest& in, const char* parameter, std::string& separator, int& numElements)
 {
-    string result;
+    std::string result;
 
     int nrParams = in.countValues(parameter);
     numElements  = nrParams;
 
     if (nrParams == 0)  // is this case even possible?
-        result = string("dummy");
+        result = std::string("dummy");
     else
-        result = string(in(parameter));
+        result = std::string(in(parameter));
 
     if (nrParams > 1) {
         for (int n = 1; n < nrParams; ++n) {
             result += separator;
-            result += string(in(parameter, n));
+            result += std::string(in(parameter, n));
         }
     }
 
@@ -100,7 +99,7 @@ string ScmVisualiser::getList(MvRequest& in, const char* parameter, string& sepa
 // Tries to get the given pstring arameter from the request, returning
 // a user-specified default if it is not there.
 
-string ScmVisualiser::getString(MvRequest& in, const char* parameter, const char* defaultVal)
+std::string ScmVisualiser::getString(MvRequest& in, const char* parameter, const char* defaultVal)
 {
     const char* val = in(parameter);
 
@@ -108,29 +107,29 @@ string ScmVisualiser::getString(MvRequest& in, const char* parameter, const char
         val = defaultVal;
 
 
-    return string(val);
+    return std::string(val);
 }
 
 
 void ScmVisualiser::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "--------------ScmVisualiser::serve() in--------------" << endl;
+    std::cout << "--------------ScmVisualiser::serve() in--------------" << std::endl;
     in.print();
 
-    string ScmVisMacro;
+    std::string ScmVisMacro;
     char* mvbin = getenv("METVIEW_BIN");
-    if (mvbin == 0) {
+    if (mvbin == nullptr) {
         setError(1, "ScmVisualiser-> No METVIEW_BIN env variable is defined. Cannot locate mv_scm_vis.mv macro!");
         return;
     }
     else {
-        ScmVisMacro = string(mvbin) + "/mv_scm_vis.mv";
+        ScmVisMacro = std::string(mvbin) + "/mv_scm_vis.mv";
     }
 
-    vector<string> params;
-    string str;
-    string listSeparator = ",";
-    const char* defVal   = "dummy";
+    std::vector<std::string> params;
+    std::string str;
+    std::string listSeparator = ",";
+    const char* defVal        = "dummy";
 
 
     // set the MARS expand flags to avoid unwanted expansion of lists
@@ -143,7 +142,7 @@ void ScmVisualiser::serve(MvRequest& in, MvRequest& out)
 
 
     // Input data
-    string dataPath;
+    std::string dataPath;
     bool ok = getDataPath(in, "SCM_DATA", "SCM_DATA_FILENAME", dataPath);
     if (!ok)
         return;  // error message already generated
@@ -156,11 +155,11 @@ void ScmVisualiser::serve(MvRequest& in, MvRequest& out)
 
 
     // comparison data
-    string compareDataBool = getString(in, "SCM_COMPARE_DATA", defVal);
+    std::string compareDataBool = getString(in, "SCM_COMPARE_DATA", defVal);
     params.push_back(compareDataBool);
 
 
-    string comparisonDataTitle;
+    std::string comparisonDataTitle;
     if (compareDataBool == "ON") {
         ok = getDataPath(in, "SCM_COMPARISON_DATA", "SCM_COMPARISON_DATA_FILENAME", dataPath);
         if (!ok)
@@ -188,7 +187,7 @@ void ScmVisualiser::serve(MvRequest& in, MvRequest& out)
 
 
     // data type (input/output from SCM)
-    string dataType = getString(in, "SCM_DATA_TYPE", defVal);
+    std::string dataType = getString(in, "SCM_DATA_TYPE", defVal);
 
 
     // variable lists
@@ -215,27 +214,27 @@ void ScmVisualiser::serve(MvRequest& in, MvRequest& out)
 
 
     // output mode and path
-    string outputMode = getString(in, "SCM_OUTPUT_MODE", defVal);
+    std::string outputMode = getString(in, "SCM_OUTPUT_MODE", defVal);
     params.push_back(outputMode);
 
     str = getString(in, "SCM_OUTPUT_FILE_PATH", defVal);
 
 
     // output path - add directory if not already supplied
-    string userResPath;
+    std::string userResPath;
     if (!str.empty()) {
-        userResPath = string(str);
+        userResPath = std::string(str);
 
-        if (userResPath.find("/") == string::npos) {
+        if (userResPath.find("/") == std::string::npos) {
             const char* callerIcon = in("_NAME");
             if (callerIcon) {
-                string callerDir(callerIcon);
+                std::string callerDir(callerIcon);
                 char* mvudir = getenv("METVIEW_USER_DIRECTORY");
                 if (mvudir) {
-                    callerDir = string(mvudir) + "/" + callerDir;
+                    callerDir = std::string(mvudir) + "/" + callerDir;
                 }
-                string::size_type pos = callerDir.find_last_of("/");
-                if (pos != string::npos) {
+                std::string::size_type pos = callerDir.find_last_of("/");
+                if (pos != std::string::npos) {
                     callerDir = callerDir.substr(0, pos);
                 }
 
@@ -268,7 +267,7 @@ void ScmVisualiser::serve(MvRequest& in, MvRequest& out)
 
 
     // plot the grid
-    string plotGridBool = getString(in, "SCM_GRID", defVal);
+    std::string plotGridBool = getString(in, "SCM_GRID", defVal);
     params.push_back(plotGridBool);
 
 
@@ -282,7 +281,7 @@ void ScmVisualiser::serve(MvRequest& in, MvRequest& out)
     //Build request to be sent to Macro
     MvRequest req("MACRO");
 
-    string processName = MakeProcessName("ScmVisualiser");
+    std::string processName = MakeProcessName("ScmVisualiser");
     MvRequest macroReq("MACRO");
     req("PATH")    = ScmVisMacro.c_str();
     req("_CLASS")  = "MACRO";
@@ -290,8 +289,8 @@ void ScmVisualiser::serve(MvRequest& in, MvRequest& out)
     req("_REPLY")  = processName.c_str();
 
     //Define argument list for the macro!
-    for (vector<string>::iterator it = params.begin(); it != params.end(); it++) {
-        req.addValue("_ARGUMENTS", (*it).c_str());
+    for (auto& param : params) {
+        req.addValue("_ARGUMENTS", param.c_str());
     }
 
     //Run macro
@@ -302,7 +301,7 @@ void ScmVisualiser::serve(MvRequest& in, MvRequest& out)
     //Call myself to process the macro reply request
     if (!error && reply) {
         const char* myname = reply("_REPLY");
-        MvApplication::callService(myname, reply, 0);
+        MvApplication::callService(myname, reply, nullptr);
     }
     else {
         setError(1, "ScmVisualiser-> Failed to run SCM visualiser! Macro failed!");
@@ -313,7 +312,7 @@ void ScmVisualiser::serve(MvRequest& in, MvRequest& out)
     //out("INPUT_DATA_PATH")=outPath.c_str();
     //out("AVAILABLE_FILE_PATH")=fAvailable.c_str();
 
-    cout << "--------------ScmVisualiser::serve() out--------------" << endl;
+    std::cout << "--------------ScmVisualiser::serve() out--------------" << std::endl;
     out.print();
 }
 
