@@ -8,15 +8,13 @@
  ***************************** LICENSE END *************************************/
 
 
-#include <iostream>
+#include <string>
+
 #include "Metview.h"
 #include "MvQApplication.h"
 
 #include "ScmDataEditor.h"
 
-using namespace std;
-
-
 int main(int argc, char** argv)
 {
     if (argc < 2) {
@@ -27,7 +25,7 @@ int main(int argc, char** argv)
     MvRequest in;
     in.read(argv[1], false, true);
 
-    marslog(LOG_INFO,"Request:");
+    marslog(LOG_INFO, "Request:");
     in.print();
 
     if (!in) {
@@ -37,9 +35,10 @@ int main(int argc, char** argv)
 
     // Get input file name
     std::string fPath;
-    if(const char* fPathCh = in("PATH")) {
+    if (const char* fPathCh = in("PATH")) {
         fPath = std::string(fPathCh);
-    } else {
+    }
+    else {
         marslog(LOG_EROR, "No PATH is specified!");
         exit(1);
     }
@@ -50,13 +49,13 @@ int main(int argc, char** argv)
     std::string appName = MvApplication::buildAppName("ScmDataEditor");
     MvQApplication app(argc, argv, appName.c_str(), {"examiner", "window", "scmEditor"});
 
-//    QFont font = app.font();
-//    font.setPointSize(9);
-//    app.setFont(font);
+    //    QFont font = app.font();
+    //    font.setPointSize(9);
+    //    app.setFont(font);
 
     MvScm data(fPath);
 
-    ScmDataEditor* browser = new ScmDataEditor;
+    auto* browser = new ScmDataEditor;
     browser->init(&data);
     browser->setAppIcon("SCM_INPUT_DATA");
     browser->show();
