@@ -77,7 +77,7 @@ ScmDataEditor::ScmDataEditor(QWidget* parent) :
     // Main layout
     //----------------------
 
-    QWidget* w  = new QWidget(this);
+    auto* w     = new QWidget(this);
     mainLayout_ = new QVBoxLayout(w);
     mainLayout_->setContentsMargins(0, 0, 0, 0);
     mainLayout_->setSpacing(1);
@@ -109,7 +109,7 @@ ScmDataEditor::ScmDataEditor(QWidget* parent) :
     // Preview area
     //-------------------
 
-    QVBoxLayout* viewVb = new QVBoxLayout;
+    auto* viewVb = new QVBoxLayout;
     viewVb->setContentsMargins(0, 0, 0, 0);
     viewVb->setSpacing(1);
     w = new QWidget(this);
@@ -141,7 +141,7 @@ ScmDataEditor::ScmDataEditor(QWidget* parent) :
     // Buttonbox
     //--------------------------
 
-    QHBoxLayout* buttonBoxHb = new QHBoxLayout;
+    auto* buttonBoxHb = new QHBoxLayout;
 
     buttonBox_ = new QDialogButtonBox(this);
 
@@ -291,19 +291,19 @@ void ScmDataEditor::setupAnimationActions()
 
     //Combo box
     //We will add items + signal/slots later in "init"!
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     hb->setContentsMargins(10, 2, 10, 2);
 
     //Combo box for key profile selection
-    QLabel* label = new QLabel(tr("&Steps:"));
-    stepCombo_    = new QComboBox;
+    auto* label = new QLabel(tr("&Steps:"));
+    stepCombo_  = new QComboBox;
     stepCombo_->view()->setTextElideMode(Qt::ElideNone);
     stepCombo_->setSizeAdjustPolicy(QComboBox::AdjustToContents);
     label->setBuddy(stepCombo_);
 
     hb->addWidget(label);
     hb->addWidget(stepCombo_);
-    QWidget* wh = new QWidget;
+    auto* wh = new QWidget;
     wh->setLayout(hb);
 
     //Slot for the ombo will be added later in init
@@ -358,7 +358,7 @@ void ScmDataEditor::setupViewActions()
 void ScmDataEditor::setupHelpActions()
 {
     // About
-    QAction* actionAbout = new QAction(this);
+    auto* actionAbout = new QAction(this);
     actionAbout->setObjectName(QString::fromUtf8("actionAbout"));
     actionAbout->setText(tr("&About Profile Data Editor"));
 
@@ -387,8 +387,8 @@ void ScmDataEditor::init(MvScm* data)
     editableVars_ << data_->soilVar(MvScm::TempSoil) << data_->soilVar(MvScm::HumSoil);
 
     //Siurface
-    for (unsigned int i = 0; i < data_->surfaceLevel().size(); i++)
-        editableVars_ << data_->surfaceLevel().at(i);
+    for (auto i : data_->surfaceLevel())
+        editableVars_ << i;
 
     //This method will select a paramater in the table view! This will trigger an uopdate in he profile view as well!
     dataPanel_->init(data, editableVars_);
@@ -406,14 +406,15 @@ void ScmDataEditor::init(MvScm* data)
             name = "  " + name + "  ";
         }
 
-        QListWidgetItem* item = new QListWidgetItem(name);
+        auto* item = new QListWidgetItem(name);
         item->setData(Qt::UserRole, i);
 
         if (editableVars_.contains(data_->modelLevel().at(i))) {
             item->setBackground(MvQTheme::colour("scmview", "params_editable_bg"));
             item->setForeground(MvQTheme::colour("scmview", "params_editable_text"));
             item->setFont(editableFont);
-        } else {
+        }
+        else {
             item->setBackground(MvQTheme::colour("scmview", "params_bg"));
         }
         parListW_->addItem(item);
@@ -431,10 +432,10 @@ void ScmDataEditor::init(MvScm* data)
     QFontMetrics fm(font);
     stepCombo_->setIconSize(QSize(16, 16));
 
-    const vector<float>& steps = data_->steps();
+    const std::vector<float>& steps = data_->steps();
 
-    for (int i = 0; i < static_cast<int>(steps.size()); i++) {
-        QString txt = QString::number(steps.at(i) / 3600) + " h      ";
+    for (float step : steps) {
+        QString txt = QString::number(step / 3600) + " h      ";
         stepCombo_->addItem(noEditPix_, txt);
         stepCombo_->setItemData(stepCombo_->count() - 1, 0);
     }
@@ -480,7 +481,7 @@ void ScmDataEditor::slotParamSelectedFromData(MvScmVar* var, int step)
         //Surf
         MvScmVar* skinT = data_->surfVar(MvScm::TempSurf);
         if (skinT) {
-            MvScmProfileData* p = new MvScmProfileData(data_, skinT, step);
+            auto* p = new MvScmProfileData(data_, skinT, step);
             lst << p;
             p->setObserver(this);
         }
@@ -488,7 +489,7 @@ void ScmDataEditor::slotParamSelectedFromData(MvScmVar* var, int step)
         //Soil
         MvScmVar* soilT = data_->soilVar(MvScm::TempSoil);
         if (soilT) {
-            MvScmProfileData* p = new MvScmProfileData(data_, soilT, step);
+            auto* p = new MvScmProfileData(data_, soilT, step);
             lst << p;
             p->setObserver(this);
         }
@@ -705,7 +706,7 @@ void ScmDataEditor::slotShowEditableParams(bool showEditable)
     dataPanel_->showEditableParams(showEditable);
 }
 
-void ScmDataEditor::slotOverwrite(bool b)
+void ScmDataEditor::slotOverwrite(bool)
 {
     if (data_) {
         int ts = stepCombo_->currentIndex();
