@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef _STATION_H_
-#define _STATION_H_
+#pragma once
 
 
 typedef struct
@@ -40,9 +39,6 @@ char *upcase(const char *p); */
 char *nice_name(const char *p);
 int open_database(char c);
 
-int open_EPS_stationfile( ifstream* EPS_file );
-int read_one_station( ifstream* EPS_file, station& st );
-#endif
-
-
+int open_EPS_stationfile( std::ifstream* EPS_file );
+int read_one_station( std::ifstream* EPS_file, station& st );
 #endif
