@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef STDAPPMANAGER_H
-#define STDAPPMANAGER_H
+#pragma once
 
 /************************************
   Application StdAppManager
@@ -36,7 +35,5 @@ protected:
     //     iv = input_visualiser(input_y_values : yvals, ...)
     // Macro converts nil to DBL_MAX
     // This function replaces DBL_MAX to a missing value indicator
-    void missingValue(MvRequest&, string, string);
+    void missingValue(MvRequest&, std::string, std::string);
 };
-
-#endif
