@@ -14,28 +14,54 @@
 #include "MvNetCDF.h"
 #include "MvObsSet.h"
 #include "MvRequestUtil.hpp"
+#include "MvException.h"
+#include "MvSci.h"
+#include "MvLog.h"
 
 #include <assert.h>
 
+//using namespace metview;
+
 const int TOBSTEMP     = 12001;
 const int TOBSTD       = 12003;
 const int TOBSDIR      = 11001;
 const int TOBSSTRENGTH = 11002;
 const int TOBSZ        = 10003;
-const double PI        = 3.14159265;
+
+bool BufrStation::initObsIter(MvObsSetIterator& iter) const
+{
+    if (pointMode_ == CoordMode) {
+        MvLocation loc1(lat_ + threshold_, lon_ - threshold_);
+        MvLocation loc2(lat_ - threshold_, lon_ + threshold_);
+        iter.setArea(loc1, loc2);
+        return true;
+    } else if (pointMode_ == WmoNameMode) {
+        iter.setIdentKey("stationOrSiteName");
+        iter.setIdentKey("shipOrMobileLandStationIdentifier");
+        iter.setIdentValue(wmoName_);
+        return true;
+    } else if (pointMode_ == WmoIdentMode) {
+        iter.setWmoStation(wmoIdent_);
+        return true;
+    } else if (pointMode_ == WigosMode) {
+        iter.setWigosId(wigosSeries_, wigosIssuer_, wigosIssueNumber_, wigosLocalName_);
+        return true;
+    }
+    return false;
+}
+
 
 BufrThermo::BufrThermo() :
-    Thermo("BUFR_THERMO"),
-    counter_(0),
-    pCount_(0),
-    nlev_(0),
-    nTIME_STR_(13)
+    Thermo("BUFR_THERMO")
 {
+    moduleLabel_ = "BufrThermo-> ";
 }
 
+
 BufrThermo::BufrThermo(const char* kw) :
     Thermo(kw)
 {
+    moduleLabel_ = "BufrThermo-> ";
 }
 
 void BufrThermo::allocateDataMemory()
@@ -86,14 +112,75 @@ void BufrThermo::initialiseDataMemory()
 bool BufrThermo::getAppParameters(MvRequest& in)
 {
     // It is expected that the input request is expanded
+    station_ = {};
 
-    // Get station input parameter
-    station_ = in.getSubrequest("STATION");
-    if (!station_) {
-        setError(1, "BufrThermo-> No Station info specified!");
-        return false;
+    // Retrieve point selection
+    if (const char* ch = in("POINT_SELECTION")) {
+        MvLog().info() << "POINT_SELECTION=" << ch;
+
+        auto ps = std::string(ch);
+        if (ps == "COORDINATES") {            
+            station_.pointMode_ = BufrStation::CoordMode;
+            in.getValue(station_.lat_, "COORDINATES", 0);
+            in.getValue(station_.lon_, "COORDINATES", 1);
+            station_.threshold_ = in("THRESHOLD");
+            checkThreshold(station_.threshold_);
+        } else if (ps == "WMO_NAME") {
+            station_.pointMode_ = BufrStation::WmoNameMode;
+            const char* chName = in("WMO_NAME");
+            if (!chName || strcmp(chName, "") == 0) {
+                throw MvException(moduleLabel_ + "No WMO_NAME specified");
+            }
+            assert(chName);
+            station_.wmoName_ = std::string(chName);
+        } else if (ps == "WMO_IDENT") {
+            station_.wmoIdent_ = in("WMO_IDENT");
+            if(checkIdent(station_.wmoIdent_, false)) {
+                station_.pointMode_ = BufrStation::WmoIdentMode;
+            }
+        } else if (ps == "WIGOS") {
+            station_.pointMode_ = BufrStation::WigosMode;
+            if (const char *wgCh = in("WIGOS_SERIES")) {
+                station_.wigosSeries_ = (int)in("WIGOS_SERIES");
+            }
+            if (const char *wgCh = in("WIGOS_ISSUER")) {
+                station_.wigosIssuer_ = (int)in("WIGOS_ISSUER");
+            }
+            if (const char *wgCh = in("WIGOS_ISSUE_NUMBER")) {
+                station_.wigosIssueNumber_ = (int)in("WIGOS_ISSUE_NUMBER");
+            }
+            if (const char *wgCh = in("WIGOS_LOCAL_NAME")) {
+                station_.wigosLocalName_ = std::string(wgCh);
+            }
+        } else if (ps == "STATION") {
+            MvRequest stReq = in.getSubrequest("STATION");
+            if (!stReq) {
+                throw MvException(moduleLabel_ + "No STATION specified");
+            }
+            if (const char* chIdent = stReq("IDENT")) {
+                station_.wmoIdent_ = stReq("IDENT");
+                if(checkIdent(station_.wmoIdent_, false)) {
+                     station_.pointMode_ = BufrStation::WmoIdentMode;
+                }
+            }
+            if (station_.pointMode_ == BufrStation::NoMode) {
+                station_.pointMode_ = BufrStation::CoordMode;
+                station_.lat_ = stReq("LATITUDE");
+                station_.lon_ = stReq("LONGITUDE");
+                station_.threshold_ = stReq("THRESHOLD");
+                checkThreshold(station_.threshold_);
+            }
+        }
     }
 
+    if (station_.pointMode_ == BufrStation::NoMode) {
+        throw MvException(moduleLabel_ + "No valid location/station specified");
+    }
+#if 0
+    MvLog().info() << MV_FN_INFO << "  mode=" << station_.pointMode_ << " ident=" << station_.wmoIdent_ <<
+                 " lat=" << station_.lat_ << " lon=" << station_.lon_ <<
+                 " wigosLocalName_=" << station_.wigosLocalName_;
+#endif
     return true;
 }
 
@@ -108,42 +195,50 @@ bool BufrThermo::processData()
     if (strcmp(dataRequest_.getVerb(), "BUFR") != 0)
         return true;
 
-    // Create a temporary netCDF file
-    std::string ncFileName = this->ncFileName();
-    MvNetCDF netcdf(ncFileName, 'w');
-    if (!netcdf.isValid()) {
-        setError(1, "BufrThermo-> Can not open a new netCDF file");
-        return false;
-    }
-
     // Get location info from the station
     MvObsSet obsset(dataRequest_);
     MvObsSetIterator iter(obsset);
-    if (!getIdent(station_, iter)) {
-        if (!getLocation(station_, iter)) {
-            setError(1, "BufrThermo-> WMO station number and/or location missing...");
-            return false;
-        }
+
+    if (!station_.initObsIter(iter)) {
+        throw MvException(moduleLabel_ + "No valid location/station specified");
     }
 
+    //-- Vertical soundings (other than satellite)
+    iter.setMessageType(2);
+
+    // we only support these subtypes. We want to skip pilot. The problem here is
+    // that 101/109 are dataSubCategories defined at ECMWF for BUFR edition 3. However,
+    // 4 is an internationalDataSubCategory defined in BUFR edition 4 (by WMO).
+    iter.setMessageSubtype(101);
+    iter.setMessageSubtype(109);
+    iter.setMessageSubtype(4);
+
     // Initialize obs variables
     MvBufrParam obsTemp(TOBSTEMP), obsTd(TOBSTD),
         obsDirection(TOBSDIR), obsStrength(TOBSSTRENGTH),
         obsZ(TOBSZ);
 
-    iter.setMessageType(2);  //-- Vertical soundings (other than satellite)
-
     // Evaluate dimensions
-    // Remove this function after updating library MvNetCDF to create
-    // files of type Netcdf4 (allowing multiple unlimited dimensions)
-    nlev_ = this->evaluateNLevels(iter);
-    if (nlev_ <= 0) {
-        setError(1, "BufrThermo-> No Levels found");
+    // TODO: Remove this function after updating library MvNetCDF to create
+    // files of type Netcdf4 (allowing multiple unlimited dimensions)   
+
+    int msgNum = 0;
+    evaluateNLevels(iter, msgNum, nlev_);
+    if (msgNum <= 0) {
+        throw MvException(moduleLabel_ + "No BUFR messages matching the required location and observation type found in input!");
+    } else if (nlev_ <= 0) {
+        throw MvException(moduleLabel_ + "No pressure levels found in input!");
+    }
+
+    // Create a temporary netCDF file
+    MvNetCDF netcdf(ncFileName(), 'w');
+    if (!netcdf.isValid()) {
+        setError(1, "BufrThermo-> Can not open a new netCDF file");
         return false;
     }
 
     // Allocate memory
-    this->allocateDataMemory();
+    allocateDataMemory();
 
     // Main loop
     // Compute data values
@@ -151,13 +246,12 @@ bool BufrThermo::processData()
     obsset.rewind();
     counter_ = 0;
     while ((obs = iter())) {
-        //FAMI20190212 only accepts BUFR sybtypes 101/109/4
-        // Skip PILOT
-        if (obs.messageSubtype() != 101 && obs.messageSubtype() != 109 && obs.messageSubtype() != 4)  //obs.messageSubtype() == 91 )  //-- ECMWF code for PILOT!
-        {
-            setError(0, "BufrThermo-> Skip PILOT soundings (full TEMP sounding needed)");
-            continue;
-        }
+//        // Skip PILOT
+//        if (obs.messageSubtype() != 101 && obs.messageSubtype() != 109 && obs.messageSubtype() != 4)  //obs.messageSubtype() == 91 )  //-- ECMWF code for PILOT!
+//        {
+//            setError(0, "BufrThermo-> Skip PILOT soundings (full TEMP sounding needed)");
+//            continue;
+//        }
 
         //obs.printAllValues();
 
@@ -192,8 +286,8 @@ bool BufrThermo::processData()
 
             // Wind values, polar -> u,v
             if (myDir != MissingValue) {
-                U_[ic] = -myStr * sin(myDir * PI / 180.0);
-                V_[ic] = -myStr * cos(myDir * PI / 180.0);
+                U_[ic] = -myStr * sin(MvSci::degToRad(myDir));
+                V_[ic] = -myStr * cos(MvSci::degToRad(myDir));
             }
 
             // Geopotential
@@ -212,7 +306,7 @@ bool BufrThermo::processData()
 
         // Consistency check
         if (pCount_ <= 1) {
-            setError(1, "BufrThermo-> Problems with BUFR data");
+            setError(1, "BufrThermo-> No pressure levels found in BUFR data");
             return false;
         }
 
@@ -467,43 +561,17 @@ bool BufrThermo::createOutputRequest(MvRequest& out)
     return true;
 }
 
-int BufrThermo::evaluateNLevels(MvObsSetIterator& iter)
+void BufrThermo::evaluateNLevels(MvObsSetIterator& iter, int& msgNum, int& maxLevNum)
 {
     MvObs obs;
     int nn;
-    int nlev = -1;
+    msgNum = 0;
+    maxLevNum = 0;
     while ((obs = iter())) {
+        msgNum++;
         nn = obs.numberOfPressureLevels();
-        if (nlev < nn)
-            nlev = nn;
+        maxLevNum = std::max(maxLevNum, nn);
     }
-
-    return nlev;
-}
-
-bool BufrThermo::getIdent(MvRequest& station, MvObsSetIterator& iter)
-{
-    long ident = station("IDENT");
-    if (ident) {
-        iter.setWmoStation(ident);
-        return true;
-    }
-
-    return false;
-}
-
-bool BufrThermo::getLocation(MvRequest& station, MvObsSetIterator& iter)
-{
-    double lat = station("LATITUDE");
-    double lon = station("LONGITUDE");
-    double eps = 0.0001;  //-- to allow for BUFR rounding differences
-
-    MvLocation loc1(lat + eps, lon - eps);
-    MvLocation loc2(lat - eps, lon + eps);
-
-    iter.setArea(loc1, loc2);
-
-    return true;
 }
 
 std::string BufrThermo::title()
@@ -534,3 +602,23 @@ std::string BufrThermo::title()
 
     return std::string(title);
 }
+
+bool BufrThermo::checkIdent(long ident, bool failOnError) const
+{
+    if (ident <= 0) {
+        if (failOnError) {
+            throw MvException(moduleLabel_ +
+                "Invalid IDENT=" + std::to_string(ident) + " specified");
+        }
+        return false;
+    }
+    return true;
+}
+
+void BufrThermo::checkThreshold(double threshold) const
+{
+    if (threshold < 0 || threshold > 100) {
+        throw MvException(moduleLabel_ +
+            "Invalid THRESHOLD=" + std::to_string(threshold) + " specified");
+    }
+}
