@@ -11,10 +11,35 @@
 
 #include "Thermo.h"
 
+namespace metview {
 class MvObs;
 class MvObsSetIterator;
+}
+
 class MvNetCDF;
 
+class BufrStation
+{
+    friend class BufrThermo;
+public:
+    BufrStation() = default;
+    bool initObsIter(MvObsSetIterator&) const;
+
+protected:
+    double lat_{0};
+    double lon_{0};
+    double threshold_{0.1}; //in degrees
+    std::string wmoName_;
+    long wmoIdent_;
+    int wigosSeries_{-1};
+    int wigosIssuer_{-1};
+    int wigosIssueNumber_{-1};
+    std::string wigosLocalName_;
+
+    enum PointMode {NoMode, CoordMode, WmoNameMode, WmoIdentMode, WigosMode};
+    PointMode pointMode_{NoMode};
+};
+
 class BufrThermo : public Thermo
 {
 public:
@@ -32,38 +57,40 @@ public:
     void initialiseDataMemory();
 
     // Process data and build all data structures
-    bool processData();
+    bool processData() override;
 
     //  Post-process and generate NetCDF output
     bool generate(MvNetCDF&, MvObs&);
 
     // Generate output request
-    bool createOutputRequest(MvRequest&);
+    bool createOutputRequest(MvRequest&) override;
 
     // Create a default title
     std::string title();
 
 protected:
     // Get application specific parameters
-    virtual bool getAppParameters(MvRequest&);
+    bool getAppParameters(MvRequest&) override;
 
     // Initialise a netCDF file: variables, dimensions and attributes
     bool ncInit(MvNetCDF&, MvObs&);
 
     // Get Identification and Location from the Bufr data
     bool getIdent(MvRequest&, MvObsSetIterator&);
+    bool getIdentName(MvRequest& station, MvObsSetIterator& iter);
     bool getLocation(MvRequest&, MvObsSetIterator&);
 
     // Get the maximum number of pressure levels
-    int evaluateNLevels(MvObsSetIterator&);
+    void evaluateNLevels(MvObsSetIterator&, int& msgNum, int& maxLevNum);
+
+    bool checkIdent(long ident, bool failOnError) const;
+    void checkThreshold(double threshold) const;
 
     // Variables members
-    MvRequest station_;  // Station input request
-
-    int counter_;    // number of thermo data
-    int pCount_;     // number of levels
-    int nlev_;       // maximum number of levels
-    int nTIME_STR_;  // 13 - yyyymmddhhmm + 1 ('end of string')
+    int counter_{0};    // number of thermo data
+    int pCount_{0};     // number of levels
+    int nlev_{0};       // maximum number of levels
+    int nTIME_STR_{13};  // 13 - yyyymmddhhmm + 1 ('end of string')
 
     std::vector<double> T_;  // variables data
     std::vector<double> P_;
@@ -71,4 +98,6 @@ protected:
     std::vector<double> U_;
     std::vector<double> V_;
     std::vector<double> Z_;
+
+    BufrStation station_;
 };
