@@ -8,8 +8,11 @@
  ***************************** LICENSE END *************************************/
 
 #include "DataThermo.h"
+
+#include <iomanip>
+
 #include "MvException.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "MvSci.h"
 #include "MvNetCDF.h"
 #include "Thermo.h"
@@ -155,8 +158,8 @@ bool MvThermoDataBase::generateWind(MvNetCDF& netcdf)
     long size = uCount_;  // uCount_ and vCount_ should have the same value
 
     // Generate NetCDF variables
-    vector<long> values_ndim;
-    vector<string> values_sdim;
+    std::vector<long> values_ndim;
+    std::vector<std::string> values_sdim;
     values_ndim.push_back(0);
     values_ndim.push_back(size);
     values_sdim.push_back(sTIME);
@@ -178,7 +181,7 @@ bool MvThermoDataBase::generateWind(MvNetCDF& netcdf)
         throw MvException("Thermo-> ERROR writing a netCDF variable: v");
 
     // Add horizontal axis values
-    vector<double> xv(size, XWIND_POS);
+    std::vector<double> xv(size, XWIND_POS);
     xvals->setCurrent(counter_);
     if (!xvals->put(xv, 1, size))
         throw MvException("Thermo-> ERROR writing a netCDF variable: xwind");
@@ -238,13 +241,13 @@ void MvThermoDataBase::collectValue(double val)
         tCount_++;
     }
     else if (par == pars_->dewId_) {
-        Q_.push_back(max(ZEPQMI, val));
+        Q_.push_back(std::max(ZEPQMI, val));
         dCount_++;
     }
     else if (par == pars_->lnPressId_)
         processPressure(val);
     else {
-        ostringstream oss;
+        std::ostringstream oss;
         oss << "Thermo-> Field contains unknown data, param = " << par;
         throw MvException(oss.str());
     }
@@ -274,11 +277,11 @@ void MvThermoDataBase::generateTimeKey()
     const char* step = req("STEP");
 
     // variable nTIME_STR = 17 (8+4+4+1)
-    ostringstream oss;
-    oss << setfill('0')
-        << setw(8) << date
-        << setw(4) << (time ? time : "TTTT")
-        << setw(4) << (step ? step : "SSSS");
+    std::ostringstream oss;
+    oss << std::setfill('0')
+        << std::setw(8) << date
+        << std::setw(4) << (time ? time : "TTTT")
+        << std::setw(4) << (step ? step : "SSSS");
 
     timeKey_ = oss.str();
 }
@@ -291,8 +294,8 @@ bool MvThermoDataBase::ncInit(MvNetCDF& netcdf)
 
     // Create variables
     long size = tCount_;
-    vector<long> values_ndim;
-    vector<string> values_sdim;
+    std::vector<long> values_ndim;
+    std::vector<std::string> values_sdim;
     values_ndim.push_back(0);
     values_sdim.push_back(sTIME);
 
@@ -319,7 +322,7 @@ bool MvThermoDataBase::ncGlobalAttributes(MvNetCDF& netcdf)
     netcdf.addAttribute("DewPoint Formulation", formulaPrintName().c_str());
     switch (pars_->pointType_) {
         case eInterpolated: {
-            ostringstream oss;
+            std::ostringstream oss;
             oss << pars_->lat_
                 << '/'
                 << pars_->lon_;
@@ -329,7 +332,7 @@ bool MvThermoDataBase::ncGlobalAttributes(MvNetCDF& netcdf)
 
         case eGridPoint: {
             MvLocation loc = currField_.nearestGridPointLocation(MvLocation(pars_->lat_, pars_->lon_));
-            ostringstream oss;
+            std::ostringstream oss;
             oss << loc.latitude() << '/'
                 << loc.longitude();
 
@@ -337,7 +340,7 @@ bool MvThermoDataBase::ncGlobalAttributes(MvNetCDF& netcdf)
         } break;
 
         case eAreaAverage: {
-            ostringstream oss;
+            std::ostringstream oss;
             oss << pars_->lat_ << '/'
                 << pars_->lon_ << '/'
                 << pars_->lat2_ << '/'
@@ -356,25 +359,25 @@ bool MvThermoDataBase::windExist()
     return flag;
 }
 
-string
+std::string
 MvThermoDataBase::formulaPrintName()
 {
-    string name = pars_->dewPointFormulaType_;
-    for (unsigned int it = 0; it < name.length(); ++it) {
-        char cc  = name[it];
-        name[it] = (cc == '_') ? ' ' : tolower(cc);
+    std::string name = pars_->dewPointFormulaType_;
+    for (char& it : name) {
+        char cc = it;
+        it      = (cc == '_') ? ' ' : tolower(cc);
     }
 
     return name;
 }
 
-string
+std::string
 MvThermoDataBase::title(MvNetCDF& netcdf)
 {
     // Get first time information
-    string sdate = timeKey_.substr(0, 8);
-    string stime = timeKey_.substr(8, 4);
-    int istep    = atoi(timeKey_.substr(12, 4).c_str());
+    std::string sdate = timeKey_.substr(0, 8);
+    std::string stime = timeKey_.substr(8, 4);
+    int istep         = atoi(timeKey_.substr(12, 4).c_str());
 
     // Create title
     char title[200];
@@ -389,7 +392,7 @@ MvThermoDataBase::title(MvNetCDF& netcdf)
         case eGridPoint: {
             // Coordinates used may not be the same as the input ones
             MvNcAtt* tmpatt = netcdf.getAttribute("Coordinates");
-            string str      = tmpatt->as_string(0);
+            std::string str = tmpatt->as_string(0);
             int ipos        = str.find('/');
             float lat       = atof(str.substr(0, ipos).c_str());
             float lon       = atof(str.substr(ipos + 1).c_str());
@@ -406,7 +409,7 @@ MvThermoDataBase::title(MvNetCDF& netcdf)
             break;
     }
 
-    return string(title);
+    return std::string(title);
 }
 
 //==============================================================
@@ -430,8 +433,7 @@ void MvThermoDataHalfLevels::computeLevelsTd()
 void MvThermoDataHalfLevels::processPressure(double val)
 {
     lnspFlag_ = true;
-    ;
-    LNSP_ = val;
+    LNSP_     = val;
 }
 
 
@@ -515,13 +517,13 @@ void MvThermoDataUkmoNDLevels::collectValue(double val)
         tCount_++;
     }
     else if (par == pars_->dewId_) {
-        Q_.push_back(max(ZEPQMI, val));
+        Q_.push_back(std::max(ZEPQMI, val));
         dCount_++;
     }
     else if (par == pars_->lnPressId_)
         processPressure(val);
     else {
-        ostringstream oss;
+        std::ostringstream oss;
         oss << "Thermo-> field contains unknown data, param = " << par;
         throw MvException(oss.str());
     }
@@ -539,7 +541,7 @@ void MvThermoDataUkmoNDLevels::computeLevelsTd()
     // same set of levelist. Therefore, all the data counters should have
     // the same value.
     if (pCount_ != tCount_ || pCount_ != dCount_) {
-        ostringstream oss;
+        std::ostringstream oss;
         oss << "Thermo-> UKmodel, the numbers of fields are inconsistent = " << pCount_ << " " << tCount_ << " " << dCount_;
         throw MvException(oss.str());
     }
@@ -585,5 +587,5 @@ MvThermoDataBase* MvThermoDataFactory(MvField& f, const ThermoParams& p)
     if (f.levelType() == cML_UKMO_ND)
         return new MvThermoDataUkmoNDLevels(f, p);
 
-    return 0;  //-- unimplemented data
+    return nullptr;  //-- unimplemented data
 }
