@@ -35,7 +35,7 @@ private:
     virtual bool getAppParameters(MvRequest&);
 
     // Variables
-    bool windFlag_;      // T - there is wind data
+    bool windFlag_{false};      // T - there is wind data
     std::string title_;  // title information
     ThermoParams pars_;  // parameters from the user interface
 };
