@@ -10,13 +10,10 @@
 // MvThermoParams.h - Nov2003/vk  - original file
 // ParamsThermo.h   - Jan2014/fii - updated to the new Thermo application
 
-#ifndef THERMOPARAM_H
-#define THERMOPARAM_H
+#pragma once
 
 #include <string>
 
-using namespace std;
-
 enum EPointType
 {
     eAreaAverage,
@@ -26,8 +23,8 @@ enum EPointType
 
 struct ThermoParams
 {
-    string dewPointFormulaType_;
-    string errorMsg_;
+    std::string dewPointFormulaType_;
+    std::string errorMsg_;
     int uFieldId_;
     int vFieldId_;
     int tempId_;
@@ -39,5 +36,3 @@ struct ThermoParams
     double lon2_;
     EPointType pointType_;
 };
-
-#endif
