@@ -47,7 +47,7 @@ void Thermo::serve(MvRequest& in, MvRequest& out)
         ncFileName_ = marstmp();
 
         // Process data
-        if (!this->processData())
+        if (!processData())
             return;
 
         // Build the output request
