@@ -39,6 +39,9 @@ enum
 class Thermo : public MvService
 {
 public:
+    Thermo(const char*);
+    virtual ~Thermo() {}
+
     // Entry point routine
     void serve(MvRequest&, MvRequest&);
 
@@ -73,8 +76,6 @@ public:
     MvRequest buildMacroConverterRequest();
 
 protected:
-    Thermo(const char*);
-
     // Get application specific parameters
     virtual bool getAppParameters(MvRequest&) = 0;
 
@@ -91,4 +92,5 @@ protected:
     int procType_;            // processing type, e.g.,THERMO_DATA_MODULE,...
     MvRequest dataRequest_;   // data request
     MvRequest origReq_;       // input request
+    std::string moduleLabel_;
 };
