@@ -12,16 +12,16 @@
 #include "MvDate.h"
 #include "Tokenizer.h"
 
+#include <algorithm>
+#include <fstream>
 #include <iostream>
 #include <stdexcept>
-#include <algorithm>
+#include "fstream_mars_fix.h"
 
 #include <unistd.h>
 
+#include "MvMiscellaneous.h"
 
-#include "MvMiscelaneous.h"
-
-using namespace std;
 
 #define VAPOR_CHK(str) \
     if (!(str))        \
@@ -31,35 +31,35 @@ class Base : public MvService
 {
 protected:
     Base(const char* a) :
-        MvService(a){};
+        MvService(a) {}
 };
 
 class VaporPrep : public Base
 {
 public:
     VaporPrep() :
-        Base("VAPOR_PREPARE"){};
+        Base("VAPOR_PREPARE") {}
     void serve(MvRequest&, MvRequest&);
 
 protected:
-    bool getDate(const string& dd, string& res, const string& parName);
-    bool getParamValue(string& resVal, MvRequest& in, const string& parMv, bool canBeEmpty = false);
-    bool checkGeometry(const string& areaStr, const string& gridStr);
+    bool getDate(const std::string& dd, std::string& res, const std::string& parName);
+    bool getParamValue(std::string& resVal, MvRequest& in, const std::string& parMv, bool canBeEmpty = false);
+    bool checkGeometry(const std::string& areaStr, const std::string& gridStr);
     bool vdfExists(MvRequest&, bool&);
-    bool getInputFiles(std::vector<string>& resVal, MvRequest& in, const string& parMv);
+    bool getInputFiles(std::vector<std::string>& resVal, MvRequest& in, const std::string& parMv);
     void vapor_visualise(MvRequest&, MvRequest&);
     void vapor_execute(MvRequest&, MvRequest&);
 };
 
 
-bool VaporPrep::getInputFiles(std::vector<string>& resVal, MvRequest& in, const string& parMv)
+bool VaporPrep::getInputFiles(std::vector<std::string>& resVal, MvRequest& in, const std::string& parMv)
 {
     MvRequest r = in(parMv.c_str());
 
     do {
         MvRequest rs = r.justOneRequest();
         if (const char* c = rs("PATH")) {
-            resVal.push_back(string(c));
+            resVal.push_back(std::string(c));
         }
 
     } while (r.advance());
@@ -72,18 +72,18 @@ bool VaporPrep::getInputFiles(std::vector<string>& resVal, MvRequest& in, const
     return retVal;
 }
 
-bool VaporPrep::getDate(const string& dd, string& res, const string& parName)
+bool VaporPrep::getDate(const std::string& dd, std::string& res, const std::string& parName)
 {
     res = dd;
 
     if (dd.size() < 8) {
-        istringstream iss(dd);
+        std::istringstream iss(dd);
         double d;
         iss >> d;
         char buf[9];
         MvDate md(mars_julian_to_date(today() + d, 1));
         md.Format("yyyymmdd", buf);
-        res = string(buf);
+        res = std::string(buf);
     }
 
     bool retVal = (res.size() == 8) ? true : false;
@@ -94,23 +94,23 @@ bool VaporPrep::getDate(const string& dd, string& res, const string& parName)
     return retVal;
 }
 
-bool VaporPrep::getParamValue(string& resVal, MvRequest& in, const string& parMv, bool canBeEmpty)
+bool VaporPrep::getParamValue(std::string& resVal, MvRequest& in, const std::string& parMv, bool canBeEmpty)
 {
     int cnt = in.countValues(parMv.c_str());
 
     if (cnt == 1) {
         const char* cval = in(parMv.c_str());
         if (cval)
-            resVal = string(cval);
+            resVal = std::string(cval);
     }
     else {
-        vector<string> vals;
+        std::vector<std::string> vals;
         int toIndex = -1;
         int byIndex = -1;
         for (int i = 0; i < cnt; i++) {
             const char* cval = in(parMv.c_str(), i);
             if (cval) {
-                vals.push_back(string(cval));
+                vals.push_back(std::string(cval));
                 if (strcmp(cval, "TO") == 0)
                     toIndex = static_cast<int>(vals.size()) - 1;
                 else if (strcmp(cval, "BY") == 0)
@@ -125,15 +125,15 @@ bool VaporPrep::getParamValue(string& resVal, MvRequest& in, const string& parMv
         }
         if (toIndex == 1 && byIndex == 3 && static_cast<int>(vals.size()) == 5) {
             int fromValue;
-            istringstream issF(vals[0]);
+            std::istringstream issF(vals[0]);
             issF >> fromValue;
 
             int toValue;
-            istringstream issT(vals[2]);
+            std::istringstream issT(vals[2]);
             issT >> toValue;
 
             int byValue;
-            istringstream issB(vals[4]);
+            std::istringstream issB(vals[4]);
             issB >> byValue;
 
             if (fromValue >= 0 && fromValue < 500 &&
@@ -145,7 +145,7 @@ bool VaporPrep::getParamValue(string& resVal, MvRequest& in, const string& parMv
                 resVal           = vals[0];
                 currentValue += byValue;
                 while (currentValue <= toValue) {
-                    stringstream sst;
+                    std::stringstream sst;
                     sst << currentValue;
                     resVal.append("/" + sst.str());
                     currentValue += byValue;
@@ -166,7 +166,7 @@ bool VaporPrep::getParamValue(string& resVal, MvRequest& in, const string& parMv
 
     /*if(isDate)
 	{
-		string s;
+		std::string s;
 		if(getDate(resVal,s,parMv))
 		{
 			  resVal=s;
@@ -193,30 +193,30 @@ bool VaporPrep::getParamValue(string& resVal, MvRequest& in, const string& parMv
     return false;
 }
 
-bool VaporPrep::checkGeometry(const string& areaStr, const string& gridStr)
+bool VaporPrep::checkGeometry(const std::string& areaStr, const std::string& gridStr)
 {
-    vector<string> vArea;
+    std::vector<std::string> vArea;
     Tokenizer parseA("/");
     parseA(areaStr, vArea);
 
-    vector<string> vGrid;
+    std::vector<std::string> vGrid;
     Tokenizer parseG("/");
     parseG(gridStr, vGrid);
 
     if (vArea.size() != 4 || vGrid.size() != 2)
         return false;
 
-    vector<float> area;
+    std::vector<float> area;
     for (unsigned int i = 0; i < 4; i++) {
-        istringstream iss(vArea[i]);
+        std::istringstream iss(vArea[i]);
         float d;
         iss >> d;
         area.push_back(d);
     }
 
-    vector<float> grid;
+    std::vector<float> grid;
     for (unsigned int i = 0; i < 2; i++) {
-        istringstream iss(vGrid[i]);
+        std::istringstream iss(vGrid[i]);
         float d;
         iss >> d;
         if (d <= 0.)
@@ -244,21 +244,21 @@ bool VaporPrep::checkGeometry(const string& areaStr, const string& gridStr)
 
 bool VaporPrep::vdfExists(MvRequest& in, bool& err)
 {
-    string errTxt;
+    std::string errTxt;
     err = false;
 
     //Add outpath
-    string outPath;
+    std::string outPath;
     if (!in.getPath("VAPOR_OUTPUT_PATH", outPath, true)) {
         setError(0, "VaporPrepare-> parameter VAPOR_OUTPUT_PATH not defined");
         err = true;
         return false;
     }
 
-    string vdfName;
+    std::string vdfName;
     getParamValue(vdfName, in, "VAPOR_VDF_NAME");
 
-    string vdfFile = outPath + "/" + vdfName + ".vdf";
+    std::string vdfFile = outPath + "/" + vdfName + ".vdf";
 
     if (::access(vdfFile.c_str(), F_OK) != 0) {
         return false;
@@ -270,40 +270,40 @@ bool VaporPrep::vdfExists(MvRequest& in, bool& err)
 
 void VaporPrep::vapor_visualise(MvRequest& in, MvRequest& /*out*/)
 {
-    string vaporScript;
+    std::string vaporScript;
     char* mvbin = getenv("METVIEW_BIN");
-    if (mvbin == 0) {
+    if (mvbin == nullptr) {
         setError(1, "VaporPrepare-> No METVIEW_BIN env variable is defined. Cannot locate mv_vapor_gui.mv macro!");
         return;
     }
     else {
-        vaporScript = string(mvbin) + "/mv_vapor_gui";
+        vaporScript = std::string(mvbin) + "/mv_vapor_gui";
     }
 
-    string errTxt;
+    std::string errTxt;
 
     //Add outpath
-    string outPath;
+    std::string outPath;
     if (!in.getPath("VAPOR_OUTPUT_PATH", outPath, true)) {
         setError(1, "VaporPrepare-> parameter VAPOR_OUTPUT_PATH not defined");
         return;
     }
 
     //Add vdf filename
-    string vdfName;
+    std::string vdfName;
     VAPOR_CHK(getParamValue(vdfName, in, "VAPOR_VDF_NAME"));
 
-    string logFile(marstmp());
-    string vdfFile = outPath + "/" + vdfName + ".vdf";
-    string cmd     = vaporScript + " \"" + vdfFile + "\" \"" + logFile + "\"";
+    std::string logFile(marstmp());
+    std::string vdfFile = outPath + "/" + vdfName + ".vdf";
+    std::string cmd     = vaporScript + " \"" + vdfFile + "\" \"" + logFile + "\"";
 
     int ret = system(cmd.c_str());
 
     //If the script failed read log file and
     //write it into LOG_EROR
     if (ret == -1 || WEXITSTATUS(ret) != 0) {
-        ifstream in(logFile.c_str());
-        string line;
+        std::ifstream in(logFile.c_str());
+        std::string line;
 
         if (WEXITSTATUS(ret) == 1) {
             marslog(LOG_EROR, "Failed to startup VAPOR!");
@@ -328,21 +328,21 @@ void VaporPrep::vapor_visualise(MvRequest& in, MvRequest& /*out*/)
 
 void VaporPrep::vapor_execute(MvRequest& in, MvRequest& out)
 {
-    string vaporMacro;
+    std::string vaporMacro;
     char* mvbin = getenv("METVIEW_BIN");
-    if (mvbin == 0) {
+    if (mvbin == nullptr) {
         setError(1, "VaporPrepare-> No METVIEW_BIN env variable is defined. Cannot locate mv_vapor_prep.mv macro!");
         return;
     }
     else {
-        vaporMacro = string(mvbin) + "/mv_vapor_prep.mv";
+        vaporMacro = std::string(mvbin) + "/mv_vapor_prep.mv";
     }
 
-    vector<string> param;
-    string str, errTxt;
+    std::vector<std::string> param;
+    std::string str, errTxt;
 
     //Add outpath
-    string outPath;
+    std::string outPath;
     if (!in.getPath("VAPOR_OUTPUT_PATH", outPath, true)) {
         setError(1, "VaporPrepare-> parameter VAPOR_OUTPUT_PATH not defined");
         return;
@@ -350,7 +350,7 @@ void VaporPrep::vapor_execute(MvRequest& in, MvRequest& out)
     param.push_back(outPath);
 
     //Add vdf filename
-    string vdfName;
+    std::string vdfName;
     VAPOR_CHK(getParamValue(vdfName, in, "VAPOR_VDF_NAME"));
     param.push_back(vdfName);
 
@@ -361,49 +361,49 @@ void VaporPrep::vapor_execute(MvRequest& in, MvRequest& out)
     //==============================
 
     //Add reuse(check) input status
-    string reuseVdf;
+    std::string reuseVdf;
     VAPOR_CHK(getParamValue(str, in, "VAPOR_REUSE_VDF"));
     param.push_back((str == "ON") ? "1" : "0");
 
 
     //Add refinement level
-    string refLevel;
+    std::string refLevel;
     VAPOR_CHK(getParamValue(refLevel, in, "VAPOR_REFINEMENT_LEVEL"));
     param.push_back(refLevel);
 
     //Add vertical grid type
-    string vGrid;
+    std::string vGrid;
     VAPOR_CHK(getParamValue(vGrid, in, "VAPOR_VERTICAL_GRID_TYPE"));
     param.push_back(vGrid);
 
     if (vGrid == "LAYERED") {
-        string hVar;
+        std::string hVar;
         VAPOR_CHK(getParamValue(hVar, in, "VAPOR_ELEVATION_PARAM"));
         param.push_back(hVar);
 
         //Add min-max vertical coordinate
-        string vMin;
+        std::string vMin;
         VAPOR_CHK(getParamValue(vMin, in, "VAPOR_BOTTOM_COORDINATE"));
         param.push_back(vMin);
 
-        string vMax;
+        std::string vMax;
         VAPOR_CHK(getParamValue(vMax, in, "VAPOR_TOP_COORDINATE"));
         param.push_back(vMax);
     }
 
     //Add are selection
-    string areaSelect;
+    std::string areaSelect;
     VAPOR_CHK(getParamValue(areaSelect, in, "VAPOR_AREA_SELECTION"));
     param.push_back((areaSelect == "INTERPOLATE") ? "1" : "0");
 
     if (areaSelect == "INTERPOLATE") {
         //Add area
-        string area;
+        std::string area;
         VAPOR_CHK(getParamValue(area, in, "VAPOR_AREA"));
         param.push_back(area);
 
         //Add grid resolution
-        string grid;
+        std::string grid;
         VAPOR_CHK(getParamValue(grid, in, "VAPOR_GRID"));
         param.push_back(grid);
 
@@ -414,22 +414,22 @@ void VaporPrep::vapor_execute(MvRequest& in, MvRequest& out)
     }
 
     //Add steps numbers
-    string stepParams;
+    std::string stepParams;
     VAPOR_CHK(getParamValue(stepParams, in, "VAPOR_STEP_NUMBER"));
     param.push_back(stepParams);
 
     //Add surf params
-    string surfParams;
+    std::string surfParams;
     VAPOR_CHK(getParamValue(surfParams, in, "VAPOR_2D_PARAMS", true));
     param.push_back(surfParams);
 
     //Add upper params
-    string upperParams;
+    std::string upperParams;
     VAPOR_CHK(getParamValue(upperParams, in, "VAPOR_3D_PARAMS"));
     param.push_back(upperParams);
 
     //Create  tmp dir for vapor
-    string tmpPath;
+    std::string tmpPath;
     if (!metview::createWorkDir("vapor", tmpPath, errTxt)) {
         setError(1, "VaporPrepare-> %s", errTxt.c_str());
         return;
@@ -437,17 +437,17 @@ void VaporPrep::vapor_execute(MvRequest& in, MvRequest& out)
     param.push_back(tmpPath);
 
     //Add perparation mode
-    string inputMode;
+    std::string inputMode;
     VAPOR_CHK(getParamValue(inputMode, in, "VAPOR_INPUT_MODE"));
     param.push_back(inputMode);
 
     //Add input files
     if (inputMode == "ICON") {
         //Add mars expver
-        vector<string> gribFiles;
+        std::vector<std::string> gribFiles;
         VAPOR_CHK(getInputFiles(gribFiles, in, "VAPOR_INPUT_DATA"));
-        for (int i = 0; i < static_cast<int>(gribFiles.size()); i++)
-            param.push_back(gribFiles[i]);
+        for (auto& gribFile : gribFiles)
+            param.push_back(gribFile);
     }
     else {
     }
@@ -455,7 +455,7 @@ void VaporPrep::vapor_execute(MvRequest& in, MvRequest& out)
     //Build request to be sent to Macro
     MvRequest req("MACRO");
 
-    string processName = MakeProcessName("VaporPrepare");
+    std::string processName = MakeProcessName("VaporPrepare");
     MvRequest macroReq("MACRO");
     req("PATH")    = vaporMacro.c_str();
     req("_CLASS")  = "MACRO";
@@ -463,8 +463,8 @@ void VaporPrep::vapor_execute(MvRequest& in, MvRequest& out)
     req("_REPLY")  = processName.c_str();
 
     //Define argument list for the macro!
-    for (vector<string>::iterator it = param.begin(); it != param.end(); it++) {
-        req.addValue("_ARGUMENTS", (*it).c_str());
+    for (auto& it : param) {
+        req.addValue("_ARGUMENTS", it.c_str());
     }
 
     //Run macro
@@ -472,8 +472,8 @@ void VaporPrep::vapor_execute(MvRequest& in, MvRequest& out)
     //marslog(LOG_INFO,"Execute macro: %s",vaporMacro.c_str());
     MvRequest reply = MvApplication::waitService("macro", req, error);
 
-    string logFile = tmpPath + "/m_log.txt";
-    string errFile = tmpPath + "/m_err.txt";
+    std::string logFile = tmpPath + "/m_log.txt";
+    std::string errFile = tmpPath + "/m_err.txt";
     if (!error && reply) {
         marslog(LOG_INFO, "Log file is available at:");
         marslog(LOG_INFO, "---------------------------");
@@ -483,8 +483,8 @@ void VaporPrep::vapor_execute(MvRequest& in, MvRequest& out)
         //MvApplication::callService(myname,reply,0);
     }
     else {
-        ifstream in(errFile.c_str());
-        string line;
+        std::ifstream in(errFile.c_str());
+        std::string line;
         marslog(LOG_EROR, "Failed to perform VAPOR Prepare!");
         marslog(LOG_EROR, "Error message:");
         while (getline(in, line)) {
@@ -509,14 +509,14 @@ void VaporPrep::vapor_execute(MvRequest& in, MvRequest& out)
 
 void VaporPrep::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "--------------VaporPrepare::serve() in--------------" << endl;
+    std::cout << "--------------VaporPrepare::serve() in--------------" << std::endl;
     in.print();
 
     // Get user action mode
     const char* modeC = (const char*)in("_ACTION");
-    string mode       = "execute";
+    std::string mode  = "execute";
     if (modeC)
-        mode = string(modeC);
+        mode = std::string(modeC);
 
     if (mode == "visualise") {
         bool err    = false;
@@ -535,7 +535,7 @@ void VaporPrep::serve(MvRequest& in, MvRequest& out)
         vapor_execute(in, out);
     }
 
-    cout << "--------------VaporPrepare::serve() out--------------" << endl;
+    std::cout << "--------------VaporPrepare::serve() out--------------" << std::endl;
     out.print();
 }
 
