@@ -8,6 +8,9 @@
  ***************************** LICENSE END *************************************/
 
 #include "Velstr.h"
+
+#include <iostream>
+
 #include "MvFortran.h"
 
 
@@ -26,7 +29,7 @@ extern "C" void velstr_(void);
 
 void Velstr ::serve(MvRequest& in, MvRequest& out)
 {
-    cout << "\n---> Entering Velstr::serve..." << endl;
+    std::cout << "\n---> Entering Velstr::serve..." << std::endl;
     in.print();
 
     // Get data
@@ -37,8 +40,8 @@ void Velstr ::serve(MvRequest& in, MvRequest& out)
     if (!Apply(out))
         return;
 
-    cout << "<--- Done OK! Leaving Velstr::serve.\n"
-         << endl;
+    std::cout << "<--- Done OK! Leaving Velstr::serve.\n"
+              << std::endl;
     out.print();
 }
 
@@ -191,8 +194,8 @@ bool Velstr::badRetVal(int ret, const char* gribApiFunc, const char* MvFunc)
 {
     if (ret != 0) {
         sendProgress(">>> %s returned %d in %s", gribApiFunc, ret, MvFunc);
-        cerr << ">>> '" << gribApiFunc << "' returned " << ret
-             << " in '" << MvFunc << "'" << endl;
+        std::cerr << ">>> '" << gribApiFunc << "' returned " << ret
+                  << " in '" << MvFunc << "'" << std::endl;
 
         return true;
     }
