@@ -26,6 +26,7 @@
  ********************************************************************************/
 
 #include "CrossS.h"
+#include "MvException.h"
 
 #include "assert.h"
 
@@ -60,6 +61,7 @@ CrossS::CrossS(const char* kw) :
 
 void CrossS::init()
 {
+    moduleLabel_ = "CrossSection-> ";
     Xsect::init();
     windProjection_   = NoWindProjection;
     windMode_         = NoWindMode;
@@ -151,8 +153,17 @@ bool CrossS::getAppParameters(MvRequest& in, ApplicationInfo& appInfo)
     if ((const char*)in("VERTICAL_COORDINATE_PARAM"))
         appInfo.setGHBC((int)in("VERTICAL_COORDINATE_PARAM"));
 
-    if (const char* ch = in("VERTICAL_COORDINATE_EXTRAPOLATE"))
+    if (const char* ch = in("VERTICAL_COORDINATE_EXTRAPOLATE")) {
         appInfo.setGHBCExtrapolate(strcmp(ch, "ON") == 0);
+    }
+    if (appInfo.extrapolateGHBC()) {
+        if (const char* ch = in("VERTICAL_COORDINATE_EXTRAPOLATE_MODE")) {
+            appInfo.setExtrapolateGHBCMode((strcmp(ch, "CONSTANT") == 0)?ConstantExtrapolation:LinearExtrapolation);
+        }
+        if (const char* ch = in("VERTICAL_COORDINATE_EXTRAPOLATE_FIXED_SIGN")) {
+            appInfo.setExtrapolateGHBCFixedSign((strcmp(ch, "ON") == 0)?true:false);
+        }
+    }
 
     // W wind component computation mode/scaling factor
     std::string wModeStr;
@@ -179,18 +190,24 @@ bool CrossS::getAppParameters(MvRequest& in, ApplicationInfo& appInfo)
     }
 
     // Retrieve parameters related to the vertical levels definition
-    if ((const char*)in("LEVEL_SELECTION_TYPE"))
+    if ((const char*)in("LEVEL_SELECTION_TYPE")) {
+        // TODO: turn it into an enum
         appInfo.levelSelectionType((const char*)in("LEVEL_SELECTION_TYPE"));
+        if (appInfo.levelSelectionType() != "FROM_DATA" && appInfo.levelSelectionType() != "ADAPTIVE" &&
+            appInfo.levelSelectionType() != "COUNT" && appInfo.levelSelectionType() != "LEVEL_LIST") {
+            setError(1, "CrossS -> Invalid value(=%s) specified for parameter LEVEL_SELECTION_TYPE!",
+                     appInfo.levelSelectionType().c_str());
+        }
+    }
 
     if ((const char*)in("LEVEL_LIST")) {
         double val;
-        double factor = 100.;  // input values are in hPa
         int cnt       = in.iterInit("LEVEL_LIST");
         std::vector<double> lslist;
         lslist.reserve(cnt);
         for (int i = 0; i < cnt; ++i) {
             in.iterGetNextValue(val);
-            lslist.push_back(val * factor);
+            lslist.push_back(val);
         }
 
         // Make sure the values are in crescent order
@@ -209,10 +226,10 @@ bool CrossS::getAppParameters(MvRequest& in, ApplicationInfo& appInfo)
     }
 
     if ((const char*)in("BOTTOM_LEVEL"))
-        appInfo.bottomLevel((double)in("BOTTOM_LEVEL") * 100.);  //hPa
+        appInfo.bottomLevel((double)in("BOTTOM_LEVEL"));
 
     if ((const char*)in("TOP_LEVEL"))
-        appInfo.topLevel((double)in("TOP_LEVEL") * 100.);  //hPa
+        appInfo.topLevel((double)in("TOP_LEVEL"));
 
     // Retrieve orography colour
     if ((const char*)in("OROGRAPHY_COLOUR"))
@@ -377,8 +394,8 @@ bool CrossS::generateXsectData(ApplicationInfo& appInfo, ParamMap& params,
 bool CrossS::generateLNSP(ApplicationInfo& appInfo, MvNetCDF& cdf, ParamInfo* par)
 {
     // Get initial info
-    double low   = appInfo.topLevel() / 100.;
-    double high  = appInfo.bottomLevel() / 100.;
+    double low   = appInfo.tohPa(appInfo.topLevel());
+    double high  = appInfo.tohPa(appInfo.bottomLevel());
     int nrPoints = appInfo.NrPoints();
 
     // Add/update LNSP and auxiliary variables to the netCDF
@@ -454,8 +471,7 @@ bool CrossS::generateLNSP(ApplicationInfo& appInfo, MvNetCDF& cdf, ParamInfo* pa
         if (splin[i] >= XMISSING_VALUE)
             y1_values[i] = high;
         else {
-            double w = exp(splin[i]);
-            w /= 100;
+            double w = appInfo.tohPa(exp(splin[i]));
             w            = MAX(low, w);
             w            = MIN(high, w);
             y1_values[i] = w;
@@ -498,6 +514,11 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
 
     assert(windMode_ == Wind2DMode);
 
+    if (par_u->Levels().size() != par_v->Levels().size()) {
+        throw MvException(moduleLabel_ + "number of levels for u and v must be the same! " +
+                          std::to_string(par_u->Levels().size()) + " != " +  std::to_string(par_v->Levels().size()));
+    }
+
     // Wind speed
     if (outputMode_ == ScalarOutput) {
         assert(useWindIntensity_ || windProjection_ != NoWindProjection);
@@ -592,8 +613,13 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
 
         // Write level values to the netCDF
         nclevels->setCurrent(ntime_);
-        for (int j = 0; j < nrLevels; j++)
-            y_values[j] /= 100.;
+
+        //Pa -> hPa
+        if (appInfo.levelType() == XS_PL || appInfo.levelType() == XS_ML_LNSP) {
+            for (int j = 0; j < nrLevels; j++) {
+                y_values[j] = appInfo.tohPa(y_values[j]);
+            }
+        }
 
         nclevels->put(y_values, 1, (long)y_values.size());
 
@@ -700,8 +726,13 @@ bool CrossS::wind2DValues(ApplicationInfo& appInfo, ParamMap& params, MvNetCDF&
 
         // Write level values to the netCDF
         nclevels->setCurrent(ntime_);
-        for (int j = 0; j < nrLevels; j++)
-            y_values[j] /= 100.;
+
+        //Pa -> hPa
+        if (appInfo.levelType() == XS_PL || appInfo.levelType() == XS_ML_LNSP) {
+            for (int j = 0; j < nrLevels; j++) {
+                y_values[j] = appInfo.tohPa(y_values[j]);
+            }
+        }
 
         nclevels->put(y_values, 1, (long)y_values.size());
 
@@ -795,6 +826,16 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
     if (!par_v)
         return false;
 
+    if (par_u->Levels().size() != par_v->Levels().size()) {
+        throw MvException(moduleLabel_ + "number of levels for u and v must be the same! " +
+                          std::to_string(par_u->Levels().size()) + " != " +  std::to_string(par_v->Levels().size()));
+    }
+
+    if (par_u->Levels().size() != par_w->Levels().size()) {
+        throw MvException(moduleLabel_ + "number of levels for u and w must be the same! " +
+                          std::to_string(par_u->Levels().size()) + " != " +  std::to_string(par_w->Levels().size()));
+    }
+
     // Create a structure for the result/horizontal component
     ParamInfo par_uv(par_v->Parameter(), par_v->Date(), par_v->Time(), par_v->Step(),
                      par_v->ParamName(), par_v->ParamLongName(), par_v->Units(),
@@ -930,8 +971,13 @@ bool CrossS::wind3DValues(ApplicationInfo& appInfo, ParamMap& params,
 
     // Write level values to the netCDF
     nclevels->setCurrent(ntime_);
-    for (int j = 0; j < nrLevels; j++)
-        y_values[j] /= 100.;
+
+    //Pa -> hPa
+    if (appInfo.levelType() == XS_PL || appInfo.levelType() == XS_ML_LNSP) {
+        for (int j = 0; j < nrLevels; j++) {
+            y_values[j] = appInfo.tohPa(y_values[j]);
+        }
+    }
 
     nclevels->put(y_values, 1, (long)y_values.size());
 
@@ -1159,6 +1205,8 @@ void CrossS::computeWind2D(ApplicationInfo& appInfo, ParamInfo& par_uv, ParamInf
     auto uu = lmap_u.begin(), vv = lmap_v.begin();
     double *uValues, *vValues;
 
+    assert(lmap_u.size() == lmap_v.size());
+
     int nrPoints   = appInfo.NrPoints();
     auto* valuesuv = new double[nrPoints];
     double ansin   = appInfo.Ansin();
@@ -1193,8 +1241,7 @@ void CrossS::computeWind2D(ApplicationInfo& appInfo, ParamInfo& par_uv, ParamInf
             }
         }
 
-        bool modlev = appInfo.levelTypeFlag();
-        par_uv.Level(valuesuv, (*uu).first, nrPoints, modlev);
+        par_uv.Level(valuesuv, (*uu).first, nrPoints, appInfo.levelType() == XS_PL);
     }
 
     delete[] valuesuv;
@@ -1211,6 +1258,9 @@ void CrossS::computeWind3D(ApplicationInfo& appInfo, ParamInfo& par_uv, ParamInf
     auto vv         = lmap_v.begin();
     auto ww         = lmap_w.begin();
 
+    assert(lmap_u.size() == lmap_v.size());
+    assert(lmap_u.size() == lmap_w.size());
+
     double *uValues = nullptr, *vValues = nullptr, *wValues = nullptr;
 
     int nrPoints   = appInfo.NrPoints();
@@ -1254,9 +1304,7 @@ void CrossS::computeWind3D(ApplicationInfo& appInfo, ParamInfo& par_uv, ParamInf
                 }
             }
         }
-
-        bool modlev = appInfo.levelTypeFlag();
-        par_uv.Level(valuesuv, (*uu).first, nrPoints, modlev);
+        par_uv.Level(valuesuv, (*uu).first, nrPoints, appInfo.levelType() == XS_PL);
     }
 
     delete[] valuesuv;
