@@ -15,6 +15,9 @@
 #include "MvException.h"
 
 #include <assert.h>
+#include <algorithm>
+#include <cmath>
+#include <numeric>
 
 // convienience method, (vk/1999-08-05)
 // checks if x is between r1 and r2
@@ -56,14 +59,17 @@ std::string ParamInfo::ExpVerTitle()
 
 // Fill in data into a level in the LevelMap. Generate the level if needed,
 // and delete any old values from the level.
-void ParamInfo::Level(double* x, std::string lev, int n, bool modlev)
+void ParamInfo::Level(double* x, std::string lev, int n, bool scaleToPa)
 {
     double flev = atof(lev.c_str());
+    if (scaleToPa) {
+        flev = ApplicationInfo::toPa(flev);
+    }
 
     // Save data for one level
     auto ii = levels_.find(lev);
     if (ii == levels_.end()) {
-        levels_[lev] = new LevelInfo(flev, modlev);
+        levels_[lev] = new LevelInfo(flev);
         ii           = levels_.find(lev);
     }
     else {
@@ -71,8 +77,9 @@ void ParamInfo::Level(double* x, std::string lev, int n, bool modlev)
             delete[](*ii).second->xvalues_;
             (*ii).second->xvalues_ = 0;
         }
+        //TODO: check if it is needed to multiply by 100
         if ((*ii).second->yvalue_ >= XMISSING_VALUE)
-            (*ii).second->yvalue_ = modlev ? flev : flev * 100;
+            (*ii).second->yvalue_ = flev;
     }
 
     if ((*ii).second->xvalues_ == 0)
@@ -83,12 +90,12 @@ void ParamInfo::Level(double* x, std::string lev, int n, bool modlev)
         xx[i] = x[i];
 }
 
-void ParamInfo::UpdateLevels(bool modlev)
+void ParamInfo::UpdateLevels(bool scaleToPa)
 {
     LevelIterator ii;
     for (ii = levels_.begin(); ii != levels_.end(); ii++) {
         double flev = atof((*ii).first.c_str());
-        (*ii).second->UpdateLevel(flev, modlev);
+        (*ii).second->UpdateLevel((scaleToPa)?ApplicationInfo::toPa(flev):flev);
     }
 }
 
@@ -120,9 +127,215 @@ double* ParamInfo::getOneLevelValues(const std::string& clev)
     return (*ll).second->XValues();
 }
 
-/////////////////// ApplicationInfo /////////////////////
+//=====================================================
+//
+// TargetLevelItem
+//
+//=====================================================
+
+class TargetLevelItem
+{
+    friend class TargetLevelMaker;
+public:
+    TargetLevelItem()=default;
+    void addValue(double val) {vals_.push_back(val);}
+    void compute();
+    bool isEmpty() const {return vals_.size() == 0;}
+
+private:
+    std::vector<double> vals_;
+    double min_{std::numeric_limits<double>::max()};
+    double max_{std::numeric_limits<double>::min()};
+    double mean_{0.};
+    double stdev_{0.};
+};
+
+void TargetLevelItem::compute()
+{
+    if (vals_.size() >0) {
+        min_ = *std::min_element(vals_.begin(),vals_.end());
+        max_ = *std::max_element(vals_.begin(),vals_.end());
+        mean_ = std::accumulate(vals_.begin(), vals_.end(), 0.0) / vals_.size();
+        std::for_each (vals_.begin(), vals_.end(), [this](const double d) {
+            stdev_ += std::pow(d - mean_, 2);
+        });
+        stdev_ = std::sqrt(stdev_ / vals_.size());
+    }
+}
+
+//=====================================================
+//
+// TargetLevelMaker
+//
+//=====================================================
+
+class TargetLevelMaker
+{
+public:
+    TargetLevelMaker(int levelNum) : levels_(levelNum) {}
+    void add(double v, int level);
+    void addDeltaFromMinMax(std::vector<double>& vals) const;
+    void getMeans(std::vector<double>&);
+    void getAdaptive(std::vector<double>&);
+    double minVal() const {return minVal_;}
+    double maxVal() const {return maxVal_;}
+
+private:
+    void compute();
+    void addTargetVal(std::vector<double> &res, double startVal, double endVal, int num) const;
+
+    bool computed_{false};
+    std::vector<TargetLevelItem> levels_;
+    double minVal_{std::numeric_limits<double>::max()};
+    double maxVal_{std::numeric_limits<double>::min()};
+};
+
+void TargetLevelMaker::add(double v, int levelIdx)
+{
+    assert(!computed_);
+    levels_[levelIdx].addValue(v);
+    if (v > maxVal_) {
+        maxVal_ = v;
+    }
+    if (v < minVal_) {
+        minVal_ = v;
+    }
+}
+
+void TargetLevelMaker::addTargetVal(std::vector<double> &res, double startVal, double endVal, int num) const
+{
+    double incr = (endVal - startVal)/(num+1);
+    for(int i=0; i < num; i++) {
+        res.push_back(startVal+i*incr);
+    }
+}
+
+void TargetLevelMaker::addDeltaFromMinMax(std::vector<double>& vals) const
+{
+    if (!vals.empty()) {
+        double deltaFirst = fabs(vals[0] - vals[1]);
+        double deltaLast  = fabs(vals[vals.size() - 1] - vals[vals.size() - 2]);
+        if (vals[0] < vals[1]) {
+            vals.insert(vals.begin(), minVal_ - deltaFirst);
+            vals.push_back(maxVal_ + deltaLast);
+        }
+        else {
+            vals.insert(vals.begin(), maxVal_ + deltaFirst);
+            vals.push_back(minVal_ - deltaLast);
+        }
+    }
+}
+
+void TargetLevelMaker::compute()
+{
+    if (!computed_) {
+        for (auto &v: levels_) {
+            v.compute();
+        }
+        levels_.erase(std::remove_if(levels_.begin(), levels_.end(),
+                               [](auto v) { return v.isEmpty(); }), levels_.end());
+        computed_ = true;
+    }
+}
+
+void TargetLevelMaker::getMeans(std::vector<double>& res)
+{
+    compute();
+    for (auto &v: levels_) {
+        assert(!v.isEmpty());
+        res.push_back(v.mean_);
+    }
+}
+
+void TargetLevelMaker::getAdaptive(std::vector<double>& res)
+{
+    compute();
+
+# if 0
+    int i=0;
+    for (auto &v: levels_) {
+        double delta = (i==0)?0:(v.mean_-levels_[i-1].mean_);
+        std::cout <<  v.vals_.size() << " " << v.mean_ << " " << v.min_ << " " << v.max_ <<
+                      " " << v.max_ - v.min_ << " " << v.stdev_ << " "
+                   << std::fabs(delta) << std::endl;
+        i++;
+    }
+#endif
+
+    // check if the level mean is representative, i.e. the spread is narrow enough (0,1)
+    std::vector<int> levRep;
+    for (std::size_t i=0; i < levels_.size(); i++) {
+        assert(!levels_[i].isEmpty());
+        double delta = (i == 0)?std::fabs(levels_[i].mean_ - levels_[i+1].mean_):
+            std::fabs(levels_[i].mean_ - levels_[i-1].mean_);
+        levRep.push_back(levels_[i].stdev_< delta);
+    }
+
+    bool ascending = levels_.front().mean_ < levels_.back().mean_;
+
+    // find levels with large spread at the front
+    int frontIdx = -1;
+    int backIdx = -1;
+    for (std::size_t i=0; i < levels_.size(); i++) {
+        if (levRep[i] == 1) {
+            if (i>0) {
+                frontIdx = i;
+            }
+            break;
+        }
+    }
+
+    // find levels with large spread at the back
+    for (std::size_t i=levels_.size()-1; i >= 0; i--) {
+        if (levRep[i] == 1) {
+            if (i < levels_.size()-1) {
+                backIdx = i;
+            }
+            break;
+        }
+    }
+
+    // construct result
+    res.clear();
+
+    // intervals via the whole range
+    if (frontIdx == -1 && backIdx == -1) {
+        double startVal = (ascending)?levels_.front().min_:levels_.back().min_;
+        double endVal = (ascending)?levels_.back().max_:levels_.front().max_;
+        int num = std::max(static_cast<int>(levels_.size())+5, 10);
+        addTargetVal(res, startVal, endVal, num);
+    } else {
+        // intervals at front
+        if (frontIdx != -1) {
+            double startVal = (ascending)?levels_.front().min_:levels_.front().max_;
+            double endVal = levels_[frontIdx-1].mean_;
+            int num = std::max(static_cast<int>(frontIdx+2), 10);
+            addTargetVal(res, startVal, endVal, num);
+        }
+
+        // means in the middle
+        std::size_t midStart = (frontIdx>-1)?frontIdx:0;
+        std::size_t midEnd = (backIdx>-1)?backIdx:levels_.size()-1;
+        for (std::size_t i=midStart; i <= midEnd; i++) {
+            res.push_back(levels_[i].mean_);
+        }
+
+        // intervals at back
+        if (backIdx != -1) {
+            double startVal = levels_[backIdx+1].mean_;
+            double endVal = (ascending)?levels_.back().max_:levels_.back().min_;
+            int num = std::max(static_cast<int>(levels_.size()-backIdx+2), 10);
+            addTargetVal(res, startVal, endVal, num);
+        }
+    }
+}
+
+//=====================================================
+//
+// ApplicationInfo
+//
+//=====================================================
 
-// Constructor
 ApplicationInfo::ApplicationInfo() :
     x1_(0),
     x2_(0),
@@ -150,8 +363,27 @@ ApplicationInfo::ApplicationInfo() :
 {
 }
 
-int ApplicationInfo::levelType(bool isML, bool isPL)
+void ApplicationInfo::determineLevelType(bool isML, bool isPL)
 {
+    // isML and isPL are both true if a fieldset contains LNSP and PL data. This is the
+    // case when LNSP is supplied for to orography curve! In this case, treat it as PL with LNSP!
+    if (haveGHBC()) {
+        if (isML && !isPL) {
+            levType_ = XS_ML_GHBC;
+        } else {
+            levType_ = XS_GHBC;
+        }
+    } else if (this->haveLNSP() && isML && !isPL) {
+        levType_ = XS_ML_LNSP;
+    } else if (isML && !isPL) {
+        levType_ = XS_ML;
+    } else if (isPL && (!isML || this->haveLNSP())) {
+        levType_ = XS_PL;
+    } else  {
+        levType_ = XS_ASIS;
+    }
+
+#if 0
     // isML and isPL are both true if a fieldset contains LNSP and PL data.
     // In this case, treat as PL with LNSP.
     if ((this->haveLNSP() || this->haveGHBC()) && !isPL) {
@@ -165,11 +397,20 @@ int ApplicationInfo::levelType(bool isML, bool isPL)
     else {
         if (isML && !isPL)
             levType_ = XS_ML;
-        else  // it must be PL
+        else if (isPL)
             levType_ = XS_PL;
     }
-
-    return levType_;
+#endif
+    // When the target vertical coordinate system is pressure we need to scale the input
+    // parameters (e.g. topLevel_) from hPa to Pa
+    if (levType_ == XS_ML_LNSP || levType_ == XS_PL) {
+        double factor = 100.;
+        topLevel_ *= factor;
+        bottomLevel_ *= factor;
+        for (std::size_t i=0; i < uiLSList_.size(); i++) {
+            uiLSList_[i] *= factor;
+        }
+    }
 }
 
 // Check the level type info and update the levels accordingly
@@ -177,12 +418,12 @@ int ApplicationInfo::levelType(bool isML, bool isPL)
 void ApplicationInfo::updateLevels(ParamMap& params)
 {
     // Get level type flag
-    bool modlev = this->levelTypeFlag();
+    bool needScaleToPa = (levType_ == XS_PL);
 
     // Update the levels
     ParamIterator ii;
     for (ii = params.begin(); ii != params.end(); ii++)
-        (*ii).second->UpdateLevels(modlev);
+        (*ii).second->UpdateLevels(needScaleToPa);
 
     return;
 }
@@ -369,6 +610,7 @@ void ApplicationInfo::InterpolateVerticala(std::vector<double>& cp, ParamInfo* p
         pk = yvals[k];
 
         if (findPressure(param->Levels(), pk, firstlev, nextlev)) {
+            // TODO: clarify the reason of this check
             if (levType_)
                 lpa = (pk - firstlev->YValue()) / (nextlev->YValue() - firstlev->YValue());
             else
@@ -381,10 +623,11 @@ void ApplicationInfo::InterpolateVerticala(std::vector<double>& cp, ParamInfo* p
             double* xnext = nextlev->XValues();
 
             for (i = 0; i < nrPoints_; i++) {
-                if (xvals[i] < XMISSING_VALUE && xnext[i] < XMISSING_VALUE)
+                if (xvals[i] < XMISSING_VALUE && xnext[i] < XMISSING_VALUE) {
                     cp.push_back(xvals[i] + (xnext[i] - xvals[i]) * lpa);  //replace k with kmodel
-                else
+                } else {
                     cp.push_back(XMISSING_VALUE);  // replace k with kmodel
+                }
             }
         }
         else
@@ -456,7 +699,7 @@ void ApplicationInfo::InterpolateVerticalb(MvField& field, std::vector<double>&
 }
 
 // Generate data values.
-// Only ever called if levType_ == XS_ML_GHBC
+// Only ever called if levType_ == XS_ML_GHBC || XS_GHBC
 void ApplicationInfo::InterpolateVerticalGHBC(std::vector<double>& cp, ParamInfo* param, ParamInfo* paramGHBC, std::vector<double>& yvals)
 {
     if (!interpolate_) {
@@ -472,32 +715,55 @@ void ApplicationInfo::InterpolateVerticalGHBC(std::vector<double>& cp, ParamInfo
     cp.clear();
     cp.reserve(nrLevels * nrPoints_);
     assert(nrLevels >= 2);
+#if 0
+    bool doLog = false;
+#endif
 
     //loop for the target levels
     for (int k = 0; k < nrLevels; k++) {
         double level = yvals[k];  // target vertical coordinate level
-
+#if 0
+        doLog = (level < 600);
+        if (doLog) std::cout << level << std::endl;
+#endif
         //loop for the xs line points
         for (int i = 0; i < nrPoints_; i++) {
+#if 0
+            if (doLog) std::cout << " (" << i << ")" << std::endl;
+#endif
+            bool needExtrapolation = false;
             //find the bounding input vc levels for the target level
             if (findModelPressureGHBC(param->Levels(), paramGHBC->Levels(), level, i,
-                                      parLev1, parLev2, vcVal1, vcVal2)) {
-                if (parLev1->XValues()[i] < XMISSING_VALUE &&
-                    parLev2->XValues()[i] < XMISSING_VALUE) {
-                    lpa = (level - vcVal1) / (vcVal2 - vcVal1);
-                    cp.push_back(parLev1->XValues()[i] + (parLev2->XValues()[i] - parLev1->XValues()[i]) * lpa);
+                                      parLev1, parLev2, vcVal1, vcVal2, needExtrapolation)) {
+#if 0
+                if (doLog && needExtrapolation) {
+                    std::cout << "   " <<  parLev1->XValues()[i] << " " << parLev2->XValues()[i] << " " << vcVal1 << " " << vcVal2 << std::endl;
                 }
-                else {
+#endif
+                if (parLev1->XValues()[i] < XMISSING_VALUE && parLev2->XValues()[i] < XMISSING_VALUE) {
+                    lpa = (level - vcVal1) / (vcVal2 - vcVal1);
+                    double rv =parLev1->XValues()[i] + (parLev2->XValues()[i] - parLev1->XValues()[i]) * lpa;
+                    if (needExtrapolation && extrapolateGHBCMode_ == LinearExtrapolation && extrapolateGHBCFixedSign_) {
+                        assert(extrapolateGHBCMode_ == LinearExtrapolation);
+                        if (parLev1->XValues()[i]*rv <= 0) {
+                            rv = 0.;
+                        }
+                    }
+                    cp.push_back(rv);
+                } else {
                     cp.push_back(XMISSING_VALUE);
                 }
-            }
-            else {
+            } else {
+#if 0
+                if (doLog) {
+                    std::cout << "   not found " <<  std::endl;
+                }
+#endif
                 cp.push_back(XMISSING_VALUE);
             }
         }
     }
 
-    return;
 }
 
 bool ApplicationInfo::findPressure(LevelMap& lmap, double value, LevelInfo*& l1, LevelInfo*& l2)
@@ -563,7 +829,7 @@ bool ApplicationInfo::findModelPressure(LevelMap& lmap, double value, double spl
 bool ApplicationInfo::findModelPressureGHBC(LevelMap& parLevels, LevelMap& vcLevels,
                                             double level, int xsPointIdx,
                                             LevelInfo*& parLev1, LevelInfo*& parLev2,
-                                            double& vcVal1, double& vcVal2)
+                                            double& vcVal1, double& vcVal2, bool &needExtrapolation)
 {
     auto itParLev = parLevels.begin();
     auto itVcLev  = vcLevels.begin();
@@ -578,21 +844,35 @@ bool ApplicationInfo::findModelPressureGHBC(LevelMap& parLevels, LevelMap& vcLev
     vcVal2           = actVcLev2->XValues()[xsPointIdx];
     bool vcAscending = vcVal1 < vcVal2;
 
+    needExtrapolation = false;
+
     //this will allow extrapolation at top/bottom
     if (extrapolateGHBC_) {
         if (!vcAscending) {
             assert(vcVal2 < vcVal1);
             if (level > vcVal1) {
-                parLev1 = actParLev1;
-                parLev2 = actParLev2;
+                needExtrapolation = true;
+                if (extrapolateGHBCMode_ == ConstantExtrapolation) {
+                    parLev1 = actParLev1;
+                    parLev2 = parLev1;
+                } else {
+                    parLev1 = actParLev1;
+                    parLev2 = actParLev2;
+                }
                 return true;
             }
         }
         else {
             assert(vcVal1 < vcVal2);
             if (level < vcVal1) {
-                parLev1 = actParLev1;
-                parLev2 = actParLev2;
+                needExtrapolation = true;
+                if (extrapolateGHBCMode_ == ConstantExtrapolation) {
+                    parLev1 = actParLev1;
+                    parLev2 = parLev1;
+                } else {
+                    parLev1 = actParLev1;
+                    parLev2 = actParLev2;
+                }
                 return true;
             }
         }
@@ -620,18 +900,30 @@ bool ApplicationInfo::findModelPressureGHBC(LevelMap& parLevels, LevelMap& vcLev
     //this will allow extrapolation at top/bottom
     if (extrapolateGHBC_) {
         if (!vcAscending) {
-            assert(vcVal2 < vcVal1);
+            assert(vcVal2 < vcVal1);           
             if (level < vcVal2) {
-                parLev1 = actParLev1;
-                parLev2 = actParLev2;
+                needExtrapolation = true;
+                if (extrapolateGHBCMode_ == ConstantExtrapolation) {
+                    parLev2 = actParLev2;
+                    parLev1 = parLev2;
+                } else {
+                    parLev1 = actParLev1;
+                    parLev2 = actParLev2;
+                }
                 return true;
             }
         }
         else {
             assert(vcVal1 < vcVal2);
             if (level > vcVal2) {
-                parLev1 = actParLev1;
-                parLev2 = actParLev2;
+                needExtrapolation = true;
+                if (extrapolateGHBCMode_ == ConstantExtrapolation) {
+                    parLev2 = actParLev2;
+                    parLev1 = parLev2;
+                } else {
+                    parLev1 = actParLev1;
+                    parLev2 = actParLev2;
+                }
                 return true;
             }
         }
@@ -653,7 +945,7 @@ void ApplicationInfo::scaleVerticalVelocity_mv3(ParamInfo* par)
     double dist    = 110442.3 * sqrt(dellat * dellat + dellona * dellona);
 
     double hscale = 21. / dist;
-    double vscale = 12. / (bottomLevel_ - topLevel_);
+    double vscale = 12. / ((bottomLevel_ - topLevel_));
 
     if (levType_ == XS_ML)
         vscale = 12. / (100 * 1000);
@@ -765,7 +1057,7 @@ void ApplicationInfo::scaleVerticalVelocity(ParamInfo* par, double factor)
 
 void ApplicationInfo::getPressureOnLevel(double* splin, MvField& field, std::vector<double>& p, double level)
 {
-    if (levType_ == XS_ML_LNSP) {
+    if (levType_ == XS_ML_LNSP || levType_ == XS_ML_GHBC) {
         assert(splin);
         for (int i = 0; i < nrPoints_; i++) {
             if (splin[i] < XMISSING_VALUE) {
@@ -890,7 +1182,7 @@ bool ApplicationInfo::computeLevelMatrixValues(ParamMap& params, const std::stri
         // Interpolate matrix
         this->InterpolateVerticalb(field, cp, resPar, splin, y_values);
     }
-    else if (levType_ == XS_ML_GHBC)  // handle height-based coordinates
+    else if (levType_ == XS_ML_GHBC || levType_ == XS_GHBC)  // handle height-based coordinates
     {
         // Get extra values
         ParamInfo* parGHBC = getParamInfo(params, paramGHBC_, key);
@@ -969,26 +1261,28 @@ bool ApplicationInfo::computeLevelMatrixValues(ParamMap& params, const std::stri
 #endif
 }
 
-int ApplicationInfo::computeLevelInfoUI(ParamInfo* par, std::vector<double>& vals, double* splin, MvField& field)
+void ApplicationInfo::computeLevelInfoUI(ParamInfo* par, std::vector<double>& vals, double* splin, MvField& field)
 {
     // Compute the levels according to the parameters given in the user interface
     if (uiLSType_ == "FROM_DATA") {
         if (splin == nullptr)
-            return this->computeLevelInfo(par, vals);
+            this->computeLevelInfo(par, vals);
         else
-            return this->computeLevelInfo(par, vals, splin, field);
-    }
-    else if (uiLSType_ == "COUNT") {
+            this->computeLevelInfoFromData(par, vals, splin, field, false);
+    } else if (uiLSType_ == "ADAPTIVE") {
+        if (splin == nullptr)
+            this->computeLevelInfo(par, vals);
+        else
+            this->computeLevelInfoFromData(par, vals, splin, field, true);
+    } else if (uiLSType_ == "COUNT") {
         LevelMap lmap = par->Levels();
         nInputLevels_ = lmap.size();
-        return this->computeLevelInfo(vals);
-    }
-    else {
+        this->computeLevelInfoWithCount(vals);
+    } else {
         assert(uiLSType_ == "LEVEL_LIST");
         vals           = this->levelList();
         nOutputLevels_ = vals.size();
         nInputLevels_  = vals.size();
-        return nOutputLevels_;
     }
 }
 
@@ -1007,7 +1301,7 @@ int ApplicationInfo::computeLevelInfo(ParamInfo* par, std::vector<double>& vals)
     return nrLevels;
 }
 
-int ApplicationInfo::computeLevelInfo(ParamInfo* par, std::vector<double>& vals, double* splin, MvField& field)
+int ApplicationInfo::computeLevelInfoFromData(ParamInfo* par, std::vector<double>& vals, double* splin, MvField& field, bool useAdaptive)
 {
     // Convert ML&LNSP to PL using the following algorithm:
     // a) for each ML value (1,2,...N) get all the correspondent values
@@ -1022,23 +1316,27 @@ int ApplicationInfo::computeLevelInfo(ParamInfo* par, std::vector<double>& vals,
     LevelMap lmap = par->Levels();
     int nrLevels  = lmap.size();
     vals.clear();
-    vals.reserve(nrLevels);  // initial allocation, it will increase in part B
+
+    TargetLevelMaker target(nrLevels);
+    int levelIdx =0;
+
     for (auto& jj : lmap) {
         LevelInfo* lInfo = jj.second;
-        double dlev      = 0.;
-        int count        = 0;
         for (int i = 0; i < nrPoints_; i++) {
             if (splin[i] < XMISSING_VALUE) {
-                dlev += field.meanML_to_Pressure_byLNSP(splin[i], (int)(lInfo->YValue()));
-                count++;
+                target.add(field.meanML_to_Pressure_byLNSP(splin[i], (int)(lInfo->YValue())), levelIdx);
             }
         }
-
-        double mean = count ? dlev / count : 0.;
-        vals.push_back(mean);
+        levelIdx++;
     }
 
-    // Part B: add extra levels
+    if (!useAdaptive) {
+        target.getMeans(vals);
+    } else {
+        target.getAdaptive(vals);
+    }
+
+    // Part B: add extra levels, bottomLevel is in hPa
     double level1 = vals[nrLevels - 1] + OFFSET_LEVELINFO;
     while (level1 <= bottomLevel_) {
         vals.push_back(level1);
@@ -1054,25 +1352,30 @@ int ApplicationInfo::computeLevelInfo(ParamInfo* par, std::vector<double>& vals,
     return nOutputLevels_;
 }
 
-int ApplicationInfo::computeLevelInfo(std::vector<double>& vals)
+int ApplicationInfo::computeLevelInfoWithCount(std::vector<double>& vals)
 {
     // Initialize array
     vals.clear();
     vals.reserve(uiLSCount_);
 
+    // Compute equally separated levels
     if (uiVLinearScaling_) {
-        // Compute equal separated levels
-        double zdp = (bottomLevel_ - topLevel_) / double(uiLSCount_ - 1);
-        for (int i = 0; i < uiLSCount_; i++)
+        double zdp = (bottomLevel_- topLevel_) / double(uiLSCount_ - 1);
+        for (int i = 0; i < uiLSCount_-1; i++) {
             vals.push_back(topLevel_ + i * zdp);
+        }
+        vals.push_back(bottomLevel_);
     }
+    // Compute levels using a log scaling
     else {
-        // Compute levels using a log scaling
         double logBottomLevel = log(bottomLevel_);
         double logTopLevel    = log(topLevel_);
         double zdp            = (logBottomLevel - logTopLevel) / double(uiLSCount_ - 1);
-        for (int i = 0; i < uiLSCount_; i++)
+        for (int i = 0; i < uiLSCount_-1; i++) {
             vals.push_back(exp(logTopLevel + i * zdp));
+        }
+        vals.push_back(logBottomLevel);
+
     }
 
     nOutputLevels_ = uiLSCount_;
@@ -1080,54 +1383,65 @@ int ApplicationInfo::computeLevelInfo(std::vector<double>& vals)
     return nOutputLevels_;
 }
 
+
 void ApplicationInfo::computeLevelInfoGHBC(ParamInfo* par, std::vector<double>& vals)
 {
-    //Compute the average vertical coordinate value for each input GHBC level
-    //along the cross section line. The result is one coordinate value per level.
+    // Compute the levels according to the parameters given in the user interface
+    if (uiLSType_ == "FROM_DATA") {
+        this->computeLevelInfoGHBCFromData(par, vals, false);
+    } else if (uiLSType_ == "ADAPTIVE") {
+        this->computeLevelInfoGHBCFromData(par, vals, true);
+    } else if (uiLSType_ == "COUNT") {
+        LevelMap lmap = par->Levels();
+        nInputLevels_ = lmap.size();
+        this->computeLevelInfoWithCount(vals);
+    } else {
+        assert(uiLSType_ == "LEVEL_LIST");
+        vals           = this->levelList();
+        nOutputLevels_ = vals.size();
+        nInputLevels_  = vals.size();
+    }
+}
+
+void ApplicationInfo::computeLevelInfoGHBCFromData(ParamInfo* par, std::vector<double>& vals, bool useAdaptive)
+{
     LevelMap lmap = par->Levels();
     int nrLevels  = lmap.size();
     vals.clear();
-    double minVal = 1E20;
-    double maxVal = -1E20;
-    double xval;
+    TargetLevelMaker target(nrLevels);
+
+    int levelIdx =0;
     for (auto& jj : lmap) {
         LevelInfo* lInfo = jj.second;
-        double dlev      = 0.;
-        int count        = 0;
         for (int i = 0; i < nrPoints_; i++) {
-            xval = lInfo->XValues()[i];
+            double xval = lInfo->XValues()[i];
             if (xval < XMISSING_VALUE) {
-                dlev += xval;
-                count++;
-                if (xval < minVal)
-                    minVal = xval;
-                if (xval > maxVal)
-                    maxVal = xval;
+                target.add(xval, levelIdx);
             }
         }
-
-        double mean = (count) ? (dlev / count) : 0.;
-        vals.push_back(mean);
+        levelIdx++;
     }
 
+    //Compute the average vertical coordinate value for each input GHBC level
+    //along the cross section line. The result is one coordinate value per level.
+    if (!useAdaptive) {
+        target.getMeans(vals);
+    // The output levels are determined with an adaptive technique
+    } else {
+        target.getAdaptive(vals);
+    }
+
+    nrLevels = vals.size();
     nInputLevels_ = nOutputLevels_ = nrLevels;
+
     // for extrapolation add min and max to levels
     //NOTE: for bounded vertical coordinates  (eg. pressure > 0)
     //we have to be sure the added levels are valid! The problem is
     //that we do not know anything about the nature of the vertical
     //coordinate (since it is "generic").
     if (extrapolateGHBC_ && nrLevels > 1) {
-        double deltaFirst = fabs(vals[0] - vals[1]);
-        double deltaLast  = fabs(vals[nrLevels - 1] - vals[nrLevels - 2]);
-        if (vals[0] < vals[1]) {
-            vals.insert(vals.begin(), minVal - deltaFirst);
-            vals.push_back(maxVal + deltaLast);
-        }
-        else {
-            vals.insert(vals.begin(), maxVal + deltaFirst);
-            vals.push_back(minVal - deltaLast);
-        }
-        nOutputLevels_ += 2;
+        target.addDeltaFromMinMax(vals);
+        nOutputLevels_ = vals.size();
     }
 }
 
@@ -1225,17 +1539,9 @@ double ApplicationInfo::Ansin()
     return sin(angle);
 }
 
-bool ApplicationInfo::levelTypeFlag()
-{
-    if (levType_ == XS_PL)
-        return false;
-    else
-        return true;
-}
-
 void ApplicationInfo::setVerticalInterpolationFlag()
 {
-    if (levType_ == XS_ML_LNSP || levType_ == XS_ML_GHBC)
+    if (levType_ == XS_ML_LNSP || levType_ == XS_ML_GHBC || levType_ == XS_GHBC)
         interpolate_ = true;
     else if (uiLSType_ == "COUNT" || uiLSType_ == "LEVEL_LIST")
         interpolate_ = true;
