@@ -26,7 +26,7 @@
  ********************************************************************************/
 
 #include "Vprofile.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "MvSci.h"
 
 // Application mode
@@ -147,10 +147,10 @@ bool Vprofile::writeLevelInfoNetcdf(MvNetCDF& cdf, ApplicationInfo& appInfo, Par
     bool found = false;
     int modlev = appInfo.levelType();
     int nlevelM;
-    vector<double> y_values;
-    for (ParamIterator ii = params.begin(); ii != params.end(); ii++) {
+    std::vector<double> y_values;
+    for (auto& param : params) {
         // Retrieve the levels info
-        LevelMap lmap = (*ii).second->Levels();
+        LevelMap lmap = param.second->Levels();
         int nlevel    = lmap.size();
 
         // Ignore it if level Type is of type Surface or LNSP
@@ -161,17 +161,17 @@ bool Vprofile::writeLevelInfoNetcdf(MvNetCDF& cdf, ApplicationInfo& appInfo, Par
         // For the remaining sets, do a simple consistency check.
         if (!found) {
             y_values.reserve(nlevel);
-            for (LevelIterator jj = lmap.begin(); jj != lmap.end(); jj++) {
+            for (auto& jj : lmap) {
                 if (modlev == XS_ML_LNSP) {
                     if (outputMode_ == VP_RTTOV)
-                        y_values.push_back((*jj).second->YValue());
+                        y_values.push_back(jj.second->YValue());
                     else
-                        y_values.push_back(field->meanML_to_Pressure_byLNSP(*splin, (int)((*jj).second->YValue())) / 100.);
+                        y_values.push_back(field->meanML_to_Pressure_byLNSP(*splin, (int)(jj.second->YValue())) / 100.);
                 }
                 else if (modlev == XS_ML || modlev == cML_UKMO_ND)
-                    y_values.push_back((*jj).second->YValue());
+                    y_values.push_back(jj.second->YValue());
                 else
-                    y_values.push_back((*jj).second->YValue() / 100.);
+                    y_values.push_back(jj.second->YValue() / 100.);
             }
 
             found   = true;
@@ -180,7 +180,7 @@ bool Vprofile::writeLevelInfoNetcdf(MvNetCDF& cdf, ApplicationInfo& appInfo, Par
         else {
             // Currently, only checks if the number of levels is the same, apart
             // from surface fields
-            if (!(*ii).second->IsSurface() && nlevelM != nlevel) {
+            if (!param.second->IsSurface() && nlevelM != nlevel) {
                 setError(1, "Vprofile-> Data has more than one LevelList");
                 return false;
             }
@@ -188,8 +188,8 @@ bool Vprofile::writeLevelInfoNetcdf(MvNetCDF& cdf, ApplicationInfo& appInfo, Par
     }
 
     // Add the 'levels' variable to the netCDF
-    vector<long> levels_dimsize(1, y_values.size());
-    vector<string> levels_name(1, XS_VARLEVEL);
+    std::vector<long> levels_dimsize(1, y_values.size());
+    std::vector<std::string> levels_name(1, XS_VARLEVEL);
     MvNcVar* nclevels = cdf.addVariable(levels_name[0], ncDouble, levels_dimsize, levels_name);
     nclevels->addAttribute("long_name", "Atmospheric Levels");
     nclevels->addAttribute("units", "hPa");
@@ -205,16 +205,16 @@ bool Vprofile::writeLevelInfoNetcdf(MvNetCDF& cdf, ApplicationInfo& appInfo, Par
 bool Vprofile::writeGeoCoordsNetcdf(MvNetCDF& cdf, ApplicationInfo& appInfo)
 {
     // Add Latitude value
-    vector<string> coord_sdim;
+    std::vector<std::string> coord_sdim;
     if (outputMode_ == VP_RTTOV)
         coord_sdim.push_back(XS_VARTIME);
     else
         coord_sdim.push_back(XS_VARLAT);
 
     double val = appInfo.Y1();
-    vector<long> coord_ndim(1, 1);
-    string coord_name = XS_VARLAT;
-    MvNcVar* nccoord  = cdf.addVariable(coord_name, ncDouble, coord_ndim, coord_sdim);
+    std::vector<long> coord_ndim(1, 1);
+    std::string coord_name = XS_VARLAT;
+    MvNcVar* nccoord       = cdf.addVariable(coord_name, ncDouble, coord_ndim, coord_sdim);
     nccoord->addAttribute("long_name", "latitude");
     nccoord->addAttribute("units", "degrees_north");
     nccoord->put(&val, 1);
@@ -250,7 +250,7 @@ bool Vprofile::writeGlobalAttributesNetcdf(MvNetCDF& netcdf, ParamMap& params, A
     if (!parInfo)
         return false;
 
-    string title = this->titleVariable(appInfo, parInfo);
+    std::string title = this->titleVariable(appInfo, parInfo);
     netcdf.addAttribute("title", title.c_str());
 
     return true;
@@ -267,9 +267,9 @@ bool Vprofile::generateExtraData(MvNetCDF& cdf, ApplicationInfo& appInfo, ParamM
 
     // Time dimension is fixed to one
     // Add Watertype variable
-    vector<long> values_ndim(1, appInfo.NTimes());
-    vector<string> values_sdim(1, XS_VARTIME);
-    string vname("water_type");
+    std::vector<long> values_ndim(1, appInfo.NTimes());
+    std::vector<std::string> values_sdim(1, XS_VARTIME);
+    std::string vname("water_type");
     MvNcVar* ncx = cdf.addVariable(vname, ncDouble, values_ndim, values_sdim);
     ncx->addAttribute("long_name", "Water Type");
     ncx->addAttribute("units", "-");
@@ -335,7 +335,7 @@ bool Vprofile::generatePressureFromLNSP(MvNetCDF& cdf, ApplicationInfo& appInfo,
 
     // Get level values
     int i, nlevels = 0;
-    double* vlevels =  nullptr;
+    double* vlevels = nullptr;
     ParamIterator ii;
     for (ii = params.begin(); ii != params.end(); ii++) {
         // Find the first model level field not LNSP
@@ -347,17 +347,17 @@ bool Vprofile::generatePressureFromLNSP(MvNetCDF& cdf, ApplicationInfo& appInfo,
         nlevels       = lmap.size();
         vlevels       = new double[nlevels];
         i             = 0;
-        for (LevelIterator jj = lmap.begin(); jj != lmap.end(); jj++)
-            vlevels[i++] = (*jj).second->YValue();
+        for (auto& jj : lmap)
+            vlevels[i++] = jj.second->YValue();
 
         break;
     }
 
     // Initialise 'pressure' variable in the netcdf file
-    vector<long> values_ndim;
+    std::vector<long> values_ndim;
     values_ndim.push_back(appInfo.NTimes());
     values_ndim.push_back(nlevels);
-    vector<string> values_sdim;
+    std::vector<std::string> values_sdim;
     values_sdim.push_back(XS_VARTIME);
     values_sdim.push_back(XS_VARLEVEL);
     MvNcVar* ncx = cdf.addVariable("pressure", ncDouble, values_ndim, values_sdim);
@@ -368,17 +368,17 @@ bool Vprofile::generatePressureFromLNSP(MvNetCDF& cdf, ApplicationInfo& appInfo,
     ncx->addAttribute("_FillValue", XMISSING_VALUE);
 
     // Get LNSP values, compute pressure and update the netcdf file
-    int ntimes     = 0;
-    double* values = new double[nlevels];
+    int ntimes   = 0;
+    auto* values = new double[nlevels];
     for (ii = params.begin(); ii != params.end(); ii++) {
         // Find LNSP field
         if (!appInfo.isLNSP((*ii).second->Parameter()))
             continue;
 
         // Retrieve the levels info (single dimension)
-        LevelMap lmap    = (*ii).second->Levels();
-        LevelIterator jj = lmap.begin();
-        double lnsp      = ((*jj).second->XValues())[0];
+        LevelMap lmap = (*ii).second->Levels();
+        auto jj       = lmap.begin();
+        double lnsp   = ((*jj).second->XValues())[0];
         for (i = 0; i < nlevels; i++) {
             values[i] = field.meanML_to_Pressure_byLNSP(lnsp, vlevels[i]);
         }
@@ -407,27 +407,27 @@ bool Vprofile::generatePressureFromLNSP(MvNetCDF& cdf, ApplicationInfo& appInfo,
 bool Vprofile::generateQ2(MvNetCDF& cdf, ApplicationInfo& appInfo, ParamMap& params)
 {
     // Get input fields: two meter temperature, LNSP, two meter dewpoint temperature
-    int ntimes     = appInfo.NTimes();
-    double* tmt    = new double[ntimes];
-    double* lnsp   = new double[ntimes];
-    double* tmdt   = new double[ntimes];
-    double* values = new double[ntimes];
+    int ntimes   = appInfo.NTimes();
+    auto* tmt    = new double[ntimes];
+    auto* lnsp   = new double[ntimes];
+    auto* tmdt   = new double[ntimes];
+    auto* values = new double[ntimes];
     int i2t = 0, ilnsp = 0, i2d = 0, icount = 0;
     double* pt;
-    for (ParamIterator ii = params.begin(); ii != params.end(); ii++) {
-        if ((*ii).second->ParamName() == "2t")
+    for (auto& param : params) {
+        if (param.second->ParamName() == "2t")
             pt = &tmt[i2t++];
-        else if ((*ii).second->ParamName() == "lnsp")
+        else if (param.second->ParamName() == "lnsp")
             pt = &lnsp[ilnsp++];
-        else if ((*ii).second->ParamName() == "2d")
+        else if (param.second->ParamName() == "2d")
             pt = &tmdt[i2d++];
         else
             continue;
 
         // Retrieve the levels info (single dimension)
-        LevelMap lmap    = (*ii).second->Levels();
-        LevelIterator jj = lmap.begin();
-        *pt              = ((*jj).second->XValues())[0];
+        LevelMap lmap = param.second->Levels();
+        auto jj       = lmap.begin();
+        *pt           = ((*jj).second->XValues())[0];
         icount++;
     }
 
@@ -442,8 +442,8 @@ bool Vprofile::generateQ2(MvNetCDF& cdf, ApplicationInfo& appInfo, ParamMap& par
         values[i] = MvSci::specificHumidityFromTd(tmt[i], exp(lnsp[i]), tmdt[i]);
 
     // Create Q2 variable in the netcdf file
-    vector<long> values_ndim(1, appInfo.NTimes());
-    vector<string> values_sdim(1, XS_VARTIME);
+    std::vector<long> values_ndim(1, appInfo.NTimes());
+    std::vector<std::string> values_sdim(1, XS_VARTIME);
     MvNcVar* ncx = cdf.addVariable("q_2", ncDouble, values_ndim, values_sdim);
 
     // Add attributes and values
@@ -468,15 +468,15 @@ bool Vprofile::generateQ2(MvNetCDF& cdf, ApplicationInfo& appInfo, ParamMap& par
 bool Vprofile::generateOrography(MvNetCDF& cdf, ApplicationInfo& appInfo, ParamMap& params)
 {
     // Get input field: geopotential surface
-    int ntimes     = appInfo.NTimes();
-    double* values = new double[ntimes];
-    int icount     = 0;
-    for (ParamIterator ii = params.begin(); ii != params.end(); ii++) {
-        if ((*ii).second->ParamName() == "z" && (*ii).second->LevelType() == "sfc") {
+    int ntimes   = appInfo.NTimes();
+    auto* values = new double[ntimes];
+    int icount   = 0;
+    for (auto& param : params) {
+        if (param.second->ParamName() == "z" && param.second->LevelType() == "sfc") {
             // Retrieve the levels info (single dimension)
-            LevelMap lmap    = (*ii).second->Levels();
-            LevelIterator jj = lmap.begin();
-            values[icount]   = ((*jj).second->XValues())[0] / 9.81;  // g (gravitation acceleration)
+            LevelMap lmap  = param.second->Levels();
+            auto jj        = lmap.begin();
+            values[icount] = ((*jj).second->XValues())[0] / 9.81;  // g (gravitation acceleration)
             icount++;
         }
     }
@@ -488,8 +488,8 @@ bool Vprofile::generateOrography(MvNetCDF& cdf, ApplicationInfo& appInfo, ParamM
     }
 
     // Create Orography variable in the netcdf file
-    vector<long> values_ndim(1, appInfo.NTimes());
-    vector<string> values_sdim(1, XS_VARTIME);
+    std::vector<long> values_ndim(1, appInfo.NTimes());
+    std::vector<std::string> values_sdim(1, XS_VARTIME);
     MvNcVar* ncx = cdf.addVariable("orog", ncDouble, values_ndim, values_sdim);
 
     // Add attributes and values
@@ -508,32 +508,32 @@ bool Vprofile::generateOrography(MvNetCDF& cdf, ApplicationInfo& appInfo, ParamM
 bool Vprofile::generateSurftype(MvNetCDF& cdf, ApplicationInfo& appInfo, ParamMap& params)
 {
     // Get input fields: LSM and CI (Sea Ice Cover)
-    int ntimes     = appInfo.NTimes();
-    double* lsm    = new double[ntimes];
-    double* ci     = new double[ntimes];
-    double* values = new double[ntimes];
+    int ntimes   = appInfo.NTimes();
+    auto* lsm    = new double[ntimes];
+    auto* ci     = new double[ntimes];
+    auto* values = new double[ntimes];
     int ilsm = 0, ici = 0, icount = 0;
     double* pt;
-    for (ParamIterator ii = params.begin(); ii != params.end(); ii++) {
-        if ((*ii).second->ParamName() == "lsm")
+    for (auto& param : params) {
+        if (param.second->ParamName() == "lsm")
             pt = &lsm[ilsm++];
-        else if ((*ii).second->ParamName() == "ci")
+        else if (param.second->ParamName() == "ci")
             pt = &ci[ici++];
         else
             continue;
 
         // Retrieve the levels info (single dimension)
-        LevelMap lmap    = (*ii).second->Levels();
-        LevelIterator jj = lmap.begin();
-        *pt              = ((*jj).second->XValues())[0];
+        LevelMap lmap = param.second->Levels();
+        auto jj       = lmap.begin();
+        *pt           = ((*jj).second->XValues())[0];
         icount++;
     }
 
     // Check consistency
     if (icount / 2 != ntimes) {
-        delete [] lsm;
-        delete [] ci;
-        delete [] values;
+        delete[] lsm;
+        delete[] ci;
+        delete[] values;
         setError(1, "Vprofile-> Number of lsm/ci fields not consistent with other fields");
         return false;
     }
@@ -551,8 +551,8 @@ bool Vprofile::generateSurftype(MvNetCDF& cdf, ApplicationInfo& appInfo, ParamMa
     }
 
     // Create Surface Type variable in the netcdf file
-    vector<long> values_ndim(1, appInfo.NTimes());
-    vector<string> values_sdim(1, XS_VARTIME);
+    std::vector<long> values_ndim(1, appInfo.NTimes());
+    std::vector<std::string> values_sdim(1, XS_VARTIME);
     MvNcVar* ncx = cdf.addVariable("surftype", ncDouble, values_ndim, values_sdim);
 
     // Add attributes and values
@@ -562,9 +562,9 @@ bool Vprofile::generateSurftype(MvNetCDF& cdf, ApplicationInfo& appInfo, ParamMa
     ncx->put(values, (long)ntimes);
 
     // Release memory
-    delete [] lsm;
-    delete [] ci;
-    delete [] values;
+    delete[] lsm;
+    delete[] ci;
+    delete[] values;
 
     return true;
 }
@@ -573,8 +573,8 @@ MvRequest Vprofile::createOutputRequest(ApplicationInfo& appInfo, ParamInfo* par
 {
     // Create netCDF data request
     // Get output data verb
-    string verb;
-    string actionMode = appInfo.actionMode();
+    std::string verb;
+    std::string actionMode = appInfo.actionMode();
     if (outputMode_ == VP_RTTOV &&
         (actionMode == "analyse" || actionMode == "prepare"))
         verb = "NETCDF_RTTOV_INPUT";
@@ -637,7 +637,7 @@ MvRequest Vprofile::createOutputRequest(ApplicationInfo& appInfo, ParamInfo* par
 // Write curve values to file
 // The routine ignores min/max_level. Remove thiese parameters later
 bool Vprofile::generateData(ApplicationInfo& appInfo, ParamMap& params,
-                            MvNetCDF& cdf, MvField&, const string& key)
+                            MvNetCDF& cdf, MvField&, const std::string& key)
 {
     // Get parameter info
     ParamInfo* par = appInfo.getParamInfo(params, key);
@@ -645,14 +645,14 @@ bool Vprofile::generateData(ApplicationInfo& appInfo, ParamMap& params,
         return false;
 
     // Add/update Parameter to the netCDF
-    string varname = this->getNetcdfVarname(par->ParamName());
-    MvNcVar* ncx   = cdf.getVariable(varname);
+    std::string varname = this->getNetcdfVarname(par->ParamName());
+    MvNcVar* ncx        = cdf.getVariable(varname);
     if (!ncx)  // Create a new variable
     {
         ntime_ = 0;
-        vector<long> values_ndim;
+        std::vector<long> values_ndim;
         values_ndim.push_back(appInfo.NTimes());
-        vector<string> values_sdim;
+        std::vector<std::string> values_sdim;
         values_sdim.push_back(XS_VARTIME);
         if (!par->IsSurface() && !appInfo.isLNSP(par->Parameter())) {
             values_ndim.push_back(par->NrLevels());
@@ -669,12 +669,12 @@ bool Vprofile::generateData(ApplicationInfo& appInfo, ParamMap& params,
     }
 
     // Retrieve xvalues
-    LevelMap lmap    = par->Levels();
-    int nlevels      = lmap.size();
-    double* x_values = new double[nlevels];
-    int i            = 0;
-    for (LevelIterator jj = lmap.begin(); jj != lmap.end(); jj++)
-        x_values[i++] = ((*jj).second->XValues())[0];
+    LevelMap lmap  = par->Levels();
+    int nlevels    = lmap.size();
+    auto* x_values = new double[nlevels];
+    int i          = 0;
+    for (auto& jj : lmap)
+        x_values[i++] = (jj.second->XValues())[0];
 
     // Write values to the netCDF
     ncx->setCurrent(ntime_++);
@@ -732,7 +732,7 @@ bool Vprofile::fieldConsistencyCheck(MvField& field, ApplicationInfo& appInfo)
     return true;
 }
 
-string Vprofile::titleVariable(ApplicationInfo& appInfo, ParamInfo* par)
+std::string Vprofile::titleVariable(ApplicationInfo& appInfo, ParamInfo* par)
 {
     char titlestr[150];
     if (inputMode_ == VP_POINT || inputMode_ == VP_GRIDPOINT)
@@ -745,7 +745,7 @@ string Vprofile::titleVariable(ApplicationInfo& appInfo, ParamInfo* par)
                 par->ParamLongName().c_str(), par->Date(), par->Time(), par->Step(),
                 par->ExpVerTitle().c_str(), appInfo.Y1(), appInfo.X1(), appInfo.Y2(), appInfo.X2());
 
-    return string(titlestr);
+    return std::string(titlestr);
 }
 
 
