@@ -104,10 +104,11 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
     // Retrieve initial info
     double X1, X2, Y1, Y2;
     double north, south, east, west;
+    // TODO: figure oiut why this call sets the levelType_
     this->getInitialFieldInfo(field, appInfo, north, south, east, west);
     appInfo.getAreaLine(X1, X2, Y1, Y2);
 
-    // Compute number of vertical points
+    // Compute number of section points
     int npoint = this->computeGeographicalPoints(appInfo, &field);
     if (npoint == 0) {
         setError(1, "Xsect-> Invalid Area/Line!");
@@ -127,6 +128,7 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
     boolean isML = false;
     std::string keystr;
     bool foundU = false, foundV = false, foundW = false, foundT = false;
+    bool foundGHBC = false;
     int iparam, idate, itime, istep;
     const char* expver = 0;
     iter.rewind();
@@ -170,7 +172,8 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
             if (appInfo.isLNSP(iparam))
                 appInfo.haveLNSP(true);
             else
-                appInfo.haveGHBC(true);
+                //appInfo.haveGHBC(true);
+                foundGHBC = true;
 
             // Calculate values along the transection line
             bool ok = fillValues(appInfo, field, xint);
@@ -221,11 +224,16 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
         }
     }  //end while (first loop)
 
+    if (appInfo.haveGHBC() && !foundGHBC) {
+        setError(1, "Xsect-> No verical coordinate field (paramId=%d) found in input!", appInfo.GHBC());
+        return false;
+    }
+
     // Update level processing type, i.e. XS_ML/XS_PL/XS_ML_LNSP/XS_ML_GHBC
     // This function will update an internal flag according to the type of
     // level from the input data. This information is only available after
     // the end of the First Loop above.
-    int levType = appInfo.levelType(isML, isPL);
+    appInfo.determineLevelType(isML, isPL);
 
     // Check if the input fieldset is compatible with the application
     // and with the parameters given in the UI
@@ -237,7 +245,7 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
 
     // Update/initialize level type info
     appInfo.updateLevels(params);
-    bool modlev = appInfo.levelTypeFlag();
+    bool needScaleToPa = appInfo.levelType() == XS_PL;
 
     // Set default interpolation flag.
     // This can be updated later, e.g. velocityValues
@@ -246,11 +254,12 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
     // Update flags
     this->setHorCompFlags(foundU, foundV, foundW, foundT);
 
+    // TODO: Review usints handling in minmax computations!!
     // Update min/max vertical axis values and number of levels
     int nlevel;
     double pBottom, pTop;
     appInfo.getMinMaxLevels(pBottom, pTop, nlevel);
-    if (this->updateTopBottomLevels(appInfo, params, levType, iter, pBottom, pTop, nlevel))
+    if (this->updateTopBottomLevels(appInfo, params, iter, pBottom, pTop, nlevel))
         appInfo.setMinMaxLevels(pBottom, pTop, nlevel);
 
     // Create/initialise netCDF structure
@@ -329,7 +338,7 @@ bool Xsect::processData(MvRequest& data, ApplicationInfo& appInfo, MvRequest& ou
                 continue;
             }
             else
-                (*paramIter).second->Level(xint, clev, npoint, modlev);
+                (*paramIter).second->Level(xint, clev, npoint, needScaleToPa);
         }
 
         // Write out the data if we have the end of what can be grouped together.
@@ -397,8 +406,9 @@ void Xsect::generateKey(std::string& str, int par, int date, int time,
     str = oss.str();
 }
 
-bool Xsect::updateTopBottomLevels(ApplicationInfo& appInfo, ParamMap& params, int levType, MvFieldSetIterator& iter, double& pBottom, double& pTop, int& nlevel)
+bool Xsect::updateTopBottomLevels(ApplicationInfo& appInfo, ParamMap& params, MvFieldSetIterator& iter, double& pBottom, double& pTop, int& nlevel)
 {
+    // TODO: improve this condition check!!!!!
     // Only computes min/max if bottom and top levels are not initialized
     if (pTop || pBottom)
         return false;
@@ -434,7 +444,7 @@ bool Xsect::updateTopBottomLevels(ApplicationInfo& appInfo, ParamMap& params, in
     }
 
     // Compute min/max pressure levels from ML&LNSP fieldset
-    if (levType == XS_ML_LNSP) {
+    if (appInfo.levelType() == XS_ML_LNSP) {
         MvField field;
         iter.rewind();
         while ((field = iter())) {
@@ -596,6 +606,8 @@ void Xsect::getInitialFieldInfo(MvField& field, ApplicationInfo& appInfo, double
     //appInfo.setGlobe(North,South,East,West);
     appInfo.Grid(Grid_ns, Grid_ew);
 
+// TODO: make absolutley sure this code is not needed!!
+#if 0
     // Check model/pressure level settings
     int levType = XS_PL;  // -1 = ML, 0 = PL, 1 = LNSP+ML, cML_UKMO_ND = UKMO New Dynamics
     if (field.isModelLevel()) {
@@ -605,7 +617,7 @@ void Xsect::getInitialFieldInfo(MvField& field, ApplicationInfo& appInfo, double
             levType = XS_ML;
     }
     appInfo.levelType(levType);
-
+#endif
     // Check field's geographical grid point positions
     fieldConsistencyCheck(field, appInfo);
 }
@@ -849,8 +861,10 @@ bool Xsect::contourValues(ApplicationInfo& appInfo, ParamMap& params,
             std::string levname = getNetcdfLevelVarname(varname);
             nclevels            = cdf.addVariable(levname, ncDouble, values_ndim, values_sdim);
             nclevels->addAttribute("long_name", "Atmospheric Levels");
-            nclevels->addAttribute("units", "hPa");
-            nclevels->addAttribute("positive", "down");
+            if (appInfo.levelType() ==  XS_PL || appInfo.levelType() == XS_ML_LNSP) {
+                nclevels->addAttribute("units", "hPa");
+                nclevels->addAttribute("positive", "down");
+            }
         }
 
         // Create variable matrix to be processed
@@ -870,14 +884,13 @@ bool Xsect::contourValues(ApplicationInfo& appInfo, ParamMap& params,
     ntime_++;
     nclevels->setCurrent(ntime_);
 
-    double factor = 1;
+    // Pa -> hPa
     if (appInfo.levelType() == XS_PL || appInfo.levelType() == XS_ML_LNSP) {
-        factor = 100;  //Pa -> hPa
+        for (int j = 0; j < nrLevels; j++) {
+            y_values[j] = appInfo.tohPa(y_values[j]);
+        }
     }
 
-    for (i = 0; i < nrLevels; i++)
-        y_values[i] /= factor;
-
     nclevels->put(y_values, 1, (long)y_values.size());
 
     // Write matrix values to the netCDF file
