@@ -97,7 +97,7 @@ protected:
 
     virtual void init();
     void getInitialFieldInfo(MvField&, ApplicationInfo&, double&, double&, double&, double&);
-    bool updateTopBottomLevels(ApplicationInfo&, ParamMap&, int, MvFieldSetIterator&, double&, double&, int&);
+    bool updateTopBottomLevels(ApplicationInfo&, ParamMap&, MvFieldSetIterator&, double&, double&, int&);
     bool checkCoordinates(double&, double&, double&, double&);
 
     // Check if parameters between two requests are consistent
@@ -164,4 +164,6 @@ protected:
     int ntime_;                // time counter. It assumes that the input data is sorted
                                // by variable and time, e.g. v1t1, v1t2, .. vntm, v2t1, ...
     std::string geoIndexVar_;  // the last dimension in the 'value' variable (lat/lon)
+
+    std::string moduleLabel_{"Xsect-> "};
 };
