@@ -21,6 +21,7 @@
 #include "MvQFileList.h"
 #include "MvQKeyManager.h"
 #include "MvQTheme.h"
+#include "MvQSimpleApplication.h"
 
 // Globals
 int ac;
@@ -38,52 +39,53 @@ int main(int argc, char** argv)
     }
 
     //Create the filelist
-    MvQFileList* fileLst = new MvQFileList(inFiles, MvQFileList::BufrFile);
+    auto* fileLst = new MvQFileList(inFiles, MvQFileList::BufrFile);
     Q_ASSERT(fileLst);
 
     //Create the qt application
-    QApplication app(ac, av);
+    MvQSimpleApplication app(ac, av, "BufrExaminer",
+                             {"examiner", "keyDialog", "window", "find", "codes_ui"});
 
-    //Init the style
-    QStringList styleLst = QStyleFactory::keys();
+    //    //Init the style
+    //    QStringList styleLst = QStyleFactory::keys();
 
-    //Set the style
-    QString style = "Plastique";
-    if (styleLst.contains(style)) {
-        app.setStyle(style);
-    }
-    else {
-        style = "Fusion";
-        if (styleLst.contains(style)) {
-            app.setStyle(style);
-        }
-    }
+    //    //Set the style
+    //    QString style = "Plastique";
+    //    if (styleLst.contains(style)) {
+    //        app.setStyle(style);
+    //    }
+    //    else {
+    //        style = "Fusion";
+    //        if (styleLst.contains(style)) {
+    //            app.setStyle(style);
+    //        }
+    //    }
 
-    //Set fontsize if defined in env var
-    if (const char* fontSizeCh = getenv("CODES_UI_FONT_SIZE")) {
-        int fontSize = atoi(fontSizeCh);
-        if (fontSize < 8)
-            fontSize = 8;
-        else if (fontSize > 28)
-            fontSize = 28;
-        QFont f = app.font();
-        f.setPointSize(fontSize);
-        app.setFont(f);
-    }
+    //    //Set fontsize if defined in env var
+    //    if (const char* fontSizeCh = getenv("CODES_UI_FONT_SIZE")) {
+    //        int fontSize = atoi(fontSizeCh);
+    //        if (fontSize < 8)
+    //            fontSize = 8;
+    //        else if (fontSize > 28)
+    //            fontSize = 28;
+    //        QFont f = app.font();
+    //        f.setPointSize(fontSize);
+    //        app.setFont(f);
+    //    }
 
-    MvQTheme::init(&app, {"examiner","keyDialog","window","find","codes_ui"});
+    //    MvQTheme::init(&app, {"examiner","keyDialog","window","find","codes_ui"});
 
     //Create the bufr key manager and initialize it
-    MvQKeyManager* manager = new MvQKeyManager(MvQKeyManager::BufrType);
+    auto* manager = new MvQKeyManager(MvQKeyManager::BufrType);
     manager->loadProfiles();
 
     //Create the grib metadata object and initialize it with the first file
-    BufrMetaData* bufr = new BufrMetaData;
+    auto* bufr = new BufrMetaData;
     if (fileLst->count() > 0)
         bufr->setFileName(fileLst->path(0).toStdString());
 
     //Create the bufr browser and initialize it
-    BufrExaminer* browser = new BufrExaminer();
+    auto* browser = new BufrExaminer();
     browser->init(bufr, manager, fileLst);
     browser->show();
 
