@@ -25,8 +25,6 @@
 #include "GribExaminer.h"
 #include "GribMetaData.h"
 
-//using namespace std;
-
 // Globals
 int ac;
 char** av;
@@ -149,7 +147,7 @@ int main(int argc, char** argv)
 
         //Create the grib browser and initialize it
         //Set tmpfile name
-        string ftmp           = "/tmp/grib1234.tmp";
+        std::string ftmp      = "/tmp/grib1234.tmp";
         GribExaminer* browser = new GribExaminer(ftmp);
         browser->init(grib, manager, fileLst);
         browser->show();
