@@ -13,6 +13,14 @@
 
 #include "fstatime.h"
 
+
+#ifdef MAGICS
+namespace magics {
+#else
+namespace metview {
+#endif
+
+
 class TDynamicTime : public TStaticTime
 {
 public:
@@ -48,4 +56,4 @@ protected:
 private:
 };
 
-//__TDYNAMICTIME_H__
+}
