@@ -16,6 +16,14 @@
 #include "fmettim.h"
 #endif  //__FMETTIM_H__
 
+
+#ifdef MAGICS
+namespace magics {
+#else
+namespace metview {
+#endif
+
+
 //__________________________________________________________________
 
 TMetTime ::TMetTime() :
@@ -207,3 +215,5 @@ short TMetTime ::GetLocalHour() const
 {
     return (GetHour() + 2) % 24;  //testiarvona vakioero
 }
+
+}
