@@ -13,6 +13,14 @@
 
 #include "fdyntime.h"
 
+
+#ifdef MAGICS
+namespace magics {
+#else
+namespace metview {
+#endif
+
+
 // TMetTime: Discrete time object for meteorological observations and
 //           forecasts.  Watch out for the "="-operator and constructors
 //           with 'out of phase' times as the TMetTime object will always
@@ -69,3 +77,5 @@ private:
 private:
     short fTimeStepInMinutes;
 };
+
+}
