@@ -14,6 +14,13 @@
 
 #include "fobject.h"
 
+
+#ifdef MAGICS
+namespace magics {
+#else
+namespace metview {
+#endif
+
 //_________________________________________________________ TFObject
 
 TFObject::TFObject() = default;
@@ -32,3 +39,5 @@ bool TFObject::operator!=(const TFObject& aObjTest) const
 {
     return (bool)(!(IsEqual(aObjTest)));
 }
+
+}
