@@ -12,6 +12,14 @@
 
 #include "fsortabl.h"
 
+
+#ifdef MAGICS
+namespace magics {
+#else
+namespace metview {
+#endif
+
+
 bool TSortable::operator<(const TSortable& aDateObject) const
 {
     return (IsLessThan(aDateObject));
@@ -33,3 +41,5 @@ bool TSortable::operator<=(const TSortable& aDateObject) const
 {
     return (bool)(*this < aDateObject || *this == aDateObject);
 }
+
+}
