@@ -15,6 +15,13 @@
 #include "fobject.h"
 
 
+#ifdef MAGICS
+namespace magics {
+#else
+namespace metview {
+#endif
+
+
 class TSortable : public TFObject
 {
 public:
@@ -28,4 +35,4 @@ public:
     bool operator<=(const TSortable&) const;
 };
 
-//__TSORTABLE_H__
+}
