@@ -18,6 +18,13 @@
 #include <iomanip>
 
 
+#ifdef MAGICS
+namespace magics {
+#else
+namespace metview {
+#endif
+
+
 static char charValueString[100];
 
 /**-----------------------------------------------------------------------*/
@@ -373,3 +380,5 @@ std::ostream& operator<<(std::ostream& oStream, const TStaticTime& myTime)
 #endif
     return oStream;
 }
+
+}
