@@ -25,6 +25,13 @@
 #endif
 
 
+#ifdef MAGICS
+namespace magics {
+#else
+namespace metview {
+#endif
+
+
 class TStaticTime : public TSortable
 {
     friend std::ostream& operator<<(std::ostream& oStream, const TStaticTime& myTime);
@@ -87,3 +94,5 @@ private:
     short fMin;
     short fSec;
 };
+
+}
