@@ -1,5 +1,5 @@
-#ifndef Assertions_H
-#define Assertions_H
+#pragma once
+
 #include <assert.h>
 
 // The require and ensure macros implement
@@ -23,5 +23,3 @@
 
 #define require(statement) assert(statement)
 #define ensure(statement) assert(statement)
-
-#endif
