@@ -1520,13 +1520,11 @@ void BufrFilterEngine::toGeopoints(const std::string& fName, const std::string&
         if (format == "GEOPOINTS") {
             out << "#";
             dataColNum = 1;
-        }
-        else if (format == "POLAR_VECTORS" || format == "XY_VECTORS") {
+        } else if (format == "POLAR_VECTOR" || format == "XY_VECTOR") {
             out << "#FORMAT " << format << std::endl
                 << "#";
             dataColNum = 2;
-        }
-        else {
+        } else {
             throw MvException("Failed to generate geopoints! Invalid format=" + format + "!");
         }
 
