@@ -10,7 +10,7 @@
 #include "BufrLocationCollector.h"
 
 #include "MvKeyProfile.h"
-#include "assert.h"
+#include <cassert>
 
 BufrLocationCollector::BufrLocationCollector(MvKeyProfile* prof, int maxNum) :
     prof_(prof),
