@@ -9,17 +9,20 @@
 
 #include <stdio.h>
 
+#include <cstdio>
+#include <fstream>
 #include <iostream>
 #include <sstream>
-#include <fstream>
-#include <cstdio>
+#include <string>
+
+#include "fstream_mars_fix.h"
 
 #include "BufrFilterDef.h"
 #include "BufrLocationCollector.h"
 #include "BufrMetaData.h"
 #include "LogHandler.h"
 #include "MvKeyProfile.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "MvEccBufr.h"
 #include "MvTmpFile.h"
 #include "MvWindef.h"
@@ -51,7 +54,7 @@ static bool shellCommand(const std::string &command, std::stringstream& out,std:
         return false;
     }
 
-    while(fgets(cbuf, sizeof(cbuf), in) != NULL)
+    while(fgets(cbuf, sizeof(cbuf), in) != nullptr)
     {
         out << cbuf;
     }
@@ -65,7 +68,7 @@ static bool shellCommand(const std::string &command, std::stringstream& out,std:
         return false;
     }
 
-    while(fgets(cbuf, sizeof(cbuf), in) != NULL)
+    while(fgets(cbuf, sizeof(cbuf), in) != nullptr)
     {
         err << cbuf;
     }
@@ -93,7 +96,7 @@ static bool shellCommand(const std::string& command, std::stringstream& out, std
         return false;
     }
 
-    while (fgets(cbuf, sizeof(cbuf), in) != NULL) {
+    while (fgets(cbuf, sizeof(cbuf), in) != nullptr) {
         out << cbuf;
     }
 
@@ -105,7 +108,7 @@ static bool shellCommand(const std::string& command, std::stringstream& out, std
         return false;
     }
 
-    while (fgets(cbuf, sizeof(cbuf), in) != NULL) {
+    while (fgets(cbuf, sizeof(cbuf), in) != nullptr) {
         err << cbuf;
     }
 
@@ -136,10 +139,10 @@ bool BufrDataDump::filterMessage(const std::string& inFile, int msgCnt, long off
     std::string cmd;
 
     if (offset > -1) {
-        cmd = BUFR_COPY_EXE + " -w count=1 -X " + metview::toString<int>(offset) + " " + inFile + " " + outFile;
+        cmd = BUFR_COPY_EXE + " -w count=1 -X " + std::to_string(offset) + " " + inFile + " " + outFile;
     }
     else {
-        cmd = BUFR_COPY_EXE + " -w count=" + metview::toString<int>(msgCnt) + " " + inFile + " " + outFile;
+        cmd = BUFR_COPY_EXE + " -w count=" + std::to_string(msgCnt) + " " + inFile + " " + outFile;
     }
 
     GuiLog().task() << "Filtering out message: " << msgCnt << GuiLog::commandKey() << cmd;
@@ -155,7 +158,7 @@ bool BufrDataDump::filterMessage(const std::string& inFile, int msgCnt, long off
         hasError = true;
         GuiLog().error() << "Command exited with code: " << exitCode;
         if (err.str().empty())
-            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + metview::toString<int>(exitCode) + " ";
+            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + std::to_string(exitCode) + " ";
     }
 
     if (!ret) {
@@ -208,7 +211,7 @@ bool BufrDataDump::filterSubset(const std::string& inFile, int msgCnt, int subse
         hasError = true;
         GuiLog().error() << "Command exited with code: " << exitCode;
         if (err.str().empty())
-            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + metview::toString<int>(exitCode) + " ";
+            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + std::to_string(exitCode) + " ";
     }
 
     if (!ret) {
@@ -254,7 +257,7 @@ bool BufrDataDump::read(const std::string& sourceFile, int msgCnt, int subsetCnt
         }
         else {
             inFile = sourceFile;
-            cmd    = BUFR_DUMP_EXE + " -ja -w count=1 -X " + metview::toString<long>(offset) + " " + "\"" + inFile + "\"";
+            cmd    = BUFR_DUMP_EXE + " -ja -w count=1 -X " + std::to_string(offset) + " " + "\"" + inFile + "\"";
         }
     }
     else {
@@ -272,7 +275,7 @@ bool BufrDataDump::read(const std::string& sourceFile, int msgCnt, int subsetCnt
         }
         else {
             inFile = sourceFile;
-            cmd    = BUFR_DUMP_EXE + " -ja  -w count=" + metview::toString<int>(msgCnt) + " " + "\"" + inFile + "\"";
+            cmd    = BUFR_DUMP_EXE + " -ja  -w count=" + std::to_string(msgCnt) + " " + "\"" + inFile + "\"";
         }
     }
 
@@ -316,7 +319,7 @@ bool BufrDataDump::read(const std::string& sourceFile, int msgCnt, int subsetCnt
         hasError = true;
         GuiLog().error() << "Command exited with code: " << exitCode;
         if (err.str().empty())
-            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + metview::toString<int>(exitCode) + " ";
+            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + std::to_string(exitCode) + " ";
     }
 
     if (!ret) {
@@ -360,7 +363,7 @@ bool BufrDataDump::debug(const std::string& sourceFile, int msgCnt, int /*subset
         }
         else {
             inFile = sourceFile;
-            cmd    = "export ECCODES_DEBUG=1; " + BUFR_DUMP_EXE + " -ja  -w count=1 -X " + metview::toString<long>(offset) + " " + "\"" + inFile + "\"";
+            cmd    = "export ECCODES_DEBUG=1; " + BUFR_DUMP_EXE + " -ja  -w count=1 -X " + std::to_string(offset) + " " + "\"" + inFile + "\"";
         }
     }
     else {
@@ -403,7 +406,7 @@ bool BufrDataDump::debug(const std::string& sourceFile, int msgCnt, int /*subset
     if (exitCode > 0) {
         if (debug_.empty()) {
             GuiLog().error() << "Command exited with code: " << exitCode;
-            errOut += "Command exited with code: " + metview::toString<int>(exitCode) + " ";
+            errOut += "Command exited with code: " + std::to_string(exitCode) + " ";
             hasError = true;
         }
     }
@@ -454,7 +457,7 @@ bool BufrDataDump::runMessageFilter(const std::string& filterStr, const std::str
         hasError = true;
         GuiLog().error() << "Command exited with code: " << exitCode;
         if (err.str().empty())
-            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + metview::toString<int>(exitCode) + " ";
+            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + std::to_string(exitCode) + " ";
     }
 
     if (!ret) {
@@ -496,16 +499,16 @@ bool BufrExpandDataDump::read(const std::string& sourceFile, int msgCnt, long of
     std::string inFile;
     std::string cmd;
 
-    if (codes_get_api_version() <  21300) {
+    if (codes_get_api_version() < 21300) {
         errOut = "Expanded descriptor dump is only available in ecCodes versions > 2.13.0";
         return false;
     }
 
 
     inFile = sourceFile;
-    cmd    = BUFR_DUMP_EXE + " -d -w count=1 -X " + metview::toString<long>(offset) + " " + "\"" + inFile + "\"";
+    cmd    = BUFR_DUMP_EXE + " -d -w count=1 -X " + std::to_string(offset) + " " + "\"" + inFile + "\"";
 
-    std::stringstream msg;   
+    std::stringstream msg;
     msg << "Generating expanded descriptor dump for message: " << msgCnt;
     GuiLog().task() << msg.str() << GuiLog::commandKey() << cmd;
 
@@ -527,7 +530,7 @@ bool BufrExpandDataDump::read(const std::string& sourceFile, int msgCnt, long of
         hasError = true;
         GuiLog().error() << "Command exited with code: " << exitCode;
         if (err.str().empty())
-            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + metview::toString<int>(exitCode) + " ";
+            errOut += "<b>Command</b>" + cmd + " exited with <b>code:</b> " + std::to_string(exitCode) + " ";
     }
 
     if (!ret) {
@@ -557,7 +560,7 @@ BufrMetaData::BufrMetaData() :
     MvMessageMetaData(BufrType)
 {
 #if 0
-    string cmd;
+    std::string cmd;
 
     GRIB_DEFINITION_PATH_ENV="";
     const char* grb_def_path=getenv("GRIB_DEFINITION_PATH");
@@ -616,8 +619,8 @@ BufrMetaData::~BufrMetaData()
 
 void BufrMetaData::clearData()
 {
-    for (std::vector<MvEccBufrMessage*>::iterator it = messages_.begin(); it != messages_.end(); ++it) {
-        delete *it;
+    for (auto& message : messages_) {
+        delete message;
     }
     messages_.clear();
     totalSubsetNum_ = 0;
@@ -626,8 +629,8 @@ void BufrMetaData::clearData()
 
 void BufrMetaData::clear()
 {
-    for (std::vector<MvEccBufrMessage*>::iterator it = messages_.begin(); it != messages_.end(); ++it) {
-        delete *it;
+    for (auto& message : messages_) {
+        delete message;
     }
     messages_.clear();
     firstTypicalDate_.clear();
@@ -663,10 +666,10 @@ void BufrMetaData::setTotalMessageNum(int num)
 
 size_t BufrMetaData::totalSubsetNum(bool forceCompute)
 {
-    if(totalSubsetNum_ == 0 || forceCompute) {
+    if (totalSubsetNum_ == 0 || forceCompute) {
         totalSubsetNum_ = 0;
-        for(auto msg: messages_) {
-            if(msg && msg->subsetNum() > 0) {
+        for (auto msg : messages_) {
+            if (msg && msg->subsetNum() > 0) {
                 totalSubsetNum_ += static_cast<size_t>(msg->subsetNum());
             }
         }
@@ -674,16 +677,16 @@ size_t BufrMetaData::totalSubsetNum(bool forceCompute)
     return totalSubsetNum_;
 }
 
-void BufrMetaData::getKeyList(string section, MvKeyProfile* prof)
+void BufrMetaData::getKeyList(std::string section, MvKeyProfile* prof)
 {
-    for (vector<MvKey*>::iterator it = allKey_->begin(); it != allKey_->end(); it++) {
-        if ((*it)->metaData("section") == section) {
-            prof->addKey((*it)->clone());
+    for (auto& it : *allKey_) {
+        if (it->metaData("section") == section) {
+            prof->addKey(it->clone());
         }
     }
 }
 
-void BufrMetaData::setFileName(string fname)
+void BufrMetaData::setFileName(std::string fname)
 {
     clear();
 
@@ -696,9 +699,9 @@ void BufrMetaData::setMessage(size_t chunkStart, const std::vector<MvEccBufrMess
 {
     assert(messages_.size() > chunkStart);
     assert(messages_.size() >= chunkStart + msgVec.size());
-    for (size_t i = 0; i < msgVec.size(); i++) {   
+    for (size_t i = 0; i < msgVec.size(); i++) {
         size_t pos = i + chunkStart;
-        assert(messages_[pos] == NULL);
+        assert(messages_[pos] == nullptr);
         messages_[pos] = msgVec[i];
         messages_[pos]->setFileInfo(this);
     }
@@ -707,7 +710,7 @@ void BufrMetaData::setMessage(size_t chunkStart, const std::vector<MvEccBufrMess
 void BufrMetaData::setMessage(size_t pos, MvEccBufrMessage* msg)
 {
     assert(messages_.size() > pos);
-    assert(messages_[pos] == NULL);
+    assert(messages_[pos] == nullptr);
     messages_[pos] = msg;
     messages_[pos]->setFileInfo(this);
 }
@@ -722,7 +725,7 @@ void BufrMetaData::allocateMessages()
 {
     assert(messages_.empty());
     if (totalMessageNum_ > 0)
-        messages_ = vector<MvEccBufrMessage*>(totalMessageNum_, 0);
+        messages_ = std::vector<MvEccBufrMessage*>(totalMessageNum_, 0);
 }
 
 const std::set<std::string>& BufrMetaData::firstMessageKeys()
@@ -740,7 +743,7 @@ void BufrMetaData::readMessageKeys(int index, std::set<std::string>& keys)
         return;
 
     FILE* fp;
-    codes_handle* ch = NULL;
+    codes_handle* ch = nullptr;
     int err          = 0;
     int bufr_count   = 0;
 
@@ -763,13 +766,13 @@ void BufrMetaData::readMessageKeys(int index, std::set<std::string>& keys)
     //fseek(fp,messages_[index]->offset(),SEEK_SET);
 
     //Get messages form the file
-    while ((ch = codes_handle_new_from_file(NULL, fp, PRODUCT_BUFR, &err)) != NULL || err != CODES_SUCCESS) {
+    while ((ch = codes_handle_new_from_file(nullptr, fp, PRODUCT_BUFR, &err)) != nullptr || err != CODES_SUCCESS) {
         if (!ch) {
             GuiLog().error() << "BufrMetaData::readFirstMessageKeys() --->  Unable to create code handle for message count: " << bufr_count + 1;
             continue;
         }
         else {
-            bufr_keys_iterator* kiter = NULL;
+            bufr_keys_iterator* kiter = nullptr;
             char* name                = 0;
 
             codes_set_long(ch, "skipExtraKeyAttributes", 1);
@@ -805,14 +808,14 @@ void BufrMetaData::readMessageKeys(int index, std::set<std::string>& keys)
     fclose(fp);
 }
 
-void BufrMetaData::getKeyProfileForFirstMessage(MvKeyProfile *prof)
+void BufrMetaData::getKeyProfileForFirstMessage(MvKeyProfile* prof)
 {
-	prof->clearKeyData();
+    prof->clearKeyData();
 
     FILE* fp;
-    codes_handle* ch = NULL;
+    codes_handle* ch = nullptr;
     int err          = 0;
-    
+
     //open bufr file for reading
     fp = fopen(fileName_.c_str(), "rb");
     if (!fp) {
@@ -821,7 +824,7 @@ void BufrMetaData::getKeyProfileForFirstMessage(MvKeyProfile *prof)
     }
 
     //Get messages form the file
-    while ((ch = codes_handle_new_from_file(NULL, fp, PRODUCT_BUFR, &err)) != NULL || err != CODES_SUCCESS) {
+    while ((ch = codes_handle_new_from_file(nullptr, fp, PRODUCT_BUFR, &err)) != nullptr || err != CODES_SUCCESS) {
         if (!ch) {
             //GuiLog().error() << "BufrMetaData::readFirstMessageKeys() --->  Unable to create code handle for message count: " << bufr_count + 1;
             continue;
@@ -847,7 +850,7 @@ void BufrMetaData::readMessage(MvKeyProfile* prof, codes_handle* ch)
     const int MAX_VAL_LEN = 1024;
     long longValue;
     char value[MAX_VAL_LEN];
-    string svalue;
+    std::string svalue;
     size_t vlen = MAX_VAL_LEN;
 
     //long centre;
@@ -930,7 +933,7 @@ void BufrMetaData::readMessage(MvKeyProfile* prof, codes_handle* ch)
 void BufrMetaData::readCompressedData(MvKeyProfile* prof, int index, int subsetNum)
 {
     FILE* fp;
-    codes_handle* ch = NULL;
+    codes_handle* ch = nullptr;
     int err          = 0;
     int bufr_count   = 0;
 
@@ -953,13 +956,13 @@ void BufrMetaData::readCompressedData(MvKeyProfile* prof, int index, int subsetN
     }
     else {
         //The first key will be the subset count
-        MvKey* subsetKey = new MvKey("subset", "subset");
+        auto* subsetKey = new MvKey("subset", "subset");
         subsetKey->setValueType(MvKey::IntType);
         subsetKey->setConstant(true);  //!!!!
         prof->addKey(subsetKey);
 
         //Get messages form the file
-        while ((ch = codes_handle_new_from_file(NULL, fp, PRODUCT_BUFR, &err)) != NULL || err != CODES_SUCCESS) {
+        while ((ch = codes_handle_new_from_file(nullptr, fp, PRODUCT_BUFR, &err)) != nullptr || err != CODES_SUCCESS) {
             if (!ch) {
                 GuiLog().error() << "BufrMetaData::readMessages() --->  Unable to create code handle for message count: " << bufr_count + 1;
                 //continue;
@@ -992,7 +995,7 @@ void BufrMetaData::readCompressedData(MvKeyProfile* prof, codes_handle* ch)
 {
     //int codes_bufr_copy_data(grib_handle* hin, grib_handle* hout)
     //{
-    bufr_keys_iterator* kiter = NULL;
+    bufr_keys_iterator* kiter = nullptr;
     char* name                = 0;
     int nkeys                 = 0;
     int keyType               = 0;
@@ -1007,7 +1010,7 @@ void BufrMetaData::readCompressedData(MvKeyProfile* prof, codes_handle* ch)
     size_t len;
     size_t maxStrLen = 128;
 
-    if (ch == NULL) {
+    if (ch == nullptr) {
         return;
     }
 
@@ -1021,7 +1024,7 @@ void BufrMetaData::readCompressedData(MvKeyProfile* prof, codes_handle* ch)
     while (codes_bufr_keys_iterator_next(kiter)) {
         if ((name = codes_bufr_keys_iterator_get_name(kiter))) {
             std::string nameStr(name);
-            MvKey* mvk = new MvKey(nameStr, nameStr);
+            auto* mvk = new MvKey(nameStr, nameStr);
             prof->addKey(mvk);
 
             if (codes_get_native_type(ch, name, &keyType) == CODES_SUCCESS &&
@@ -1032,30 +1035,36 @@ void BufrMetaData::readCompressedData(MvKeyProfile* prof, codes_handle* ch)
                         char* buf = new char[maxStrLen];
                         mvk->setConstant(true);
                         codes_get_string(ch, name, buf, &maxStrLen);
-                        mvk->addStringValue(std::string(buf));
+                        auto sv = std::string(buf);
+                        checkStringValue(sv);
+                        mvk->addStringValue(sv);
                         delete[] buf;
                     }
                     else if (len > 1) {
                         mvk->setConstant(false);
                         if (len != strArrayLen) {
                             if (strArray) {
-                                for (size_t i = 0; i < strArrayLen; ++i)
+                                for (size_t i = 0; i < strArrayLen; ++i) {
                                     free(strArray[i]);
-
+                                }
                                 free(strArray);
                             }
                             strArrayLen = len;
                             strArray    = (char**)malloc(len * sizeof(char*));
-                            for (size_t i = 0; i < len; ++i)
+                            for (size_t i = 0; i < len; ++i) {
                                 strArray[i] = new char[maxStrLen];
+                            }
                         }
 
                         //Get all values
                         size_t itotal = maxStrLen * len;
                         codes_get_string_array(ch, name, strArray, &itotal);
 
-                        for (size_t i = 0; i < len; ++i)
-                            mvk->addStringValue(std::string(strArray[i]));
+                        for (size_t i = 0; i < len; ++i) {
+                            auto sv = std::string(strArray[i]);
+                            checkStringValue(sv);
+                            mvk->addStringValue(sv);
+                        }
                     }
                 }
                 else if (keyType == CODES_TYPE_LONG) {
@@ -1145,25 +1154,25 @@ void BufrMetaData::readCompressedData(MvKeyProfile* prof, codes_handle* ch)
     }
 }
 
-string BufrMetaData::formatDate(string y, string m, string d)
+std::string BufrMetaData::formatDate(std::string y, std::string m, std::string d)
 {
-    string res = y;
+    std::string res = y;
     res.append((m.size() == 1) ? "0" + m : m);
     res.append((d.size() == 1) ? "0" + d : d);
 
-    if (res.find("N/A") != string::npos)
+    if (res.find("N/A") != std::string::npos)
         res = "N/A";
 
     return res;
 }
 
-string BufrMetaData::formatTime(string h, string m, string s)
+std::string BufrMetaData::formatTime(std::string h, std::string m, std::string s)
 {
-    string res = (h.size() == 1) ? "0" + h : h;
+    std::string res = (h.size() == 1) ? "0" + h : h;
     res.append((m.size() == 1) ? "0" + m : m);
     res.append((s.size() == 1) ? "0" + s : s);
 
-    if (res.find("N/A") != string::npos)
+    if (res.find("N/A") != std::string::npos)
         res = "N/A";
 
     return res;
@@ -1173,7 +1182,7 @@ string BufrMetaData::formatTime(string h, string m, string s)
 bool BufrMetaData::readLocations(BufrLocationCollector* collector, std::string& errOut)
 {
     FILE* fp;
-    codes_handle* ch = NULL;
+    codes_handle* ch = nullptr;
     int err          = 0;
     int bufr_count   = 1;
 
@@ -1196,7 +1205,7 @@ bool BufrMetaData::readLocations(BufrLocationCollector* collector, std::string&
     if (filterEnabled_ == true) {
     }
     else {
-        while ((ch = codes_handle_new_from_file(NULL, fp, PRODUCT_BUFR, &err)) != NULL || err != CODES_SUCCESS) {
+        while ((ch = codes_handle_new_from_file(nullptr, fp, PRODUCT_BUFR, &err)) != nullptr || err != CODES_SUCCESS) {
             if (!ch) {
                 GuiLog().error() << "BufrMetaData::readLocations() --->  Unable to create code handle for message count: " << bufr_count + 1;
                 //continue;
@@ -1295,8 +1304,8 @@ void BufrMetaData::readMessageLocations(codes_handle* ch, int msgCnt, BufrLocati
             latLen = 0;
             lonLen = 0;
 
-            std::string latName = "#" + metview::toString(ir) + "#latitude";
-            std::string lonName = "#" + metview::toString(ir) + "#longitude";
+            std::string latName = "#" + std::to_string(ir) + "#latitude";
+            std::string lonName = "#" + std::to_string(ir) + "#longitude";
 
             //MV_CODES_CHECK(codes_get_size(ch, latName.c_str(), &latLen),0);
             //MV_CODES_CHECK(codes_get_size(ch, lonName.c_str(), &lonLen),0);
@@ -1345,8 +1354,8 @@ void BufrMetaData::readMessageLocations(codes_handle* ch, int msgCnt, BufrLocati
             latLen = 0;
             lonLen = 0;
 
-            std::string latName = "/subsetNumber=" + metview::toString<int>(i + 1) + "/latitude";
-            std::string lonName = "/subsetNumber=" + metview::toString<int>(i + 1) + "/longitude";
+            std::string latName = "/subsetNumber=" + std::to_string(i + 1) + "/latitude";
+            std::string lonName = "/subsetNumber=" + std::to_string(i + 1) + "/longitude";
 
             //MV_CODES_CHECK(codes_get_size(ch, latName.c_str(), &latLen),0);
             //MV_CODES_CHECK(codes_get_size(ch, lonName.c_str(), &lonLen),0);
@@ -1397,3 +1406,18 @@ void BufrMetaData::readDoubleArray(codes_handle* ch, const std::string& key, std
 
     MV_CODES_CHECK(codes_get_double_array(ch, key.c_str(), *data, &len), 0);
 }
+
+void BufrMetaData::checkStringValue(std::string& t)
+{
+    static const std::string mStr = "missing";
+    static const char chFF        = static_cast<char>(0xFF);
+
+    if (t.length() > 0) {
+        for (char i : t) {
+            if (i != chFF) {
+                return;
+            }
+        }
+    }
+    t = mStr;
+}
