@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef FORTRANTYPES_H
-#define FORTRANTYPES_H
+#pragma once
 
 //This definition was taken from mars.h
 //We only need this when mars.h cannot be used (e.g. inW codes_ui)
@@ -49,5 +48,3 @@ typedef double fortfloat;
 #endif
 
 #endif
-
-#endif  // FORTRANTYPES_H
