@@ -21,6 +21,7 @@
 #include "MvTmpFile.h"
 #include "MvWindef.h"
 #include "Tokenizer.h"
+#include "MvLog.h"
 
 #include "eccodes.h"
 
@@ -592,6 +593,7 @@ bool GribMvDump::read(const std::string& fname, int count)
                     size_t len;
                     long longValue;
                     double doubleValue;
+                    value[0] = '\0';
 
                     if (grib_get_native_type(gh, name, &keyType) == CODES_SUCCESS &&
                         grib_get_size(gh, name, &len) == CODES_SUCCESS &&
@@ -614,9 +616,7 @@ bool GribMvDump::read(const std::string& fname, int count)
                                 item->setValue(doubleValue, value);
                             }
                         } else if (keyType == CODES_TYPE_STRING) {
-                            if (grib_get_string(gh, name, value, &vlen) == CODES_SUCCESS) {
-                                item->setValue(value);
-                            }
+                            item->setValue(value);
                         } else {
                             svalue = "Array (" + std::to_string(len) + ")";
                             item->setValue(svalue);
