@@ -9,10 +9,12 @@
 
 #include "MvBinaryReader.h"
 
-#include <iostream>
 #include <fstream>
+#include <iostream>
 
-#include <assert.h>
+#include "fstream_mars_fix.h"
+
+#include <cassert>
 
 MvBinaryReader::MvBinaryReader(const std::string& fname) :
     data_(nullptr),
@@ -36,7 +38,7 @@ MvBinaryReader::MvBinaryReader(const std::string& fname) :
 MvBinaryReader::~MvBinaryReader()
 {
     if (dataStart_)
-        delete [] dataStart_;
+        delete[] dataStart_;
 }
 
 bool MvBinaryReader::isValid() const
