@@ -7,23 +7,26 @@
 
  ***************************** LICENSE END *************************************/
 
-// MvBufr.h,   vk Sep94
-//        rev vk 010720
-
 #pragma once
 
 #include <eccodes.h>  //F ec
 #include "fdyntime.h"
 
 #include <map>
-#include <string>
 #include <ostream>
+#include <string>
 
 /*! \file */
 
+#ifdef MAGICS
+namespace magics {
+#else
+namespace metview {
+#endif
+
 //--------------------------------------------------------
 // This constant should be removed into 'Site Dependent Values'...
-//--------------------------------------------------------
+//----------------------s----------------------------------
 const int BUFR_ORIGINATING_CENTER = 98;  // 98 == ECMWF
 
 
@@ -46,7 +49,7 @@ const int kFortranBufrMissingIntValue = 2147483647;
 // NOTE2: IBM/AIX cannot handle bigger arrays in -q32 mode
 //--------------------------------------------------------
 #if defined(AIX) || defined(MV_USE_SMALL_ARRAYS)
-const int MAX_KELEM                 = 40000;  //12000;
+const int MAX_KELEM                 = 40000;  // 12000;
 const int NUM_MAX_KVALS             = 3;
 const int aMAX_KVALS[NUM_MAX_KVALS] = {90000, 180000, 360000};  // previous max values: 80000
 //                                      7MB    14MB   27MB
@@ -55,10 +58,11 @@ const int MAX_KVALS = aMAX_KVALS[NUM_MAX_KVALS - 1];  // biggest entry in aMAX_K
 #else
 const int MAX_KELEM                 = 160000;  // max allowed is 160,000 !!!  // 80000;  // 40000;   //12000;
 const int NUM_MAX_KVALS             = 3;
-const int aMAX_KVALS[NUM_MAX_KVALS] = {600000, 1500000, 4096000};  //360000;   //80000;
-                                                                   //                                      45MB    115MB   312MB
-                                                                   //                                    (vals*80)/(1024*1024)MB
-const int MAX_KVALS = aMAX_KVALS[NUM_MAX_KVALS - 1];               // biggest entry in aMAX_KVALS
+const int aMAX_KVALS[NUM_MAX_KVALS] = {600000, 1500000,
+                                       4096000};      // 360000;   //80000;
+                                                      //                                       45MB    115MB   312MB
+                                                      //                                     (vals*80)/(1024*1024)MB
+const int MAX_KVALS = aMAX_KVALS[NUM_MAX_KVALS - 1];  // biggest entry in aMAX_KVALS
 #endif
 
 //! \enum EBufrInState Status of a BUFR message being read
@@ -92,8 +96,7 @@ enum EElementValueType
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 //  Sections of a BUFR message
-typedef struct
-{
+typedef struct {
     unsigned char startStr;   // "B"
     unsigned char startStr2;  // "U"
     unsigned char startStr3;  // "F"
@@ -136,8 +139,7 @@ typedef struct
 
 const unsigned char cOctetMissingIndicator = 255;
 
-class Section1Base
-{
+class Section1Base {
 public:
     Section1Base(const unsigned char* octs);
     Section1Base(const Section1Base* aSec1);
@@ -163,13 +165,10 @@ protected:
     unsigned char* octets_;
 };
 
-class Section1_preEd4 : public Section1Base
-{
+class Section1_preEd4 : public Section1Base {
 public:
-    Section1_preEd4(const unsigned char* octs) :
-        Section1Base(octs){};
-    Section1_preEd4(const Section1Base* aSec1) :
-        Section1Base(aSec1){};
+    Section1_preEd4(const unsigned char* octs) : Section1Base(octs){};
+    Section1_preEd4(const Section1Base* aSec1) : Section1Base(aSec1){};
 
     bool hasSection2();
     TDynamicTime date();
@@ -184,13 +183,10 @@ public:
     int localTableVersion();
 };
 
-class Section1_Ed4 : public Section1Base
-{
+class Section1_Ed4 : public Section1Base {
 public:
-    Section1_Ed4(const unsigned char* octs) :
-        Section1Base(octs){};
-    Section1_Ed4(const Section1Base* aSec1) :
-        Section1Base(aSec1){};
+    Section1_Ed4(const unsigned char* octs) : Section1Base(octs){};
+    Section1_Ed4(const Section1Base* aSec1) : Section1Base(aSec1){};
 
     bool hasSection2();
     TDynamicTime date();
@@ -205,16 +201,14 @@ public:
     int localTableVersion();
 };
 
-typedef struct
-{
+typedef struct {
     unsigned char len;  // : 24;
     unsigned char len2;
     unsigned char len3;
     unsigned char reserved;  // :  8;
 } TSection2;
 
-typedef struct
-{
+typedef struct {
     unsigned char len;  // : 24;
     unsigned char len2;
     unsigned char len3;
@@ -224,8 +218,7 @@ typedef struct
     unsigned char bitField;  //  8;
 } TSection3;
 
-typedef struct
-{
+typedef struct {
     unsigned char len;  // : 24;
     unsigned char len2;
     unsigned char len3;
@@ -243,10 +236,9 @@ class MvObsSet;
  *  subroutine 'bufren'. This class should be hidden from Metview applications
  *  and the methods of this class should be called only from MvObs.
  */
-class MvBufrBase
-{
+class MvBufrBase {
     friend class MvBufrOut;  //???
-    //friend class MvObsSet;
+    // friend class MvObsSet;
 
 protected:
     int _refCount;
@@ -290,8 +282,7 @@ protected:
 /*! This class and its methods are a lower level wrapper around Fortran
  *   subroutine 'bufren'. These methods should be called only via MvObs class.
  */
-class MvBufr : public MvBufrBase
-{
+class MvBufr : public MvBufrBase {
     friend class MvObs;
     friend class MvObsSet;
     friend class MvObsSetIterator;
@@ -303,7 +294,7 @@ class MvBufr : public MvBufrBase
 protected:
     MvBufr(char* msg, long len, long aMessageNumber = 0);
     ~MvBufr(void);
-    //F
+    // F
     void setEccodes(codes_handle** ecH);
 
     void Decode(void);
@@ -360,7 +351,7 @@ protected:
 private:
     void computeIn_KELEM(void);
 
-    codes_handle** _ecH;  //F ec
+    codes_handle** _ecH;  // F ec
 
 
 protected:
@@ -426,3 +417,5 @@ class MvBufrOut : public MvBufrBase
    Section1Base* _currentSec1;
 };
 #endif
+
+}  // namespace
\ No newline at end of file
