@@ -9,46 +9,34 @@
 
 #include "MvBufrEdition.h"
 
-#ifdef METVIEW_BUFR
-namespace metview
-{
-static std::vector<MvBufrEdition*> bufrEditionItems;
-}
+#ifdef MAGICS
+namespace magics {
 #else
-static std::vector<MvBufrEdition*> bufrEditionItems;
+namespace metview {
 #endif
 
-MvBufrEdition::MvBufrEdition(int masterNumber, int masterVersion, int localVersion,
-                             int centre, int subCentre) :
+static std::vector<MvBufrEdition*> bufrEditionItems;
+
+MvBufrEdition::MvBufrEdition(int masterNumber, int masterVersion, int localVersion, int centre, int subCentre) :
     masterNumber_(masterNumber),
     masterVersion_(masterVersion),
     localVersion_(localVersion),
     centre_(centre),
-    subCentre_(subCentre)
-{
-#ifdef METVIEW_BUFR
-    metview::bufrEditionItems.push_back(this);
-#else
+    subCentre_(subCentre) {
     bufrEditionItems.push_back(this);
-#endif
 }
 
-MvBufrEdition* MvBufrEdition::find(int masterNumber, int masterVersion, int localVersion,
-                                   int centre, int subCentre)
+MvBufrEdition* MvBufrEdition::find(int masterNumber, int masterVersion, int localVersion, int centre, int subCentre)
 {
-#ifdef METVIEW_BUFR
-    for (auto item : metview::bufrEditionItems) {
-#else
     for (auto item : bufrEditionItems) {
-#endif
         if (item->masterNumber_ == masterNumber && item->masterVersion_ == masterVersion &&
-            item->localVersion_ == localVersion && item->centre_ == centre &&
-            item->subCentre_ == subCentre) {
+            item->localVersion_ == localVersion && item->centre_ == centre && item->subCentre_ == subCentre) {
             return item;
         }
     }
 
-    auto* e = new MvBufrEdition(masterNumber, masterVersion, localVersion,
-                                centre, subCentre);
+    auto* e = new MvBufrEdition(masterNumber, masterVersion, localVersion, centre, subCentre);
     return e;
 }
+
+}  // namespace
