@@ -9,11 +9,16 @@
 
 #pragma once
 
-#include <vector>
 #include <string>
+#include <vector>
 
-class MvBufrEdition
-{
+#ifdef MAGICS
+namespace magics {
+#else
+namespace metview {
+#endif
+
+class MvBufrEdition {
 public:
     int masterTablesNumber() const { return masterNumber_; }
     int masterTablesVersionNumber() const { return masterVersion_; }
@@ -24,12 +29,10 @@ public:
     const std::string& centreAsStr() const { return centreAsStr_; }
     void setCentreAsStr(const std::string& c) { centreAsStr_ = c; }
 
-    static MvBufrEdition* find(int masterNumber, int masterVersion, int localVersionr,
-                               int centre, int subCentre);
+    static MvBufrEdition* find(int masterNumber, int masterVersion, int localVersionr, int centre, int subCentre);
 
 protected:
-    MvBufrEdition(int masterNumber, int masterVersion, int localVersionr,
-                  int centre, int subCentre);
+    MvBufrEdition(int masterNumber, int masterVersion, int localVersionr, int centre, int subCentre);
 
     int masterNumber_;
     int masterVersion_;
@@ -37,5 +40,7 @@ protected:
     int centre_;
     int subCentre_;
     std::string centreAsStr_;
-    //static std::vector<MvBufrEdition*> items_;
+    // static std::vector<MvBufrEdition*> items_;
 };
+
+}  // namespace
\ No newline at end of file
