@@ -14,19 +14,18 @@
 #include <assert.h>
 #include <iostream>
 
-#define MV_CODES_CHECK(a, msg) codesCheck(#a, __FILE__, __LINE__, a, msg)
-
-#ifdef METVIEW_BUFR
-namespace metview
-{
-static std::vector<MvBufrElementTable*> bufrElementTableItems;
-}
+#ifdef MAGICS
+namespace magics {
 #else
-static std::vector<MvBufrElementTable*> bufrElementTableItems;
+namespace metview {
 #endif
 
-bool codesCheck(const char* call, const char* /*file*/, int /*line*/, int e, const char* /*msg*/)
-{
+
+#define MV_CODES_CHECK(a, msg) codesCheck(#a, __FILE__, __LINE__, a, msg)
+
+static std::vector<MvBufrElementTable*> bufrElementTableItems;
+
+bool codesCheck(const char* call, const char* /*file*/, int /*line*/, int e, const char* /*msg*/) {
     if (e) {
         std::cout << call << grib_get_error_message(e);
         return false;
@@ -34,34 +33,22 @@ bool codesCheck(const char* call, const char* /*file*/, int /*line*/, int e, con
     return true;
 }
 
-MvBufrElementTable::MvBufrElementTable(MvBufrEdition* edition) :
-    edition_(edition)
-{
+MvBufrElementTable::MvBufrElementTable(MvBufrEdition* edition) : edition_(edition) {
     // Build descriptor-key table
     buildElementTable();
 
     // Store myself
-#ifdef METVIEW_BUFR
-    metview::bufrElementTableItems.push_back(this);
-#else
     bufrElementTableItems.push_back(this);
-#endif
 }
 
-MvBufrElementTable::~MvBufrElementTable()
-{
+MvBufrElementTable::~MvBufrElementTable() {
     std::cout << "delete element" << std::endl;
     edition_ = nullptr;
     melems_.clear();
 }
 
-MvBufrElementTable* MvBufrElementTable::find(MvBufrEdition* edition)
-{
-#ifdef METVIEW_BUFR
-    for (auto item : metview::bufrElementTableItems) {
-#else
+MvBufrElementTable* MvBufrElementTable::find(MvBufrEdition* edition) {
     for (auto item : bufrElementTableItems) {
-#endif
         if (item->edition_ == edition)
             return item;
     }
@@ -70,8 +57,7 @@ MvBufrElementTable* MvBufrElementTable::find(MvBufrEdition* edition)
     return elem;
 }
 
-const std::string&
-MvBufrElementTable::keyName(int descriptor)  //const
+const std::string& MvBufrElementTable::keyName(int descriptor)  // const
 {
     static std::string emptyStr;
 
@@ -148,8 +134,7 @@ std::cout << it->second << std::endl;
 
 using map_bufr_table = std::map<int, std::string>;
 
-static map_bufr_table create_map()
-{
+static map_bufr_table create_map() {
     map_bufr_table map;
 
     map[1001]  = "blockNumber";
@@ -1747,8 +1732,9 @@ static map_bufr_table create_map()
     return map;
 }
 
-bool MvBufrElementTable::buildElementTable()
-{
+bool MvBufrElementTable::buildElementTable() {
     melems_ = create_map();
     return true;
 }
+
+}  // namespace
