@@ -7,7 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
-#include "inc_iostream.h"
+#include <iostream>
+#include <sstream>
+#include <vector>
+
 #include "MvApplication.h"
 #include "MvDate.h"
 
@@ -111,10 +114,10 @@ int MvDate::Julian() const
 
 static request* pref()
 {
-    static request* p = 0;
+    static request* p = nullptr;
     static MvRequest r;  // declare locally to avoid the destructor removing it
 
-    if (p == 0) {
+    if (p == nullptr) {
         r = MvApplication::getPreferences();
         p = r;
     }
@@ -136,14 +139,14 @@ const char* MvDate::DayName(int n, boolean full)
     return s ? s : _day[n - 1][int(full)];
 }
 
-const char* MvDate::StringFormat(void)
+const char* MvDate::StringFormat()
 {
     request* p    = pref();
     const char* s = no_quotes(get_value(p, "STRING_DATE_FORMAT", 0));
     return s ? s : stringFormat;
 }
 
-const char* MvDate::NumberFormat(void)
+const char* MvDate::NumberFormat()
 {
     request* p    = pref();
     const char* s = no_quotes(get_value(p, "NUMBER_DATE_FORMAT", 0));
@@ -153,14 +156,14 @@ const char* MvDate::NumberFormat(void)
 
 // dates in the format JAN-16, NOV-21, MAR-02, etc
 // we just convert to a number that can be used in a sorting algorithm
-int MvDate::climDateNumber(const char *climDate)
+int MvDate::climDateNumber(const char* climDate)
 {
     int number = 0;
 
     if (strlen(climDate) == 6) {
         for (int i = 0; i < 12; i++) {
             if (!strncasecmp(climDate, _month[i][0], 3)) {
-                number = (i+1) * 100;
+                number = (i + 1) * 100;
                 break;
             }
         }
@@ -184,7 +187,7 @@ void MvDate::Print() const
 {
     char buf[1024];
     Format(StringFormat(), buf);
-    cout << buf;
+    std::cout << buf;
 }
 
 
@@ -228,12 +231,12 @@ MvDate::MvDate(const char* s) :
     }
 }
 
-bool MvDate::parseYYYYMMDD(const string& dd, string& res)
+bool MvDate::parseYYYYMMDD(const std::string& dd, std::string& res)
 {
     res.clear();
     res = dd;
     if (dd.size() < 8) {
-        istringstream iss(dd);
+        std::istringstream iss(dd);
         double d;
         iss >> d;
         char buf[9];
@@ -245,14 +248,14 @@ bool MvDate::parseYYYYMMDD(const string& dd, string& res)
 }
 
 //Convert hh:mm:ss format to hhmmss
-bool MvDate::timeToHHMMSS(const string& tt, string& res)
+bool MvDate::timeToHHMMSS(const std::string& tt, std::string& res)
 {
     res.clear();
     bool retVal = false;
     if (tt.size() < 8) {
-        string hh, mm = "00", ss = "00";
+        std::string hh, mm = "00", ss = "00";
 
-        std::vector<string> tok;
+        std::vector<std::string> tok;
         Tokenizer parse(":");
         parse(tt, tok);
 
@@ -285,7 +288,7 @@ bool MvDate::timeToHHMMSS(const string& tt, string& res)
 }
 
 //Convert hhmmss format to seconds
-bool MvDate::HHMMSStoSec(const string& tt, int& sec)
+bool MvDate::HHMMSStoSec(const std::string& tt, int& sec)
 {
     if (tt.size() != 6)
         return false;
@@ -294,7 +297,7 @@ bool MvDate::HHMMSStoSec(const string& tt, int& sec)
     int ival;
 
     //Hour
-    istringstream hh(tt.substr(0, 1));
+    std::istringstream hh(tt.substr(0, 1));
     hh >> ival;
 
     if (ival < 0 || ival > 23)
@@ -303,7 +306,7 @@ bool MvDate::HHMMSStoSec(const string& tt, int& sec)
     sec += ival * 3600;
 
     //Minute
-    istringstream mm(tt.substr(2, 3));
+    std::istringstream mm(tt.substr(2, 3));
     mm >> ival;
 
     if (ival < 0 || ival > 60)
@@ -312,7 +315,7 @@ bool MvDate::HHMMSStoSec(const string& tt, int& sec)
     sec += ival * 60;
 
     //Second
-    istringstream ss(tt.substr(4, 5));
+    std::istringstream ss(tt.substr(4, 5));
     ss >> ival;
 
     if (ival < 0 || ival > 60)
@@ -345,7 +348,7 @@ bool MvDate::HHMMSStoSec(int tt, int& sec)
         ss = tt;
     }
 
-    //cout << "hh=" << hh << " mm=" << mm << " ss=" << ss << endl;
+    //std::cout << "hh=" << hh << " mm=" << mm << " ss=" << ss << std::endl;
 
     if (hh < 0 || hh > 23)
         return false;
@@ -365,17 +368,17 @@ bool MvDate::HHMMSStoSec(int tt, int& sec)
 }
 
 //Convert hhh:mm:ss format to seconds
-bool MvDate::timeToLenInSec(const string& tt, string& res)
+bool MvDate::timeToLenInSec(const std::string& tt, std::string& res)
 {
     res.clear();
 
     if (tt.size() > 9)
         return false;
 
-    string hh, mm = "00", ss = "00";
+    std::string hh, mm = "00", ss = "00";
     bool retVal = true;
 
-    std::vector<string> tok;
+    std::vector<std::string> tok;
     Tokenizer parse(":");
     parse(tt, tok);
 
@@ -398,13 +401,13 @@ bool MvDate::timeToLenInSec(const string& tt, string& res)
 
     if (retVal) {
         int sec, i;
-        istringstream ish(hh);
+        std::istringstream ish(hh);
         ish >> i;
         sec = i * 3600;
-        istringstream ism(mm);
+        std::istringstream ism(mm);
         ism >> i;
         sec += i * 60;
-        istringstream iss(ss);
+        std::istringstream iss(ss);
         iss >> i;
         sec += i;
 
@@ -418,17 +421,17 @@ bool MvDate::timeToLenInSec(const string& tt, string& res)
 }
 
 //Convert hhh:mm:ss format to hhhmmss format
-bool MvDate::timeToLenAsHHHMMSS(const string& tt, string& res)
+bool MvDate::timeToLenAsHHHMMSS(const std::string& tt, std::string& res)
 {
     res.clear();
 
     if (tt.size() > 9)
         return false;
 
-    string hh, mm = "00", ss = "00";
+    std::string hh, mm = "00", ss = "00";
     bool retVal = true;
 
-    std::vector<string> tok;
+    std::vector<std::string> tok;
     Tokenizer parse(":");
     parse(tt, tok);
 
@@ -717,6 +720,8 @@ void MvDate::Format(const char* f, char* buf) const
                         break;
                 }
                 break;
+            default:
+                break;
         }
 
         if (n < 0)
@@ -743,8 +748,8 @@ double MvDate::time_interval_mins(const MvDate& d) const
 
 double MvDate::dayOfTheYear() const
 {
-    auto y = Year();
-    auto first = MvDate(y*1E4 + 101);
+    auto y     = Year();
+    auto first = MvDate(y * 1E4 + 101);
     return first.time_interval_days(*this);
 }
 
@@ -814,25 +819,34 @@ long MvDate::magicsSub(const MvDate& d) const
     return mm * 10000 + dd * 100 + HH;
 }
 
-int MvDate::hhmmss(void) const
+int MvDate::hhmmss() const
 {
     return Hour() * 10000 + Minute() * 100 + Second();
 }
 
-int MvDate::yyyyddd(void) const
+int MvDate::yyyyddd() const
 {
     return Year() * 1000 + Julian();
 }
 
-string
+std::string
 MvDate::magicsDate() const
 {
     static char buf[32];
     Format("yyyy-mm-dd HH:MM", buf);
-    return string(buf);
+    return std::string(buf);
 }
 
-ostream& operator<<(ostream& aStream, const MvDate& d)
+std::string
+MvDate::ISO8601() const
+{
+    static char buf[32];
+    Format("yyyy-mm-ddTHH:MM:00Z", buf);
+    return std::string(buf);
+}
+
+
+std::ostream& operator<<(std::ostream& aStream, const MvDate& d)
 {
     char buf[512];
     d.Format(d.StringFormat(), buf);
