@@ -11,14 +11,18 @@
 
 #include "MvBufrEdition.h"
 #include "LogHandler.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "BufrMetaData.h"
 #include "Tokenizer.h"
 
-#include <fstream>
-#include <sstream>
-#include <iomanip>
 #include <algorithm>
+#include <fstream>
+#include <iomanip>
+#include <sstream>
+#include <vector>
+
+#include "fstream_mars_fix.h"
+
 #include <stdlib.h>
 #include <assert.h>
 #include <stdio.h>
@@ -40,7 +44,7 @@ std::vector<std::string> MvEccBufrMessage::definitionsDir_;
 //
 //=========================================================
 
-MvEccBufrMessage::MvEccBufrMessage(codes_bufr_header *bh, int index):
+MvEccBufrMessage::MvEccBufrMessage(codes_bufr_header* bh, int index) :
     index_(index),
     headerValid_(true),
     dataValid_(true),
@@ -52,35 +56,37 @@ MvEccBufrMessage::MvEccBufrMessage(codes_bufr_header *bh, int index):
     compressed_(false),
     hasSection2_(false),
     edition_(nullptr),
-    fileInfo_(NULL),
+    fileInfo_(nullptr),
     offset_(0),
     totalLenght_(0)
-{   
+{
     if (!bh || bh->message_size == 0) {
         headerValid_ = false;
-        dataValid_ = false;
+        dataValid_   = false;
         return;
     }
 
-    offset_ = bh->message_offset;
+    offset_      = bh->message_offset;
     totalLenght_ = bh->message_size;
 
-    dataCategory_ = bh->dataCategory;
+    dataCategory_    = bh->dataCategory;
     dataSubCategory_ = bh->dataSubCategory;
 
     //Edition
     long masterNumber, masterVersion, localVersion, centre, subCentre;
     masterVersion = bh->masterTablesVersionNumber;
-    masterNumber = bh->masterTableNumber;
-    localVersion = bh->localTablesVersionNumber;
-    centre = bh->bufrHeaderCentre;
-    subCentre = bh->bufrHeaderSubCentre;
+    masterNumber  = bh->masterTableNumber;
+    localVersion  = bh->localTablesVersionNumber;
+    centre        = bh->bufrHeaderCentre;
+    subCentre     = bh->bufrHeaderSubCentre;
 
     edition_ = MvBufrEdition::find(masterNumber, masterVersion, localVersion, centre, subCentre);
     assert(edition_);
     if (edition_->centreAsStr().empty()) {
-        size_t vlen = 0;
-        char charVal[512]={0,};
+        size_t vlen       = 0;
+        char charVal[512] = {
+            0,
+        };
         charVal[0] = '\n';
         if (codes_bufr_header_get_string(bh, "centre", charVal, &vlen) == CODES_SUCCESS) {
             if (vlen > 0)
@@ -94,7 +100,7 @@ MvEccBufrMessage::MvEccBufrMessage(codes_bufr_header *bh, int index):
         compressed_ = true;
 
     if (centre == 98) {
-        rdbType_ =  bh->rdbType;
+        rdbType_ = bh->rdbType;
     }
 }
 
@@ -110,7 +116,7 @@ MvEccBufrMessage::MvEccBufrMessage(codes_handle* h, int index) :
     compressed_(false),
     hasSection2_(false),
     edition_(nullptr),
-    fileInfo_(NULL),
+    fileInfo_(nullptr),
     offset_(0),
     totalLenght_(0)
 {
@@ -167,39 +173,37 @@ MvEccBufrMessage::MvEccBufrMessage(codes_handle* h, int index) :
     }
 }
 
-MvEccBufrMessage::~MvEccBufrMessage()
-{
-}
+MvEccBufrMessage::~MvEccBufrMessage() = default;
 
 int MvEccBufrMessage::centre() const
 {
-    return (edition_)?edition_->centre():0;
+    return (edition_) ? edition_->centre() : 0;
 }
 
 int MvEccBufrMessage::subCentre() const
 {
-    return (edition_)?edition_->subCentre():0;
+    return (edition_) ? edition_->subCentre() : 0;
 }
 
 int MvEccBufrMessage::masterTablesNumber() const
 {
-    return (edition_)?edition_->masterTablesNumber():0;
+    return (edition_) ? edition_->masterTablesNumber() : 0;
 }
 
 int MvEccBufrMessage::masterTablesVersionNumber() const
 {
-    return (edition_)?edition_->masterTablesVersionNumber():0;
+    return (edition_) ? edition_->masterTablesVersionNumber() : 0;
 }
 
 int MvEccBufrMessage::localTablesVersionNumber() const
 {
-    return (edition_)?edition_->localTablesVersionNumber():0;
+    return (edition_) ? edition_->localTablesVersionNumber() : 0;
 }
 
 const std::string& MvEccBufrMessage::centreAsStr() const
 {
     static std::string empty;
-    return (edition_)?edition_->centreAsStr():empty;
+    return (edition_) ? edition_->centreAsStr() : empty;
 }
 
 const std::vector<int>& MvEccBufrMessage::unexpandedDesc()
@@ -216,7 +220,7 @@ void MvEccBufrMessage::getUnexpanded()
         return;
 
     size_t vlen = 0;
-    int err = 0;
+    int err     = 0;
 
     FILE* fp;
     fp = fopen(fileInfo_->fileName().c_str(), "rb");
@@ -229,7 +233,7 @@ void MvEccBufrMessage::getUnexpanded()
         return;
     }
 
-    if (codes_handle* ch = codes_handle_new_from_file(NULL, fp, PRODUCT_BUFR, &err)) {
+    if (codes_handle* ch = codes_handle_new_from_file(nullptr, fp, PRODUCT_BUFR, &err)) {
         MV_CODES_CHECK_HEADER(codes_get_size(ch, "unexpandedDescriptors", &vlen), 0);
         if (vlen > 0) {
             long* descriptors = (long*)malloc(vlen * sizeof(long));
@@ -270,7 +274,7 @@ void MvEccBufrMessage::tablesDirs(std::vector<std::string>& tablesMasterDir, std
     }
 
     std::string masterDirPattern, localDirPattern;
-    if (codes_handle* ch = codes_handle_new_from_file(NULL, fp, PRODUCT_BUFR, &err)) {
+    if (codes_handle* ch = codes_handle_new_from_file(nullptr, fp, PRODUCT_BUFR, &err)) {
         //tables
         vlen = MAX_CHAR_LEN;
         if (MV_CODES_CHECK(codes_get_string(ch, "tablesMasterDir", charVal, &vlen), 0)) {
@@ -290,14 +294,14 @@ void MvEccBufrMessage::tablesDirs(std::vector<std::string>& tablesMasterDir, std
         replace(localDirPattern, "[bufrHeaderSubCentre]", subCentre());
 
         if (definitionsDir_.empty()) {
-            if (char* defPath = codes_definition_path(NULL)) {
+            if (char* defPath = codes_definition_path(nullptr)) {
                 std::string dStr(defPath);
                 Tokenizer parse(":");
                 parse(dStr, definitionsDir_);
             }
         }
 
-        for(auto defDir: definitionsDir_) {
+        for (auto defDir : definitionsDir_) {
             tablesMasterDir.push_back(defDir + "/" + masterDirPattern);
             tablesLocalDir.push_back(defDir + "/" + localDirPattern);
         }
@@ -375,9 +379,9 @@ int MvEccBufr::computeMessageNum()
 
 int MvEccBufr::scan()
 {
-    FILE* in = NULL;
+    FILE* in = nullptr;
 
-    codes_handle* h = NULL;
+    codes_handle* h = nullptr;
     int err = 0, cnt = 0;
 
     in = fopen(fileName_.c_str(), "rb");
@@ -386,11 +390,11 @@ int MvEccBufr::scan()
         return 1;
     }
 
-    while ((h = codes_handle_new_from_file(NULL, in, PRODUCT_BUFR, &err)) != NULL || err != CODES_SUCCESS) {
-        MvEccBufrMessage* m = new MvEccBufrMessage(h, cnt);
+    while ((h = codes_handle_new_from_file(nullptr, in, PRODUCT_BUFR, &err)) != nullptr || err != CODES_SUCCESS) {
+        auto* m = new MvEccBufrMessage(h, cnt);
         msg_.push_back(m);
 
-        if (h == NULL) {
+        if (h == nullptr) {
             printf("Error: unable to create handle for message %d\n", cnt);
         }
         else {
@@ -403,9 +407,9 @@ int MvEccBufr::scan()
     return 0;
 }
 
-MvEccBufrMessage* MvEccBufr::message(int cnt)
+MvEccBufrMessage* MvEccBufr::message(int /*cnt*/)
 {
-    return NULL;
+    return nullptr;
 }
 
 MvEccBufr::ElementDefType MvEccBufr::elementDefType(int elem)
@@ -423,7 +427,7 @@ MvEccBufr::ElementDefType MvEccBufr::elementDefType(int elem)
     return UnknownElement;
 }
 
-bool MvEccBufr::codesCheck(const char* call, const char* file, int line, int e, const char* msg)
+bool MvEccBufr::codesCheck(const char* call, const char* /*file*/, int /*line*/, int e, const char* /*msg*/)
 {
     if (e) {
         GuiLog().error() << call << grib_get_error_message(e);
@@ -451,15 +455,15 @@ MvBufrCodeTable::MvBufrCodeTable(int element, MvBufrEdition* edition, const std:
 const std::string& MvBufrCodeTable::value(int code) const
 {
     static std::string es;
-    std::map<int, std::string>::const_iterator it = items_.find(code);
+    auto it = items_.find(code);
     return (it != items_.end()) ? it->second : es;
 }
 
 MvBufrCodeTable* MvBufrCodeTable::find(int element, MvEccBufrMessage* msg)
 {
-    for (std::vector<MvBufrCodeTable*>::const_iterator it = tables_.begin(); it != tables_.end(); ++it) {
-        if ((*it)->element_ == element && (*it)->edition_ == msg->edition())
-            return *it;
+    for (auto table : tables_) {
+        if (table->element_ == element && table->edition_ == msg->edition())
+            return table;
     }
 
     return make(element, msg);
@@ -467,7 +471,7 @@ MvBufrCodeTable* MvBufrCodeTable::find(int element, MvEccBufrMessage* msg)
 
 std::string MvBufrCodeTable::buildFileName(int element, const std::string& path)
 {
-    return path + "/codetables/" + metview::toString<int>(element) + ".table";
+    return path + "/codetables/" + std::to_string(element) + ".table";
 }
 
 MvBufrCodeTable* MvBufrCodeTable::make(int element, MvEccBufrMessage* msg)
@@ -489,13 +493,13 @@ MvBufrCodeTable* MvBufrCodeTable::make(int element, MvEccBufrMessage* msg)
             break;
     }
 
-    for (auto p: path) {
+    for (auto p : path) {
         //Check if the file exists and can be open for reading
         std::string fname = buildFileName(element, p);
         std::ifstream in(fname.c_str(), std::ios::in);
         if (in.is_open()) {
             in.close();
-            MvBufrCodeTable* t = new MvBufrCodeTable(element, msg->edition(), p);
+            auto* t = new MvBufrCodeTable(element, msg->edition(), p);
             return t;
         }
     }
@@ -574,12 +578,12 @@ void MvBufrFlagTable::values(int code, int width, MvBufrFlagInfo& v) const  //st
 
     for (size_t i = 0; i < n; i++) {
         if (bits[i] == 1) {
-            std::map<int, std::string>::const_iterator it = items_.find(i + 1);
+            auto it = items_.find(i + 1);
             std::string desc;
             if (it != items_.end()) {
                 desc = it->second;
             }
-            v.flags_.push_back(std::make_pair(metview::toString<int>(i + 1), desc));
+            v.flags_.push_back(std::make_pair(std::to_string(i + 1), desc));
         }
     }
 }
@@ -598,9 +602,9 @@ void MvBufrFlagTable::getBits(unsigned int code, int width, std::vector<int>& v)
 
 MvBufrFlagTable* MvBufrFlagTable::find(int element, MvEccBufrMessage* msg)
 {
-    for (std::vector<MvBufrFlagTable*>::const_iterator it = tables_.begin(); it != tables_.end(); ++it) {
-        if ((*it)->element_ == element && (*it)->edition_ == msg->edition())
-            return *it;
+    for (auto table : tables_) {
+        if (table->element_ == element && table->edition_ == msg->edition())
+            return table;
     }
 
     return MvBufrFlagTable::make(element, msg);
@@ -608,7 +612,7 @@ MvBufrFlagTable* MvBufrFlagTable::find(int element, MvEccBufrMessage* msg)
 
 std::string MvBufrFlagTable::buildFileName(int element, const std::string& path)
 {
-    return path + "/codetables/" + metview::toString<int>(element) + ".table";
+    return path + "/codetables/" + std::to_string(element) + ".table";
 }
 
 MvBufrFlagTable* MvBufrFlagTable::make(int element, MvEccBufrMessage* msg)
@@ -630,13 +634,13 @@ MvBufrFlagTable* MvBufrFlagTable::make(int element, MvEccBufrMessage* msg)
             break;
     }
 
-    for (auto p: path) {
+    for (auto p : path) {
         //Check if the file exists and can be open for read!
         std::string fname = buildFileName(element, p);
         std::ifstream in(fname.c_str(), std::ios::in);
         if (in.is_open()) {
             in.close();
-            MvBufrFlagTable* t = new MvBufrFlagTable(element, msg->edition(), p);
+            auto* t = new MvBufrFlagTable(element, msg->edition(), p);
             return t;
         }
     }
