@@ -17,10 +17,15 @@
 
 #include "MvVariant.h"
 
-class MvEccBufrMessage;
+namespace metview {
 class MvBufrEdition;
+}
+
+class MvEccBufrMessage;
 class BufrMetaData;
 
+using namespace metview;
+
 class MvBufrCodeTable
 {
 public:
