@@ -41,6 +41,4 @@ void MvElement ::setElemBoth(const char* name, int code)
     _elem_code = code;
 }
 
-MvElement::~MvElement()
-{
-}
+MvElement::~MvElement() = default;
