@@ -1,5 +1,4 @@
-#ifndef MvElement_H
-#define MvElement_H
+#pragma once
 
 #include <stdio.h>
 #include <string.h>
@@ -26,7 +25,7 @@ public:
     //	Destructor is virtual to enable the real component to
     //	be deleted when MvList or MvLink is deleted
 
-    virtual void callback(const char*, void* = NULL){};
+    virtual void callback(const char*, void* = nullptr) {}
     //	Define virtual callback.
 
     void increment() { _count++; }
@@ -57,5 +56,3 @@ public:
 
     friend class MvList;
 };
-
-#endif
