@@ -7,11 +7,9 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVEXCEPTION_H_
-#define MVEXCEPTION_H_
+#pragma once
 
 #include <string>
-using std::string;
 
 class MvException
 {
@@ -20,11 +18,10 @@ public:
         what_(why) {}
     MvException(const std::string& why) :
         what_(why) {}
-    const char* what() { return what_.c_str(); }
+    const char* what() const { return what_.c_str(); }
 
 protected:
     std::string what_;
 };
 
-#endif
 // MVEXCEPTION_H_
