@@ -381,7 +381,7 @@ void MvFieldSetIterator::sort(const char* keyCh, char order)
 
     // the most typical keys
     static std::map<std::string, std::string> keys {{"EXPVER", "str"}, {"PARAM","str"},
-                                          {"LEVELIST", "long"}, {"STEP", "str"}, {"TIME", "long"},
+                                          {"LEVELIST", "long"}, {"STEP", "long"}, {"TIME", "long"},
                                           {"DATE", "date"}, {"NUMBER", "long"}, {"_DIAGITER", "str"}};
 
     // determine type. By default string value is used
