@@ -521,13 +521,14 @@ public:
  */
 class MvFieldState
 {
-    MvField* Field;
-    field_state OldState;
-    bool readonly;
-
 protected:
     MvFieldState(const MvField&, field_state, field_state state_to_revert_to = unknown, bool readonlyflag = true);
     virtual ~MvFieldState();
+
+private:
+    MvField* Field{nullptr};
+    field_state OldState{unknown};
+    bool readonly{true};
 };
 
 // ... this one load a field from file into memory, still in grib
