@@ -12,7 +12,7 @@
 void MvFilter::_init(const char* name)
 {
     value* v  = new_value(strcache(name));
-    Condition = new_condition(t_val, (condition*)v, NULL);
+    Condition = new_condition(t_val, (condition*)v, nullptr);
 }
 
 MvFilter::MvFilter(condition* c)
@@ -40,7 +40,7 @@ MvFilter::~MvFilter()
 MvFilter& MvFilter::operator=(const MvFilter& f)
 {
     free_condition(Condition);
-    Condition = NULL;
+    Condition = nullptr;
     Condition = clone_condition(f.Condition);
     return *this;
 }
@@ -75,7 +75,7 @@ MvFilter MvFilter::operator||(const MvFilter& f)
 MvFilter MvFilter::operator!()
 {
     condition* c = new_condition(t_not,
-                                 clone_condition(Condition), NULL);
+                                 clone_condition(Condition), nullptr);
     return MvFilter(c);
 }
 
