@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvFilter_DEFINED
-#define MvFilter_DEFINED
+#pragma once
 
 //! Define request filtering conditions
 /*! MvFilter defines filtering conditions on a general MvRequest.
@@ -45,7 +44,7 @@ public:
     MvFilter(const char* param);
 
     //! Constructor, may take an external condition to build the MvFilter or builds an empty MvFilter
-    MvFilter(condition* cond = NULL);
+    MvFilter(condition* cond = nullptr);
 
     //! Destructor
     ~MvFilter();
@@ -151,4 +150,3 @@ public:
     //! Operator that negates the condition in a MvFilter and returns the new condition
     MvFilter operator!();
 };
-#endif
