@@ -11,13 +11,16 @@
 
 #include <iostream>
 #include <fstream>
+
+#include "fstream_mars_fix.h"
+
 #include <stdio.h>
 #include <string.h>
 #include <assert.h>
 
 #include "MvBinaryReader.h"
 #include "MvDate.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 //----------------------------------------------------------------
 // Class to read flexpart file "header" produced by writeheader.f90
@@ -189,8 +192,8 @@ void MvFlexpartHeader::print()
     std::cout << "  dy: " << dy << std::endl;
 
     std::cout << "  levelNum : " << levels.size() << std::endl;
-    for (size_t i = 0; i < levels.size(); i++)
-        std::cout << "    level: " << levels[i] << std::endl;
+    for (float level : levels)
+        std::cout << "    level: " << level << std::endl;
 
     std::cout << "  species: " << specNum << std::endl;
     for (int i = 0; i < specNum; i++) {
@@ -200,22 +203,22 @@ void MvFlexpartHeader::print()
 
     std::cout << "  relaseNum : " << release.size() << std::endl;
     std::cout << "    ---------------------------" << std::endl;
-    for (size_t i = 0; i < release.size(); i++) {
-        std::cout << "    name: " << release[i].name << std::endl;
-        std::cout << "    start: " << release[i].start << std::endl;
-        std::cout << "    end: " << release[i].end << std::endl;
-        std::cout << "    west: " << release[i].west << std::endl;
-        std::cout << "    east: " << release[i].east << std::endl;
-        std::cout << "    north: " << release[i].north << std::endl;
-        std::cout << "    south: " << release[i].south << std::endl;
-        std::cout << "    bottom: " << release[i].bottom << std::endl;
-        std::cout << "    top: " << release[i].top << std::endl;
-        std::cout << "    levelUnitsType: " << release[i].levType << std::endl;
-        std::cout << "    particleCount: " << release[i].num << std::endl;
+    for (auto& i : release) {
+        std::cout << "    name: " << i.name << std::endl;
+        std::cout << "    start: " << i.start << std::endl;
+        std::cout << "    end: " << i.end << std::endl;
+        std::cout << "    west: " << i.west << std::endl;
+        std::cout << "    east: " << i.east << std::endl;
+        std::cout << "    north: " << i.north << std::endl;
+        std::cout << "    south: " << i.south << std::endl;
+        std::cout << "    bottom: " << i.bottom << std::endl;
+        std::cout << "    top: " << i.top << std::endl;
+        std::cout << "    levelUnitsType: " << i.levType << std::endl;
+        std::cout << "    particleCount: " << i.num << std::endl;
 
-        std::cout << "    massesNum : " << release[i].massForSpec.size() << std::endl;
-        for (size_t j = 0; j < release[i].massForSpec.size(); j++)
-            std::cout << "      mass: " << release[i].massForSpec[j] << std::endl;
+        std::cout << "    massesNum : " << i.massForSpec.size() << std::endl;
+        for (size_t j = 0; j < i.massForSpec.size(); j++)
+            std::cout << "      mass: " << i.massForSpec[j] << std::endl;
 
         std::cout << "    ---------------------------" << std::endl;
     }
@@ -227,8 +230,8 @@ void MvFlexpartHeader::print()
     std::cout << "  receptorUnitsType: " << indReceptor << std::endl;
 
     std::cout << "  ageClasses : " << ageClass.size() << std::endl;
-    for (size_t i = 0; i < ageClass.size(); i++)
-        std::cout << "    ageClass: " << ageClass[i] << std::endl;
+    for (int ageClas : ageClass)
+        std::cout << "    ageClass: " << ageClas << std::endl;
 }
 
 //----------------------------------------------------------------
@@ -263,5 +266,5 @@ void MvFlexpartDates::print()
 {
     std::cout << "dates:" << std::endl;
     for (int i = 0; i < num; i++)
-        cout << "  date: " << date[i] << "  time: " << time[i] << std::endl;
+        std::cout << "  date: " << date[i] << "  time: " << time[i] << std::endl;
 }
