@@ -9,15 +9,21 @@
 
 #include "MvFlextra.h"
 
-#include "MvDate.h"
-
-#include <iostream>
 #include <fstream>
+#include <iostream>
+#include <map>
+#include <sstream>
+#include <string>
+#include <vector>
+
+#include "fstream_mars_fix.h"
+
+#include "MvDate.h"
 
 //This is how flextra writes out the trajectory output in trajout.f
 //format(i9,2f9.4,f7.4,f7.1,2f8.1,f8.3,f6.1,e9.2)
 static const int fieldWidthArr[] = {9, 9, 9, 7, 7, 8, 8, 8, 6, 9};
-static vector<int> fieldWidthVec(fieldWidthArr, fieldWidthArr + sizeof(fieldWidthArr) / sizeof(fieldWidthArr[0]));
+static std::vector<int> fieldWidthVec(fieldWidthArr, fieldWidthArr + sizeof(fieldWidthArr) / sizeof(fieldWidthArr[0]));
 
 //=========================================================
 //
@@ -51,31 +57,31 @@ MvFlextraItem::MvFlextraItem(int id) :
     pointKeyType_["theta"]        = FloatType;
 }
 
-string MvFlextraItem::metaData(const string& key) const
+std::string MvFlextraItem::metaData(const std::string& key) const
 {
-    map<string, string>::const_iterator it = metaData_.find(key);
+    auto it = metaData_.find(key);
     if (it != metaData_.end())
         return it->second;
     else
-        return string();
+        return std::string();
 }
 
-void MvFlextraItem::pointData(const string& key, vector<string>& data, MvFlextraItem::DataType& type) const
+void MvFlextraItem::pointData(const std::string& key, std::vector<std::string>& data, MvFlextraItem::DataType& type) const
 {
-    map<string, int>::const_iterator it = pointKeyIndex_.find(key);
+    auto it = pointKeyIndex_.find(key);
     if (it != pointKeyIndex_.end()) {
         int id = it->second;
-        for (unsigned int i = 0; i < points_.size(); i++) {
-            if (id >= 0 && id < static_cast<int>(points_.at(i).size())) {
-                data.push_back(points_.at(i).at(id));
+        for (const auto& point : points_) {
+            if (id >= 0 && id < static_cast<int>(point.size())) {
+                data.push_back(point.at(id));
             }
             else {
-                data.push_back(string());
+                data.push_back(std::string());
             }
         }
     }
 
-    map<string, DataType>::const_iterator itT = pointKeyType_.find(key);
+    auto itT = pointKeyType_.find(key);
     if (itT != pointKeyType_.end())
         type = itT->second;
 }
@@ -95,36 +101,36 @@ MvFlextraBlock::MvFlextraBlock()
 
 MvFlextraBlock::~MvFlextraBlock()
 {
-    for (size_t i = 0; i < items_.size(); i++) {
-        delete items_[i];
+    for (auto& item : items_) {
+        delete item;
     }
 }
 
 
-void MvFlextraBlock::decode(string fileName)
+void MvFlextraBlock::decode(std::string fileName)
 {
-    ifstream in(fileName.c_str());
-    string line;
+    std::ifstream in(fileName.c_str());
+    std::string line;
     decode(in, line);
     in.close();
 }
 
-void MvFlextraBlock::decode(ifstream& in, string& line)
+void MvFlextraBlock::decode(std::ifstream& in, std::string& line)
 {
     bool headerPassed      = false;
     bool firstRowPassed    = false;
     bool directionDetected = false;
 
-    map<string, string> trTypeName;
+    std::map<std::string, std::string> trTypeName;
     trTypeName["3-DIMENSIONAL"] = "3D";
 
-    map<string, string> info;
+    std::map<std::string, std::string> info;
     MvDate baseDate;
-    string metaDataText;
-    string keySuffix;
-    vector<string> metaData;
-    map<string, vector<string> > trInfo;
-    map<string, string> constInfo;
+    std::string metaDataText;
+    std::string keySuffix;
+    std::vector<std::string> metaData;
+    std::map<std::string, std::vector<std::string> > trInfo;
+    std::map<std::string, std::string> constInfo;
     MvFlextraItem* item = 0;
 
     int cnt = 0;
@@ -135,12 +141,12 @@ void MvFlextraBlock::decode(ifstream& in, string& line)
 
 
     while (getline(in, line)) {
-        if (line.find("Number of header lines") != string::npos) {
+        if (line.find("Number of header lines") != std::string::npos) {
             break;
         }
 
-        else if (line.find("*") != string::npos && headerPassed == false) {
-            string value, valueFrom, valueTo;
+        else if (line.find("*") != std::string::npos && headerPassed == false) {
+            std::string value, valueFrom, valueTo;
             if (parseHeaderLine(line, "TYPE OF TRAJECTORIES:", value)) {
                 if (trTypeName.find(value) != trTypeName.end()) {
                     metaData_["type"] = trTypeName[value];
@@ -183,18 +189,18 @@ void MvFlextraBlock::decode(ifstream& in, string& line)
                 }
             }
         }
-        else if (line.find("DATE:") != string::npos) {
+        else if (line.find("DATE:") != std::string::npos) {
             cnt++;
 
             item = new MvFlextraItem(cnt);
             items_.push_back(item);
 
-            stringstream sst_cnt;
+            std::ostringstream sst_cnt;
             sst_cnt << cnt;
 
             //Parse "Date:" line
-            stringstream sst(line);
-            string s, sDate, sTime, sIndex;
+            std::istringstream sst(line);
+            std::string s, sDate, sTime, sIndex;
             sst >> s >> sDate >> s >> sTime >> s >> s >> sIndex;
 
             s     = sDate;
@@ -202,7 +208,7 @@ void MvFlextraBlock::decode(ifstream& in, string& line)
 
             s = sTime;
             if (s.size() < 6) {
-                s = string(6 - s.size(), '0').append(s);
+                s = std::string(6 - s.size(), '0').append(s);
             }
             sTime = s.substr(0, 2) + ":" + s.substr(3, 2) + ":" + s.substr(4, 2);
 
@@ -232,8 +238,8 @@ void MvFlextraBlock::decode(ifstream& in, string& line)
         }
         else if (headerPassed) {
             if (!firstRowPassed) {
-                istringstream issMeta(line);
-                string s, lon, lat, eta, pres, z, z_oro, pv, theta;
+                std::istringstream issMeta(line);
+                std::string s, lon, lat, eta, pres, z, z_oro, pv, theta;
                 issMeta >> s >> lon >> lat >> eta >> pres >> z >> z_oro >> pv >> theta;
                 item->addMetaData("startLat", lat);
                 item->addMetaData("startLon", lon);
@@ -248,12 +254,12 @@ void MvFlextraBlock::decode(ifstream& in, string& line)
             }
 
             if (!directionDetected) {
-                istringstream iss(line);
-                string s;
+                std::istringstream iss(line);
+                std::string s;
                 iss >> s;
 
                 if (s != "0") {
-                    if (s.find("-") != string::npos) {
+                    if (s.find("-") != std::string::npos) {
                         direction_ = "Backward";
                     }
                     metaData_["direction"] = direction_;
@@ -263,14 +269,14 @@ void MvFlextraBlock::decode(ifstream& in, string& line)
 
             //Parse the line with the data taking the widths form the
             //original flextra ouput fortran FORMAT statement
-            vector<string> pointData;
+            std::vector<std::string> pointData;
             int pos = 0;
             for (size_t i = 0; i < fieldWidthVec.size(); i++) {
                 pointData.push_back(line.substr(pos, fieldWidthVec[i]));
                 pos += fieldWidthVec[i];
             }
 
-            istringstream iss(pointData[0]);
+            std::istringstream iss(pointData[0]);
             double d;
             iss >> d;
 
@@ -280,14 +286,14 @@ void MvFlextraBlock::decode(ifstream& in, string& line)
             char buf[100];
             md.Format("yyyy-mm-dd HH:MM:SS", buf);
 
-            pointData.insert(pointData.begin(), string(buf));
+            pointData.insert(pointData.begin(), std::string(buf));
 
             item->addPoint(pointData);
         }
     }
 
 
-    stringstream ssNum;
+    std::ostringstream ssNum;
     ssNum << items_.size();
     metaData_["trNum"] = ssNum.str();
 
@@ -303,9 +309,8 @@ void MvFlextraBlock::decode(ifstream& in, string& line)
         metaData_["startTime"] = items_.at(0)->metaData("startTime");
     }
 
-    string keys[6] = {"startEta", "startPres", "startZ", "startZAboveGround", "startPv", "startTheta"};
-    for (unsigned int i = 0; i < 6; i++) {
-        string s = keys[i];
+    std::string keys[6] = {"startEta", "startPres", "startZ", "startZAboveGround", "startPv", "startTheta"};
+    for (auto s : keys) {
         if (isMetaDataConst(s)) {
             metaData_[s] = items_.at(0)->metaData(s);
         }
@@ -319,44 +324,40 @@ void MvFlextraBlock::decode(ifstream& in, string& line)
 }
 
 
-void MvFlextraBlock::writeAll(const string& outFile, int& metaDataCnt)
+void MvFlextraBlock::writeAll(const std::string& outFile, int& metaDataCnt)
 {
-    ofstream out;
+    std::ofstream out;
     out.open(outFile.c_str());
 
     metaDataCnt = 0;
     writeMetaData(out, metaDataCnt);
 
     //Write out trajectory data
-    for (vector<MvFlextraItem*>::const_iterator it = items_.begin(); it != items_.end(); it++) {
-        const MvFlextraItem* item = *it;
-
-        for (vector<vector<string> >::const_iterator itP = item->points().begin(); itP != item->points().end(); itP++) {
+    for (auto item : items_) {
+        for (const auto& P : item->points()) {
             out << item->id();
-            for (vector<string>::const_iterator itS = (*itP).begin(); itS != (*itP).end(); itS++) {
-                out << "," << *itS;
+            for (const auto& S : P) {
+                out << "," << S;
             }
-            out << endl;
+            out << std::endl;
         }
     }
 
     out.close();
 }
 
-void MvFlextraBlock::writeHighlightPoints(const string& outFile, int& metaDataCnt, string periodHour)
+void MvFlextraBlock::writeHighlightPoints(const std::string& outFile, int& metaDataCnt, std::string periodHour)
 {
-    ofstream out;
+    std::ofstream out;
     out.open(outFile.c_str());
 
     metaDataCnt = 0;
     writeMetaData(out, metaDataCnt);
 
     //Write out trajectory data
-    for (vector<MvFlextraItem*>::const_iterator it = items_.begin(); it != items_.end(); it++) {
-        const MvFlextraItem* item = *it;
-
-        for (vector<vector<string> >::const_iterator itP = item->points().begin(); itP != item->points().end(); itP++) {
-            const vector<string>& data = (*itP);
+    for (auto item : items_) {
+        for (auto itP = item->points().begin(); itP != item->points().end(); itP++) {
+            const std::vector<std::string>& data = (*itP);
 
             if (data.size() > 0) {
                 MvDate md(data.at(0).c_str());
@@ -371,14 +372,14 @@ void MvFlextraBlock::writeHighlightPoints(const string& outFile, int& metaDataCn
                     else if (periodHour == "24h")
                         found = (h == 0);
                     else if (periodHour == "48h" && data.size() > 1) {
-                        istringstream iss(data[1]);
+                        std::istringstream iss(data[1]);
                         int isec;
                         iss >> isec;
                         found = (h == 0 && (isec / 86400) % 2 == 0);
                     }
 
                     if (found) {
-                        out << item->id() << "," << data[0] << "," << data[2] << "," << data[3] << endl;
+                        out << item->id() << "," << data[0] << "," << data[2] << "," << data[3] << std::endl;
                     }
                 }
             }
@@ -389,21 +390,17 @@ void MvFlextraBlock::writeHighlightPoints(const string& outFile, int& metaDataCn
 }
 
 
-void MvFlextraBlock::writeLabels(const string& outFile, int& metaDataCnt, string periodHour, vector<string>& labels)
+void MvFlextraBlock::writeLabels(const std::string& outFile, int& metaDataCnt, std::string periodHour, std::vector<std::string>& labels)
 {
-    ofstream out;
+    std::ofstream out;
     out.open(outFile.c_str());
 
     metaDataCnt = 0;
     writeMetaData(out, metaDataCnt);
 
     //Write out trajectory data
-    for (vector<MvFlextraItem*>::const_iterator it = items_.begin(); it != items_.end(); it++) {
-        const MvFlextraItem* item = *it;
-
-        for (vector<vector<string> >::const_iterator itP = item->points().begin(); itP != item->points().end(); itP++) {
-            const vector<string>& data = (*itP);
-
+    for (auto item : items_) {
+        for (const auto& data : item->points()) {
             if (data.size() > 0) {
                 MvDate md(data.at(0).c_str());
                 if (md.Minute() == 0 && md.Second() == 0) {
@@ -417,7 +414,7 @@ void MvFlextraBlock::writeLabels(const string& outFile, int& metaDataCnt, string
                     else if (periodHour == "24h")
                         found = (h == 0);
                     else if (periodHour == "48h" && data.size() > 1) {
-                        istringstream iss(data[1]);
+                        std::istringstream iss(data[1]);
                         int isec;
                         iss >> isec;
                         found = (h == 0 && (isec / 86400) % 2 == 0);
@@ -427,7 +424,7 @@ void MvFlextraBlock::writeLabels(const string& outFile, int& metaDataCnt, string
                         char buf1[100];
                         md.Format("dd:HH", buf1);
                         out << "1"
-                            << "," << data[0] << "," << data[2] << "," << data[3] << endl;
+                            << "," << data[0] << "," << data[2] << "," << data[3] << std::endl;
                         labels.push_back(buf1);
                     }
                 }
@@ -438,25 +435,25 @@ void MvFlextraBlock::writeLabels(const string& outFile, int& metaDataCnt, string
     out.close();
 }
 
-void MvFlextraBlock::writeMetaData(ofstream& out, int& metaDataCnt)
+void MvFlextraBlock::writeMetaData(std::ofstream& out, int& metaDataCnt)
 {
     metaDataCnt = 0;
 
     //Write out global meta-data
-    for (map<string, string>::const_iterator it = metaData_.begin(); it != metaData_.end(); it++) {
+    for (auto it = metaData_.begin(); it != metaData_.end(); it++) {
         out << it->first + "=" + it->second << " ";
     }
-    out << "direction=" << direction_ << endl;
+    out << "direction=" << direction_ << std::endl;
     metaDataCnt++;
 
     //Write out trajectory meta-data
-    string keys[12] = {"id", "startDate", "startTime", "startLat", "startLon", "startEta",
-                       "startPres", "startZ", "startZAboveGround", "startPv", "startTheta", "stopIndex"};
+    std::string keys[12] = {"id", "startDate", "startTime", "startLat", "startLon", "startEta",
+                            "startPres", "startZ", "startZAboveGround", "startPv", "startTheta", "stopIndex"};
 
-    for (int i = 0; i < 12; i++) {
-        string s;
-        for (vector<MvFlextraItem*>::iterator it = items_.begin(); it != items_.end(); it++) {
-            string val = (*it)->metaData(keys[i]);
+    for (auto& key : keys) {
+        std::string s;
+        for (auto& item : items_) {
+            std::string val = item->metaData(key);
             if (s.empty()) {
                 s.append(val);
             }
@@ -466,22 +463,22 @@ void MvFlextraBlock::writeMetaData(ofstream& out, int& metaDataCnt)
         }
 
         if (!s.empty()) {
-            out << keys[i] + "_TR=" + s << endl;
+            out << key + "_TR=" + s << std::endl;
             metaDataCnt++;
         }
     }
 }
 
 
-bool MvFlextraBlock::parseHeaderLine(const string& line, const string& key, string& value)
+bool MvFlextraBlock::parseHeaderLine(const std::string& line, const std::string& key, std::string& value)
 {
     bool found = false;
-    string::size_type pos;
-    if ((pos = line.find(key)) != string::npos) {
-        stringstream sst(string(line, pos + key.size()));
-        string s;
+    std::string::size_type pos;
+    if ((pos = line.find(key)) != std::string::npos) {
+        std::istringstream sst(std::string(line, pos + key.size()));
+        std::string s;
         while (sst >> s) {
-            if (s.find("*") == string::npos) {
+            if (s.find("*") == std::string::npos) {
                 if (value.empty()) {
                     value = s;
                 }
@@ -496,13 +493,13 @@ bool MvFlextraBlock::parseHeaderLine(const string& line, const string& key, stri
     return found;
 }
 
-bool MvFlextraBlock::parseHeaderLine(const string& line, const string& key, string& fromValue, string& toValue)
+bool MvFlextraBlock::parseHeaderLine(const std::string& line, const std::string& key, std::string& fromValue, std::string& toValue)
 {
     bool found = false;
-    string::size_type pos;
-    if ((pos = line.find(key)) != string::npos) {
-        stringstream sst(string(line, pos + key.size()));
-        string s;
+    std::string::size_type pos;
+    if ((pos = line.find(key)) != std::string::npos) {
+        std::istringstream sst(std::string(line, pos + key.size()));
+        std::string s;
         sst >> fromValue;
         sst >> s;
         sst >> toValue;
@@ -512,12 +509,12 @@ bool MvFlextraBlock::parseHeaderLine(const string& line, const string& key, stri
     return found;
 }
 
-bool MvFlextraBlock::isMetaDataConst(const string& key)
+bool MvFlextraBlock::isMetaDataConst(const std::string& key)
 {
     if (items_.size() == 0)
         return false;
 
-    string val = items_.at(0)->metaData(key);
+    std::string val = items_.at(0)->metaData(key);
     if (val.empty())
         return false;
 
@@ -532,24 +529,24 @@ bool MvFlextraBlock::isMetaDataConst(const string& key)
 
 void MvFlextraBlock::checkStepType()
 {
-    for (vector<MvFlextraItem*>::const_iterator it = items_.begin(); it != items_.end(); it++) {
-        const vector<vector<string> >& pts = (*it)->points();
+    for (auto item : items_) {
+        const std::vector<std::vector<std::string> >& pts = item->points();
 
         if (pts.size() < 3)
             continue;
 
-        istringstream iss0(pts.at(0).at(1));
+        std::istringstream iss0(pts.at(0).at(1));
         double first;
         iss0 >> first;
 
-        istringstream iss1(pts.at(1).at(1));
+        std::istringstream iss1(pts.at(1).at(1));
         double prev;
         iss1 >> prev;
 
         double diff   = prev - first;
         bool sameDiff = true;
-        for (unsigned int i = 2; i < (*it)->points().size() && i < 6; i++) {
-            istringstream iss((*it)->points().at(i).at(1));
+        for (unsigned int i = 2; i < item->points().size() && i < 6; i++) {
+            std::istringstream iss(item->points().at(i).at(1));
             double d;
             iss >> d;
 
@@ -579,7 +576,7 @@ void MvFlextraBlock::checkStepType()
 //
 //=========================================================
 
-MvFlextra::MvFlextra(const string& fileName) :
+MvFlextra::MvFlextra(const std::string& fileName) :
     fileName_(fileName)
 {
     decode();
@@ -587,20 +584,20 @@ MvFlextra::MvFlextra(const string& fileName) :
 
 MvFlextra::~MvFlextra()
 {
-    for (size_t i = 0; i < blocks_.size(); i++) {
-        delete blocks_[i];
+    for (auto& block : blocks_) {
+        delete block;
     }
 }
 
 
 void MvFlextra::decode()
 {
-    ifstream in(fileName_.c_str());
+    std::ifstream in(fileName_.c_str());
 
-    string line;
+    std::string line;
 
-    while (line.find("Number of header lines") != string::npos || getline(in, line)) {
-        MvFlextraBlock* data = new MvFlextraBlock;
+    while (line.find("Number of header lines") != std::string::npos || getline(in, line)) {
+        auto* data = new MvFlextraBlock;
         blocks_.push_back(data);
         data->decode(in, line);
     }
@@ -611,17 +608,17 @@ void MvFlextra::decode()
     //Guess if a trajectory block contains uncertainty trajecories or not!
     //It is working only if the FLEXTRA file containing several blocks was
     //generated by metview.
-    vector<pair<string, bool> > ref;
-    for (unsigned int i = 0; i < blocks_.size(); i++) {
-        string comment = blocks_[i]->comment();
-        bool cstep     = blocks_[i]->constantStep();
+    std::vector<std::pair<std::string, bool> > ref;
+    for (auto& block : blocks_) {
+        std::string comment = block->comment();
+        bool cstep          = block->constantStep();
 
-        pair<string, bool> p = make_pair(comment, cstep);
+        std::pair<std::string, bool> p = make_pair(comment, cstep);
 
         bool newRef = true;
-        for (unsigned int j = 0; j < ref.size(); j++) {
-            if (ref[j] == p) {
-                blocks_[i]->setUncertantyTr(true);
+        for (auto& j : ref) {
+            if (j == p) {
+                block->setUncertantyTr(true);
                 newRef = false;
                 break;
             }
@@ -634,8 +631,8 @@ void MvFlextra::decode()
 
 void MvFlextra::write(FILE* f)
 {
-    ifstream in(fileName_.c_str());
-    string line;
+    std::ifstream in(fileName_.c_str());
+    std::string line;
 
     while (getline(in, line)) {
         fputs(line.c_str(), f);
@@ -645,20 +642,20 @@ void MvFlextra::write(FILE* f)
 }
 
 
-void MvFlextra::write(const string& outFile, int block)
+void MvFlextra::write(const std::string& outFile, int block)
 {
     if (block < 0 || block >= static_cast<int>(blocks_.size()))
         return;
 
-    ofstream out;
+    std::ofstream out;
     out.open(outFile.c_str());
 
-    ifstream in(fileName_.c_str());
-    string line;
+    std::ifstream in(fileName_.c_str());
+    std::string line;
 
     int cnt = -1;
     while (getline(in, line)) {
-        if (line.find("Number of header lines") != string::npos) {
+        if (line.find("Number of header lines") != std::string::npos) {
             cnt++;
         }
 
@@ -666,7 +663,7 @@ void MvFlextra::write(const string& outFile, int block)
             break;
 
         if (cnt == block) {
-            out << line << endl;
+            out << line << std::endl;
         }
     }
 
