@@ -27,22 +27,41 @@
 // the precision with which we write geopoints values
 #define VALUE_PRECISION (10)
 
+std::vector<std::string> MvGeoPointColumnInfo::usedColNames() const
+{
+    // get the complete list of column names, and then remove those that
+    // are not actually used (possible: elevation)
+    std::vector<std::string> cnames(colNames_);
+    if (!hasElevations_) {
+        cnames.erase(std::remove_if(cnames.begin(), cnames.end(),
+                                    [](std::string colname) { return colname == "elevation"; }),
+                     cnames.end());
+    }
+    return cnames;
+}
 
-bool MvGeoPointColumnInfo::operator==(const MvGeoPointColumnInfo& in)
+std::vector<eGeoColType> MvGeoPointColumnInfo::usedColTypes() const
+{
+    // get the complete list of column types, and then remove those that
+    // are not actually used (possible: elevation)
+    std::vector<eGeoColType> ctypes(colTypes_);
+    if (!hasElevations_) {
+        ctypes.erase(std::remove_if(ctypes.begin(), ctypes.end(),
+                                    [](eGeoColType coltype) { return coltype == eGeoColElevation; }),
+                     ctypes.end());
+    }
+    return ctypes;
+}
+
+bool MvGeoPointColumnInfo::isCompatibleForMerging(const MvGeoPointColumnInfo& in)
 {
-    if (colNames_ != in.colNames_)
-        return false;
-    if (ncols_ != in.ncols_)
-        return false;
-    if (ncoordcols_ != in.ncoordcols_)
-        return false;
     if (nvalcols_ != in.nvalcols_)
         return false;
     if (nvalcolsforcompute_ != in.nvalcolsforcompute_)
         return false;
-    //if (hasStnIds_ != in.hasStnIds_)
-    //    return false;
-    if (colTypes_ != in.colTypes_)
+    if (usedColNames() != in.usedColNames())
+        return false;
+    if (usedColTypes() != in.usedColTypes())
         return false;
 
     return true;
