@@ -90,7 +90,6 @@ enum eGeoCopyMode
 class MvGeoPointColumnInfo
 {
 public:
-    bool operator==(const MvGeoPointColumnInfo& in);
     void ensureOnlyOneValueColumn();
 
     std::vector<std::string> colNames_;
@@ -101,6 +100,11 @@ public:
     bool hasStnIds_;
     bool hasElevations_;
     std::vector<eGeoColType> colTypes_;
+    bool isCompatibleForMerging(const MvGeoPointColumnInfo& in);
+
+private:
+    std::vector<std::string> usedColNames() const;
+    std::vector<eGeoColType> usedColTypes() const;
 };
 
 
@@ -382,7 +386,7 @@ public:
 
 
     //! Returns whether another geopoints variable is compatible with this one in terms of columns
-    bool isCompatible(const MvGeoPoints& in) { return colInfo_ == in.colInfo_; }
+    bool isCompatibleForMerging(const MvGeoPoints& in) { return colInfo_.isCompatibleForMerging(in.colInfo_);} //colInfo_ == in.colInfo_; }
 
 
     //! Returns index of the named value (e.g. 'temperature'), or -1 if it does not exist for this data
