@@ -16,12 +16,15 @@
 #include <string>
 #include <map>
 #include <vector>
+#include <memory>
 
 #include "mars.h"
 
 #include "MvLocation.h"
 #include "MvMatrix.h"
 
+using namespace metview;
+
 enum eGribHeaderType
 {
     GRIB_LONG = 0,
@@ -53,6 +56,8 @@ void nontested_eccodes_port(const char* msg);
 
 
 class MvGridBase;
+using MvGridPtr = std::shared_ptr<MvGridBase>;
+
 //! Function to create an instance of a suitable MvGrid object.
 MvGridBase* MvGridFactory(field* myfield,
                           bool memoryToBeReleased = true,
@@ -274,8 +279,8 @@ public:
         }
     }
 
-    void setAllValuesToMissing();
-    static void setAllValuesToMissing(field*);
+    void setAllValuesToMissing(bool flagBitmap=true);
+    static void setAllValuesToMissing(field*,bool flagBitmap=true);
 
     //! Returns the value of the \c i:th grid point
     double valueAt(int i) const;
@@ -325,23 +330,36 @@ public:
 
     virtual void boundingBox(std::vector<double>&) {}
 
+    static eGribHeaderType getNativeType(field* fld, const char* name);
     eGribHeaderType getNativeType(const char* name) const;
+    static long getLong(field* fld, const char* name, bool throwOnError = false, bool quiet = false);
     long getLong(const char* name, bool throwOnError = false, bool quiet = false) const;
+    static double getDouble(field* fld, const char* name, bool throwOnError = false, bool quiet = false);
     double getDouble(const char* name, bool throwOnError = false, bool quiet = false) const;
+    static std::string getString(field* fld,const char* name, bool throwOnError = false, bool quiet = false);
     std::string getString(const char* name, bool throwOnError = false, bool quiet = false) const;
 
+    static long getLongArray(field* fld, const char* name, long** lvals, bool throwOnError = false, bool quiet = false);
     long getLongArray(const char* name, long** lvals, bool throwOnError = false, bool quiet = false) const;
+    static long getDoubleArray(field* fld, const char* name, double** lvals, bool throwOnError = false, bool quiet = false);
     long getDoubleArray(const char* name, double** lvals, bool throwOnError = false, bool quiet = false) const;
 
-
+    static bool setLong(field* fld, const char* name, long val);
     bool setLong(const char* name, long val);
+    static bool setDouble(field* fld, const char* name, double val);
     bool setDouble(const char* name, double val);
+
+    static bool setString(field* fld, const char* name, std::string& val);
     bool setString(const char* name, std::string& val);
 
+    static double validityDateTime(field* fld);
+    double validityDateTime() const;
+
     long vertCoordCoefPairCount();
     bool vertCoordCoefs(double& C1, double& C2, int level);
 
     field* fieldPtr() { return field_; }
+    void  setForgetValuesOnDestroy(bool b) {forgetValuesOnDestroy_=b;}
 
 protected:
     virtual bool ScanModeCheck(double first, double last, double step) const;
@@ -360,6 +378,7 @@ protected:
     field_state oldState_;
     bool memoryToBeReleased_;
     bool restoreShapeOnDestroy_;
+    bool forgetValuesOnDestroy_{false};
 };
 
 //===================================================================
