@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvIconClassCore_H
-#define MvIconClassCore_H
+#pragma once
 
 #include <string>
 
@@ -50,7 +49,7 @@ public:
     //static bool isValid(const std::string& name);
     //static const MvIconClass& find(const std::string&);
     //static const MvIconClass& find(const std::string& name, const std::string& defaultType, bool);
-    //static void find(const std::string&, vector<const MvIconClass*>&, bool onlyCreatable = true);
+    //static void find(const std::string&, std::vector<const MvIconClass*>&, bool onlyCreatable = true);
     //static void load(request*);
 
     //static void scan(ClassScanner&);
@@ -63,5 +62,3 @@ private:
     MvIconClassCore(const MvIconClassCore&);
     MvIconClassCore& operator=(const MvIconClassCore&);
 };
-
-#endif // MvIconClassCore_H
