@@ -12,12 +12,13 @@
 #include "Path.h"
 #include "MvIconClassCore.h"
 #include "MvIconParameter.h"
+#include "MvLog.h"
 
-typedef map<string, MvIconLanguage*> Map;
+using Map = std::map<std::string, MvIconLanguage*>;
 static Map languages;
 
-static map<string, request*> lang_cache;
-static map<string, rule*> rule_cache;
+static std::map<std::string, request*> lang_cache;
+static std::map<std::string, rule*> rule_cache;
 
 MvIconLanguage::MvIconLanguage(const MvIconClassCore* c) :
     inited_(false),
@@ -48,7 +49,7 @@ const char* MvIconLanguage::getKind() const
 
 MvIconLanguage& MvIconLanguage::find(const MvIconClassCore* c)
 {
-    Map::iterator j = languages.find(c->name());
+    auto j = languages.find(c->name());
     if (j != languages.end())
         return *(*j).second;
     return *(new MvIconLanguage(c));
@@ -61,22 +62,22 @@ void MvIconLanguage::init()
 
     inited_ = true;
 
-    string langs                      = class_->definitionFile().str();
-    map<string, request*>::iterator j = lang_cache.find(langs);
+    std::string langs = class_->definitionFile().str();
+    auto j            = lang_cache.find(langs);
     if (j != lang_cache.end())
         lang_ = (*j).second;
     else {
-        //cout << "read " << langs << endl;
+        //std::cout << "read " << langs << std::endl;
         lang_             = read_language_file(langs.c_str());
         lang_cache[langs] = lang_;
     }
 
-    string rules                   = class_->rulesFile().str();
-    map<string, rule*>::iterator k = rule_cache.find(rules);
+    std::string rules = class_->rulesFile().str();
+    auto k            = rule_cache.find(rules);
     if (k != rule_cache.end())
         rule_ = (*k).second;
     else {
-        //cout << "read " << rules << endl;
+        //std::cout << "read " << rules << std::endl;
         rule_             = read_check_file(rules.c_str());
         rule_cache[rules] = rule_;
     }
@@ -120,7 +121,6 @@ Request MvIconLanguage::expand(const Request& r, long flags, bool ruleFlag)
 
     expand_flags(save);
 
-
     if (a == 0)
         return result;
 
@@ -133,13 +133,13 @@ Request MvIconLanguage::expand(const Request& r)
 }
 
 
-vector<string> MvIconLanguage::interfaces(const char* name)
+std::vector<std::string> MvIconLanguage::interfaces(const char* name)
 {
     init();
 
     // Need something a little bit more "C++"
 
-    vector<string> result;
+    std::vector<std::string> result;
     parameter* p = lang_->params;
     while (p) {
         if (p->interface) {
@@ -173,8 +173,8 @@ Request MvIconLanguage::interfaceRequest(const char* name)
 void MvIconLanguage::scan(MvIconLanguageScanner& s)
 {
     init();
-    for (vector<MvIconParameter*>::iterator j = params_.begin(); j != params_.end(); ++j)
-        s.next(*(*j));
+    for (auto& param : params_)
+        s.next(*param);
 }
 
 static value* find_values(const request* r, const char* parname)
@@ -187,7 +187,7 @@ static value* find_values(const request* r, const char* parname)
             p = p->next;
         }
     }
-    return NULL;
+    return nullptr;
 }
 
 MvIconLanguage::MvIconLanguage(const MvIconClassCore* c, const Request& def) :
@@ -196,8 +196,8 @@ MvIconLanguage::MvIconLanguage(const MvIconClassCore* c, const Request& def) :
     class_(c)
 {
     const char *name, *ui;
-    parameter *param, *lastparam = NULL;
-    value* val = NULL;
+    parameter *param, *lastparam = nullptr;
+    value* val = nullptr;
 
     const request* r = def;
 
@@ -208,7 +208,7 @@ MvIconLanguage::MvIconLanguage(const MvIconClassCore* c, const Request& def) :
         name = get_value(r, "name", 0);
         if (!name)
             break;
-        param                 = new_parameter(strcache(name), NULL);
+        param                 = new_parameter(strcache(name), nullptr);
         ui                    = r->name;
         val                   = find_values(r, "values");
         param->values         = clone_all_values(val);
