@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvIconParameter_H
-#define MvIconParameter_H
+#pragma once
 
 struct parameter;
 struct value;
@@ -43,18 +42,19 @@ public:
     const char* ribbon_control() const;
     const char* ribbon_separator() const;
     const char* ribbon_size_range() const;
+    bool hiddenInTemporary() const;
 
     Request interfaceRequest() const;
 
-    const string& beautifiedName(const string&) const;
-    const string& beautifiedName() const;
+    const std::string& beautifiedName(const std::string&) const;
+    const std::string& beautifiedName() const;
 
     void scan(ParameterScanner&) const;
 
     bool multiple() const;
     bool hasDefaults() const;
 
-    const vector<string>& defaults() const;
+    const std::vector<std::string>& defaults() const;
 
 private:
     // No copy allowed
@@ -66,11 +66,11 @@ private:
     parameter* param_;
     bool multiple_;
     bool beautify_;
-    map<string, string> beau_;
-    string name_;
-    vector<string> defaults_;
+    std::map<std::string, std::string> beau_;
+    std::string name_;
+    std::vector<std::string> defaults_;
 
-    const string& beautify(const string&) const;
+    const std::string& beautify(const std::string&) const;
     void scan(ParameterScanner&, const value*) const;
 };
 
@@ -80,5 +80,3 @@ inline void destroy(MvIconParameter**) {}
 //#ifdef _ODI_OSSG_
 //OS_MARK_SCHEMA_TYPE(Parameter);
 //#endif
-
-#endif
