@@ -8,7 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 #include "MvKeyCondition.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 MvKeyCondition* MvKeyCondition::make(const MvKeyConditionDefinition& condDef, MvVariant::Type type)
 {
@@ -17,8 +17,8 @@ MvKeyCondition* MvKeyCondition::make(const MvKeyConditionDefinition& condDef, Mv
 
     if (type == MvVariant::IntType) {
         std::vector<int> vals;
-        for (size_t i = 0; i < condDef.values_.size(); i++)
-            vals.push_back(metview::fromString<int>(condDef.values_[i]));
+        for (const auto& value : condDef.values_)
+            vals.push_back(metview::fromString<int>(value));
 
         std::vector<MvVariant> vv = MvVariant::makeVector(vals);
         return MvKeyCondition::make(condDef.oper_, condDef.key_, vv);
@@ -109,8 +109,8 @@ MvVariant::Type MvKeyValueCondition::type() const
 
 void MvKeyValueCondition::eval(const MvVariant& value)
 {
-    for (std::size_t i = 0; i < values_.size(); i++)
-        if (value == values_[i]) {
+    for (auto& i : values_)
+        if (value == i) {
             match_ = true;
             return;
         }
