@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVKEYCONDITION_H
-#define MVKEYCONDITION_H
+#pragma once
 
 #include <string>
 #include <vector>
@@ -50,15 +49,15 @@ public:
     virtual MvVariant::Type type() const = 0;
     const std::string& data() const { return data_; }
     void setData(const std::string& d) { data_ = d; }
-    void setCurrentKeyValue(MvVariant v) { currentKeyValue_ = v;}
-    MvVariant currentKeyValue() const {return currentKeyValue_;}
+    void setCurrentKeyValue(MvVariant v) { currentKeyValue_ = v; }
+    MvVariant currentKeyValue() const { return currentKeyValue_; }
 
     bool match() const { return match_; }
     bool check(const std::string& key, const MvVariant& value);
-    void reset() { match_ = false;}
+    void reset() { match_ = false; }
     virtual void eval(const MvVariant& value) = 0;
-    bool isEnabled() const {return enabled_;}
-    void setEnabled(bool b) {enabled_ = b;}
+    bool isEnabled() const { return enabled_; }
+    void setEnabled(bool b) { enabled_ = b; }
 
     static MvKeyCondition* make(const std::string& cond, const std::string& key, std::vector<MvVariant> v);
     static MvKeyCondition* make(const MvKeyConditionDefinition& condDef, MvVariant::Type type);
@@ -68,7 +67,7 @@ protected:
     bool match_;
     std::string data_;
     MvVariant currentKeyValue_;
-    bool enabled_ {true};
+    bool enabled_{true};
 };
 
 class MvKeyValueCondition : public MvKeyCondition
@@ -161,5 +160,3 @@ public:
 protected:
     void eval(const MvVariant& value);
 };
-
-#endif  // MVKEYCONDITION_H
