@@ -7,12 +7,15 @@
 
  ***************************** LICENSE END *************************************/
 
+#include "MvKeyManager.h"
+
+#include <fstream>
 #include <iostream>
 #include <sstream>
-#include <fstream>
-#include <cstdio>
+#include <string>
+
+#include "fstream_mars_fix.h"
 
-#include "MvKeyManager.h"
 #include "MvKeyProfile.h"
 
 /*key_.push_back(MvKey("count","Count",true));
@@ -36,33 +39,33 @@ MvKeyManager::~MvKeyManager()
 
 void MvKeyManager::clear()
 {
-    for (vector<MvKeyProfile*>::iterator it = begin(); it != end(); it++) {
-        delete (*it);
+    for (auto& it : *this) {
+        delete it;
     }
 
-    vector<MvKeyProfile*>::clear();
+    std::vector<MvKeyProfile*>::clear();
 }
 
-MvKeyProfile* MvKeyManager::addProfile(string name)
+MvKeyProfile* MvKeyManager::addProfile(std::string name)
 {
-    MvKeyProfile* profile = new MvKeyProfile(name);
+    auto* profile = new MvKeyProfile(name);
     push_back(profile);
     return profile;
 }
 
 void MvKeyManager::deleteProfile(int index)
 {
-    vector<MvKeyProfile*>::iterator it = begin() + index;
+    auto it = begin() + index;
     delete (*it);
     erase(it);
 }
 
 void MvKeyManager::loadProfiles()
 {
-    ifstream in(fprof_.c_str(), ifstream::in);
+    std::ifstream in(fprof_.c_str(), std::ifstream::in);
 
     if (!in) {
-        MvKeyProfile* prof = new MvKeyProfile("Metview default");
+        auto* prof = new MvKeyProfile("Metview default");
         push_back(prof);
 
         prof->addKey(new MvKey("count", "Index"));
@@ -79,15 +82,15 @@ void MvKeyManager::loadProfiles()
     else {
         //Create a deafult profile
         char c[256];
-        string name, sname;
+        std::string name, sname;
 
         MvKeyProfile* prof = nullptr;
         while (in.getline(c, 256)) {
-            //cout << c << endl;
+            //cout << c << std::endl;
 
-            string s = c;
+            std::string s = c;
 
-            if (s.find("#PROFILE") != string::npos) {
+            if (s.find("#PROFILE") != std::string::npos) {
                 in.getline(c, 256);
 
                 if (!prof) {
@@ -113,18 +116,15 @@ void MvKeyManager::loadProfiles()
 
 void MvKeyManager::saveProfiles()
 {
-    ofstream out(fprof_.c_str(), ofstream::out);
+    std::ofstream out(fprof_.c_str(), std::ofstream::out);
 
-    for (vector<MvKeyProfile*>::iterator it = begin(); it != end(); it++) {
-        MvKeyProfile* prof = *it;
-
-        out << "#PROFILE" << endl;
-        out << prof->name() << endl;
-        //out  << prof->size() << endl;
-        for (vector<MvKey*>::iterator it1 = prof->begin(); it1 != prof->end(); it1++) {
-            MvKey* key = *it1;
-            out << key->name() << endl;
-            out << key->shortName() << endl;
+    for (auto prof : *this) {
+        out << "#PROFILE" << std::endl;
+        out << prof->name() << std::endl;
+        //out  << prof->size() << std::endl;
+        for (auto key : *prof) {
+            out << key->name() << std::endl;
+            out << key->shortName() << std::endl;
         }
     }
 
