@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvKeyProfile_H
-#define MvKeyProfile_H
+#pragma once
 
 #include <iostream>
 #include <map>
@@ -17,13 +16,11 @@
 
 class MvVariant;
 
-using namespace std;
-
 class MvKey
 {
 public:
     MvKey();
-    MvKey(const string& name, const string& shortName, string description = string(""));
+    MvKey(const std::string& name, const std::string& shortName, std::string description = std::string(""));
     MvKey(const MvKey&);
 
     MvKey* clone();
@@ -63,36 +60,36 @@ public:
         FloatType,
         DoubleType
     };
-    void setValueType(ValueType, bool useMissingValue=false);
+    void setValueType(ValueType, bool useMissingValue = false);
     ValueType valueType() const { return valueType_; }
 
-    const string& shortName() const { return shortName_; }
-    const string& name() const { return name_; }
-    const map<string, string>& metaData() const { return metaData_; }
-    const string& metaData(const string&) const;
-    const string& description() const { return description_; }
+    const std::string& shortName() const { return shortName_; }
+    const std::string& name() const { return name_; }
+    const std::map<std::string, std::string>& metaData() const { return metaData_; }
+    const std::string& metaData(const std::string&) const;
+    const std::string& description() const { return description_; }
 
-    void setShortName(const string& s) { shortName_ = s; }
-    void setName(const string& s) { name_ = s; }
-    void setMetaData(const string&, const string&);
-    void setDescription(const string& d) { description_ = d; }
+    void setShortName(const std::string& s) { shortName_ = s; }
+    void setName(const std::string& s) { name_ = s; }
+    void setMetaData(const std::string&, const std::string&);
+    void setDescription(const std::string& d) { description_ = d; }
 
     int valuePrecision() const { return precision_; }
     void setValuePrecision(int p) { precision_ = p; }
 
     //TODO: refactor the usage of the "value" functions
-    void addValue(const string& v) { addStringValue(v); }
-    const vector<string>& value() const { return stringVal_; }
-    void setValue(int idx, const string& v) { setStringValue(idx, v); }
+    void addValue(const std::string& v) { addStringValue(v); }
+    const std::vector<std::string>& value() const { return stringVal_; }
+    void setValue(int idx, const std::string& v) { setStringValue(idx, v); }
     std::string valueAsString(int idx) const;
 
-    void addStringValue(const string&);
-    const vector<string>& stringValue() const { return stringVal_; }
-    const string& stringConstantValue() const;
-    void setStringValue(int, const string&);
+    void addStringValue(const std::string&);
+    const std::vector<std::string>& stringValue() const { return stringVal_; }
+    const std::string& stringConstantValue() const;
+    void setStringValue(int, const std::string&);
 
     void addIntValue(int);
-    const vector<int>& intValue() const { return intVal_; }
+    const std::vector<int>& intValue() const { return intVal_; }
     int intConstantValue() const;
     void setIntValue(int, int);
     void setIntRange(int, int);
@@ -104,7 +101,7 @@ public:
     int intMissingValue() const { return intMissingVal_; }
 
     void addLongValue(long);
-    const vector<long>& longValue() const { return longVal_; }
+    const std::vector<long>& longValue() const { return longVal_; }
     long longConstantValue() const;
     void setLongValue(int, long);
     void setLongRange(long, long);
@@ -116,7 +113,7 @@ public:
     long longMissingValue() const { return longMissingVal_; }
 
     void addDoubleValue(double);
-    const vector<double>& doubleValue() const { return doubleVal_; }
+    const std::vector<double>& doubleValue() const { return doubleVal_; }
     double doubleConstantValue() const;
     void setDoubleValue(int, double);
     void setDoubleMissingValue(double v)
@@ -133,7 +130,7 @@ public:
     void clearMetaData();
     void clearData();
 
-    //const map<string,int>& counter() const {return counter_;}
+    //const std::map<std::string,int>& counter() const {return counter_;}
 
     bool readIntAsString() const { return readIntAsString_; }
     void setReadIntAsString(bool b) { readIntAsString_ = b; }
@@ -148,38 +145,38 @@ public:
     bool operator!=(const MvKey&) const;
 
 protected:
-    void addToCounter(const string&);
+    void addToCounter(const std::string&);
 
-    string name_;
-    string shortName_;
-    string description_;
-    map<string, string> metaData_;
+    std::string name_;
+    std::string shortName_;
+    std::string description_;
+    std::map<std::string, std::string> metaData_;
 
     Role role_;
     KeyType keyType_;
     int precision_;
     ValueType valueType_;
     bool constant_;
-    vector<string> stringVal_;
-    vector<int> intVal_;
-    vector<long> longVal_;
-    vector<float> floatVal_;
-    vector<double> doubleVal_;
+    std::vector<std::string> stringVal_;
+    std::vector<int> intVal_;
+    std::vector<long> longVal_;
+    std::vector<float> floatVal_;
+    std::vector<double> doubleVal_;
     int intMissingVal_;
     long longMissingVal_;
     float floatMissingVal_;
     double doubleMissingVal_;
     bool missingValDefined_;
 
-    //map<string,int> counter_;
+    //std::map<std::string,int> counter_;
     bool readIntAsString_;
     bool editable_;  //if false only shortname is editable
 };
 
-class MvKeyProfile : public vector<MvKey*>
+class MvKeyProfile : public std::vector<MvKey*>
 {
 public:
-    MvKeyProfile(string n) :
+    MvKeyProfile(std::string n) :
         name_(n),
         systemProfile_(false) {}
     MvKeyProfile(const MvKeyProfile&);
@@ -193,12 +190,12 @@ public:
     void deleteKey(int);
     void swap(int, int);
     void reposition(int, int);
-    void reposition(const vector<int>&);
-    MvKey* key(string) const;
+    void reposition(const std::vector<int>&);
+    MvKey* key(std::string) const;
     MvKey* key(MvKey::Role role) const;
     MvKey* key(MvKey::Role role, int occurence) const;
-    string name() { return name_; }
-    void setName(string n) { name_ = n; }
+    std::string name() { return name_; }
+    void setName(std::string n) { name_ = n; }
     int valueNum(int);
     int valueNum() const;
     void clearKeyData();
@@ -210,18 +207,16 @@ public:
     void preAllocate(int);
     void setValuesInChunk(int chunkStart, int chunkSize, MvKeyProfile* prof);
 
-    const string& metaData(const string&) const;
-    void setMetaData(const string&, const string&);
+    const std::string& metaData(const std::string&) const;
+    void setMetaData(const std::string&, const std::string&);
     void clearMetaData();
 
     bool operator==(const MvKeyProfile&) const;
     bool operator!=(const MvKeyProfile&) const;
 
 private:
-    string name_;
+    std::string name_;
     bool systemProfile_;
     std::vector<int> errorRows_;
-    map<string, string> metaData_;
+    std::map<std::string, std::string> metaData_;
 };
-
-#endif
