@@ -19,12 +19,7 @@ MvMatrix::MvMatrix(int nlin, int ncol) :
     vec_.resize(nlin * ncol);
 }
 
-MvMatrix::MvMatrix(const MvMatrix& m) :
-    nlin_(m.nlin_),
-    ncol_(m.ncol_),
-    vec_(m.vec_)
-{
-}
+MvMatrix::MvMatrix(const MvMatrix& m) = default;
 
 void MvMatrix::operator=(const MvMatrix& m)
 {
