@@ -186,6 +186,12 @@ MvNcValues::~MvNcValues()
         case NC_INT:
             delete[](int*) values_;
             break;
+        case NC_UINT:
+            delete[](unsigned int*) values_;
+            break;
+        case NC_INT64:
+            delete[](long *) values_;
+            break;
         case NC_FLOAT:
             delete[](float*) values_;
             break;
@@ -251,6 +257,27 @@ int MvNcValues::as_int(long n) const
     }
 }
 
+unsigned int MvNcValues::as_uint(long n) const
+{
+    switch (type_) {
+        case NC_UINT:
+            return *((unsigned int*)values_ + n);
+        default:
+            return 0;
+    }
+}
+
+long MvNcValues::as_int64(long n) const
+{
+    switch (type_) {
+        case NC_INT64:
+            return *((long*)values_ + n);
+        default:
+            return 0;
+    }
+}
+
+
 float MvNcValues::as_float(long n) const
 {
     switch (type_) {
@@ -278,6 +305,8 @@ double MvNcValues::as_double(long n) const
             return (double)(*((ushort*)values_ + n));
         case NC_INT:
             return (double)(*((int*)values_ + n));
+        case NC_UINT:
+            return (double)(*((unsigned int*)values_ + n));
         case NC_FLOAT:
             return (double)(*((float*)values_ + n));
         case NC_DOUBLE:
@@ -333,7 +362,16 @@ int MvNcValues::allocateMemory()
             values_ = (void*)vint_;
             break;
         }
-            //      case NC_LONG:
+        case NC_UINT: {
+            vuint_   = new unsigned int[nvalues_];
+            values_ = (void*)vuint_;
+            break;
+        }            //      case NC_LONG:
+        case NC_INT64: {
+            vint64_   = new long[nvalues_];
+            values_ = (void*)vint64_;
+            break;
+        }
             //         vlong_ = new long[nvalues_];
             //         values_ = vlong_;
             //         break;
@@ -484,6 +522,14 @@ std::string MvNcAtt::as_string(long n)
             oss << values()->as_int(n);
             return oss.str();
         }
+        case NC_UINT: {
+            oss << values()->as_uint(n);
+            return oss.str();
+        }
+        case NC_INT64: {
+            oss << values()->as_int64(n);
+            return oss.str();
+        }
         case NC_BYTE: {
             oss << values()->as_char(n);
             return oss.str();
@@ -1606,7 +1652,13 @@ missing values for -32766, while NC_FILL_SHORT=-32767, and SHRT_MIN=-32768 */
      NC_FILL_DOUBLE}, /* NC_DOUBLE, double precision floating point number */
     {0xffff, 0,
      NC_FILL_USHORT}, /* NC_USHORT,  unsigned 2 byte integer */
-};
+    {0xfffffff, 0,
+     NC_FILL_UINT}, /* NC_UINT,  unsigned 4 byte integer */
+    {0xfffffff, 0,
+     NC_FILL_UINT}, /* NC_INT64,  signed 8 byte integer */};
+
+// note: fillvalue for NC_INT64 should be NC_FILL_INT64 but this does not fit into a double.
+// this is ok for now, because we only need this type for attributes rather than data
 
 //--------------------------------------------------------------
 // MvNetCDFBehaviour
