@@ -46,6 +46,8 @@
 #define ncFloat NC_FLOAT    // 5
 #define ncDouble NC_DOUBLE  // 6
 #define ncUShort NC_USHORT  // 8
+#define ncUInt NC_UINT      // 9
+#define ncInt64 NC_INT64    // 10
 //------------------------------------------------------------
 
 typedef int NcBool;
@@ -189,6 +191,8 @@ public:
     short as_short(long) const;
     ushort as_ushort(long) const;
     int as_int(long) const;
+    unsigned int as_uint(long) const;
+    long as_int64(long n) const;
     float as_float(long) const;
     double as_double(long) const;
     std::string as_string(long) const;
@@ -219,6 +223,8 @@ private:
     short* vshort_;
     ushort* vushort_;
     int* vint_;
+    unsigned int* vuint_;
+    long *vint64_;
     //   long* vlong_;
     float* vfloat_;
     double* vdouble_;
@@ -888,7 +894,7 @@ private:
 
 #endif
 
-#define NC_TYPES 9
+#define NC_TYPES 11
     struct nc_types_values
     {
         double nc_type_max;
