@@ -8,17 +8,16 @@
  ***************************** LICENSE END *************************************/
 
 #include <stdlib.h>
+
+#include <cstring>
 #include <fstream>
-#include <sstream>
 #include <iostream>
 
+#include "fstream_mars_fix.h"
+
 #include "MvApplication.h"
 #include "MvNetwork.h"
 
-
-using std::cout;
-using std::endl;
-
 // 7.21.0
 #define MINCURLVERSIONFORWILDCARD 0x071500
 
@@ -49,7 +48,7 @@ void MvNetworkData::clear()
 
 size_t MvNetworkData::add(char* ptr, size_t size)
 {
-    if (buffer_ == NULL) {
+    if (buffer_ == nullptr) {
         pos_    = 0;
         len_    = initialSize_;
         buffer_ = static_cast<char*>(malloc(len_));
@@ -67,18 +66,18 @@ size_t MvNetworkData::add(char* ptr, size_t size)
         }
     }
 
-    memcpy(buffer_ + pos_, ptr, size);
+    std::memcpy(buffer_ + pos_, ptr, size);
     pos_ += size;
 
     return size;
 }
 
-string MvNetworkData::toString()
+std::string MvNetworkData::toString()
 {
     if (buffer_ && len_ > 0) {
-        return string(buffer_) + '\0';
+        return std::string(buffer_) + '\0';
     }
-    return string();
+    return std::string();
 }
 
 
@@ -122,7 +121,7 @@ void MvNetwork::setupProxy()
 
     bool use             = false;
     const char* useProxy = myPref("USE_NETWORK_PROXY");
-    if ((useProxy != NULL))
+    if ((useProxy != nullptr))
         use = (strcmp(useProxy, "Yes") == 0 ||
                strcmp(useProxy, "YES") == 0 ||
                strcmp(useProxy, "yes") == 0)
@@ -134,16 +133,16 @@ void MvNetwork::setupProxy()
         const char* proxyUrl = myPref("PROXY_URL");
         if (proxyUrl) {
             curl_easy_setopt(ch_, CURLOPT_PROXY, proxyUrl);
-            cout << "Using user proxy URL: " << proxyUrl << std::endl;
+            std::cout << "Using user proxy URL: " << proxyUrl << std::endl;
         }
 #else
-        cout << "Curl version is not new enough to support CURLOPT_PROXY - proxy setting not applied." << std::endl;
+        std::cout << "Curl version is not new enough to support CURLOPT_PROXY - proxy setting not applied." << std::endl;
 #endif
 
         const char* proxyPort = myPref("PROXY_PORT");
         if (proxyPort) {
             curl_easy_setopt(ch_, CURLOPT_PROXYPORT, atoi(proxyPort));
-            cout << "Using user proxy port: " << proxyPort << std::endl;
+            std::cout << "Using user proxy port: " << proxyPort << std::endl;
         }
 
 
@@ -151,16 +150,16 @@ void MvNetwork::setupProxy()
         const char* noProxy = myPref("NO_PROXY_FOR");  // comma-separated list
         if (noProxy) {
             curl_easy_setopt(ch_, CURLOPT_NOPROXY, noProxy);
-            cout << "Using user no_proxy: " << noProxy << std::endl;
+            std::cout << "Using user no_proxy: " << noProxy << std::endl;
         }
 #else
-        cout << "Curl version is not new enough to support CURLOPT_NOPROXY - no_proxy setting not applied." << std::endl;
+        std::cout << "Curl version is not new enough to support CURLOPT_NOPROXY - no_proxy setting not applied." << std::endl;
 #endif
     }
 }
 
 
-bool MvNetwork::get(const string& req, const string& outfile, const string mimeType, string& errorMsg)
+bool MvNetwork::get(const std::string& req, const std::string& outfile, const std::string /*mimeType*/, std::string& errorMsg)
 {
     curl_easy_setopt(ch_, CURLOPT_URL, req.c_str());
 
@@ -172,7 +171,7 @@ bool MvNetwork::get(const string& req, const string& outfile, const string mimeT
         return false;
     }
 
-    cout << "data size " << data_.len_ << endl;
+    std::cout << "data size " << data_.len_ << std::endl;
 
     if (data_.len_ == 0) {
         errorMsg = "No bytes received.";
@@ -190,7 +189,7 @@ bool MvNetwork::get(const string& req, const string& outfile, const string mimeT
     if (out.good()) {
         out.write(data_.buffer_, data_.pos_);
         out.close();
-        cout << "outfile " << outfile << endl;
+        std::cout << "outfile " << outfile << std::endl;
     }
     else {
         errorMsg = "Could not open file for writing: " + outfile;
@@ -201,7 +200,7 @@ bool MvNetwork::get(const string& req, const string& outfile, const string mimeT
     // in case CURL did anything to change the URL...
     const char* usedUrl;
     curl_easy_getinfo(ch_, CURLINFO_EFFECTIVE_URL, &usedUrl);
-    cout << "Used URL: " << usedUrl << endl;
+    std::cout << "Used URL: " << usedUrl << std::endl;
 
     data_.clear();  // clear the data buffer
     return true;
@@ -209,11 +208,11 @@ bool MvNetwork::get(const string& req, const string& outfile, const string mimeT
 
 size_t MvNetwork::writeCb(char* ptr, size_t size, size_t nmemb, void* userdata)
 {
-    //cout << "writeCB " << size*nmemb <<  endl;
+    //std::cout << "writeCB " << size*nmemb <<  std::endl;
     if (!userdata)
         return 0;
 
-    if (MvNetwork* obj = static_cast<MvNetwork*>(userdata)) {
+    if (auto* obj = static_cast<MvNetwork*>(userdata)) {
         return obj->data_.add(ptr, size * nmemb);
     }
 
@@ -225,7 +224,7 @@ size_t MvNetwork::headerCb(char* ptr, size_t size, size_t nmemb, void* userdata)
     if (!userdata)
         return 0;
 
-    if (MvNetwork* obj = static_cast<MvNetwork*>(userdata)) {
+    if (auto* obj = static_cast<MvNetwork*>(userdata)) {
         return obj->header_.add(ptr, size * nmemb);
     }
 
