@@ -7,13 +7,11 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVNETWORK_H
-#define MVNETWORK_H
+#pragma once
 
+#include <string>
 
-#include <string.h>
 #include <curl/curl.h>  // needed because we use the CURL type in MvNetwork
-using std::string;
 
 
 // ----------------------------------------------------------------------------
@@ -34,7 +32,7 @@ public:
     void clear();
 
     size_t add(char* ptr, size_t size);
-    string toString();
+    std::string toString();
 
     char* buffer_;
     size_t pos_;
@@ -52,8 +50,8 @@ class MvNetwork
 {
 public:
     MvNetwork();
-    bool get(const string&, const string&, const string, string&);
-    string header() { return header_.toString(); }
+    bool get(const std::string&, const std::string&, const std::string, std::string&);
+    std::string header() { return header_.toString(); }
     long responseCode() { return responseCode_; }
 
 protected:
@@ -66,6 +64,3 @@ protected:
     MvNetworkData header_;
     long responseCode_;
 };
-
-
-#endif  //MVNETWORK_H
