@@ -1547,6 +1547,46 @@ int MvObs::WmoStationNumber() {
     return myValue == kBufrMissingIntValue ? 0 : (int)myValue;
 }
 
+//____________________________________________________________ findSomeIdent
+std::string MvObs::findSomeIdent()
+{
+    //-- 5-digit WMO identifier available?
+    long lid = WmoIdentNumber();
+    if (lid > 0) {
+        std::ostringstream oss;
+        oss << std::setw(5) << std::setfill('0') << lid;
+        return oss.str();
+    }
+
+    //-- No WMO id found, thus look for other candidates,
+    //-- this is a list of known identifier candidates.
+    const std::string idList[] =
+        {
+            "shipOrMobileLandStationIdentifier",                // 1011
+            "buoyOrPlatformIdentifier",                         // 1005
+            "aircraftFlightNumber",                             // 1006
+            "satelliteIdentifier",                              // 1007
+            "aircraftRegistrationNumberOrOtherIdentification",  // 1008
+            "stationaryBuoyPlatformIdentifierEGCManBuoys",      // 1010
+            "stormIdentifier",                                  // 1025
+            "stormName",                                        // 1026
+            "longStormName"                                     // 1027
+        };
+
+    int idVals = sizeof(idList) / sizeof(idList[0]);
+    for (int i = 0; i < idVals; ++i) {
+        std::string descr = idList[i];
+        long myValue      = intValue(descr);
+        if (myValue != kBufrMissingIntValue) {
+            std::ostringstream oss;
+            oss << std::setw(5) << std::setfill('0') << myValue;
+            return oss.str();
+        }
+    }
+
+    return std::string("id???");
+}
+
 int MvObs::wigosSeries()
 {
     auto v = intValue("wigosIdentifierSeries");
@@ -1767,6 +1807,9 @@ const std::string& MvObs::headerIdent() {
     return headerIdent_;
 }
 
+
+
+
 //_________________________________________________________________ msgTime
 TDynamicTime MvObs::msgTime() {
     // Get values from the Header
