@@ -7,13 +7,13 @@
 
  ***************************** LICENSE END *************************************/
 
-#include <math.h>
-#include <sstream>
-#include <fstream>
-#include <cstdio>
 #include <MvOdb.h>
 
-using namespace std;
+#include <math.h>
+
+#include <sstream>
+#include <map>
+#include <cstdio>
 
 #include <odc/Reader.h>
 #include <odc/Writer.h>
@@ -22,9 +22,6 @@ using namespace std;
 #include <odc/api/ColumnType.h>
 
 
-//using namespace odb;
-
-
 //This include must come after the oda includes, otherwise
 //compilation fails!!
 #include "MvScanFileType.h"
@@ -32,15 +29,15 @@ using namespace std;
 //const int intMissingValue   = -2147480000;
 const int floatMissingValue = -2.14748e+09;
 
-static map<odc::api::ColumnType, MvOdbColumn::OdbColumnType> typeMap;
+static std::map<odc::api::ColumnType, MvOdbColumn::OdbColumnType> typeMap;
 
-void MvOdbColumn::setName(string s)
+void MvOdbColumn::setName(std::string s)
 {
     name_ = s;
 
     shortName_      = name_;
     std::size_t pos = name_.find("@");
-    if (pos != string::npos) {
+    if (pos != std::string::npos) {
         shortName_ = name_.substr(0, pos);
     }
 }
@@ -62,7 +59,7 @@ void MvOdbColumn::addToStats(float val)
     std_ += val * val;
 }
 
-void MvOdbColumn::addToStats(double val)
+void MvOdbColumn::addToStats(double)
 {
 }
 
@@ -114,7 +111,7 @@ int MvOdbColumn::rowNum() const
 //
 //=============================
 
-MvAbstractOdb::MvAbstractOdb(string path, string sourcePath, string query, OdbVersion version) :
+MvAbstractOdb::MvAbstractOdb(std::string path, std::string sourcePath, std::string query, OdbVersion version) :
     path_(path),
     sourcePath_(sourcePath),
     query_(query),
@@ -126,7 +123,7 @@ MvAbstractOdb::MvAbstractOdb(string path, string sourcePath, string query, OdbVe
     //init();
 }
 
-MvAbstractOdb::MvAbstractOdb(string path, OdbVersion version) :
+MvAbstractOdb::MvAbstractOdb(std::string path, OdbVersion version) :
     path_(path),
     version_(version)
 {
@@ -135,8 +132,8 @@ MvAbstractOdb::MvAbstractOdb(string path, OdbVersion version) :
 
 MvAbstractOdb::~MvAbstractOdb()
 {
-    for (vector<MvOdbColumn*>::iterator it = column_.begin(); it != column_.end(); it++) {
-        delete *it;
+    for (auto& it : column_) {
+        delete it;
     }
 }
 
@@ -155,7 +152,6 @@ void MvAbstractOdb::detectOdbVersion()
         case S_IFDIR:
             version_ = VersionOld;
             break;
-            ;
 
         case S_IFREG:
             if (ScanFileType(fname) == "ODB_DB")
@@ -178,21 +174,19 @@ void MvAbstractOdb::detectOdbVersion()
 
 #ifdef METVIEW_ODB_NEW
 
-MvOdb::MvOdb(string path, string sourcePath, string query) :
+MvOdb::MvOdb(std::string path, std::string sourcePath, std::string query) :
     MvAbstractOdb(path, sourcePath, query, VersionNew)
 {
     init();
 }
 
-MvOdb::MvOdb(string path) :
+MvOdb::MvOdb(std::string path) :
     MvAbstractOdb(path, VersionNew)
 {
     init();
 }
 
-MvOdb::~MvOdb()
-{
-}
+MvOdb::~MvOdb() = default;
 
 void MvOdb::init()
 {
@@ -220,7 +214,7 @@ void MvOdb::readMetaData()
     if (headerIsRead_)
         return;
 
-    //string SELECT  = "select * from \"" + path_ + "\";";
+    //std::string SELECT  = "select * from \"" + path_ + "\";";
 
     //ODA oda("");
     odc::Reader oda(path_);
@@ -237,27 +231,27 @@ void MvOdb::readMetaData()
 
     //size_t n = beg.columns().size();
 
-    for (odc::core::MetaData::const_iterator it = beg->columns().begin(); it != beg->columns().end(); ++it) {
-        MvOdbColumn* acol = new MvOdbColumn;
+    for (auto it : beg->columns()) {
+        auto* acol = new MvOdbColumn;
 
         //if(rowNum_==0)
         //	rowNum_=(*it)->noRows();
 
-        string s = (*it)->name();
+        std::string s = it->name();
 
-        //cout << s << endl;
+        //std::cout << s << std::endl;
 
         acol->setName(s);
-        if (typeMap.find((*it)->type()) != typeMap.end()) {
-            acol->setType(typeMap[(*it)->type()]);
+        if (typeMap.find(it->type()) != typeMap.end()) {
+            acol->setType(typeMap[it->type()]);
         }
 
 
         if (acol->type() == MvOdbColumn::Bitfield) {
             int pos = 0;
-            for (unsigned int i = 0; i < (*it)->bitfieldDef().first.size(); i++) {
-                string name = (*it)->bitfieldDef().first.at(i);
-                int size    = (*it)->bitfieldDef().second.at(i);
+            for (unsigned int i = 0; i < it->bitfieldDef().first.size(); i++) {
+                std::string name = it->bitfieldDef().first.at(i);
+                int size         = it->bitfieldDef().second.at(i);
                 acol->addBitfieldMember(new MvOdbBitfieldMember(name, pos, size));
                 pos += size;
             }
@@ -294,9 +288,9 @@ void MvOdb::readMetaData()
 	for(int col=0; col < column_.size(); col++)
 	{
 		column_[col]->compStats();
-		cout << column_[col]->name() << " " << column_[col]->type() << endl;
-		cout << " " << column_[col]->min() << " " <<  column_[col]->max() << " " <<
-                column_[col]->avg() << " " << column_[col]->std() << endl;
+		std::cout << column_[col]->name() << " " << column_[col]->type() << std::endl;
+		std::cout << " " << column_[col]->min() << " " <<  column_[col]->max() << " " <<
+                column_[col]->avg() << " " << column_[col]->std() << std::endl;
 	}*/
 
     headerIsRead_ = true;
@@ -330,17 +324,17 @@ int MvOdb::totalSizeInMb()
 
     float totalSize = 0.;
 
-    for (unsigned int i = 0; i < column_.size(); i++) {
-        if (column_[i]->type() == MvOdbColumn::Int) {
+    for (auto& i : column_) {
+        if (i->type() == MvOdbColumn::Int) {
             totalSize += (rowNum * intSize) / mb;
         }
-        else if (column_[i]->type() == MvOdbColumn::Float) {
+        else if (i->type() == MvOdbColumn::Float) {
             totalSize += (rowNum * floatSize) / mb;
         }
-        else if (column_[i]->type() == MvOdbColumn::Double) {
+        else if (i->type() == MvOdbColumn::Double) {
             totalSize += (rowNum * doubleSize) / mb;
         }
-        else if (column_[i]->type() == MvOdbColumn::String) {
+        else if (i->type() == MvOdbColumn::String) {
             totalSize += (rowNum * 8) / mb;
         }
         else {
@@ -357,9 +351,9 @@ int MvOdb::rowNum()
         return rowNum_;
 
     readMetaData();
-    for (unsigned int i = 0; i < column_.size(); i++) {
-        if (column_[i]->isLoaded()) {
-            return column_[i]->rowNum();
+    for (auto& i : column_) {
+        if (i->isLoaded()) {
+            return i->rowNum();
         }
     }
 
@@ -385,13 +379,13 @@ int MvOdb::columnNum()
     return column_.size();
 }
 
-const vector<MvOdbColumn*>& MvOdb::columns()
+const std::vector<MvOdbColumn*>& MvOdb::columns()
 {
     readMetaData();
     return column_;
 }
 
-int MvOdb::findColumn(string cname)
+int MvOdb::findColumn(std::string cname)
 {
     readMetaData();
     for (unsigned int i = 0; i < column_.size(); i++) {
@@ -403,28 +397,28 @@ int MvOdb::findColumn(string cname)
     return -1;
 }
 
-bool MvOdb::hasColumn(const string& cname)
+bool MvOdb::hasColumn(const std::string& cname)
 {
     readMetaData();
 
     //We try with the full column name
-    for (unsigned int i = 0; i < column_.size(); i++) {
-        if (cname == column_[i]->name()) {
+    for (auto& i : column_) {
+        if (cname == i->name()) {
             return true;
         }
     }
 
     //If there is no match we try without the @tablename suffix
 
-    string shortName = cname;
-    std::size_t pos  = cname.find("@");
-    if (pos != string::npos) {
+    std::string shortName = cname;
+    std::size_t pos       = cname.find("@");
+    if (pos != std::string::npos) {
         shortName = cname.substr(0, pos);
     }
 
     //We try with the full column name
-    for (unsigned int i = 0; i < column_.size(); i++) {
-        if (shortName == column_[i]->shortName()) {
+    for (auto& i : column_) {
+        if (shortName == i->shortName()) {
             return true;
         }
     }
@@ -447,7 +441,7 @@ const MvOdbColumn* MvOdb::loadColumn(int pos, bool reload)
         return column_[pos];
     }
 
-    string sval;
+    std::string sval;
 
     odc::Reader oda(path_);
 
@@ -514,7 +508,7 @@ const MvOdbColumn* MvOdb::loadColumn(int pos, bool reload)
     return column_[pos];
 }
 
-const MvOdbColumn* MvOdb::loadColumn(string cname, bool reload)
+const MvOdbColumn* MvOdb::loadColumn(std::string cname, bool reload)
 {
     int colPos = findColumn(cname);
     return loadColumn(colPos, reload);
@@ -530,7 +524,7 @@ void MvOdb::unloadColumn(int pos)
     column_[pos]->unload();
 }
 
-void MvOdb::unloadColumn(string cname)
+void MvOdb::unloadColumn(std::string cname)
 {
     int colPos = findColumn(cname);
     unloadColumn(colPos);
@@ -542,7 +536,7 @@ void MvOdb::loadAllColumns()
 
     unloadAllColumns();
 
-    string sval;
+    std::string sval;
 
     odc::Reader oda(path_);
 
@@ -593,16 +587,16 @@ void MvOdb::loadAllColumns()
         }
     }
 
-    for (int pos = 0; pos < static_cast<int>(column_.size()); pos++)
-        column_[pos]->setLoaded(true);
+    for (auto& pos : column_)
+        pos->setLoaded(true);
 }
 
 void MvOdb::unloadAllColumns()
 {
     readMetaData();
 
-    for (int pos = 0; pos < static_cast<int>(column_.size()); pos++)
-        column_[pos]->unload();
+    for (auto& pos : column_)
+        pos->unload();
 }
 
 
@@ -616,7 +610,7 @@ const MvOdbColumn* MvOdb::column(int pos)
     return column_[pos];
 }
 
-const MvOdbColumn* MvOdb::column(string cname)
+const MvOdbColumn* MvOdb::column(std::string cname)
 {
     int colPos = findColumn(cname);
     return column(colPos);
@@ -656,18 +650,18 @@ void MvOdb::setChunkSize(int chunkSize)
     }
 }
 
-bool MvOdb::retrieveToFile(string query, string inFile, string outFile)
+bool MvOdb::retrieveToFile(std::string query, std::string inFile, std::string outFile)
 {
     //odb_start();
 
-    string SELECT;
+    std::string SELECT;
 
     //Find "where" statement in query
     std::string wd = query;
     std::transform(wd.begin(), wd.end(), wd.begin(), ::tolower);
 
-    string::size_type wherePos = wd.find("where");
-    if (wherePos != string::npos) {
+    std::string::size_type wherePos = wd.find("where");
+    if (wherePos != std::string::npos) {
         SELECT = query.substr(0, wherePos) + " " +
                  " from \"" + inFile + "\"" +
                  query.substr(wherePos) + ";";
@@ -676,7 +670,7 @@ bool MvOdb::retrieveToFile(string query, string inFile, string outFile)
         SELECT = query + " from \"" + inFile + "\";";
     }
 
-    //cout << "Select: " << SELECT << endl;
+    //std::cout << "Select: " << SELECT << std::endl;
 
     odc::Writer<> writer(outFile);
     odc::Writer<>::iterator outit = writer.begin();
@@ -694,9 +688,9 @@ bool MvOdb::retrieveToFile(string query, string inFile, string outFile)
     return true;
 }
 
-bool MvOdb::toGeopoints(string outFile, string geoType)
+bool MvOdb::toGeopoints(std::string outFile, std::string geoType)
 {
-    map<string, unsigned int> colNumForGeoType;
+    std::map<std::string, unsigned int> colNumForGeoType;
     colNumForGeoType["GEO_STANDARD"]  = 6;
     colNumForGeoType["GEO_XYV"]       = 3;
     colNumForGeoType["GEO_XY_VECTOR"] = 7;
@@ -715,9 +709,9 @@ bool MvOdb::toGeopoints(string outFile, string geoType)
     odc::Reader::iterator it = oda.begin();
 
     //Columns
-    vector<string> colName;
-    for (odc::core::MetaData::const_iterator itc = it->columns().begin(); itc != it->columns().end(); ++itc) {
-        string s = (*itc)->name();
+    std::vector<std::string> colName;
+    for (auto itc : it->columns()) {
+        std::string s = itc->name();
         colName.push_back(s);
     }
 
@@ -888,13 +882,13 @@ bool MvOdb::toGeopoints(string outFile, string geoType)
 
 #ifdef METVIEW_ODB_OLD
 
-MvOldOdb::MvOldOdb(string path, string sourcePath, string query) :
+MvOldOdb::MvOldOdb(std::string path, std::string sourcePath, std::string query) :
     MvAbstractOdb(path, sourcePath, query, VersionOld)
 {
     init();
 }
 
-MvOldOdb::MvOldOdb(string path) :
+MvOldOdb::MvOldOdb(std::string path) :
     MvAbstractOdb(path, VersionOld)
 {
     init();
@@ -932,13 +926,13 @@ int MvOldOdb::columnNum()
     return column_.size();
 }
 
-const vector<MvOdbColumn*>& MvOldOdb::columns()
+const std::vector<MvOdbColumn*>& MvOldOdb::columns()
 {
     readMetaData();
     return column_;
 }
 
-int MvOldOdb::findColumn(string cname)
+int MvOldOdb::findColumn(std::string cname)
 {
     readMetaData();
 
@@ -957,7 +951,7 @@ const MvOdbColumn* MvOldOdb::loadColumn(int /*pos*/, bool /*reload*/)
     return 0;
 }
 
-const MvOdbColumn* MvOldOdb::loadColumn(string cname, bool reload)
+const MvOdbColumn* MvOldOdb::loadColumn(std::string cname, bool reload)
 {
     int colPos = findColumn(cname);
     return loadColumn(colPos, reload);
@@ -973,7 +967,7 @@ void MvOldOdb::unloadColumn(int pos)
     column_[pos]->unload();
 }
 
-void MvOldOdb::unloadColumn(string cname)
+void MvOldOdb::unloadColumn(std::string cname)
 {
     int colPos = findColumn(cname);
     unloadColumn(colPos);
@@ -989,17 +983,17 @@ const MvOdbColumn* MvOldOdb::column(int pos)
     return column_[pos];
 }
 
-const MvOdbColumn* MvOldOdb::column(string cname)
+const MvOdbColumn* MvOldOdb::column(std::string cname)
 {
     int colPos = findColumn(cname);
     return column(colPos);
 }
 
-/*void MvOldOdb::retrieveToFile(string query, string inFile,string outFile)
+/*void MvOldOdb::retrieveToFile(std::string query, std::string inFile,std::string outFile)
 {
 }*/
 
-bool MvOldOdb::toGeopoints(string /*outFile*/, string /*geoType*/)
+bool MvOldOdb::toGeopoints(std::string /*outFile*/, std::string /*geoType*/)
 {
     return false;
 }
@@ -1013,10 +1007,10 @@ bool MvOldOdb::toGeopoints(string /*outFile*/, string /*geoType*/)
 //
 //=============================
 
-MvAbstractOdb* MvOdbFactory::make(string path, string sourcePath, string query)
+MvAbstractOdb* MvOdbFactory::make(std::string path, std::string sourcePath, std::string query)
 {
     //We suppose it is an ODB
-    string type = MvOdbType(path.c_str(), false);
+    std::string type = MvOdbType(path.c_str(), false);
 
     if (type == "ODB_NEW") {
 #ifdef METVIEW_ODB_NEW
