@@ -7,8 +7,6 @@
 
  ***************************** LICENSE END *************************************/
 
-// MvPrepBufrPrep.cc
-
 #include "MvPrepBufrPrep.h"
 
 #include <stdlib.h>
@@ -22,6 +20,8 @@
 
 #include "MvObsSet.h"
 
+namespace metview {
+
 const std::string cNoBufrTablesDir("NO_TABLE_DIR");
 const std::string cCommonNamePart("_prepbufr.txt");
 const std::string cAUX_TABLE_B("prepbufr_table_B.txt");
@@ -538,3 +538,5 @@ int main()
   extract.extract();
 }
 #endif
+
+}
