@@ -19,6 +19,8 @@
 
 #include "MvBufrObs.h"
 
+namespace metview {
+
 class MvObsSet;
 
 //_____________________________________________________
@@ -115,4 +117,4 @@ private:
 };
 //_____________________________________________________
 
-// MvPrepBufrPrep_DEFINED
+}
