@@ -7,6 +7,8 @@
 
  ***************************** LICENSE END *************************************/
 
+#include <algorithm>
+
 #include <Metview.h>
 #include <MvPath.hpp>
 #include <MvScanFileType.h>
@@ -76,13 +78,13 @@ MvRequest& MvRequest::operator=(const MvRequest& r)
 
 MvRequest MvRequest::operator+(const MvRequest& r) const
 {
-    if (CurrentRequest == NULL)
+    if (CurrentRequest == nullptr)
         return r;
 
     request* a = clone_all_requests(CurrentRequest);
     request* b = clone_all_requests(r.CurrentRequest);
 
-    request *q = NULL, *p = a;
+    request *q = nullptr, *p = a;
 
     while (p) {
         q = p;
@@ -97,8 +99,8 @@ MvRequest MvRequest::operator+(const MvRequest& r) const
 
 void MvRequest::operator+=(const MvRequest& r)
 {
-    request* a = NULL;
-    request* b = NULL;
+    request* a = nullptr;
+    request* b = nullptr;
 
     if (CurrentRequest) {
         a = CurrentRequest;
@@ -108,7 +110,7 @@ void MvRequest::operator+=(const MvRequest& r)
         b = clone_all_requests(r.CurrentRequest);
     }
 
-    request *q = NULL, *p = a;
+    request *q = nullptr, *p = a;
 
     if (a) {
         while (p)  // find the end of request a
@@ -177,7 +179,7 @@ void MvRequest::print(bool force) const
 
 const char* MvRequest::getVerb() const
 {
-    return CurrentRequest ? CurrentRequest->name : NULL;
+    return CurrentRequest ? CurrentRequest->name : nullptr;
 }
 
 void MvRequest::unsetParam(const char* pname)
@@ -191,7 +193,7 @@ void MvRequest::read(const char* fileNamePath, bool expand, bool hidden)
     boolean debugOriVal = mars.debug;
     if (hidden && !mars.debug) {
         debugOriVal = mars.debug;
-        mars.debug = 1;
+        mars.debug  = 1;
     }
 
     // Read request using MARS library
@@ -211,7 +213,7 @@ void MvRequest::read(const char* fileNamePath, bool expand, bool hidden)
     // Get object request. This will help to find out if a parameter
     // is a subrequest, which in this case will need to be expanded.
     request* obj = this->findRequestObject();
-    if (obj == NULL) {
+    if (obj == nullptr) {
         if (mars.debug != debugOriVal) {
             mars.debug = debugOriVal;
         }
@@ -219,7 +221,7 @@ void MvRequest::read(const char* fileNamePath, bool expand, bool hidden)
     }
 
     // Expand subrequests
-    string path = mdirname(fileNamePath);
+    std::string path = mdirname(fileNamePath);
     this->importSubObjects(path, obj);
 
     if (mars.debug != debugOriVal) {
@@ -234,10 +236,11 @@ void MvRequest::save(const char* file, bool hidden) const
         if (hidden && !mars.debug) {
             //boolean is defined in mars.h as int
             boolean oriDebugVal = mars.debug;
-            mars.debug = 1;
+            mars.debug          = 1;
             save(fp);
             mars.debug = oriDebugVal;
-        } else {
+        }
+        else {
             save(fp);
         }
         fclose(fp);
@@ -261,7 +264,7 @@ void MvAccess::operator=(const MvAccess& a)
     set_value(
         Request->CurrentRequest, LastGet, "%s",
         get_value(a.Request->CurrentRequest, a.LastGet, a.LastIndex));
-    LastGet   = NULL;
+    LastGet   = nullptr;
     LastIndex = 0;
 }
 
@@ -350,35 +353,35 @@ void MvAccess::operator=(const char* val)
 {
     if (LastGet)
         set_value(Request->CurrentRequest, LastGet, "%s", val);
-    LastGet   = NULL;
+    LastGet   = nullptr;
     LastIndex = 0;
 }
 void MvAccess::operator=(double val)
 {
     if (LastGet)
         set_value(Request->CurrentRequest, LastGet, "%.12g", val);
-    LastGet   = NULL;
+    LastGet   = nullptr;
     LastIndex = 0;
 }
 void MvAccess::operator=(int val)
 {
     if (LastGet)
         set_value(Request->CurrentRequest, LastGet, "%d", val);
-    LastGet   = NULL;
+    LastGet   = nullptr;
     LastIndex = 0;
 }
 void MvAccess::operator=(const request* val)
 {
     if (LastGet)
         set_subrequest(Request->CurrentRequest, LastGet, val);
-    LastGet   = NULL;
+    LastGet   = nullptr;
     LastIndex = 0;
 }
 void MvAccess::operator=(long val)
 {
     if (LastGet)
         set_value(Request->CurrentRequest, LastGet, "%ld", val);
-    LastGet   = NULL;
+    LastGet   = nullptr;
     LastIndex = 0;
 }
 
@@ -389,7 +392,7 @@ void MvAccess::operator=(const MvDate& val)
     if (LastGet)
         set_value(Request->CurrentRequest,
                   LastGet, "%s", buf);
-    LastGet   = NULL;
+    LastGet   = nullptr;
     LastIndex = 0;
 }
 
@@ -405,7 +408,7 @@ void MvAccess::operator+=(const MvDate& val)
     if (LastGet)
         add_value(Request->CurrentRequest,
                   LastGet, "%s", buf);
-    LastGet   = NULL;
+    LastGet   = nullptr;
     LastIndex = 0;
 }
 
@@ -413,7 +416,7 @@ void MvAccess::operator+=(const char* val)
 {
     if (LastGet)
         add_value(Request->CurrentRequest, LastGet, "%s", val);
-    LastGet   = NULL;
+    LastGet   = nullptr;
     LastIndex = 0;
 }
 
@@ -428,7 +431,7 @@ void MvAccess::operator+=(const MvAccess& a)
     add_value(
         Request->CurrentRequest, LastGet, "%s",
         get_value(a.Request->CurrentRequest, a.LastGet, a.LastIndex));
-    LastGet   = NULL;
+    LastGet   = nullptr;
     LastIndex = 0;
 }
 
@@ -604,7 +607,7 @@ void MvRequest::advanceToEnd()
         advance();
 }
 
-MvRequest& MvRequest::advanceTo(string& verb)
+MvRequest& MvRequest::advanceTo(std::string& verb)
 {
     while (CurrentRequest) {
         if (getVerb() == verb)
@@ -615,7 +618,7 @@ MvRequest& MvRequest::advanceTo(string& verb)
     return *this;
 }
 
-MvRequest& MvRequest::advanceAfter(string& verb)
+MvRequest& MvRequest::advanceAfter(std::string& verb)
 {
     while (CurrentRequest) {
         if (getVerb() == verb) {
@@ -716,13 +719,13 @@ int MvRequest::countParameters(bool includeHidden) const
 {
     if (!CurrentRequest)
         return 0;
-    int n        = 0;
-    parameter* p = CurrentRequest->params;
+    int n            = 0;
+    parameter* p     = CurrentRequest->params;
     parameter* lastp = p;
     while (p) {
         n++;
         lastp = p;
-        p = p->next;
+        p     = p->next;
     }
     // here, 'hidden' means that it starts with a double underscore, as in "__strings"
     if (!includeHidden) {
@@ -739,7 +742,7 @@ int MvRequest::countParameters(bool includeHidden) const
 const char* MvRequest::getParameter(int i) const
 {
     if (!CurrentRequest)
-        return NULL;
+        return nullptr;
 
     int n        = 0;
     parameter* p = CurrentRequest->params;
@@ -748,7 +751,7 @@ const char* MvRequest::getParameter(int i) const
             return p->name;
         p = p->next;
     }
-    return NULL;
+    return nullptr;
 }
 
 bool MvRequest::iterInitParam()
@@ -784,7 +787,7 @@ bool MvRequest::iterGetNextParamInterface(MvRequest& req)
 const char* MvRequest :: enquire(const char* name, const char* classe, const char* keyw)
 {
 	const char* classe_value;
-	const char* cmd = NULL;
+	const char* cmd = nullptr;
 	request* reqst = FirstRequest;
 
 	while (reqst)
@@ -804,7 +807,7 @@ const char* MvRequest :: enquire(const char* name, const char* classe, const cha
 
 const char* MvRequest ::enquire(const char* name, const char* keyw, int posit)
 {
-    const char* value = NULL;
+    const char* value = nullptr;
     request* reqst    = FirstRequest;
 
     while (reqst && !value) {
@@ -858,7 +861,7 @@ void MvRequest::update(const MvRequest& r)
     parameter* p = b->params;
     while (p) {
         // Parameter not found in the target request
-        if (find_parameter(a, p->name) == NULL) {
+        if (find_parameter(a, p->name) == nullptr) {
             p = p->next;
             continue;
         }
@@ -890,10 +893,10 @@ void MvRequest::update(const MvRequest& r)
 // FI 20201103: does it need to check for subrequests and default_values?
 MvRequest MvRequest::convertLetterCase(bool upper)
 {
-    if (CurrentRequest == NULL)
-        return MvRequest(NULL, false);
+    if (CurrentRequest == nullptr)
+        return MvRequest(nullptr, false);
 
-    string spar;
+    std::string spar;
     request* a = clone_all_requests(FirstRequest);
     request* b = a;
     while (b) {
@@ -939,11 +942,11 @@ void MvRequest::update_value(request* r, const char* parname, const char* valnam
         return;
 
 
-    if ((p = find_parameter(r, parname)) == NULL)
+    if ((p = find_parameter(r, parname)) == nullptr)
         return;
 
     if (append) {
-        value *a = p->values, *b = NULL;
+        value *a = p->values, *b = nullptr;
         while (a) {
             b = a;
             //			c = b;
@@ -960,7 +963,7 @@ void MvRequest::update_value(request* r, const char* parname, const char* valnam
     else {
         if (p->values) {
             free_all_values(p->values->next);
-            p->values->next = NULL;
+            p->values->next = nullptr;
             p->count        = 0;
             if (EQ(p->values->name, valname))
                 return;
@@ -980,23 +983,23 @@ void MvRequest::update_value(request* r, const char* parname, const char* valnam
 MvRequest MvRequest::ExpandRequest(const char* defName, const char* rulesName, long expandFlag)
 {
     // Create the full path
-    string sdef   = MakeSystemEtcPath(defName);
-    string srules = MakeSystemEtcPath(rulesName);
+    std::string sdef   = MakeSystemEtcPath(defName);
+    std::string srules = MakeSystemEtcPath(rulesName);
 
     MvLanguage langMetview(sdef.c_str(), srules.c_str(), expandFlag);
 
     return langMetview.expandOne(CurrentRequest);
 }
 
-bool MvRequest::getPath(const string& par, string& resPath, bool canBeEmpty)
+bool MvRequest::getPath(const std::string& par, std::string& resPath, bool canBeEmpty) const
 {
     const char* inPath = (*this)(par.c_str());
 
     if (inPath && strlen(inPath) > 0) {
-        resPath = string(inPath);
+        resPath = std::string(inPath);
 
         if (resPath[0] == ' ') {
-            string errTxt = "Leading whitespace in parameter: " + string(par) + "!";
+            std::string errTxt = "Leading whitespace in parameter: " + std::string(par) + "!";
             marslog(LOG_EROR, "%s", errTxt.c_str());
             return false;
         }
@@ -1008,15 +1011,15 @@ bool MvRequest::getPath(const string& par, string& resPath, bool canBeEmpty)
 
             if (const char* fromMacro = (*this)("_MACRO")) {
                 if (const char* fromMacroPathCh = (*this)("_PATH")) {
-                    string fromMacroPath(fromMacroPathCh);
+                    std::string fromMacroPath(fromMacroPathCh);
                     if (fromMacroPath.size() > 0 && fromMacroPath[0] == '/') {
                         resPath = fromMacroPath + "/" + resPath;
                         return true;
                     }
                     else {
-                        string errTxt = "Could not resolve path for parameter=" + string(par) +
-                                        " because both _MACRO=" + fromMacro + "and _PATH=" + fromMacroPath +
-                                        " but _PATH does not seem to be an absolute path!";
+                        std::string errTxt = "Could not resolve path for parameter=" + std::string(par) +
+                                             " because both _MACRO=" + fromMacro + "and _PATH=" + fromMacroPath +
+                                             " but _PATH does not seem to be an absolute path!";
                         marslog(LOG_EROR, "%s", errTxt.c_str());
                         return false;
                     }
@@ -1026,7 +1029,7 @@ bool MvRequest::getPath(const string& par, string& resPath, bool canBeEmpty)
             //We try to use the path of the icon the request belongs to
             const char* callerIcon = (*this)("_NAME");
             if (callerIcon) {
-                string callerDir(callerIcon);
+                std::string callerDir(callerIcon);
 
                 //special case: if callerDir is a path with "Process@" in it, then it
                 //very probably means that this was run from a macro - in this case, we can't
@@ -1036,17 +1039,17 @@ bool MvRequest::getPath(const string& par, string& resPath, bool canBeEmpty)
                 //As a fallback solution we suppose that the path is relative to where the macro is run
                 //from; so in this case we would simplyremove the path.
 
-                if (callerDir.find("Process@") != string::npos) {
+                if (callerDir.find("Process@") != std::string::npos) {
                     // yes, it's called from Macro - files are relative to current dir
                     callerDir = ".";
                 }
                 else {
                     char* mvudir = getenv("METVIEW_USER_DIRECTORY");
                     if (mvudir) {
-                        callerDir = string(mvudir) + "/" + callerDir;
+                        callerDir = std::string(mvudir) + "/" + callerDir;
                     }
-                    string::size_type pos = callerDir.find_last_of("/");
-                    if (pos != string::npos) {
+                    std::string::size_type pos = callerDir.find_last_of("/");
+                    if (pos != std::string::npos) {
                         callerDir = callerDir.substr(0, pos);
                     }
                 }
@@ -1057,7 +1060,7 @@ bool MvRequest::getPath(const string& par, string& resPath, bool canBeEmpty)
     }
 
     if (!inPath || (resPath.empty() && canBeEmpty == false)) {
-        string errTxt = "No value is defined for parameter: " + string(par) + "!";
+        std::string errTxt = "No value is defined for parameter: " + std::string(par) + "!";
         marslog(LOG_EROR, "%s", errTxt.c_str());
         return false;
     }
@@ -1079,7 +1082,7 @@ bool MvRequest::getPathAndReplace(const std::string& parName, std::string& resPa
     return getPath(parName, resPath, canBeEmpty);
 }
 
-bool MvRequest::getPath(const char* iconPar, const char* textPar, string& resPath, bool canBeEmpty, string& errTxt)
+bool MvRequest::getPath(const char* iconPar, const char* textPar, std::string& resPath, bool canBeEmpty, std::string& errTxt)
 {
     errTxt.clear();
 
@@ -1088,12 +1091,12 @@ bool MvRequest::getPath(const char* iconPar, const char* textPar, string& resPat
 
     //First try to get the path from the icon object
     if (dataPath) {
-        resPath = string(dataPath);
+        resPath = std::string(dataPath);
     }
     //If there is no icon we use the text parameter to get the path
     else {
         if (textPar) {
-            string s(textPar);
+            std::string s(textPar);
             if (!getPath(s, resPath, true)) {
                 return false;
             }
@@ -1104,7 +1107,7 @@ bool MvRequest::getPath(const char* iconPar, const char* textPar, string& resPat
     }
 
     if (!canBeEmpty && resPath.empty()) {
-        errTxt = "No value found for paramaters: " + string(iconPar) + " " + string(textPar);
+        errTxt = "No value found for paramaters: " + std::string(iconPar) + " " + std::string(textPar);
         return false;
     }
 
@@ -1124,10 +1127,10 @@ int MvRequest::getBaseDate()
     return date;
 }
 
-bool MvRequest::getDate(const string& par, string& value, bool canBeEmpty)
+bool MvRequest::getDate(const std::string& par, std::string& value, bool canBeEmpty)
 {
     bool retVal = false;
-    string str;
+    std::string str;
     if ((retVal = getValue(par, str, canBeEmpty)) == true) {
         if ((retVal = MvDate::parseYYYYMMDD(str, value)) == false) {
             marslog(LOG_EROR, "Invalid date value (%s) used for parameter: %s", str.c_str(), par.c_str());
@@ -1136,7 +1139,7 @@ bool MvRequest::getDate(const string& par, string& value, bool canBeEmpty)
     return retVal;
 }
 
-bool MvRequest::getDate(const string& par, const string& str, string& value)
+bool MvRequest::getDate(const std::string& par, const std::string& str, std::string& value)
 {
     bool retVal = false;
     if ((retVal = MvDate::parseYYYYMMDD(str, value)) == false) {
@@ -1145,60 +1148,60 @@ bool MvRequest::getDate(const string& par, const string& str, string& value)
     return retVal;
 }
 
-bool MvRequest::getTime(const string& par, string& value, bool canBeEmpty)
+bool MvRequest::getTime(const std::string& par, std::string& value, bool canBeEmpty)
 {
     bool retVal = false;
-    string str;
+    std::string str;
     if ((retVal = getValue(par, str, canBeEmpty)) == true) {
         retVal = MvRequest::getTime(par, str, value);
     }
     return retVal;
 }
 
-bool MvRequest::getTime(const string& par, const string& str, string& value)
+bool MvRequest::getTime(const std::string& par, const std::string& str, std::string& value)
 {
     bool retVal = false;
     if ((retVal = MvDate::timeToHHMMSS(str, value)) == false) {
-        string errTxt = "Time value=" + str + "for param=" + par +
-                        " does not match the expected format: hh[:mm[:ss]]";
+        std::string errTxt = "Time value=" + str + "for param=" + par +
+                             " does not match the expected format: hh[:mm[:ss]]";
         marslog(LOG_EROR, "%s", errTxt.c_str());
         return false;
     }
     return retVal;
 }
 
-bool MvRequest::getTimeLenInSec(const string& par, string& value, bool canBeEmpty)
+bool MvRequest::getTimeLenInSec(const std::string& par, std::string& value, bool canBeEmpty)
 {
     bool retVal = false;
-    string str;
+    std::string str;
     if ((retVal = getValue(par, str, canBeEmpty)) == true) {
         retVal = MvRequest::getTimeLenInSec(par, str, value);
     }
     return retVal;
 }
 
-bool MvRequest::getTimeLenInSec(const string& par, const string& str, string& value)
+bool MvRequest::getTimeLenInSec(const std::string& par, const std::string& str, std::string& value)
 {
     bool retVal = false;
     if ((retVal = MvDate::timeToLenInSec(str, value)) == false) {
-        string errTxt = "Time value=" + str + "for param=" + par +
-                        " does not match the expected format: hhh[:mm[:ss]]";
+        std::string errTxt = "Time value=" + str + "for param=" + par +
+                             " does not match the expected format: hhh[:mm[:ss]]";
         marslog(LOG_EROR, "%s", errTxt.c_str());
         return false;
     }
     return retVal;
 }
 
-bool MvRequest::getValueId(const string& par, string& value, const std::map<string, string>& idMap, bool canBeEmpty)
+bool MvRequest::getValueId(const std::string& par, std::string& value, const std::map<std::string, std::string>& idMap, bool canBeEmpty)
 {
     value.clear();
 
     const char* cval = (*this)(par.c_str());
 
     if (cval) {
-        value = string(cval);
+        value = std::string(cval);
         if (idMap.empty() == false) {
-            std::map<string, string>::const_iterator it = idMap.find(value);
+            auto it = idMap.find(value);
             if (it != idMap.end())
                 value = it->second;
             else
@@ -1206,13 +1209,13 @@ bool MvRequest::getValueId(const string& par, string& value, const std::map<stri
         }
     }
     else if (!canBeEmpty) {
-        string errTxt = "Parameter not found: " + par;
+        std::string errTxt = "Parameter not found: " + par;
         marslog(LOG_EROR, "%s", errTxt.c_str());
         return false;
     }
 
     if (!canBeEmpty && value.empty()) {
-        string errTxt = "No value found for paramater: " + string(par);
+        std::string errTxt = "No value found for paramater: " + std::string(par);
         marslog(LOG_EROR, "%s", errTxt.c_str());
         return false;
     }
@@ -1221,23 +1224,23 @@ bool MvRequest::getValueId(const string& par, string& value, const std::map<stri
 }
 
 
-bool MvRequest::getValue(const string& par, string& value, bool canBeEmpty) const
+bool MvRequest::getValue(const std::string& par, std::string& value, bool canBeEmpty) const
 {
     value.clear();
 
     const char* cval = (*this)(par.c_str());
 
     if (cval) {
-        value = string(cval);
+        value = std::string(cval);
     }
     else if (!canBeEmpty) {
-        string errTxt = "Parameter not found: " + string(par);
+        std::string errTxt = "Parameter not found: " + std::string(par);
         marslog(LOG_EROR, "%s", errTxt.c_str());
         return false;
     }
 
     if (!canBeEmpty && value.empty()) {
-        string errTxt = "No value found for parameter: " + string(par);
+        std::string errTxt = "No value found for parameter: " + std::string(par);
         marslog(LOG_EROR, "%s", errTxt.c_str());
         return false;
     }
@@ -1245,28 +1248,28 @@ bool MvRequest::getValue(const string& par, string& value, bool canBeEmpty) cons
     return true;
 }
 
-bool MvRequest::getValue(const string& par, std::vector<string>& value, bool canBeEmpty) const
+bool MvRequest::getValue(const std::string& par, std::vector<std::string>& value, bool canBeEmpty) const
 {
     value.clear();
     int cnt = countValues(par.c_str());
 
     if (cnt == 0) {
         if (!canBeEmpty) {
-            string errTxt = "No value found for parameter: " + par;
+            std::string errTxt = "No value found for parameter: " + par;
             marslog(LOG_EROR, "%s", errTxt.c_str());
             return false;
         }
     }
     else if (cnt == 1) {
         if (const char* cval = (*this)(par.c_str())) {
-            value.push_back(string(cval));
+            value.push_back(std::string(cval));
         }
     }
     else {
-        string val;
+        std::string val;
         for (int i = 0; i < cnt; i++) {
             if (const char* cval = (*this)(par.c_str(), i)) {
-                value.push_back(string(cval));
+                value.push_back(std::string(cval));
             }
         }
     }
@@ -1277,7 +1280,7 @@ bool MvRequest::getValue(const string& par, std::vector<string>& value, bool can
 // Algorithm:
 // - find a subrequest ERROR and get the error message from parameter MESSAGE
 // - only the first message is retrieved (if any)
-bool MvRequest::getError(string& err)
+bool MvRequest::getError(std::string& err)
 {
     if (!CurrentRequest)
         return false;
@@ -1286,7 +1289,7 @@ bool MvRequest::getError(string& err)
     parameter* p = CurrentRequest->params;
     while (p) {
         if ((req = getSubrequest(p->name))) {
-            if (string(req.getVerb()) == string("ERROR")) {
+            if (std::string(req.getVerb()) == std::string("ERROR")) {
                 if ((const char*)req("MESSAGE")) {
                     // build error message
                     err = "ERROR-> ";
@@ -1310,7 +1313,7 @@ void MvAccess::operator+=(double val)
 {
     if (LastGet)
         add_value(Request->CurrentRequest, LastGet, "%.12g", val);
-    LastGet   = NULL;
+    LastGet   = nullptr;
     LastIndex = 0;
 }
 
@@ -1357,7 +1360,7 @@ MvGrib::MvGrib(const char* s)
 //----------------------------------------------
 
 
-void MvRequest::importSubObjects(string& path, request* obj)
+void MvRequest::importSubObjects(std::string& path, request* obj)
 {
     // Get the definition filename
     const char* defFile = get_value(obj, "definition_file", 0);
@@ -1395,7 +1398,7 @@ void MvRequest::importSubObjects(string& path, request* obj)
                 for (int i = 0; i < this->countValues(p->name); i++) {
                     // Build subrequest
                     this->getValue(q, p->name, i);
-                    string fullPath = (path[path.size() - 1] == '/') ? path + q : path + "/" + q;
+                    std::string fullPath = (path[path.size() - 1] == '/') ? path + q : path + "/" + q;
                     if (!IsBinaryOrMissingFile(fullPath.c_str())) {
                         // Read request from file and add parameter _CLASS.
                         // Do not add parameter _NAME because this request
@@ -1413,8 +1416,8 @@ void MvRequest::importSubObjects(string& path, request* obj)
                         reqAux("_CLASS") = cclass;
 
                         // Name without the Metview user directory path
-                        string user_dir   = GetUserDirectory();
-                        std::size_t found = fullPath.find(user_dir);
+                        std::string user_dir = GetUserDirectory();
+                        std::size_t found    = fullPath.find(user_dir);
                         if (found != std::string::npos)
                             reqAux("_NAME") = fullPath.substr(found + user_dir.size()).c_str();
                         else
@@ -1441,8 +1444,9 @@ void MvRequest::importSubObjects(string& path, request* obj)
 request* MvRequest::findRequestObject()
 {
     const char* className = this->getVerb();
-    if (!className)
-        return NULL;
+    if (className == nullptr) {
+        return nullptr;
+    }
 
     const char* c;
     request* u = mars.setup;
@@ -1455,27 +1459,27 @@ request* MvRequest::findRequestObject()
         u = u->next;
     }
 
-    return NULL;
+    return nullptr;
 }
 
-bool MvRequest::checkParameters(MvRequest& req, vector<string>& params)
+bool MvRequest::checkParameters(MvRequest& req, std::vector<std::string>& params)
 {
     const char* par;
 
-    for (int i = 0; i < (signed)params.size(); i++) {
-        par = params[i].c_str();
+    for (auto& param : params) {
+        par = param.c_str();
         if (!checkOneParameter(req, par))
             return false;
     }
     return true;
 }
 
-bool MvRequest::checkParameters(MvRequest& req, vector<string>& params, string& parOut)
+bool MvRequest::checkParameters(MvRequest& req, std::vector<std::string>& params, std::string& parOut)
 {
     const char* par;
 
-    for (int i = 0; i < (signed)params.size(); i++) {
-        par = params[i].c_str();
+    for (auto& param : params) {
+        par = param.c_str();
         if (!checkOneParameter(req, par)) {
             parOut = par;
             return false;
@@ -1484,7 +1488,7 @@ bool MvRequest::checkParameters(MvRequest& req, vector<string>& params, string&
     return true;
 }
 
-bool MvRequest::checkOneParameter(MvRequest& req, const string& param)
+bool MvRequest::checkOneParameter(MvRequest& req, const std::string& param)
 {
     const char *v1, *v2;
 
@@ -1510,27 +1514,38 @@ void MvRequest::replaceDotInPath(MvRequest& in)
     while (in) {
         MvRequest rCurrent = in.justOneRequest();
         if (const char* ch = in("_PATH")) {
-//            marslog(LOG_INFO,"replaceDotInPath: found _PATH=%s", ch);
+            //            marslog(LOG_INFO,"replaceDotInPath: found _PATH=%s", ch);
             if (strcmp(ch, ".") == 0) {
-                marslog(LOG_INFO,"replaceDotInPath: replace _PATH");
+                marslog(LOG_INFO, "replaceDotInPath: replace _PATH");
                 rCurrent("_PATH") = "./";
-            }            
+            }
         }
         int n = in.countParameters();
-        for(int i=0; i < n; i++) {
+        for (int i = 0; i < n; i++) {
             const char* pch = in.getParameter(i);
-            MvRequest sr = in.getSubrequest(pch);
+            MvRequest sr    = in.getSubrequest(pch);
             if (sr) {
-//                marslog(LOG_INFO, "replaceDotInPath: check subrequest=%s", pch);
+                //                marslog(LOG_INFO, "replaceDotInPath: check subrequest=%s", pch);
                 replaceDotInPath(sr);
                 rCurrent(pch) = sr;
             }
         }
-//        marslog(LOG_INFO, "current request=");
-//        in.justOneRequest().print();
+        //        marslog(LOG_INFO, "current request=");
+        //        in.justOneRequest().print();
         r = r + rCurrent;
         in.advance();
     }
     in.rewind();
     in = r;
 }
+
+std::string MvRequest::toJson() const
+{
+    auto v = request2json(CurrentRequest);
+    json_print(v);
+    auto ch = json_get_string(v);
+    if (ch) {
+        return std::string(ch);
+    }
+    return {};
+}
