@@ -8,8 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 
-#ifndef MvRequest_DEFINED
-#define MvRequest_DEFINED
+#pragma once
 
 class MvRequest;
 
@@ -60,7 +59,7 @@ public:
     MvAccess(MvRequest* r, const char* get, int idx) :
         Request(r),
         LastGet(get),
-        LastIndex(idx){};
+        LastIndex(idx) {}
 
     MvAccess(const MvAccess&);
     void operator=(const MvAccess&);
@@ -130,7 +129,7 @@ public:
     MvConstAccess(const MvRequest* r, const char* get, int idx) :
         Request(r),
         LastGet(get),
-        LastIndex(idx){};
+        LastIndex(idx) {}
 
     MvConstAccess(const MvConstAccess&);
     MvConstAccess(const MvAccess&);
@@ -187,7 +186,7 @@ protected:
     request* copyFromCurrentTo_Recursive(const request* r, const char* verb);
 
     // Expand subrequests
-    void importSubObjects(string&, request*);
+    void importSubObjects(std::string&, request*);
 
 public:
     // Contructors
@@ -201,7 +200,7 @@ public:
     /*! If argument 'clone' is true, a copy of 'req' is done,
 	 *  otherwise a pointer to 'req' itself is stored in MvRequest.
 	 */
-    MvRequest(request* req = NULL, boolean clone = true, boolean free_req = true);
+    MvRequest(request* req = nullptr, boolean clone = true, boolean free_req = true);
 
     //! Copy constructor
     MvRequest(const MvRequest&);
@@ -235,7 +234,7 @@ public:
     operator request*() const { return CurrentRequest; }
 
     //! Returns 1 (true) when MvRequest object contains no requests
-    int operator!() const { return CurrentRequest == NULL; }
+    int operator!() const { return CurrentRequest == nullptr; }
 
     //! Access the 'n'th value in list parameter 'p'
     /*! Returns a MvAccess object, which normally is not visible
@@ -360,7 +359,7 @@ public:
 
     //! Get current value as 'char*' and advance the list iterator
     /*! If no more values are available in the list, returns
-	 *  'false' and sets argument 'val' to 0 (NULL pointer);
+	 *  'false' and sets argument 'val' to 0 (nullptr);
 	 *  otherwise returns 'true' and returns the current list
 	 *  item in argument 'val', and then advances the list iterator.
 	 */
@@ -379,7 +378,7 @@ public:
     /*! When a MvRequest object contains more than one request in a single
 	 *  linked list, this method allows the sequential access to all of them.
 	 *  Each time this method is called, it advances the current request
-	 *  to the next one in the list and returns it. A NULL is returned when
+	 *  to the next one in the list and returns it. nullptr is returned when
 	 *  the current request points to the end of the list.\n \n
 	 *  Example:
 	 * <PRE>
@@ -391,10 +390,10 @@ public:
     MvRequest& advance();
 
     // Advance to the next verb request
-    MvRequest& advanceTo(string&);
+    MvRequest& advanceTo(std::string&);
 
     // Advance to after the next verb request
-    MvRequest& advanceAfter(string&);
+    MvRequest& advanceAfter(std::string&);
 
     // Advance to the end of all requests
     void advanceToEnd();
@@ -444,7 +443,7 @@ public:
     // -----
 
     //! Returns the number of parameters
-    int countParameters(bool includeHidden=true) const;
+    int countParameters(bool includeHidden = true) const;
 
     //! Returns the name of the 'n'th parameter
     /*! NOTE: Method uses C style indexing (n=0,1,...) */
@@ -485,7 +484,7 @@ public:
     void update(const MvRequest&);
 
     // Convert request to upper/lower case
-    MvRequest convertLetterCase(bool upper=true);
+    MvRequest convertLetterCase(bool upper = true);
 
     // -----
 
@@ -519,7 +518,7 @@ public:
     /*! Hidden parameters are not printed (unless -DEBUG flag
 	 *  is used, or mars.debug is set to non-zero)
 	 */
-    void print(bool force=false) const;
+    void print(bool force = false) const;
 
     //! Reads a request from file named 'file'.
     /*! if the second parameter is true then any request parameter,
@@ -586,7 +585,7 @@ public:
     //! Removes everything, making the request empty
     void clean();
 
-    bool isEmpty() {return (FirstRequest == 0);}
+    bool isEmpty() { return (FirstRequest == 0); }
 
     // Get the Object request given its name
     request* findRequestObject();
@@ -599,30 +598,32 @@ public:
     int getBaseDate();
 
     //Find out path (it can be relative path as well) stored in parameter par.
-    bool getPath(const string& par, string& resPath, bool canBeEmpty);
-    bool getPath(const char* iconPar, const char* textPar, string& resPath, bool canBeEmpty, string& errTxt);
+    bool getPath(const std::string& par, std::string& resPath, bool canBeEmpty) const;
+    bool getPath(const char* iconPar, const char* textPar, std::string& resPath, bool canBeEmpty, std::string& errTxt);
     bool getPathAndReplace(const std::string& par, std::string& resPath, const std::string& replaceFrom,
                            const std::string& replaceTo, bool canBeEmpty = false);
-    bool getDate(const string& par, string& value, bool canbeEmpty = false);
-    bool getTime(const string& par, string& value, bool canBeEmpty = false);
-    bool getTimeLenInSec(const string& par, string& value, bool canBeEmpty = false);
-    bool getValueId(const string& par, string& value, const std::map<string, string>& idMap, bool canBeEmpty = false);
-    bool getValue(const string& par, string& value, bool canBeEmpty = false) const;
-    bool getValue(const string& par, std::vector<string>& value, bool canBeEmpty = false) const;
+    bool getDate(const std::string& par, std::string& value, bool canbeEmpty = false);
+    bool getTime(const std::string& par, std::string& value, bool canBeEmpty = false);
+    bool getTimeLenInSec(const std::string& par, std::string& value, bool canBeEmpty = false);
+    bool getValueId(const std::string& par, std::string& value, const std::map<std::string, std::string>& idMap, bool canBeEmpty = false);
+    bool getValue(const std::string& par, std::string& value, bool canBeEmpty = false) const;
+    bool getValue(const std::string& par, std::vector<std::string>& value, bool canBeEmpty = false) const;
 
-    static bool getDate(const string& par, const string& str, string& value);
-    static bool getTime(const string& par, const string& str, string& value);
-    static bool getTimeLenInSec(const string& par, const string& str, string& value);
+    static bool getDate(const std::string& par, const std::string& str, std::string& value);
+    static bool getTime(const std::string& par, const std::string& str, std::string& value);
+    static bool getTimeLenInSec(const std::string& par, const std::string& str, std::string& value);
 
     // Get error message from the request
-    bool getError(string&);
+    bool getError(std::string&);
 
     // Check if the input request has the same contents given a set of parameters
-    bool checkParameters(MvRequest&, std::vector<string>&);
-    bool checkParameters(MvRequest&, std::vector<string>&, string&);
-    bool checkOneParameter(MvRequest&, const string&);
+    bool checkParameters(MvRequest&, std::vector<std::string>&);
+    bool checkParameters(MvRequest&, std::vector<std::string>&, std::string&);
+    bool checkOneParameter(MvRequest&, const std::string&);
 
     static void replaceDotInPath(MvRequest& in);
+
+    std::string toJson() const;
 };
 
 //! Convenience class (not used currently)
@@ -657,4 +658,3 @@ public:
     //! Constructor, with GRIB file path name as an argument
     MvGrib(const char* path);
 };
-#endif
