@@ -12,6 +12,20 @@
 #include <MvRequest.h>
 #include <MvRequestUtil.hpp>
 
+namespace metview {
+
+void copyParam(const MvRequest& inRequest, MvRequest& outRequest,
+                             const std::string& oldName, const std::string& newName)
+{
+    int n = inRequest.countValues(oldName.c_str());
+    outRequest.unsetParam(oldName.c_str());
+    for (int j = 0; j < n; j++) {
+        const char* value = nullptr;
+        inRequest.getValue(value, oldName.c_str(), j);
+        outRequest.addValue(newName.c_str(), value);
+    }
+}
+
 //
 // FUNCTION: CopyAndRemoveParameters
 //
@@ -24,7 +38,6 @@
 // OUTPUT  : - A request which does not contain the desired params
 //
 
-
 void CopyAndRemoveParameters(const MvRequest& inRequest,
                              MvRequest& outRequest,
                              const char* prefix)
@@ -309,3 +322,5 @@ void CopyParametersAndStackingOrder(const MvRequest& inRequestOld, const MvReque
 
     return;
 }
+
+}
