@@ -173,22 +173,22 @@ static const char* isWeatherSymbolJson(const File& f)
     fread(&asciiBuf[0], 1, 99, f.f_);
     rewind(f.f_);
 
-    MvLog().dbg() << __func__ << " asciiBuf=" << asciiBuf;
+//    MvLog().dbg() << __func__ << " asciiBuf=" << asciiBuf;
     std::string t(asciiBuf);
     if (metview::startsWith(t, startBraceCh, true) && t.find(conv) != std::string::npos) {
         // the file is probably a metview ws json file
-        MvLog().dbg() << " match 1";
+//        MvLog().dbg() << " match 1";
         auto pos = t.find(classStr);
         if (pos != std::string::npos) {
-            MvLog().dbg() << " match2";
+//            MvLog().dbg() << " match2";
             auto sp = t.find(quoteCh, pos + classStr.length());
             if (sp != std::string::npos) {
-                MvLog().dbg() << " match3";
+//                MvLog().dbg() << " match3";
                 auto ep = t.find(quoteCh, sp + 1);
                 if (ep != std::string::npos) {
                     auto cls = t.substr(sp + 1, ep - sp - 1);
-                    auto it  = clsSet.find(cls);
-                    MvLog().dbg() << " cls=" << cls;
+                    auto it = clsSet.find(cls);
+//                    MvLog().dbg() << " cls=" << cls;
                     if (it != clsSet.end()) {
                         return (*it).c_str();
                     }
