@@ -16,8 +16,15 @@ class MvSci
 public:
     static const double cEarthRadiusInKm;
     static const double cEarthG;
-    static double degToRad(double d);
-    static double radToDeg(double r);
+    static const double cRadian;
+    static const double cDegree;
+    static const double cMetreToRadian;
+    static const double cRadianToMetre;
+
+    static double degToRad(double d) {return d * cDegree;}
+    static double radToDeg(double r) {return r * cRadian;}
+    static double metresToRadians(double m) {return m*cMetreToRadian;}
+    static double radiansToMetres(double r) {return r*cRadianToMetre;}
     static double geoDistanceInKm(double fi1, double la1, double fi2, double la2);
     //static void   latLonToXyz(double lat, double lon, double &x, double &y, double &z);
     static double saturationMixingRatio(double t, double p);
@@ -39,6 +46,8 @@ public:
     static double equivalentPotentialTemperature(double t, double p, double q, bool flag);
     static double saturatedEquivalentPotentialTemperature(double t, double p, bool flag);
     static double saturatedEquivalentPotentialTemperatureWithPTerm(double t, double p, double pTerm, bool flag);
+#ifdef METVIEW
     static double solarDeclinationInRad(double dateTime);
     static double cosineSolarZenithAngle(double lat, double lon, double declInRad, double hourAngleGM);
+#endif
 };
