@@ -9,13 +9,16 @@
 
 #include "MvScm.h"
 
-#include "MvMiscelaneous.h"
-#include "MvSci.h"
-
 #include <fstream>
+#include <iostream>
+#include <map>
 #include <set>
-#include <sstream>
-#include <string.h>
+#include <vector>
+
+#include "fstream_mars_fix.h"
+
+#include "MvMiscellaneous.h"
+#include "MvSci.h"
 
 //A nicer solution is needed!
 bool MvScm::needConsistency_ = false;
@@ -32,7 +35,7 @@ void MvScmConsistency::exec(int ts, int level)
     double d2 = source2_->consistencyValue(ts, level);
     double d3 = source3_->consistencyValue(ts, level);
 
-    float val = static_cast<float>((*proc_)(d1, d2, d3));
+    auto val = static_cast<float>((*proc_)(d1, d2, d3));
 
     target_->setConsistentValue(ts, level, val);
 }
@@ -66,7 +69,7 @@ MvScmProfileData::MvScmProfileData(MvScm* scm, MvScmVar* var, int step) :
     name_  = var_->longName();
     units_ = var_->units();
 
-    stringstream sst;
+    std::stringstream sst;
     sst << scm->steps().at(step_) / 3600;
     stepString_ = sst.str();
     stepString_ += " h";
@@ -123,7 +126,7 @@ float MvScmProfileData::auxLevel(int index)
     return -1;
 }
 
-void MvScmProfileData::levels(vector<float>& lev)
+void MvScmProfileData::levels(std::vector<float>& lev)
 {
     if (var_->levelType() == MvScmVar::ModelLevelType) {
         for (int i = 0; i < count(); i++) {
@@ -165,13 +168,13 @@ bool MvScmProfileData::acceptChange(const MvProfileChange& ch) const
 //
 //=========================================================
 
-void MvScmDim::init(MvNetCDF& nc, string name)
+void MvScmDim::init(MvNetCDF& nc, std::string name)
 {
     name_ = name;
 
     if (MvNcDim* dim = nc.getDimension(name)) {
         size_ = dim->size();
-        if (MvNcVar *var = nc.getVariable(name)) {
+        if (MvNcVar* var = nc.getVariable(name)) {
             setVar(var);
         }
     }
@@ -181,7 +184,7 @@ void MvScmDim::setVar(MvNcVar* var)
 {
     values_.clear();
 
-    if (!var || size_ <=0)
+    if (!var || size_ <= 0)
         return;
 
     if (var->getNumberOfDimensions() != 1) {
@@ -191,9 +194,10 @@ void MvScmDim::setVar(MvNcVar* var)
     MvNcDim* dim = var->getDimension(0);
 
     if (dim && strcmp(dim->name(), name_.c_str()) == 0) {
-        values_ = vector<float>();
+        values_ = std::vector<float>();
         var->get(values_, size_);
-    } else {
+    }
+    else {
         for (int i = 0; i < size_; i++)
             values_.push_back(i + 1);
     }
@@ -211,7 +215,7 @@ void MvScmDim::setAttributes(MvNcVar* var)
             }
             else if (att->sname() == "units" && att->values()) {
                 units_ = att->as_string(0);
-            }           
+            }
         }
     }
 }
@@ -237,12 +241,12 @@ MvScmVar::MvScmVar(LevelType levelType, MvNcVar* var, const MvScmDim& timeDim) :
     long counts[1];
 
     for (int i = 0; i < tNum; i++) {
-        vector<float> vals;
+        std::vector<float> vals;
         counts[0] = 1;
         var->setCurrent(i);
         var->get(vals, counts);
         data_.push_back(vals);
-        dataOri_.push_back(vector<float>());
+        dataOri_.push_back(std::vector<float>());
     }
 }
 
@@ -257,23 +261,23 @@ MvScmVar::MvScmVar(LevelType levelType, MvNcVar* var, const MvScmDim& timeDim, c
     setName(var);
     setAttributes(var);
 
-    int tNum = timeDim.size();
+    int tNum   = timeDim.size();
     int levNum = levDim.size();
     long counts[2];
 
     for (int i = 0; i < tNum; i++) {
-        vector<float> vals;
+        std::vector<float> vals;
         counts[0] = 1;
         counts[1] = levNum;
-        var->setCurrent(i,0);
+        var->setCurrent(i, 0);
         var->get(vals, counts);
         data_.push_back(vals);
-        dataOri_.push_back(vector<float>());
+        dataOri_.push_back(std::vector<float>());
     }
 }
 
 //Create a new variable that is not present in the file
-MvScmVar::MvScmVar(const string& name, const string& longName, const string& units, MvScmVar* var) :
+MvScmVar::MvScmVar(const std::string& name, const std::string& longName, const std::string& units, MvScmVar* var) :
     name_(name),
     longName_(longName),
     units_(units),
@@ -286,8 +290,8 @@ MvScmVar::MvScmVar(const string& name, const string& longName, const string& uni
 
     for (int i = 0; i < var->stepNum(); i++) {
         var->data(i);
-        data_.push_back(vector<float>(var->data(i).size(), 0.));
-        dataOri_.push_back(vector<float>());
+        data_.push_back(std::vector<float>(var->data(i).size(), 0.));
+        dataOri_.push_back(std::vector<float>());
     }
 }
 
@@ -297,26 +301,26 @@ MvScmVar::~MvScmVar()
         delete consistency_;
 }
 
-const vector<float>& MvScmVar::data(int ts) const
+const std::vector<float>& MvScmVar::data(int ts) const
 {
     if (ts >= 0 && ts < static_cast<int>(data_.size()))
         return data_.at(ts);
 
-    static vector<float> emptyVec;
+    static std::vector<float> emptyVec;
     return emptyVec;
 }
 
-const vector<float>& MvScmVar::dataOri(int ts) const
+const std::vector<float>& MvScmVar::dataOri(int ts) const
 {
     if (ts >= 0 && ts < static_cast<int>(dataOri_.size()))
         return dataOri_.at(ts);
 
-    static vector<float> emptyVec;
+    static std::vector<float> emptyVec;
     return emptyVec;
 }
 
 
-string MvScmVar::units() const
+std::string MvScmVar::units() const
 {
     if (unitsConverter_)
         return unitsConverter_->units_;
@@ -339,7 +343,7 @@ void MvScmVar::setAttributes(MvNcVar* var)
             }
             else if (att->sname() == "units" && att->values()) {
                 units_ = att->as_string(0);
-            }           
+            }
         }
     }
 }
@@ -425,7 +429,7 @@ bool MvScmVar::setValue(int ts, int lev, float val, MvScmProfileChange& ch, bool
     return false;
 }
 
-bool MvScmVar::setValues(int ts, float val, vector<MvScmProfileChange>& ch, bool checkCons)
+bool MvScmVar::setValues(int ts, float val, std::vector<MvScmProfileChange>& ch, bool checkCons)
 {
     if (ts >= 0 && ts < static_cast<int>(data_.size())) {
         int levnum = static_cast<int>(data_.at(ts).size());
@@ -522,7 +526,7 @@ bool MvScmVar::saveChanges(MvNetCDF& nc)
                     counts[1] = data_.at(ts).size();
 
                     if (unitsConverter_) {
-                        vector<float> vals(data_.at(ts).size());
+                        std::vector<float> vals(data_.at(ts).size());
                         for (size_t i = 0; i < data_.at(ts).size(); i++) {
                             vals[i] = unitsConverter_->convertFrom(data_.at(ts).at(i));
                         }
@@ -540,7 +544,7 @@ bool MvScmVar::saveChanges(MvNetCDF& nc)
                     counts[0] = 1;
 
                     if (unitsConverter_) {
-                        vector<float> vals;
+                        std::vector<float> vals;
                         vals.push_back(unitsConverter_->convertFrom(data_.at(ts).at(0)));
                         outVar->setCurrent(ts);
                         outVar->put(vals, counts[0]);
@@ -596,7 +600,7 @@ bool MvScmVar::fitToRange(float& val)
 void MvScmVar::compute(MvScmVar* v1, CompProc1 proc)
 {
     for (unsigned int ts = 0; ts < data_.size(); ts++) {
-        const vector<float>& d1 = v1->data(ts);
+        const std::vector<float>& d1 = v1->data(ts);
 
         for (unsigned int lev = 0; lev < data_.at(ts).size(); lev++) {
             float val = (*proc)(d1.at(lev));
@@ -609,8 +613,8 @@ void MvScmVar::compute(MvScmVar* v1, CompProc1 proc)
 void MvScmVar::compute(MvScmVar* v1, MvScmVar* v2, CompProc2 proc)
 {
     for (unsigned int ts = 0; ts < data_.size(); ts++) {
-        const vector<float>& d1 = v1->data(ts);
-        const vector<float>& d2 = v2->data(ts);
+        const std::vector<float>& d1 = v1->data(ts);
+        const std::vector<float>& d2 = v2->data(ts);
 
         for (unsigned int lev = 0; lev < data_.at(ts).size(); lev++) {
             float val = (*proc)(d1.at(lev), d2.at(lev));
@@ -623,9 +627,9 @@ void MvScmVar::compute(MvScmVar* v1, MvScmVar* v2, CompProc2 proc)
 void MvScmVar::compute(MvScmVar* v1, MvScmVar* v2, MvScmVar* v3, CompProc3 proc)
 {
     for (unsigned int ts = 0; ts < data_.size(); ts++) {
-        const vector<float>& d1 = v1->data(ts);
-        const vector<float>& d2 = v2->data(ts);
-        const vector<float>& d3 = v3->data(ts);
+        const std::vector<float>& d1 = v1->data(ts);
+        const std::vector<float>& d2 = v2->data(ts);
+        const std::vector<float>& d3 = v3->data(ts);
 
         for (unsigned int lev = 0; lev < data_.at(ts).size(); lev++) {
             float val = (*proc)(d1.at(lev), d2.at(lev), d3.at(lev));
@@ -653,7 +657,7 @@ void MvScmVar::setConsistency(MvScmConsistency* c)
     consistency_ = c;
 }
 
-void MvScmVar::setUnits(float offset, float scale, string units)
+void MvScmVar::setUnits(float offset, float scale, std::string units)
 {
     if (unitsConverter_)
         return;
@@ -663,9 +667,9 @@ void MvScmVar::setUnits(float offset, float scale, string units)
     unitsConverter_->scale_  = scale;
     unitsConverter_->units_  = units;
 
-    for (unsigned int ts = 0; ts < data_.size(); ts++) {
-        for (unsigned int lev = 0; lev < data_.at(ts).size(); lev++) {
-            data_.at(ts)[lev] = unitsConverter_->convertTo(data_.at(ts)[lev]);
+    for (auto& ts : data_) {
+        for (unsigned int lev = 0; lev < ts.size(); lev++) {
+            ts[lev] = unitsConverter_->convertTo(ts[lev]);
         }
     }
 }
@@ -694,17 +698,17 @@ bool MvScmVar::overwrite(int fromTs)
     return false;
 }
 
-bool MvScmVar::write(ofstream& out, int ts, bool useConverted, bool newline)
+bool MvScmVar::write(std::ofstream& out, int ts, bool useConverted, bool newline)
 {
     if (ts >= 0 && ts < static_cast<int>(data_.size())) {
-        for (unsigned int lev = 0; lev < data_.at(ts).size(); lev++) {
+        for (float lev : data_.at(ts)) {
             if (!unitsConverter_ || useConverted)
-                out << data_.at(ts)[lev];
+                out << lev;
             else
-                out << unitsConverter_->convertFrom(data_.at(ts)[lev]);
+                out << unitsConverter_->convertFrom(lev);
 
             if (newline)
-                out << endl;
+                out << std::endl;
         }
         return true;
     }
@@ -719,7 +723,7 @@ bool MvScmVar::write(ofstream& out, int ts, bool useConverted, bool newline)
 //
 //=========================================================
 
-MvScm::MvScm(const string& fileName, bool convertUnits) :
+MvScm::MvScm(const std::string& fileName, bool convertUnits) :
     fileName_(fileName),
     convertUnits_(convertUnits)
 {
@@ -727,7 +731,7 @@ MvScm::MvScm(const string& fileName, bool convertUnits) :
     decodeId();
 
     //Map variables
-    if (id_.find("SCM") != string::npos || id_.find("scm") != string::npos) {
+    if (id_.find("SCM") != std::string::npos || id_.find("scm") != std::string::npos) {
         mapScmVars();
     }
     if (id_ == "NETCDF_RTTOV_INPUT") {
@@ -740,22 +744,22 @@ MvScm::MvScm(const string& fileName, bool convertUnits) :
 
 MvScm::~MvScm()
 {
-    for (int i = 0; i < static_cast<int>(ml_.size()); i++)
-        delete ml_.at(i);
+    for (auto& i : ml_)
+        delete i;
 
-    for (int i = 0; i < static_cast<int>(pl_.size()); i++)
-        delete pl_.at(i);
+    for (auto& i : pl_)
+        delete i;
 
-    for (int i = 0; i < static_cast<int>(surf_.size()); i++)
-        delete surf_.at(i);
+    for (auto& i : surf_)
+        delete i;
 
-    for (int i = 0; i < static_cast<int>(soil_.size()); i++)
-        delete soil_.at(i);
+    for (auto& i : soil_)
+        delete i;
 }
 
 void MvScm::decodeId()
 {
-    MvNetCDF nc(fileName_,'r');
+    MvNetCDF nc(fileName_, 'r');
 
     //Get id
     int n = nc.getNumberOfAttributes();
@@ -861,11 +865,11 @@ void MvScm::decode()
 	for(int i=0; i < n; i++)
 	{  	
 		NcAtt* att=nc.get_att(i);
-		if(att != NULL && att->name() != NULL && 
+		if(att != nullptr && att->name() != nullptr && 
 		   strcmp(att->name(),"dataID") == 0 && att->num_vals() > 0)
 		{  
 			char* v=att->as_string(0);
-			if(v) id_=string(v);
+			if(v) id_=std::string(v);
 			break;
 		}
 	}*/
@@ -884,9 +888,9 @@ void MvScm::decodeVar(MvNcVar* var)
         return;
     }
 
-    std::set<string> dims;
+    std::set<std::string> dims;
     for (int i = 0; i < var->getNumberOfDimensions(); i++) {
-        MvNcDim* dim     = var->getDimension(i);
+        MvNcDim* dim = var->getDimension(i);
         dims.insert(dim->sname());
     }
 
@@ -897,7 +901,7 @@ void MvScm::decodeVar(MvNcVar* var)
 
     if (dims.size() == 1) {
         surf_.push_back(new MvScmVar(MvScmVar::SurfaceLevelType, var, timeDim_));
-        map<string, SurfVariable>::iterator it = surfVarName_.find(surf_.back()->name());
+        auto it = surfVarName_.find(surf_.back()->name());
         if (it != surfVarName_.end()) {
             surfVarIndex_[it->second] = surf_.size() - 1;
         }
@@ -906,7 +910,7 @@ void MvScm::decodeVar(MvNcVar* var)
         if (dims.find(modelLevDim_.name()) != dims.end()) {
             ml_.push_back(new MvScmVar(MvScmVar::ModelLevelType, var, timeDim_, modelLevDim_));
 
-            map<string, ModelLevelVariable>::iterator it = mlVarName_.find(ml_.back()->name());
+            auto it = mlVarName_.find(ml_.back()->name());
             if (it != mlVarName_.end()) {
                 mlVarIndex_[it->second] = ml_.size() - 1;
 
@@ -915,7 +919,7 @@ void MvScm::decodeVar(MvNcVar* var)
                     MvScmVar* r = ml_.back();
                     r->setRange(0., 1.);
 
-                    map<ModelLevelVariable, int>::iterator tempIt = mlVarIndex_.find(TempML);
+                    auto tempIt = mlVarIndex_.find(TempML);
                     if (tempIt != mlVarIndex_.end()) {
                         int pos = tempIt->second + 1;
                         ml_.insert(ml_.begin() + pos, r);
@@ -934,7 +938,7 @@ void MvScm::decodeVar(MvNcVar* var)
         }
         else if (dims.find(soilLevDim_.name()) != dims.end()) {
             soil_.push_back(new MvScmVar(MvScmVar::SoilLevelType, var, timeDim_, soilLevDim_));
-            map<string, SoilVariable>::iterator it = soilVarName_.find(soil_.back()->name());
+            auto it = soilVarName_.find(soil_.back()->name());
             if (it != soilVarName_.end()) {
                 soilVarIndex_[it->second] = soil_.size() - 1;
             }
@@ -947,49 +951,49 @@ void MvScm::save()
     //Open progvar
     MvNetCDF nc(fileName_, 'w');
 
-    for (unsigned int i = 0; i < ml_.size(); i++) {
-        ml_.at(i)->saveChanges(nc);
+    for (auto& i : ml_) {
+        i->saveChanges(nc);
     }
-    for (unsigned int i = 0; i < surf_.size(); i++) {
-        surf_.at(i)->saveChanges(nc);
+    for (auto& i : surf_) {
+        i->saveChanges(nc);
     }
-    for (unsigned int i = 0; i < soil_.size(); i++) {
-        soil_.at(i)->saveChanges(nc);
+    for (auto& i : soil_) {
+        i->saveChanges(nc);
     }
-    for (unsigned int i = 0; i < pl_.size(); i++) {
-        pl_.at(i)->saveChanges(nc);
+    for (auto& i : pl_) {
+        i->saveChanges(nc);
     }
 }
 
 void MvScm::reset()
 {
-    for (unsigned int i = 0; i < ml_.size(); i++) {
-        ml_.at(i)->reset();
+    for (auto& i : ml_) {
+        i->reset();
     }
-    for (unsigned int i = 0; i < surf_.size(); i++) {
-        surf_.at(i)->reset();
+    for (auto& i : surf_) {
+        i->reset();
     }
-    for (unsigned int i = 0; i < soil_.size(); i++) {
-        soil_.at(i)->reset();
+    for (auto& i : soil_) {
+        i->reset();
     }
-    for (unsigned int i = 0; i < pl_.size(); i++) {
-        pl_.at(i)->reset();
+    for (auto& i : pl_) {
+        i->reset();
     }
 }
 
 bool MvScm::overwrite(int fromTs)
 {
-    for (unsigned int i = 0; i < ml_.size(); i++) {
-        ml_.at(i)->overwrite(fromTs);
+    for (auto& i : ml_) {
+        i->overwrite(fromTs);
     }
-    for (unsigned int i = 0; i < surf_.size(); i++) {
-        surf_.at(i)->overwrite(fromTs);
+    for (auto& i : surf_) {
+        i->overwrite(fromTs);
     }
-    for (unsigned int i = 0; i < soil_.size(); i++) {
-        soil_.at(i)->overwrite(fromTs);
+    for (auto& i : soil_) {
+        i->overwrite(fromTs);
     }
-    for (unsigned int i = 0; i < pl_.size(); i++) {
-        pl_.at(i)->overwrite(fromTs);
+    for (auto& i : pl_) {
+        i->overwrite(fromTs);
     }
 
     return true;
@@ -997,7 +1001,7 @@ bool MvScm::overwrite(int fromTs)
 
 int MvScm::mlVarIndex(ModelLevelVariable var)
 {
-    map<ModelLevelVariable, int>::iterator it = mlVarIndex_.find(var);
+    auto it = mlVarIndex_.find(var);
     if (it != mlVarIndex_.end()) {
         return it->second;
     }
@@ -1018,7 +1022,7 @@ MvScmVar* MvScm::mlVar(ModelLevelVariable var)
 
 int MvScm::soilVarIndex(SoilVariable var)
 {
-    map<SoilVariable, int>::iterator it = soilVarIndex_.find(var);
+    auto it = soilVarIndex_.find(var);
     if (it != soilVarIndex_.end()) {
         return it->second;
     }
@@ -1037,7 +1041,7 @@ MvScmVar* MvScm::soilVar(SoilVariable var)
 
 int MvScm::surfVarIndex(SurfVariable var)
 {
-    map<SurfVariable, int>::iterator it = surfVarIndex_.find(var);
+    auto it = surfVarIndex_.find(var);
     if (it != surfVarIndex_.end()) {
         return it->second;
     }
@@ -1097,12 +1101,12 @@ void MvScm::needConsistency(bool b)
 // Static methods
 //==========================================================
 
-int MvScm::modelLevelNum(const string& fileName)
+int MvScm::modelLevelNum(const std::string& fileName)
 {
     //Open file
     MvNetCDF nc(fileName);
 
-    int num    = -1;
+    int num = -1;
     if (MvNcDim* dim = nc.getDimension("nlev")) {
         num = dim->size();
     }
@@ -1114,20 +1118,20 @@ int MvScm::modelLevelNum(const string& fileName)
 
 
 //We add diag and diag2 contents to progvar
-bool MvScm::mergeOutFiles(const string& progvarFileName, const string& diagvarFileName, const string& diagvar2FileName)
+bool MvScm::mergeOutFiles(const std::string& progvarFileName, const std::string& diagvarFileName, const std::string& diagvar2FileName)
 {
     //Open progvar
     MvNetCDF nc(progvarFileName, 'w');
 
     //Get dims from progvar
-    vector<MvNcDim*> dims;
+    std::vector<MvNcDim*> dims;
     for (int i = 0; i < nc.getNumberOfDimensions(); i++) {
         MvNcDim* dim = nc.getDimension(i);
         if (dim) {
-            dims.push_back(dim);            
+            dims.push_back(dim);
         }
         else {
-            std::cout << "MvScm::mergeOutFiles --> bad dimension at position=" << i << endl;
+            std::cout << "MvScm::mergeOutFiles --> bad dimension at position=" << i << std::endl;
         }
     }
 
@@ -1184,10 +1188,10 @@ bool MvScm::addDimensionsToFile(MvNetCDF& inNc, MvNetCDF& outNc, std::vector<MvN
 {
     for (int i = 0; i < inNc.getNumberOfDimensions(); i++) {
         MvNcDim* dim = inNc.getDimension(i);
-        bool found = false;
-        for (unsigned int j = 0; j < dims.size(); j++) {           
-            if (strcmp(dim->name(), dims.at(j)->name()) == 0) {
-                if (dim->size() != dims.at(j)->size()) {
+        bool found   = false;
+        for (auto& j : dims) {
+            if (strcmp(dim->name(), j->name()) == 0) {
+                if (dim->size() != j->size()) {
                     return false;
                 }
                 else {
@@ -1209,21 +1213,21 @@ void MvScm::addVarToFile(MvNcVar* inVar, MvNetCDF& outNc, const std::vector<MvNc
     for (int i = 0; i < outNc.getNumberOfVariables(); i++) {
         MvNcVar* v = outNc.getVariable(i);
         if (v && strcmp(v->name(), inVar->name()) == 0) {
-            //cout << v->name() << endl;
+            //std::cout << v->name() << std::endl;
             return;
         }
     }
 
     //Check dims
-    vector<MvNcDim*> dims;
+    std::vector<MvNcDim*> dims;
     for (int i = 0; i < inVar->getNumberOfDimensions(); i++) {
         MvNcDim* dim = inVar->getDimension(i);
         if (dim) {
-            //cout << dim->sname() << " " << dim->size() << endl;
-            for (unsigned int j = 0; j < outDims.size(); j++) {
-                if (strcmp(dim->name(), outDims.at(j)->name()) == 0 &&
-                    dim->size() == outDims.at(j)->size()) {
-                    dims.push_back(outDims.at(j));
+            //std::cout << dim->sname() << " " << dim->size() << std::endl;
+            for (auto outDim : outDims) {
+                if (strcmp(dim->name(), outDim->name()) == 0 &&
+                    dim->size() == outDim->size()) {
+                    dims.push_back(outDim);
                     break;
                 }
             }
@@ -1265,7 +1269,7 @@ void MvScm::addVarToFile(MvNcVar* inVar, MvNetCDF& outNc, const std::vector<MvNc
     }
     if (inVar->getNumberOfDimensions() == 1) {
         long counts[1];
-        counts[0]   = dims[0]->size();
+        counts[0] = dims[0]->size();
         //float* vals = new float[counts[0]];
         std::vector<float> vals;
         inVar->get(vals, counts[0]);
@@ -1273,8 +1277,8 @@ void MvScm::addVarToFile(MvNcVar* inVar, MvNetCDF& outNc, const std::vector<MvNc
     }
     if (inVar->getNumberOfDimensions() == 2) {
         long counts[2];
-        counts[0]   = dims[0]->size();
-        counts[1]   = dims[1]->size();
+        counts[0] = dims[0]->size();
+        counts[1] = dims[1]->size();
         std::vector<float> vals;
         //float* vals = new float[counts[0] * counts[1]];
         inVar->get(vals, counts[0], counts[1]);
@@ -1283,16 +1287,16 @@ void MvScm::addVarToFile(MvNcVar* inVar, MvNetCDF& outNc, const std::vector<MvNc
 }
 
 //Create an ASCII input file for RTTOV
-bool MvScm::createRttovInput(const string& inFileName, const string& outFileName,
+bool MvScm::createRttovInput(const std::string& inFileName, const std::string& outFileName,
                              float sat_zenith_angle, float sat_azimuth_angle,
                              float solar_zenith_angle, float solar_azimuth_angle,
-                             bool useOzone, string& errTxt)
+                             bool useOzone, std::string& errTxt)
 {
     //Open input NetCDF file, and use original units
     MvScm in(inFileName.c_str(), false);
 
     //Check the required profiles
-    string nfTxt = " not found!";
+    std::string nfTxt = " not found!";
 
     MvScmVar* t = in.mlVar(TempML);
     if (!t) {
@@ -1314,7 +1318,7 @@ bool MvScm::createRttovInput(const string& inFileName, const string& outFileName
     }
 
     //Compute water vapour ppmv
-    MvScmVar* ppmv = new MvScmVar("ppmv", "ppmv", "ppmv", q);
+    auto* ppmv = new MvScmVar("ppmv", "ppmv", "ppmv", q);
     ppmv->compute(p, q, &MvSci::vapourPPMV);
 
     //Ozone
@@ -1486,12 +1490,12 @@ bool MvScm::createRttovInput(const string& inFileName, const string& outFileName
         clfract = v->value(0, 0);
 
     //Open ASCII output
-    ofstream out(outFileName.c_str());
+    std::ofstream out(outFileName.c_str());
     if (!out.good())
         return false;
 
     //Generate ASCII output
-    out << "! --- Profile 1 ---" << endl;
+    out << "! --- Profile 1 ---" << std::endl;
 
     out << "! \n\
 ! Pressure levels (hPa) \n\
@@ -1525,34 +1529,34 @@ bool MvScm::createRttovInput(const string& inFileName, const string& outFileName
 !\n";
 
 
-    out << t2 << " " << q2ppmv << " " << psurf / 100. << " " << u10 << " " << v10 << " 100000." << endl;
+    out << t2 << " " << q2ppmv << " " << psurf / 100. << " " << u10 << " " << v10 << " 100000." << std::endl;
 
     //tSurf->write(out,0,false);
-    //out << "  15248.0550  1007.30      5.000             2.0000            100000." << endl;
+    //out << "  15248.0550  1007.30      5.000             2.0000            100000." << std::endl;
 
     out << "!\n\
 ! Skin variables:\n\
 !  Skin T (K)  FASTEM parameters for land surfaces\n\
 !\n";
-    out << tskin << "   3.0 5.0 15.0 0.1 0.3" << endl;
+    out << tskin << "   3.0 5.0 15.0 0.1 0.3" << std::endl;
 
 
     out << "!\n\
 ! Surface type (0=land, 1=sea, 2=sea-ice) and water type (0=fresh, 1=ocean)\n\
 !\n";
-    out << surfType << " " << waterType << endl;
+    out << surfType << " " << waterType << std::endl;
 
     out << "!\n\
 ! Elevation (km), latitude and longitude (degrees)\n\
 !\n";
 
     out << orog << " "
-        << " " << lat << " " << lon << endl;
+        << " " << lat << " " << lon << std::endl;
 
     out << "!\n\
 ! Sat. zenith and azimuth angles, solar zenith and azimuth angles (degrees)\n\
 !\n";
-    out << sat_zenith_angle << "  " << sat_azimuth_angle << "  " << solar_zenith_angle << "  " << solar_azimuth_angle << endl;
+    out << sat_zenith_angle << "  " << sat_azimuth_angle << "  " << solar_zenith_angle << "  " << solar_azimuth_angle << std::endl;
 
 
     out << "!\n\
@@ -1560,7 +1564,7 @@ bool MvScm::createRttovInput(const string& inFileName, const string& outFileName
 !\n";
 
 
-    out << cltop << " " << clfract << endl;
+    out << cltop << " " << clfract << std::endl;
 
     out << "!\n\
 ! --- End of profile 1 ---\n\
