@@ -13,7 +13,8 @@
 #include <sys/time.h>
 #include <unistd.h>
 
-#include "inc_iostream.h"
+#include <iostream>
+
 #include "MvStopWatch.h"
 
 //_________________________________________________________ Constructors
@@ -54,7 +55,7 @@ void MvStopWatch::reset(const char* anExplanationString)
     printTimes(startingTimeStamp_, startingClockStamp_);
 
     printHead("reset - start new stopwatch!");
-    cout << anExplanationString << " - ";
+    std::cout << anExplanationString << " - ";
     printDateTime();
 
     explanationString_ = anExplanationString;
@@ -73,7 +74,7 @@ void MvStopWatch::lapTime()
 void MvStopWatch::lapTime(const char* anExplanationString)
 {
     printHead("laptime");
-    cout << anExplanationString << ": ";
+    std::cout << anExplanationString << ": ";
     printTimes(previousTimeStamp_, previousClockStamp_);
 
     previousTimeStamp_  = currentTimeStamp_;
@@ -97,11 +98,11 @@ void MvStopWatch::startTimer()
 
 void MvStopWatch::printHead(const char* string)
 {
-    cout << "["
-         << explanationString_.c_str()
-         << "\\"
-         << string
-         << "] ";
+    std::cout << "["
+              << explanationString_.c_str()
+              << "\\"
+              << string
+              << "] ";
 }
 //_________________________________________________________ printTimes
 
@@ -112,16 +113,16 @@ void MvStopWatch::printTimes(struct tms& beginTimeStamp, struct timeval& beginCl
     times(&currentTimeStamp_);
     gettimeofday(&currentClockStamp_, nullptr);
 
-    double userTicks = (double)(currentTimeStamp_.tms_utime - beginTimeStamp.tms_utime);
-    double sysTicks  = (double)(currentTimeStamp_.tms_stime - beginTimeStamp.tms_stime);
+    auto userTicks = (double)(currentTimeStamp_.tms_utime - beginTimeStamp.tms_utime);
+    auto sysTicks  = (double)(currentTimeStamp_.tms_stime - beginTimeStamp.tms_stime);
 
-    cout << userTicks / sClockTicks
-         << "u/"
-         << sysTicks / sClockTicks
-         << "s CPU ["
-         << (currentClockStamp_.tv_sec - beginClockStamp.tv_sec)
-         << " sec wall clock]"
-         << endl;
+    std::cout << userTicks / sClockTicks
+              << "u/"
+              << sysTicks / sClockTicks
+              << "s CPU ["
+              << (currentClockStamp_.tv_sec - beginClockStamp.tv_sec)
+              << " sec wall clock]"
+              << std::endl;
     times(&currentTimeStamp_);
 }
 //_________________________________________________________ printDateTime
@@ -130,5 +131,5 @@ void MvStopWatch::printDateTime()
 {
     time_t t;
     time(&t);
-    cout << ctime(&t);  //-- ctime ends with a '\n'!!!
+    std::cout << ctime(&t);  //-- ctime ends with a '\n'!!!
 }
