@@ -10,14 +10,12 @@
 // rev vk 031125 ---------------- (vk Jun92) ---------------- MvStopWatch.h
 //
 
-#ifndef MVSTOPWATCH_H
-#define MVSTOPWATCH_H
+#pragma once
 
 #include <time.h>
 #include <sys/times.h>
-#include "inc_iostream.h"
-#include <string.h>
-using std::string;
+
+#include <string>
 
 class MvStopWatch
 {
@@ -46,7 +44,5 @@ private:
     struct timeval previousClockStamp_;
     struct timeval currentClockStamp_;
 
-    string explanationString_;
+    std::string explanationString_;
 };
-
-#endif  //MVSTOPWATCH_H
