@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvTemplates_DEFINED
-#define MvTemplates_DEFINED
+#pragma once
 
 #include <Metview.h>
 
@@ -114,13 +113,15 @@ public:
             if (exitOnError_) {
                 exit(0);
             }
-        } else {
+        }
+        else {
             saveOutRequest(in, out);
             sendReply(out);
         }
     }
 
-    void saveOutRequest(const MvRequest& in, const MvRequest& out) {
+    void saveOutRequest(const MvRequest& in, const MvRequest& out)
+    {
         // Save request to be processed by uPlotManager?
         if (!outParamName_.empty()) {
             //if ((const char*)in("_UPLOT_MANAGER_ID"))
@@ -166,6 +167,3 @@ public:
     void callback(MvRequest&);
 };
 #endif
-
-
-#endif
