@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVTMPFILE_H
-#define MVTMPFILE_H
+#pragma once
 
 #include <string>
 
@@ -26,5 +25,3 @@ protected:
     std::string path_;
     bool autoRemove_;
 };
-
-#endif  // MVTMPFILE_H
