@@ -11,7 +11,7 @@
 #include <cstdlib>
 
 #include "MvVersionInfo.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 #include "eccodes.h"
 
