@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVWINDEF_H
-#define MVWINDEF_H
+#pragma once
 
 /* Microsoft Windows Visual Studio support */
 #if defined(_WIN32) && defined(_MSC_VER)
@@ -24,5 +23,3 @@
 #define WEXITSTATUS(status) (status)
 
 #endif
-
-#endif  // MVWINDEF_H
