@@ -8,7 +8,8 @@
  ***************************** LICENSE END *************************************/
 
 #include "Point.hpp"
-#include "min_max_macros.h"
+
+#include <algorithm>
 
 short Point ::get(FILE* fp)
 {
@@ -46,10 +47,10 @@ Point Point ::operator=(const Point& p)
 
 Point Point ::pmax(const Point& p) const
 {
-    return Point(max(_x, p._x), max(_y, p._y));
+    return Point(std::max(_x, p._x), std::max(_y, p._y));
 }
 
 Point Point ::pmin(const Point& p) const
 {
-    return Point(min(_x, p._x), min(_y, p._y));
+    return Point(std::min(_x, p._x), std::min(_y, p._y));
 }
