@@ -9,9 +9,15 @@
 
 #include "TableReader.h"
 
+#ifdef MAGICS
+#include "MagException.h"
+#include "MagicsGlobal.h"
+namespace magics {
+#else
+namespace metview {
+#endif
 
-void TableReader::resizeDecoders(unsigned int numNeeded)
-{
+void TableReader::resizeDecoders(unsigned int numNeeded) {
     // do we need to resize our list of decoders?
 
     if (numNeeded > decoderSets_.size()) {
@@ -23,8 +29,8 @@ void TableReader::resizeDecoders(unsigned int numNeeded)
 }
 
 
-void TableReader::setFieldContainer(int index, std::string& name, std::vector<double>& container, double outputMissingIndicator)
-{
+void TableReader::setFieldContainer(int index, std::string& name, std::vector<double>& container,
+                                    double outputMissingIndicator) {
     if (index == -1)  // is the user wanting to find a field with the given name?
     {
         int foundIndex = indexOfField(name);  // try to find it
@@ -55,8 +61,8 @@ void TableReader::setFieldContainer(int index, std::string& name, std::vector<do
 }
 
 
-void TableReader::setFieldContainer(int index, std::string& name, std::vector<std::string>& container, std::string outputMissingIndicator)
-{
+void TableReader::setFieldContainer(int index, std::string& name, std::vector<std::string>& container,
+                                    std::string outputMissingIndicator) {
     if (index == -1)  // is the user wanting to find a field with the given name?
     {
         int foundIndex = indexOfField(name);  // try to find it
@@ -92,8 +98,7 @@ void TableReader::setFieldContainer(int index, std::string& name, std::vector<st
 //  NOTE: this function is destructive to the input string!
 // ---------------------------------------------------------------------------
 
-void TableReader::splitLine(char* line, std::vector<char*>& tokens)
-{
+void TableReader::splitLine(char* line, std::vector<char*>& tokens) {
     char* current = line;
     char* token   = current;
 
@@ -119,8 +124,7 @@ void TableReader::splitLine(char* line, std::vector<char*>& tokens)
 //  NOTE: this function is destructive to the input string!
 // ---------------------------------------------------------------------------
 
-void TableReader::splitLineConsecutiveDelimiters(char* line, std::vector<char*>& tokens)
-{
+void TableReader::splitLineConsecutiveDelimiters(char* line, std::vector<char*>& tokens) {
     char* current = line;
     char* token   = current;
 
@@ -151,8 +155,7 @@ void TableReader::splitLineConsecutiveDelimiters(char* line, std::vector<char*>&
 }
 
 
-void TableReader::ensureHaveMetaData()
-{
+void TableReader::ensureHaveMetaData() {
     if (!gotMetaData_)  // caller should have retrieved the meta-data already
     {
         std::string msg;
@@ -163,40 +166,35 @@ void TableReader::ensureHaveMetaData()
     }
 }
 
-std::vector<TableReader::eTableReaderFieldType>& TableReader::fieldTypes()
-{
+std::vector<TableReader::eTableReaderFieldType>& TableReader::fieldTypes() {
     ensureHaveMetaData();
 
     return types_;
 }
 
 
-std::vector<std::string>& TableReader::fieldNames()
-{
+std::vector<std::string>& TableReader::fieldNames() {
     ensureHaveMetaData();
 
     return namesAll_;
 }
 
 
-std::map<std::string, std::string>& TableReader::userMetaData()
-{
+std::map<std::string, std::string>& TableReader::userMetaData() {
     ensureHaveMetaData();
 
     return userMetaData_;
 }
 
 
-int TableReader::numRecords()
-{
+int TableReader::numRecords() {
     ensureHaveMetaData();
 
     return numRecords_;
 }
 
 
-int TableReader::indexOfField(std::string& name)
-{
+int TableReader::indexOfField(std::string& name) {
     ensureHaveMetaData();
 
 
@@ -219,8 +217,7 @@ int TableReader::indexOfField(std::string& name)
 // takes an element and tries to decide which data type it is, e.g. number
 // ---------------------------------------------------------------------------
 
-TableReader::eTableReaderFieldType TableReader::guessFieldType(char* str)
-{
+TableReader::eTableReaderFieldType TableReader::guessFieldType(char* str) {
     if (str) {
         char* pch = str;
 
@@ -238,8 +235,7 @@ TableReader::eTableReaderFieldType TableReader::guessFieldType(char* str)
 }
 
 
-int TableReader::nextLineTokens(char* line, size_t sizeOfLine, std::vector<char*>& tokens)
-{
+int TableReader::nextLineTokens(char* line, size_t sizeOfLine, std::vector<char*>& tokens) {
     // skip blank lines
 
     /*    bool gotLine = true;
@@ -260,7 +256,8 @@ int TableReader::nextLineTokens(char* line, size_t sizeOfLine, std::vector<char*
 
         std::streamsize numread = f_.gcount();
 
-        if ((numread >= 2) && (line[numread - 1] == '\0') && (line[numread - 2] == '\r'))  // remove extraneous newline characters from Windows
+        if ((numread >= 2) && (line[numread - 1] == '\0') &&
+            (line[numread - 2] == '\r'))  // remove extraneous newline characters from Windows
             line[numread - 2] = '\0';
 
         if (consecutiveDelimitersAsOne_)
@@ -284,8 +281,7 @@ int TableReader::nextLineTokens(char* line, size_t sizeOfLine, std::vector<char*
 // PARAM1=VALUE1 PARAM2=VALUE2
 // ---------------------------------------------------------------------------
 
-bool TableReader::readUserMetaData(char* line, size_t sizeOfLine, std::string& errorMessage)
-{
+bool TableReader::readUserMetaData(char* line, size_t sizeOfLine, std::string& errorMessage) {
     int currentRow      = 1;
     char oldDelimiter   = delimiter_;                   // store because we will over-ride it
     bool oldConsecutive = consecutiveDelimitersAsOne_;  // store because we will over-ride it
@@ -345,8 +341,7 @@ bool TableReader::readUserMetaData(char* line, size_t sizeOfLine, std::string& e
 // into.
 // ---------------------------------------------------------------------------
 
-void TableReader::skipLines(int linesToSkip, char* line, size_t sizeOfLine)
-{
+void TableReader::skipLines(int linesToSkip, char* line, size_t sizeOfLine) {
     for (int i = 0; i < linesToSkip; i++) {
         f_.getline(line, sizeOfLine);
     }
@@ -360,8 +355,7 @@ void TableReader::skipLines(int linesToSkip, char* line, size_t sizeOfLine)
 // file.
 // ---------------------------------------------------------------------------
 
-bool TableReader::getMetaData(std::string& errorMessage)
-{
+bool TableReader::getMetaData(std::string& errorMessage) {
     if (gotMetaData_)  // we should only need to get the meta-data once
         return true;
 
@@ -393,6 +387,11 @@ bool TableReader::getMetaData(std::string& errorMessage)
 
     if (f_.fail()) {
         errorMessage = "TableReader: Could not open table file: " + path();
+#ifdef MAGICS
+        if (MagicsGlobal::strict()) {
+            throw CannotOpenFile(path());
+        }
+#endif
         return false;
     }
 
@@ -468,7 +467,8 @@ bool TableReader::getMetaData(std::string& errorMessage)
             else  // this is a data row
             {
                 if (types_.size() != tokens.size()) {
-                    errorMessage = "Not the same number of elements in the first 2 lines of table. Check file format parameters.";
+                    errorMessage =
+                        "Not the same number of elements in the first 2 lines of table. Check file format parameters.";
                     f_.close();  // close the input file
                     return false;
                 }
@@ -490,8 +490,7 @@ bool TableReader::getMetaData(std::string& errorMessage)
 }
 
 
-bool TableReader::read(std::string& errorMessage)
-{
+bool TableReader::read(std::string& errorMessage) {
     const int MAX_CHARS_IN_LINE = 1024 * 100;
     char line[MAX_CHARS_IN_LINE];
 
@@ -576,7 +575,8 @@ bool TableReader::read(std::string& errorMessage)
                 else  // otherwise, the disparity in numbers indicates a problem
                 {
                     char msg[128];
-                    sprintf(msg, "TableReader: record %d has %u elements, but the first record has %u. Failed to read.", i + 1, (unsigned int)tokens.size(), (unsigned int)decoderSets_.size());
+                    sprintf(msg, "TableReader: record %d has %u elements, but the first record has %u. Failed to read.",
+                            i + 1, (unsigned int)tokens.size(), (unsigned int)decoderSets_.size());
                     errorMessage = msg;
                     f_.close();  // close the input file
                     return false;
@@ -591,7 +591,7 @@ bool TableReader::read(std::string& errorMessage)
             for (auto& decoderSet : decoderSets_) {
                 for (auto decoder = decoderSet.begin(); decoder != decoderSet.end(); ++decoder) {
                     if (*decoder != nullptr) {
-                        //std::string str(*s);
+                        // std::string str(*s);
                         (*decoder)->addValue(*s);
                     }
                 }
@@ -604,3 +604,4 @@ bool TableReader::read(std::string& errorMessage)
 
     return true;
 }
+}
\ No newline at end of file
