@@ -16,6 +16,11 @@
 #include <vector>
 #include "fstream_mars_fix.h"
 
+#ifdef MAGICS
+namespace magics {
+#else
+namespace metview {
+#endif
 
 /*! -----------------------------------------------------------------
     \class TableFormatAttributes
@@ -23,14 +28,9 @@
     file is formatted.
    ----------------------------------------------------------------- */
 
-class TableFormatAttributes
-{
+class TableFormatAttributes {
 public:
-    TableFormatAttributes() :
-        delimiter_(','),
-        headerRow_(1),
-        consecutiveDelimitersAsOne_(false),
-        dataRowOffset_(0) {}
+    TableFormatAttributes() : delimiter_(','), headerRow_(1), consecutiveDelimitersAsOne_(false), dataRowOffset_(0) {}
 
     void setPath(std::string& path) { path_ = path; }
     void setPath(const char* path) { path_ = std::string(path); }
@@ -63,16 +63,14 @@ protected:
     particular data types (e.g. double, string).
    ----------------------------------------------------------------- */
 
-class TableElementDecoder
-{
+class TableElementDecoder {
 public:
-    TableElementDecoder() :
-        currentIndex_(0) {}
+    TableElementDecoder() : currentIndex_(0) {}
     virtual ~TableElementDecoder() {}
 
     virtual void initialise(int numValues) = 0;
     virtual void addValue(char* value)     = 0;
-    //virtual void decodeElement (char *element) = 0;
+    // virtual void decodeElement (char *element) = 0;
 
 protected:
     int currentIndex_;
@@ -81,16 +79,14 @@ protected:
 
 /*! -----------------------------------------------------------------
     \class TableDoubleVectorElementDecoder
-    Derived class to handle the decoding of numeric data from a 
+    Derived class to handle the decoding of numeric data from a
     table file. The data will be put into a vector of doubles.
    ----------------------------------------------------------------- */
 
-class TableDoubleVectorElementDecoder : public TableElementDecoder
-{
+class TableDoubleVectorElementDecoder : public TableElementDecoder {
 public:
     TableDoubleVectorElementDecoder(std::vector<double>& target, double outMiss) :
-        target_(target),
-        outputMissingIndicator_(outMiss) {}
+        target_(target), outputMissingIndicator_(outMiss) {}
 
     void initialise(int numValues) { target_.reserve(numValues); }
     void addValue(char* value) { target_.push_back((value[0] != '\0') ? atof(value) : outputMissingIndicator_); }
@@ -103,16 +99,14 @@ private:
 
 /*! -----------------------------------------------------------------
     \class TableStringVectorElementDecoder
-    Derived class to handle the decoding of string data from a 
+    Derived class to handle the decoding of string data from a
     table file. The data will be put into a vector of strings.
    ----------------------------------------------------------------- */
 
-class TableStringVectorElementDecoder : public TableElementDecoder
-{
+class TableStringVectorElementDecoder : public TableElementDecoder {
 public:
     TableStringVectorElementDecoder(std::vector<std::string>& target, std::string outMiss) :
-        target_(target),
-        outputMissingIndicator_(outMiss) {}
+        target_(target), outputMissingIndicator_(outMiss) {}
 
     void initialise(int numValues) { target_.reserve(numValues); }
     void addValue(char* value) { target_.push_back((value[0] != '\0') ? value : outputMissingIndicator_); }
@@ -138,8 +132,7 @@ typedef std::vector<TableElementDecoder*> TableElementDecoders;  // for shorthan
 
    ----------------------------------------------------------------- */
 
-class TableReader : public TableFormatAttributes
-{
+class TableReader : public TableFormatAttributes {
 public:
     enum eTableReaderFieldType
     {
@@ -147,20 +140,19 @@ public:
         TABFIELD_STRING
     };
 
-    TableReader()
-    {
+    TableReader() {
         gotMetaData_ = false;
         errorCode_   = 0;
     }
-    TableReader(std::string& path)
-    {
+    TableReader(std::string& path) {
         setPath(path);
         gotMetaData_ = false;
         errorCode_   = 0;
     }
 
     void setFieldContainer(int index, std::string& name, std::vector<double>& container, double outputMissingIndicator);
-    void setFieldContainer(int index, std::string& name, std::vector<std::string>& container, std::string outputMissingIndicator);
+    void setFieldContainer(int index, std::string& name, std::vector<std::string>& container,
+                           std::string outputMissingIndicator);
 
     // setFieldContainer (std::string &name, std::vector<double>);
     // setFieldContainer (std::string &name, std::vector<std::string>);
@@ -175,20 +167,22 @@ public:
 
 private:
     void resizeDecoders(unsigned int numNeeded);
-    int nextLineTokens(char* line, size_t sizeOfLine, std::vector<char*>& tokens);    // reads the next line and splits into tokens
-    void splitLine(char* line, std::vector<char*>& tokens);                           // splits a line into tokens based on the current settings
-    void splitLineConsecutiveDelimiters(char* line, std::vector<char*>& tokens);      // splits a line into tokens based on the current settings
+    int nextLineTokens(char* line, size_t sizeOfLine,
+                       std::vector<char*>& tokens);          // reads the next line and splits into tokens
+    void splitLine(char* line, std::vector<char*>& tokens);  // splits a line into tokens based on the current settings
+    void splitLineConsecutiveDelimiters(
+        char* line, std::vector<char*>& tokens);  // splits a line into tokens based on the current settings
     bool readUserMetaData(char* line, size_t sizeOfLine, std::string& errorMessage);  // reads user meta-data into a map
-    int indexOfField(std::string& name);                                              // returns the index of the field with a given name (or -1)
-    void setError(std::string msg)
-    {
+    int indexOfField(std::string& name);  // returns the index of the field with a given name (or -1)
+    void setError(std::string msg) {
         errorCode_ = 1;
         errorMsg_  = msg;
     }                                                                // set an error message to be used later
     void clearError() { errorCode_ = 0; }                            // clear error message and code to be used later
     void ensureHaveMetaData();                                       // loads the meta-data if not already there
     void skipLines(int linesToSkip, char* line, size_t sizeOfLine);  // skips a user-defined number of rows
-    TableReader::eTableReaderFieldType guessFieldType(char* str);    // tries to determine whether the field is, for example, string or number
+    TableReader::eTableReaderFieldType guessFieldType(
+        char* str);  // tries to determine whether the field is, for example, string or number
 
     std::vector<TableElementDecoders> decoderSets_;  // each column can have multiple decoders attached to it
     std::vector<std::string*> names_;
@@ -202,3 +196,4 @@ private:
     int errorCode_;         // some functions will set these to be used later
     std::string errorMsg_;  // some functions will set these to be used later
 };
+}
\ No newline at end of file
