@@ -9,22 +9,19 @@
 
 #include "Tokenizer.h"
 
-Tokenizer::Tokenizer(const string& separators)
+Tokenizer::Tokenizer(const std::string& separators)
 {
-    for (size_t i = 0; i < separators.length(); i++)
-        separator_.insert(separators[i]);
+    for (char separator : separators)
+        separator_.insert(separator);
 }
 
-Tokenizer::~Tokenizer()
-{
-}
+Tokenizer::~Tokenizer() = default;
 
-
-void Tokenizer::operator()(const string& raw, std::vector<string>& v)
+void Tokenizer::operator()(const std::string& raw, std::vector<std::string>& v)
 {
-    int index    = 0;
-    int length   = raw.length();
-    string token = "";
+    int index         = 0;
+    int length        = raw.length();
+    std::string token = "";
 
     while (index < length) {
         char c = raw[index];
