@@ -13,12 +13,13 @@
 // For the new Magics version, both files should be
 // replaced by a single C++ version.
 
-#include <string.h>
+#include "proj_braz.hpp"
+
 #include <stdio.h>
-#include <string.h>
 #include <stdlib.h>
 #include <math.h>
-#include "proj_braz.hpp"
+
+#include <cstring>
 
 static Datum* D;
 static SProjection *Sp1, *Sp2;
@@ -478,7 +479,7 @@ void pimind_(int i1, char* tx, Real Pdx, Real Pdy, Real Pdz, double Prd, double
     return;
 }
 
-void pimp1_(char* txo, char* txs, int Pid, int Pcode, int Pdatum, int i3, Real Pdx, Real Pdy, Real Pdz, double Prd, double Pflt, double Poffx, double Poffy)
+void pimp1_(char* txo, char* txs, int Pid, int Pcode, int Pdatum, int /*i3*/, Real Pdx, Real Pdy, Real Pdz, double Prd, double Pflt, double Poffx, double Poffy)
 {
     //	int			i;
     //	short		Pcode,Pdatum;
@@ -511,7 +512,7 @@ void pimp1_(char* txo, char* txs, int Pid, int Pcode, int Pdatum, int i3, Real P
     return;
 }
 
-void pimp2_(char* txo, char* txs, int Pid, int Pcode, int Pdatum, int i3, Real Pdx, Real Pdy, Real Pdz, double Prd, double Pflt, double Poffx, double Poffy)
+void pimp2_(char* txo, char* txs, int Pid, int Pcode, int Pdatum, int /*i3*/, Real Pdx, Real Pdy, Real Pdz, double Prd, double Pflt, double Poffx, double Poffy)
 {
     //	int		i;
     //	short		Pcode,Pdatum;
@@ -1241,7 +1242,7 @@ CPoint pPolPC2LL(SProjection* Sp, CPoint ptpc)
         equad, /* Squared eccentricity */
         e,     /* Eccentricity */
         lon0,  /* auxilliary origin longitude */
-        ro, t, xx, aux1, aux2, aux3, aux4, aux5, ptpcx=0., ptpcy, px, py;
+        ro, t, xx, aux1, aux2, aux3, aux4, aux5, ptpcx = 0., ptpcy, px, py;
     short GPhemis;
     double GPlon0;
     double Pflt, Prd;
