@@ -64,7 +64,7 @@ AbstractSearchLine::AbstractSearchLine(QWidget* parent) :
     // we have to add CTRL-G ourselves.
 
     QKeySequence ctrlg(tr("Ctrl+G"));
-    QShortcut* shortcut = new QShortcut(ctrlg, parent);  // should be destroyed by parent
+    auto* shortcut = new QShortcut(ctrlg, parent);  // should be destroyed by parent
     connect(shortcut, SIGNAL(activated()), this, SLOT(slotFindNext()));
 
     status_ = true;
@@ -75,7 +75,7 @@ AbstractSearchLine::AbstractSearchLine(QWidget* parent) :
     caseSensitive_ = false;
     wholeWords_    = false;
     highlightAll_  = false;
-    QMenu* menu    = new QMenu(this);
+    auto* menu     = new QMenu(this);
     menu->addAction(actionCaseSensitive_);
     menu->addAction(actionWholeWords_);
     menu->addAction(actionHighlightAll_);
@@ -87,15 +87,13 @@ AbstractSearchLine::AbstractSearchLine(QWidget* parent) :
     setConfirmSearch(false);
 }
 
-AbstractSearchLine::~AbstractSearchLine()
-{
-}
+AbstractSearchLine::~AbstractSearchLine() = default;
 
 void AbstractSearchLine::setColours()
 {
-    QString group  = "searchline";
-    notFoundSh_ = MvQTheme::styleSheet(group, "not_found");
-    oriSh_ = MvQTheme::styleSheet(group, "normal");
+    QString group = "searchline";
+    notFoundSh_   = MvQTheme::styleSheet(group, "not_found");
+    oriSh_        = MvQTheme::styleSheet(group, "normal");
 }
 
 void AbstractSearchLine::clear()
@@ -116,7 +114,7 @@ void AbstractSearchLine::selectAll()
 
 void AbstractSearchLine::toDefaultState()
 {
-     searchLine_->setStyleSheet(oriSh_);
+    searchLine_->setStyleSheet(oriSh_);
 }
 
 void AbstractSearchLine::updateButtons(bool found)
