@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef VIEWER_SRC_ABSTRACTTEXTEDITSEARCHINTERFACE_HPP_
-#define VIEWER_SRC_ABSTRACTTEXTEDITSEARCHINTERFACE_HPP_
+#pragma once
 
 #include "StringMatchMode.h"
 #include "MvQProperty.h"
@@ -43,6 +42,3 @@ protected:
     MvQProperty* vpAutomaticSearchFrom_;
     MvQProperty* vpAutomaticSearchCase_;
 };
-
-
-#endif /* VIEWER_SRC_ABSTRACTTEXTEDITSEARCHINTERFACE_HPP_ */
