@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef CALENDARDIALOG_H
-#define CALENDARDIALOG_H
+#pragma once
 
 #include "ui_CalendarDialog.h"
 
@@ -26,5 +25,3 @@ public:
 Q_SIGNALS:
     void dateSelected(QDate);
 };
-
-#endif  // CALENDARDIALOG_H
