@@ -10,7 +10,7 @@
 DateEditWidget::DateEditWidget(QWidget* parent) :
     QWidget(parent)
 {
-    QHBoxLayout* hb = new QHBoxLayout(this);
+    auto* hb = new QHBoxLayout(this);
     hb->setContentsMargins(0, 0, 0, 0);
     hb->setSpacing(0);
 
