@@ -1,5 +1,5 @@
-#ifndef DATEEDITWIDGET_H
-#define DATEEDITWIDGET_H
+
+#pragma once
 
 #include <QWidget>
 
@@ -21,5 +21,3 @@ private:
     QDateEdit* dateEdit_;
     QToolButton* clearTb_;
 };
-
-#endif  // DATEEDITWIDGET_H
