@@ -7,19 +7,17 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef GotoLineDialog_H
-#define GotoLineDialog_H
+#pragma once
 
 #include "ui_GotoLineDialog.h"
 
-using namespace std;
 
-class GotoLineDialog : public QDialog, private Ui::GotoLineDialogQ
+class GotoLineDialog : public QDialog, private Ui::GotoLineDialog
 {
     Q_OBJECT
 
 public:
-    explicit GotoLineDialog(QWidget* parent = 0);
+    explicit GotoLineDialog(QWidget* parent = nullptr);
     ~GotoLineDialog();
     void setupUIBeforeShow();
 
@@ -31,5 +29,3 @@ public Q_SLOTS:
     void slotDone();
     void setButtonStatus();
 };
-
-#endif
