@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef ICONPROVIDER_HPP_
-#define ICONPROVIDER_HPP_
+#pragma once
 
 #include <QPixmap>
 
@@ -73,5 +72,3 @@ private:
     static std::map<QString, IconItem*> icons_;
     static std::map<int, IconItem*> iconsById_;
 };
-
-#endif
