@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef LOCATIONMAP_H
-#define LOCATIONMAP_H
+#pragma once
 
 #include "ui_LocationMap.h"
 
@@ -39,5 +38,3 @@ protected:
 
     bool ignoreSlider_;
 };
-
-#endif  // LOCATIONMAP_H
