@@ -18,7 +18,7 @@
 #include <QWheelEvent>
 #include <QGraphicsRectItem>
 
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 #include <cmath>
 
@@ -390,9 +390,9 @@ void LocationView::addPoints(const std::vector<double>& lat, const std::vector<d
 
         if (lonVal <= 180. && lonVal >= -180. &&
             latVal >= -90. && latVal <= 90.) {
-            hasValidPoint       = true;
-            MapMarkerItem* item = new MapMarkerItem(i);
-            markers_[i]         = item;
+            hasValidPoint = true;
+            auto* item    = new MapMarkerItem(i);
+            markers_[i]   = item;
             item->setPos(QPointF(lonVal, latVal));
             scene_->addItem(item);
 
