@@ -46,7 +46,7 @@ LocationWidget::LocationWidget(QWidget* parent) :
 
     prof_ = new MvKeyProfile("location");
 
-    MvKey* key = new MvKey("msg", "Message");
+    auto* key = new MvKey("msg", "Message");
     key->setRole(MvKey::MessageIndexRole);
     key->setValueType(MvKey::IntType);
     prof_->addKey(key);
