@@ -20,10 +20,10 @@
 #include <QToolButton>
 
 #include "MvQArrowSpinWidget.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "MvQTheme.h"
 
-MessageControlPanel::MessageControlPanel(bool hasSubset, bool hasFilter, QWidget* parent) :
+MessageControlPanel::MessageControlPanel(bool hasSubset, bool /*hasFilter*/, QWidget* parent) :
     MvQPanel(parent),
     subsetSpin_(nullptr),
     subsetLabel_(nullptr)
@@ -33,7 +33,7 @@ MessageControlPanel::MessageControlPanel(bool hasSubset, bool hasFilter, QWidget
     layout_ = new QHBoxLayout(this);
     layout_->setContentsMargins(4, 2, 4, 2);
 
-    QLabel* messageTitleLab = new QLabel(tr("&Message:"), this);
+    auto* messageTitleLab = new QLabel(tr("&Message:"), this);
     messageTitleLab->setProperty("panelStyle", styleId);
     messageTitleLab->setObjectName("messageTitleLabel");
     messageSpin_ = new MvQArrowSpinWidget(this);
@@ -78,7 +78,7 @@ MessageControlPanel::MessageControlPanel(bool hasSubset, bool hasFilter, QWidget
     optionsTb_->setPopupMode(QToolButton::InstantPopup);
     optionsTb_->setToolTip(tr("Options"));
 
-    QMenu* menu = new QMenu(this);
+    auto* menu = new QMenu(this);
     menu->setTearOffEnabled(true);
     optionsTb_->setMenu(menu);
 
@@ -86,12 +86,12 @@ MessageControlPanel::MessageControlPanel(bool hasSubset, bool hasFilter, QWidget
 }
 
 
-void MessageControlPanel::setMessageValue(int num, bool b)
+void MessageControlPanel::setMessageValue(int num, bool /*b*/)
 {
     messageSpin_->setValue(num, false);
 }
 
-void MessageControlPanel::resetMessageNum(int num, bool b)
+void MessageControlPanel::resetMessageNum(int num, bool /*b*/)
 {
     messageSpin_->reset(num, false);
 
@@ -99,7 +99,7 @@ void MessageControlPanel::resetMessageNum(int num, bool b)
     totalLabel_->setText(s);
 }
 
-void MessageControlPanel::resetSubsetNum(int num, bool b)
+void MessageControlPanel::resetSubsetNum(int num, bool)
 {
     Q_ASSERT(subsetSpin_);
     subsetSpin_->reset(num, false);
@@ -107,7 +107,7 @@ void MessageControlPanel::resetSubsetNum(int num, bool b)
 
 void MessageControlPanel::setCurrentSubset(int cnt)
 {
-    if (cnt>=1 && subsetSpin_->value() != cnt) {
+    if (cnt >= 1 && subsetSpin_->value() != cnt) {
         subsetSpin_->setValue(cnt, true);
     }
 }
@@ -121,8 +121,8 @@ void MessageControlPanel::setSubsetLabel(QString txt)
 void MessageControlPanel::setSubsetTotalLabel(int msgNum, int subsetNum)
 {
     QString s = "(total number of messages: <b>" +
-            QString::number(msgNum) +
-            "</b>, subsets: <b>" +  QString::number(subsetNum) + "</b>)";
+                QString::number(msgNum) +
+                "</b>, subsets: <b>" + QString::number(subsetNum) + "</b>)";
     totalLabel_->setText(s);
 }
 
@@ -173,7 +173,7 @@ void MessageControlPanel::addButtonAction(QAction* ac)
 {
     buttonActions_ << ac;
     Q_ASSERT(ac);
-    QToolButton* tb = new QToolButton(this);
+    auto* tb = new QToolButton(this);
     tb->setDefaultAction(ac);
     tb->setProperty("panelStyle", 2);
     layout_->insertWidget(layout_->count() - 1, tb);
