@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQAbout_H
-#define MvQAbout_H
+#pragma once
 
 #include <QDialog>
 #include <QMap>
@@ -35,5 +34,3 @@ public:
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(MvQAbout::Versions);
-
-#endif
