@@ -44,7 +44,6 @@
 
 #include <iostream>
 #include <sstream>
-#include <fstream>
 #include <cstdio>
 #include <stdio.h>
 #include <stdlib.h>
@@ -52,7 +51,7 @@
 #include "MvQAbstractMessageExaminer.h"
 
 #include "MvKeyProfile.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 #ifdef METVIEW
 #include "MvVersionInfo.h"
@@ -84,6 +83,7 @@
 
 #include "MvQBufrMessageScanner.h"
 #include "MvQGribMessageScanner.h"
+#include "MvLog.h"
 
 #define _UI_MVQABSTRACTMESSAGEEXAMINER_DEBUG
 
@@ -96,7 +96,7 @@ MvQMessagePanel::MvQMessagePanel(QWidget* parent) :
     // Message tree (key profile)
     //--------------------------------
 
-    QVBoxLayout* layout = new QVBoxLayout(this);
+    auto* layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(1);
 
@@ -112,8 +112,8 @@ MvQMessagePanel::MvQMessagePanel(QWidget* parent) :
     sortModel_->setFilterKeyColumn(0);
 
     //progress bar
-    progWidget_         = new QWidget(this);
-    QHBoxLayout* progHb = new QHBoxLayout(progWidget_);
+    progWidget_  = new QWidget(this);
+    auto* progHb = new QHBoxLayout(progWidget_);
     progHb->setContentsMargins(0, 1, 0, 0);
 
     progLabel_ = new QLabel(this);
@@ -203,14 +203,14 @@ void MvQMessagePanel::loadKeyProfileCore(MvKeyProfile* prof)
         connect(loader_, SIGNAL(profileReady(MvKeyProfile*)),
                 this, SLOT(slotKeyProfileReady(MvKeyProfile*)));
 
-//        connect(loader_, SIGNAL(started()),
-//                this, SLOT(slotKeyProfileLoadStarted()));
+        //        connect(loader_, SIGNAL(started()),
+        //                this, SLOT(slotKeyProfileLoadStarted()));
 
         connect(loader_, SIGNAL(loadStarted()),
                 this, SLOT(slotKeyProfileLoadStarted()));
 
-//        connect(loader_, SIGNAL(finished()),
-//                this, SLOT(slotKeyProfileLoadFinished()));
+        //        connect(loader_, SIGNAL(finished()),
+        //                this, SLOT(slotKeyProfileLoadFinished()));
 
         connect(loader_, SIGNAL(loadFinished()),
                 this, SLOT(slotKeyProfileLoadFinished()));
@@ -233,6 +233,7 @@ void MvQMessagePanel::slotKeyProfileLoadStarted()
 void MvQMessagePanel::slotKeyProfileLoadFinished()
 {
     progWidget_->hide();
+    tree_->viewport()->update();
     emit keyProfileLoadFinished();
 }
 
@@ -348,7 +349,7 @@ void MvQMessagePanel::adjustProfile(bool reload, int selectedRow)
         Q_ASSERT(profDef);
         //Clear the data
         MvKeyProfile* prof = profDef->clone();
-        prof->setMetaData("selectedRow", metview::toString<int>(selectedRow));
+        prof->setMetaData("selectedRow", std::to_string(selectedRow));
 
         //Update grib metadata with the new key profile
         loadKeyProfileCore(prof);  //can be threaded!!!!
@@ -437,7 +438,7 @@ MvQAbstractMessageExaminer::MvQAbstractMessageExaminer(QString appName, Type typ
     // The main layout (the upper part of mainSplitter)
     //-----------------------------------------------------
 
-    QVBoxLayout* mainLayout = new QVBoxLayout;
+    auto* mainLayout = new QVBoxLayout;
     mainLayout->setObjectName(QString::fromUtf8("vboxLayout"));
     mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->setSpacing(0);
@@ -687,9 +688,9 @@ void MvQAbstractMessageExaminer::setupEditMenu()
 void MvQAbstractMessageExaminer::setupSettingsMenu()
 {
 #ifdef ECCODES_UI
-    QMenu *styleMenu = new QMenu(tr("UI Theme"), this);
+    QMenu* styleMenu = new QMenu(tr("UI Theme"), this);
 
-    styleAg_ = new QActionGroup(this);
+    styleAg_                   = new QActionGroup(this);
     QAction* actionLightStyle_ = new QAction(this);
     actionLightStyle_->setText(tr("Light"));
     actionLightStyle_->setData("light");
@@ -716,7 +717,7 @@ void MvQAbstractMessageExaminer::setupSettingsMenu()
 void MvQAbstractMessageExaminer::setupProfilesMenu()
 {
     //
-    QAction* actionNew = new QAction(this);
+    auto* actionNew = new QAction(this);
     actionNew->setObjectName(QString::fromUtf8("actionProfileNew"));
     actionNew->setText(tr("&New profile"));
     actionNew->setToolTip(tr("Create new key profile"));
@@ -724,7 +725,7 @@ void MvQAbstractMessageExaminer::setupProfilesMenu()
     icon.addPixmap(QPixmap(QString::fromUtf8(":/keyDialog/profile_add.svg")), QIcon::Normal, QIcon::Off);
     actionNew->setIcon(icon);
 
-    QAction* actionSaveAs = new QAction(this);
+    auto* actionSaveAs = new QAction(this);
     actionSaveAs->setObjectName(QString::fromUtf8("actionProfileSaveAs"));
     actionSaveAs->setText(tr("&Duplicate profile ..."));
     actionSaveAs->setToolTip(tr("Duplicate key profile"));
@@ -732,7 +733,7 @@ void MvQAbstractMessageExaminer::setupProfilesMenu()
     icon2.addPixmap(QPixmap(QString::fromUtf8(":/keyDialog/profile_duplicate.svg")), QIcon::Normal, QIcon::Off);
     actionSaveAs->setIcon(icon2);
 
-    QAction* actionProfileManager = new QAction(this);
+    auto* actionProfileManager = new QAction(this);
     actionProfileManager->setObjectName(QString::fromUtf8("actionKeyProfileManager"));
     actionProfileManager->setText(tr("&Manage profiles"));
     actionProfileManager->setToolTip(tr("Manage key profiles"));
@@ -764,15 +765,15 @@ void MvQAbstractMessageExaminer::setupProfilesMenu()
             this, SLOT(slotManageKeyProfiles()));
 
 
-    QWidget* wh     = new QWidget(this);
-    QHBoxLayout* hb = new QHBoxLayout(wh);
+    auto* wh = new QWidget(this);
+    auto* hb = new QHBoxLayout(wh);
     hb->setContentsMargins(1, 1, 1, 1);
 
     //Combo box
     //We will add items + signal/slots later in "init"!
     //Combo box for key profile selection
-    QLabel* keyLabel = new QLabel(tr("Key profile:"), wh);
-    keyCombo_ = new QComboBox(wh);
+    auto* keyLabel = new QLabel(tr("Key profile:"), wh);
+    keyCombo_      = new QComboBox(wh);
     keyLabel->setBuddy(keyCombo_);
 
     hb->addWidget(keyLabel);
@@ -794,7 +795,7 @@ void MvQAbstractMessageExaminer::setupProfilesMenu()
 void MvQAbstractMessageExaminer::setupHelpMenu()
 {
     // About
-    QAction* actionAbout = new QAction(this);
+    auto* actionAbout = new QAction(this);
     actionAbout->setObjectName(QString::fromUtf8("actionAbout"));
     actionAbout->setText(tr("&About ") + appName_);
 
@@ -1039,7 +1040,7 @@ void MvQAbstractMessageExaminer::slotManageKeyProfiles()
 
     if (profDialog.exec() == QDialog::Accepted) {
         //Save the current profile name
-        string currentProfName = keyCombo_->currentText().toStdString();
+        std::string currentProfName = keyCombo_->currentText().toStdString();
 #if 0
 		messageModel_->keyProfileIsAboutToChange();
 		messageModel_->setKeyProfile(0);
@@ -1056,7 +1057,7 @@ void MvQAbstractMessageExaminer::slotManageKeyProfiles()
 
         int i     = 0;
         int index = -1;
-        for (vector<MvKeyProfile*>::const_iterator it = keyManager_->data().begin(); it != keyManager_->data().end(); it++) {
+        for (auto it = keyManager_->data().begin(); it != keyManager_->data().end(); it++) {
             keyCombo_->addItem(QString((*it)->name().c_str()));
             if ((*it)->name() == currentProfName) {
                 index = i;
@@ -1208,7 +1209,7 @@ void MvQAbstractMessageExaminer::slotUiStyleSelect(QAction* ac)
 {
     if (ac) {
         MvQTheme::writeCodesUiStyleName(ac->data().toString());
-        QMessageBox::information(this,"codes_ui", tr("Please restart codes_ui to apply the Ui Theme change."));
+        QMessageBox::information(this, "codes_ui", tr("Please restart codes_ui to apply the Ui Theme change."));
     }
 }
 #endif
@@ -1311,7 +1312,7 @@ void MvQAbstractMessageExaminer::readSettings(QSettings& settings)
 
 #ifdef ECCODES_UI
     auto styleName = MvQTheme::id();
-    for (auto ac: styleAg_->actions()) {
+    for (auto ac : styleAg_->actions()) {
         if (ac->data().toString() == styleName) {
             ac->setChecked(true);
             break;
@@ -1319,4 +1320,3 @@ void MvQAbstractMessageExaminer::readSettings(QSettings& settings)
     }
 #endif
 }
-
