@@ -7,16 +7,26 @@
 
  ***************************** LICENSE END *************************************/
 
+#include "MvQApplication.h"
+
+#include <cstring>
+#include <exception>
+#include <fstream>
+#include <iostream>
+#include "fstream_mars_fix.h"
+
 #include <QtGui>
 #include <QStyleFactory>
 #include <QMainWindow>
 
 #include <MvTemplates.h>
 
-#include "MvQApplication.h"
 #include "MvQMethods.h"
 #include "MvQTheme.h"
 #include "PmContext.h"
+#include "MvException.h"
+#include "MvLog.h"
+#include "MvLog.h"
 
 MvQApplication::MvQApplication(int& ac, char** av, const char* name, QStringList resources) :
     QApplication(ac, av),
@@ -33,38 +43,38 @@ MvQApplication::MvQApplication(int& ac, char** av, const char* name, QStringList
     //Get desktop name
     char* desktop = getenv("MV_DESKTOP_NAME");
     if (desktop == 0) {
-        std::cout << "Error: MV_DESKTOP_NAME is not defined! MvQApplication exits" << endl;
+        std::cout << "Error: MV_DESKTOP_NAME is not defined! MvQApplication exits" << std::endl;
         exit(1);
     }
 
     std::string dn(desktop);
     desktopName_            = new char[dn.size() + 1];
     desktopName_[dn.size()] = '\0';
-    memcpy(desktopName_, dn.c_str(), dn.size());
+    std::memcpy(desktopName_, dn.c_str(), dn.size());
 
     //Get qt style
     char* styleCh = getenv("METVIEW_QT_STYLE");
     if (styleCh == 0) {
-        marslog(LOG_EROR," Error: METVIEW_QT_STYLE is not defined! MvQApplication exits");
+        marslog(LOG_EROR, " Error: METVIEW_QT_STYLE is not defined! MvQApplication exits");
         exit(1);
     }
 
     std::string style(styleCh);
     QStringList styleLst = QStyleFactory::keys();
-    QString styleQs = QString::fromStdString(style);
+    QString styleQs      = QString::fromStdString(style);
     if (styleLst.contains(styleQs)) {
         marslog(LOG_INFO, "Setting qt style to: %s", style.c_str());
         setStyle(styleQs);
     }
 
     //Set fontsize if defined in env var
-    if(const char* fontSizeCh=getenv("MV_FONT_SIZE")) {
-        int fontSize=atoi(fontSizeCh);
-        if(fontSize < 8)
-            fontSize=8;
-        else if(fontSize > 32)
-            fontSize=32;
-        QFont f=font();
+    if (const char* fontSizeCh = getenv("MV_FONT_SIZE")) {
+        int fontSize = atoi(fontSizeCh);
+        if (fontSize < 8)
+            fontSize = 8;
+        else if (fontSize > 32)
+            fontSize = 32;
+        QFont f = font();
         f.setPointSize(fontSize);
         setFont(f);
     }
@@ -83,11 +93,14 @@ MvQApplication::MvQApplication(int& ac, char** av, const char* name, QStringList
 
     // load ui theme
     MvQTheme::init(this, resources);
+
+    //    // init application logger
+    //    MvLog::registerApp(this);
 }
 
 MvQApplication::~MvQApplication()
 {
-    delete [] desktopName_;
+    delete[] desktopName_;
 }
 
 void MvQApplication::slotDataReceived(int)
@@ -115,12 +128,12 @@ void MvQApplication::messageCallbackCore(svcid* id, request* r, void* obj)
     std::cout << "MvQService::messageCallback" << std::endl;
     print_all_requests(r);
 #endif
-    if (MvQApplication* s = static_cast<MvQApplication*>(obj))
+    if (auto* s = static_cast<MvQApplication*>(obj))
         s->messageCallback(id, r);
 }
 
 //the apps own callback function for message
-void MvQApplication::messageCallback(svcid* id, request* r)
+void MvQApplication::messageCallback(svcid* /*id*/, request* r)
 {
     if (strcmp(r->name, "RAISE_WINDOW") == 0 && win_) {
         auto pidStr = std::to_string(getpid());
@@ -140,13 +153,13 @@ void MvQApplication::registerToDesktop(QMainWindow* win)
         return;
 
     win_ = win;
-    add_message_callback(MvApplication::getService(), NULL,
+    add_message_callback(MvApplication::getService(), nullptr,
                          messageCallbackCore, (void*)this);
 }
 
 void MvQApplication::writePidToFile(const MvRequest& r)
 {
-    if(const char *ch = r("_PID_FILE")) {
+    if (const char* ch = r("_PID_FILE")) {
         std::ofstream f;
         f.open(ch);
         if (f.good())
@@ -156,3 +169,28 @@ void MvQApplication::writePidToFile(const MvRequest& r)
     }
 }
 
+// Handle uncaught exceptions
+bool MvQApplication::notify(QObject* receiver, QEvent* event)
+{
+    static std::string txtIntro{"Fatal error: " + name() + " raised an uncaught exception!\n\nError: "};
+
+    try {
+        return QApplication::notify(receiver, event);
+    }
+    catch (const MvException& e) {
+        std::string txt = txtIntro + std::string((e.what()) ? e.what() : "");
+        abortWithPopup(txt);
+    }
+    catch (const std::exception& e) {
+        std::string txt = txtIntro + std::string((e.what()) ? e.what() : "");
+        abortWithPopup(txt);
+    }
+    return false;
+}
+
+void MvQApplication::writeToUiLog(const std::string& msg, MvLogLevel level, bool popup)
+{
+    if (popup) {
+        MvQ::showMessageBox(msg, level);
+    }
+}
