@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQARROWSPINWIDGET_HPP
-#define MVQARROWSPINWIDGET_HPP
+#pragma once
 
 #include <QWidget>
 
@@ -46,6 +45,3 @@ protected:
     QSpinBox* spin_;
     bool broadcast_;
 };
-
-
-#endif  // ARROWSPINWIDGET_HPP
