@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQConfigDialog_H
-#define MvQConfigDialog_H
+#pragma once
 
 #include <QDialog>
 #include <QIcon>
@@ -34,5 +33,3 @@ protected:
     QListWidget* list_;
     QStackedWidget* page_;
 };
-
-#endif
