@@ -14,7 +14,7 @@
 #include "MvQMethods.h"
 
 
-MvQDropTarget* MvQDropTarget::instance_ = 0;
+MvQDropTarget* MvQDropTarget::instance_ = nullptr;
 
 MvQDropTarget* MvQDropTarget::Instance()
 {
@@ -24,7 +24,7 @@ MvQDropTarget* MvQDropTarget::Instance()
 }
 
 MvQDropTarget::MvQDropTarget() :
-    QLabel(0),
+    QLabel(nullptr),
     move_(true),
     xPadding_(4),
     yPadding_(4)
