@@ -38,8 +38,8 @@ QString MvQFileInfoLabel::buildTextLabel(QString fileName, QString fileExtraText
     MvQFileInfo info(fileName);
 
     auto subCol = MvQTheme::subText();
-    auto bold = MvQTheme::boldFileInfoTitle();
-    s = MvQ::formatText("File: ", subCol, bold) + info.absoluteFilePath();
+    auto bold   = MvQTheme::boldFileInfoTitle();
+    s           = MvQ::formatText("File: ", subCol, bold) + info.absoluteFilePath();
 
     if (!fileExtraText.isEmpty()) {
         s += " " + fileExtraText;
@@ -49,7 +49,7 @@ QString MvQFileInfoLabel::buildTextLabel(QString fileName, QString fileExtraText
     if (info.isSymLink()) {
         s += MvQ::formatText("Symlink target: ", subCol) + info.symLinkTarget() + "<br>";
     }
-        
+
     s += MvQ::formatText("Permissions: ", subCol, bold) + info.formatPermissions();
     s += MvQ::formatText(" Owner: ", subCol, bold) + info.owner();
     s += MvQ::formatText(" Group: ", subCol, bold) + info.group();
@@ -70,21 +70,21 @@ void MvQFileInfoLabel::setGribTextLabel(QString fileName, int messageNum, bool f
     QString s = buildTextLabel(fileName);
     s += "<br>";
 
-    auto subCol = MvQTheme::subText();
+    auto subCol    = MvQTheme::subText();
     auto accentCol = MvQTheme::accentText();
-    auto bold = MvQTheme::boldFileInfoTitle();
-   
+    auto bold      = MvQTheme::boldFileInfoTitle();
+
     if (filtered) {
         s += MvQ::formatText("Number of filtered messages: ", subCol, bold) +
-                QString::number(filteredMessageNum) +
-                " (out of " + QString::number(messageNum) + ")";
+             QString::number(filteredMessageNum) +
+             " (out of " + QString::number(messageNum) + ")";
     }
     else {
         s += MvQ::formatText("Total number of messages: ", subCol, bold) +
-            QString::number(messageNum);
-        
+             QString::number(messageNum);
+
         if (hasMultiMessage) {
-            s += MvQ::formatText(" (some messages contain multiple fields!) ", accentCol);        
+            s += MvQ::formatText(" (some messages contain multiple fields!) ", accentCol);
         }
     }
     setText(s);
@@ -95,19 +95,20 @@ void MvQFileInfoLabel::setBufrTextLabel(QString fileName, int messageNum, bool f
     QString s = buildTextLabel(fileName);
     s += "<br>";
 
-    auto subCol = MvQTheme::subText();
+    auto subCol    = MvQTheme::subText();
     auto accentCol = MvQTheme::accentText();
-    auto bold = MvQTheme::boldFileInfoTitle();
+    auto bold      = MvQTheme::boldFileInfoTitle();
 
     if (filtered) {
         s += MvQ::formatText("Number of filtered messages: ", subCol, bold) +
              MvQ::formatText(QString::number(filteredMessageNum) +
-                          " (out of " + QString::number(messageNum) + ")", accentCol);
+                                 " (out of " + QString::number(messageNum) + ")",
+                             accentCol);
     }
     else {
         s += MvQ::formatText("Total number of messages: ", subCol, bold) +
-            QString::number(messageNum);
-        
+             QString::number(messageNum);
+
         if (hasSubset) {
             s += MvQ::formatText(" (some messages contain subsets!) ", accentCol);
         }
@@ -124,8 +125,8 @@ void MvQFileInfoLabel::setOdbTextLabel(QString fileName, QString)
 void MvQFileInfoLabel::setGeopTextLabel(QString fileName, QString format, long itemNum)
 {
     auto subCol = MvQTheme::subText();
-    auto bold = MvQTheme::boldFileInfoTitle();
-    QString s = buildTextLabel(fileName);
+    auto bold   = MvQTheme::boldFileInfoTitle();
+    QString s   = buildTextLabel(fileName);
     s += "<br>";
     s += MvQ::formatText("Format: ", subCol, bold) + format + "<br>" +
          MvQ::formatText(" Total number of points: ", subCol, bold) + QString::number(itemNum);
@@ -135,21 +136,21 @@ void MvQFileInfoLabel::setGeopTextLabel(QString fileName, QString format, long i
 void MvQFileInfoLabel::setFlextraTextLabel(QString fileName, QString iconName, int itemNum)
 {
     auto subCol = MvQTheme::subText();
-    auto bold = MvQTheme::boldFileInfoTitle();
+    auto bold   = MvQTheme::boldFileInfoTitle();
     QString s;
     if (!iconName.isEmpty()) {
-         s = MvQ::formatText("Icon: ", subCol, bold) + iconName + "<br>";
+        s = MvQ::formatText("Icon: ", subCol, bold) + iconName + "<br>";
     }
     s += buildTextLabel(fileName) + "<br>" +
-        MvQ::formatText("Total number of groups: ", subCol, bold) + QString::number(itemNum);
+         MvQ::formatText("Total number of groups: ", subCol, bold) + QString::number(itemNum);
     setText(s);
 }
 
 void MvQFileInfoLabel::setProfileTextLabel(QString fileName, int stepNum, int levNum, QString id)
 {
     auto subCol = MvQTheme::subText();
-    auto bold = MvQTheme::boldFileInfoTitle();
-    QString s = buildTextLabel(fileName);
+    auto bold   = MvQTheme::boldFileInfoTitle();
+    QString s   = buildTextLabel(fileName);
     s += "<br>";
     s += MvQ::formatText("Steps: ", subCol, bold) + QString::number(stepNum) +
          MvQ::formatText(" Model levels: ", subCol, bold) + QString::number(levNum) +
