@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQFileInfoLabel_H
-#define MvQFileInfoLabel_H
+#pragma once
 
 #include <QLabel>
 
@@ -27,5 +26,3 @@ public:
 protected:
     QString buildTextLabel(QString, QString fileExtraText = QString());
 };
-
-#endif
