@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQFILELISTMODEL_H
-#define MVQFILELISTMODEL_H
+#pragma once
 
 #include <QAbstractItemModel>
 
@@ -43,5 +42,3 @@ public slots:
 protected:
     MvQFileList* data_;
 };
-
-#endif  // MVQFILELISTMODEL_H
