@@ -46,8 +46,8 @@ MvQFsFilterModel::MvQFsFilterModel(QObject* parent) :
 
 bool MvQFsFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const
 {
-    QModelIndex index         = sourceModel()->index(sourceRow, 0, sourceParent);
-    QFileSystemModel* fsModel = qobject_cast<QFileSystemModel*>(sourceModel());
+    QModelIndex index = sourceModel()->index(sourceRow, 0, sourceParent);
+    auto* fsModel     = qobject_cast<QFileSystemModel*>(sourceModel());
 
     if (!fsModel)
         return false;
@@ -71,7 +71,7 @@ bool MvQFsFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex& source
 
 bool MvQFsFilterModel::lessThan(const QModelIndex& left, const QModelIndex& right) const
 {
-    QFileSystemModel* fsModel = qobject_cast<QFileSystemModel*>(sourceModel());
+    auto* fsModel = qobject_cast<QFileSystemModel*>(sourceModel());
 
     if (!fsModel)
         return false;
@@ -93,34 +93,33 @@ MvQFileListWidget::MvQFileListWidget(QWidget* parent) :
     QWidget(parent),
     fileLst_(0)
 {
-    QVBoxLayout* vb = new QVBoxLayout(this);
+    auto* vb = new QVBoxLayout(this);
     vb->setContentsMargins(0, 0, 0, 0);
     vb->setSpacing(0);
 
     auto titleBar = new MvQPanel(this);
     vb->addWidget(titleBar);
 
-    QHBoxLayout* titleHb = new QHBoxLayout(titleBar);
+    auto* titleHb = new QHBoxLayout(titleBar);
     titleHb->setContentsMargins(0, 0, 0, 0);
     titleHb->addSpacing(4);
     //hb->setSpacing(0);
     //QLabel* titleLabel=new QLabel("<b>" + tr("Files") + "</b>",this);
-    QLabel* titleLabel = new QLabel(tr("Files"), this);
+    auto* titleLabel = new QLabel(tr("Files"), this);
     titleLabel->setProperty("panelStyle", "2");
     titleHb->addWidget(titleLabel);
 
-    QToolButton* clearTb = new QToolButton(this);
+    auto* clearTb = new QToolButton(this);
     clearTb->setAutoRaise(true);
     clearTb->setIcon(QPixmap(":/examiner/wastebasket_orange.svg"));
     clearTb->setProperty("panelStyle", "2");
     clearTb->setToolTip(tr("Clear file list"));
     titleHb->addWidget(clearTb);
-    ;
 
     connect(clearTb, SIGNAL(clicked(bool)),
             this, SIGNAL(clearPanel(bool)));
 
-    QToolButton* closeTb = new QToolButton(this);
+    auto* closeTb = new QToolButton(this);
     closeTb->setAutoRaise(true);
     //closeTb->setIcon(QPixmap(":/find/close.svg"));
     closeTb->setIcon(QPixmap(":/examiner/panel_close.svg"));
