@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQFILELISTWIDGET_H
-#define MVQFILELISTWIDGET_H
+#pragma once
 
 #include <QWidget>
 
@@ -47,5 +46,3 @@ protected:
     MvQFsFilterModel* fsFilterModel_;
     QTreeView* fsView_;
 };
-
-#endif  // MVQFILELISTWIDGET_H
