@@ -12,8 +12,6 @@
 
 #include "MvQHighlighter.h"
 
-using namespace std;
-
 MvQHighlighter::MvQHighlighter(QTextDocument* parent) :
     QSyntaxHighlighter(parent)
 {
@@ -21,16 +19,16 @@ MvQHighlighter::MvQHighlighter(QTextDocument* parent) :
 
 void MvQHighlighter::highlightBlock(const QString& text)
 {
-    foreach (HighlightingRule rule, highlightingRules) {       
+    foreach (HighlightingRule rule, highlightingRules) {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
         QRegularExpression expression(rule.pattern);
         QRegularExpressionMatch rmatch;
         int index = text.indexOf(expression, 0, &rmatch);
         while (index >= 0) {
-             int length = rmatch.capturedLength();
-             setFormat(index, length, rule.format);
-             index = text.indexOf(expression, index + length, &rmatch);
-         }
+            int length = rmatch.capturedLength();
+            setFormat(index, length, rule.format);
+            index = text.indexOf(expression, index + length, &rmatch);
+        }
 #else
         QRegExp expression(rule.pattern);
         int index = text.indexOf(expression);
@@ -44,7 +42,7 @@ void MvQHighlighter::highlightBlock(const QString& text)
     setCurrentBlockState(0);
 }
 
-MvQOdbSqlHighlighter::MvQOdbSqlHighlighter(QTextDocument* parent, QStringList columns, QStringList functions) :
+MvQOdbSqlHighlighter::MvQOdbSqlHighlighter(QTextDocument* parent, QStringList columns, QStringList /*functions*/) :
     MvQHighlighter(parent)
 {
     HighlightingRule rule;
