@@ -42,28 +42,28 @@
 //===================================
 
 
-MvQKeyProfileDialog::MvQKeyProfileDialog(QString title, MvQKeyManager* manager, int currentRow, QWidget* parent) :
+MvQKeyProfileDialog::MvQKeyProfileDialog(QString /*title*/, MvQKeyManager* manager, int currentRow, QWidget* parent) :
     QWidget(parent),
     manager_(manager)
 {
-    QVBoxLayout* layout = new QVBoxLayout;
+    auto* layout = new QVBoxLayout;
     setLayout(layout);
 
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     layout->addLayout(hb);
 
     profList_ = new QListWidget(this);
     //profList_->setAlternatingRowColors(true);
     hb->addWidget(profList_);
 
-    QVBoxLayout* vb = new QVBoxLayout;
+    auto* vb = new QVBoxLayout;
     hb->addLayout(vb);
 
-    QPushButton* addPb = new QPushButton(tr("&New"), this);
+    auto* addPb = new QPushButton(tr("&New"), this);
     addPb->setIcon(QIcon(QPixmap(QString::fromUtf8(":/keyDialog/profile_add.svg"))));
     addPb->setToolTip(tr("Add new profile"));
 
-    QPushButton* saveAsPb = new QPushButton(tr("Du&plicate"), this);
+    auto* saveAsPb = new QPushButton(tr("Du&plicate"), this);
     saveAsPb->setIcon(QIcon(QPixmap(QString::fromUtf8(":/keyDialog/profile_duplicate.svg"))));
     saveAsPb->setToolTip(tr("Duplicate profile"));
 
@@ -101,11 +101,11 @@ MvQKeyProfileDialog::MvQKeyProfileDialog(QString title, MvQKeyManager* manager,
 
 void MvQKeyProfileDialog::init(int row)
 {
-    for (vector<MvKeyProfile*>::const_iterator it = manager_->data().begin(); it != manager_->data().end(); it++) {
-        MvKeyProfile* prof    = *it;
-        QListWidgetItem* item = new QListWidgetItem(QString(prof->name().c_str()));
+    for (auto it : manager_->data()) {
+        MvKeyProfile* prof = it;
+        auto* item         = new QListWidgetItem(QString(prof->name().c_str()));
 
-        if ((*it)->systemProfile()) {
+        if (it->systemProfile()) {
             item->setIcon(MvQTheme::logo());
         }
 
@@ -254,7 +254,7 @@ void MvQKeyProfileDialog::slotRenameProfile()
 //
 //=================================================
 
-MvQKeyListPage::MvQKeyListPage(QString title, MvQKeyManager* manager, QList<MvKeyProfile*> allKeys,
+MvQKeyListPage::MvQKeyListPage(QString /*title*/, MvQKeyManager* manager, QList<MvKeyProfile*> allKeys,
                                QWidget* parent) :
     QWidget(parent),
     manager_(manager),
@@ -262,16 +262,16 @@ MvQKeyListPage::MvQKeyListPage(QString title, MvQKeyManager* manager, QList<MvKe
 {
     //setWindowTitle(title);
 
-    QVBoxLayout* layout = new QVBoxLayout;
+    auto* layout = new QVBoxLayout;
     setLayout(layout);
 
     //Profiles
 
-    QHBoxLayout* profHb = new QHBoxLayout;
+    auto* profHb = new QHBoxLayout;
     layout->addLayout(profHb);
 
-    QLabel* label = new QLabel(tr("Profile:"), this);
-    profCombo_    = new QComboBox(this);
+    auto* label = new QLabel(tr("Profile:"), this);
+    profCombo_  = new QComboBox(this);
     label->setBuddy(profCombo_);
     profHb->addWidget(label);
     profHb->addWidget(profCombo_);
@@ -283,7 +283,7 @@ MvQKeyListPage::MvQKeyListPage(QString title, MvQKeyManager* manager, QList<MvKe
     // Keys control
     //-----------------------------
 
-    QHBoxLayout* hbPb = new QHBoxLayout;
+    auto* hbPb = new QHBoxLayout;
     hbPb->setSpacing(2);
     layout->addLayout(hbPb);
 
@@ -329,10 +329,10 @@ MvQKeyListPage::MvQKeyListPage(QString title, MvQKeyManager* manager, QList<MvKe
     splitter_ = new QSplitter(this);
     layout->addWidget(splitter_);
 
-    QWidget* w = new QWidget(this);
+    auto* w = new QWidget(this);
     splitter_->addWidget(w);
 
-    QVBoxLayout* vbKey = new QVBoxLayout(w);
+    auto* vbKey = new QVBoxLayout(w);
     vbKey->setContentsMargins(0, 0, 0, 0);
     vbKey->setSpacing(4);
 
@@ -356,14 +356,14 @@ MvQKeyListPage::MvQKeyListPage(QString title, MvQKeyManager* manager, QList<MvKe
     w = new QWidget(this);
     splitter_->addWidget(w);
 
-    QVBoxLayout* vbAllKey = new QVBoxLayout(w);
+    auto* vbAllKey = new QVBoxLayout(w);
     vbAllKey->setContentsMargins(0, 0, 0, 0);
     vbAllKey->setSpacing(4);
 
-    QHBoxLayout* comboLayout = new QHBoxLayout;
+    auto* comboLayout = new QHBoxLayout;
 
-    QLabel* comboLabel = new QLabel(tr(" Available keys in category: "), this);
-    allKeyCombo_       = new QComboBox(this);
+    auto* comboLabel = new QLabel(tr(" Available keys in category: "), this);
+    allKeyCombo_     = new QComboBox(this);
     comboLabel->setBuddy(allKeyCombo_);
 
     comboLayout->addWidget(comboLabel);
@@ -440,8 +440,7 @@ MvQKeyListPage::MvQKeyListPage(QString title, MvQKeyManager* manager, QList<MvKe
 void MvQKeyListPage::init()
 {
     int i = 0;
-    for (vector<MvKeyProfile*>::const_iterator it = manager_->data().begin(); it != manager_->data().end(); it++) {
-        MvKeyProfile* prof = *it;
+    for (auto prof : manager_->data()) {
         profCombo_->addItem(QString(prof->name().c_str()));
         if (prof->systemProfile()) {
             profCombo_->setItemIcon(i, MvQTheme::logo());
@@ -470,12 +469,12 @@ void MvQKeyListPage::slotProfilesChanged()
 
     int i     = 0;
     int index = -1;
-    for (vector<MvKeyProfile*>::const_iterator it = manager_->data().begin(); it != manager_->data().end(); it++) {
-        profCombo_->addItem(QString((*it)->name().c_str()));
-        if ((*it)->name() == currentProfName.toStdString()) {
+    for (auto it : manager_->data()) {
+        profCombo_->addItem(QString(it->name().c_str()));
+        if (it->name() == currentProfName.toStdString()) {
             index = i;
         }
-        if ((*it)->systemProfile()) {
+        if (it->systemProfile()) {
             profCombo_->setItemIcon(i, MvQTheme::logo());
         }
         i++;
@@ -542,7 +541,7 @@ void MvQKeyListPage::slotAddKey()
     if (prof == 0)  //|| !index.isValid())
         return;
 
-    MvKey* key = new MvKey;
+    auto* key = new MvKey;
     MvQKeyEditDialog keyDialog(key);
 
     if (keyDialog.exec() == QDialog::Accepted && !key->name().empty()) {
@@ -640,7 +639,7 @@ void MvQKeyListPage::slotEditKey()
     }
 }
 
-void MvQKeyListPage::slotEditTree(const QModelIndex& index)
+void MvQKeyListPage::slotEditTree(const QModelIndex& /*index*/)
 {
     slotEditKey();
 }
@@ -709,7 +708,7 @@ void MvQKeyListPage::readSettings(QSettings& settings)
     settings.endGroup();
 }
 
-MvQKeyImportPage::MvQKeyImportPage(QString title, MvQKeyManager* manager, QWidget* parent) :
+MvQKeyImportPage::MvQKeyImportPage(QString /*title*/, MvQKeyManager* manager, QWidget* parent) :
     QWidget(parent),
     manager_(manager)
 {
@@ -720,32 +719,32 @@ MvQKeyImportPage::MvQKeyImportPage(QString title, MvQKeyManager* manager, QWidge
 
     QLabel* label;
 
-    QVBoxLayout* layout = new QVBoxLayout;
+    auto* layout = new QVBoxLayout;
     setLayout(layout);
 
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     layout->addLayout(hb);
 
     label = new QLabel(tr("Profiles in GribExaminer:"), this);
     hb->addWidget(label);
 
-    QHBoxLayout* hbMain = new QHBoxLayout;
+    auto* hbMain = new QHBoxLayout;
     layout->addLayout(hbMain);
 
     profList_ = new QListWidget(this);
     hbMain->addWidget(profList_);
 
-    QVBoxLayout* vb = new QVBoxLayout;
+    auto* vb = new QVBoxLayout;
     hbMain->addLayout(vb);
 
-    QPushButton* importPb = new QPushButton(tr("&Import"), this);
+    auto* importPb = new QPushButton(tr("&Import"), this);
     importPb->setIcon(QIcon(QPixmap(QString::fromUtf8(":/keyDialog/profile_import.svg"))));
     importPb->setToolTip(tr("Import selected profiles"));
 
-    QPushButton* selectAllPb = new QPushButton(tr("&Select all"), this);
+    auto* selectAllPb = new QPushButton(tr("&Select all"), this);
     selectAllPb->setToolTip(tr("Select all profiles"));
 
-    QPushButton* unselectAllPb = new QPushButton(tr("&Unselect all"), this);
+    auto* unselectAllPb = new QPushButton(tr("&Unselect all"), this);
     unselectAllPb->setToolTip(tr("Unselect all profiles"));
 
     vb->addWidget(importPb);
@@ -773,9 +772,8 @@ MvQKeyImportPage::~MvQKeyImportPage()
 void MvQKeyImportPage::init()
 {
     //QStringList items;
-    for (vector<MvKeyProfile*>::const_iterator it = inManager_->data().begin(); it != inManager_->data().end(); it++) {
-        MvKeyProfile* prof    = *it;
-        QListWidgetItem* item = new QListWidgetItem(profList_);
+    for (auto prof : inManager_->data()) {
+        auto* item = new QListWidgetItem(profList_);
         item->setText(QString(prof->name().c_str()));
 
         if (prof->systemProfile()) {
@@ -815,7 +813,7 @@ void MvQKeyImportPage::slotImport()
         if (profList_->item(i)->flags() & Qt::ItemIsUserCheckable &&
             profList_->item(i)->checkState() == Qt::Checked) {
             MvKeyProfile* prof = inManager_->data().at(i);
-            string name        = prof->name();
+            std::string name   = prof->name();
 
             QString qsName(name.c_str());
             qsName = manager_->findUniqueProfileName(qsName);
@@ -835,10 +833,10 @@ MvQKeyEditDialog::MvQKeyEditDialog(MvKey* key, QWidget* parent) :
 {
     setWindowTitle(tr("Edit key"));
 
-    QVBoxLayout* layout = new QVBoxLayout;
+    auto* layout = new QVBoxLayout;
     setLayout(layout);
 
-    QGridLayout* grid = new QGridLayout;
+    auto* grid = new QGridLayout;
     layout->addLayout(grid);
 
     int row = 0;
@@ -868,7 +866,7 @@ MvQKeyEditDialog::MvQKeyEditDialog(MvKey* key, QWidget* parent) :
 
     //colourCb_=0;
 
-    for (map<string, string>::const_iterator it = key->metaData().begin(); it != key->metaData().end(); it++) {
+    for (auto it = key->metaData().begin(); it != key->metaData().end(); it++) {
         QWidget* w;
 
         grid->addWidget(new QLabel(QString::fromStdString(it->first) + ":", this), row, 0);
@@ -894,7 +892,7 @@ MvQKeyEditDialog::MvQKeyEditDialog(MvKey* key, QWidget* parent) :
         row++;
     }
 
-    QDialogButtonBox* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
 
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
@@ -902,16 +900,14 @@ MvQKeyEditDialog::MvQKeyEditDialog(MvKey* key, QWidget* parent) :
     layout->addWidget(buttonBox);
 }
 
-MvQKeyEditDialog::~MvQKeyEditDialog()
-{
-}
+MvQKeyEditDialog::~MvQKeyEditDialog() = default;
 
 void MvQKeyEditDialog::accept()
 {
     key_->setName(nameLe_->text().toStdString());
     key_->setShortName(shortLe_->text().toStdString());
     key_->setDescription(descLe_->text().toStdString());
-    QMapIterator<string, QLineEdit*> it(metaLe_);
+    QMapIterator<std::string, QLineEdit*> it(metaLe_);
     while (it.hasNext()) {
         it.next();
         key_->setMetaData(it.key(), it.value()->text().toStdString());
@@ -966,7 +962,7 @@ MvQKeyDialog::MvQKeyDialog(QString title, MvQKeyManager::KeyType type,
     keyPage_->slotChangeCurrentProfile(currentRow);
 
     if (type == MvQKeyManager::FrameType) {
-        MvQKeyImportPage* importPage = new MvQKeyImportPage("Import from GribExaminer", manager_, this);
+        auto* importPage = new MvQKeyImportPage("Import from GribExaminer", manager_, this);
         QIcon iconImport(QPixmap(QString::fromUtf8(":/keyDialog/profile_import.svg")));
         addPage(importPage, iconImport, "Import");
 
