@@ -150,7 +150,7 @@ void MvQKeyFilterModel::setupKeyFilter()
         MvKey* key = profile_->at(i);
         QString keyName(key->name().c_str());
 
-        for (map<string, int>::iterator it = key->counter().begin();
+        for (map<std::string, int>::iterator it = key->counter().begin();
              it != key->counter().end(); it++) {
             filter_[keyName].push_back(QString(it->first.c_str()));
         }
@@ -201,7 +201,7 @@ QVariant MvQKeyFilterModel::data(const QModelIndex& index, int role) const
         QString keyName(key->name().c_str());
 
         QStringList str;
-        for (map<string, int>::iterator it = key->counter().begin();
+        for (map<std::string, int>::iterator it = key->counter().begin();
              it != key->counter().end(); it++) {
             str.push_back(QString(it->first.c_str()));
         }
