@@ -23,8 +23,3 @@ QStringList MvQKeyMimeData::formats() const
 {
     return QStringList("metview/mvkey");  //QMimeData::formats();
 }
-
-QVariant MvQKeyMimeData::retrieveData(const QString& mimeType, QVariant::Type type) const
-{
-    return QVariant();
-}
