@@ -7,9 +7,9 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQKeyMimeData_H
-#define MvQKeyMimeData_H
+#pragma once
 
+#include <QtGlobal>
 #include <QMimeData>
 #include <QStringList>
 
@@ -22,20 +22,28 @@ class MvQKeyMimeData : public QMimeData
 
 public:
     MvQKeyMimeData(const QAbstractItemModel* model) :
-        model_(model){};
+        model_(model) {}
 
-    bool hasFormat(const QString& mimeType) const;
-    QStringList formats() const;
+    bool hasFormat(const QString& mimeType) const override;
+    QStringList formats() const override;
 
     void addKey(MvKey* key, int row) { keys_[row] = key; }
     const QMap<int, MvKey*>& keys() const { return keys_; }
     const QAbstractItemModel* model() const { return model_; }
 
 protected:
-    QVariant retrieveData(const QString& mimeType, QVariant::Type type) const;
-
+    // TODO: implement this method
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QVariant retrieveData(const QString& /*mimeType*/, QMetaType /*type*/) const override
+    {
+        return {};
+    }
+#else
+    QVariant retrieveData(const QString& /*mimeType*/, QVariant::Type /*type*/) const override
+    {
+        return {};
+    }
+#endif
     const QAbstractItemModel* model_;
     QMap<int, MvKey*> keys_;
 };
-
-#endif
\ No newline at end of file
