@@ -224,7 +224,7 @@ QString MvQKeyModel::label(MvKey* key, const int row, const int column, int role
     else if (mode_ == ShortNameMode) {
         if (column == 0) {
             if (role == Qt::ToolTipRole) {
-                string cntStr = key->metaData("path_count");
+                std::string cntStr = key->metaData("path_count");
                 if (!cntStr.empty())
                     return QString();
                 else
@@ -305,7 +305,7 @@ QStringList MvQKeyModel::mimeTypes() const
 
 QMimeData* MvQKeyModel::mimeData(const QModelIndexList& indexes) const
 {
-    MvQKeyMimeData* mimeData = new MvQKeyMimeData(this);
+    auto* mimeData = new MvQKeyMimeData(this);
 
     QList<int> procRows;
 
@@ -336,7 +336,7 @@ bool MvQKeyModel::dropMimeData(const QMimeData* data,
     if (!data->hasFormat("metview/mvkey"))
         return false;
 
-    const MvQKeyMimeData* keyData = qobject_cast<const MvQKeyMimeData*>(data);
+    const auto* keyData = qobject_cast<const MvQKeyMimeData*>(data);
 
     if (!keyData || keyData->keys().isEmpty())
         return false;
