@@ -96,13 +96,34 @@ MvQKeyProfileModel::MvQKeyProfileModel(QObject* parent) :
     QAbstractItemModel(parent),
     profile_(nullptr),
     shadeFirstColumn_(false)
-{    
-    possibleStringKeys_ << "shortName" << "name" << "nameECMWF" << "levelType" << "typeOfLevel" << "units"<<
-                        "centre" << "dataType" << "gridType" <<  "packingType" <<
-                        "class" << "domain" << "levtype" << "stream" << "type" <<
-                        "stepType" << "stepUnits" << "marsClass" << "marsType" <<
-                        "marsStream" << "pressureUnits" << "parameterName" << "parameterUnits" <<
-                        "nameECMWF" << "cfName" << "cfVarName" << "ident";
+{
+    possibleStringKeys_ << "shortName"
+                        << "name"
+                        << "nameECMWF"
+                        << "levelType"
+                        << "typeOfLevel"
+                        << "units"
+                        << "centre"
+                        << "dataType"
+                        << "gridType"
+                        << "packingType"
+                        << "class"
+                        << "domain"
+                        << "levtype"
+                        << "stream"
+                        << "type"
+                        << "stepType"
+                        << "stepUnits"
+                        << "marsClass"
+                        << "marsType"
+                        << "marsStream"
+                        << "pressureUnits"
+                        << "parameterName"
+                        << "parameterUnits"
+                        << "nameECMWF"
+                        << "cfName"
+                        << "cfVarName"
+                        << "ident";
 }
 
 MvQKeyProfileModel::~MvQKeyProfileModel()
@@ -170,7 +191,7 @@ void MvQKeyProfileModel::setKeyProfile(MvKeyProfile* prof)
     endResetModel();
 }
 
-void MvQKeyProfileModel::setKeyFilter(MvQKeyFilter filter)
+void MvQKeyProfileModel::setKeyFilter(MvQKeyFilter /*filter*/)
 {
 #if 0
 
@@ -308,7 +329,7 @@ QVariant MvQKeyProfileModel::data(const QModelIndex& index, int role) const
     }
 
     else if (role == Qt::BackgroundRole) {
-         return QVariant();
+        return QVariant();
     }
 
     else if (role == SubTextRole) {
@@ -336,7 +357,8 @@ QVariant MvQKeyProfileModel::data(const QModelIndex& index, int role) const
                     return QString::fromStdString(key->stringConstantValue()).toInt();
                 else
                     return QString::fromStdString(key->stringValue()[row]).toInt();
-            } else if (!isPossibleStringKey(key->name())){
+            }
+            else if (!isPossibleStringKey(key->name())) {
                 if (key->isConstant())
                     return QString::fromStdString(key->stringConstantValue()).toDouble();
                 else
@@ -402,8 +424,8 @@ QVariant MvQKeyProfileModel::headerData(const int section, const Qt::Orientation
         QString desc = QString::fromStdString(profile_->at(section)->description());
 
         if (profile_->at(section)->name() == "MV_Value") {
-            string xv = profile_->at(section)->metaData("x_coord");
-            string yv = profile_->at(section)->metaData("y_coord");
+            std::string xv = profile_->at(section)->metaData("x_coord");
+            std::string yv = profile_->at(section)->metaData("y_coord");
 
             QString s("key: ");
             s += QString(profile_->at(section)->name().c_str()) + "\n";
@@ -440,7 +462,7 @@ QVariant MvQKeyProfileModel::headerData(const int section, const Qt::Orientation
 
         return desc;
 #if 0
-		if(profile_->at(section)->name().find("MV_") != string::npos)
+		if(profile_->at(section)->name().find("MV_") !=std::string::npos)
 		{	
 			//QString str="MV key: "  + QString(profile_->at(section)->name().c_str()) +  "\n";
 			//str += desc;
@@ -523,7 +545,7 @@ QString MvQKeyProfileModel::label(const int row, const int column) const
     return QString();
 }
 
-QModelIndex MvQKeyProfileModel::index(int row, int column, const QModelIndex& parent) const
+QModelIndex MvQKeyProfileModel::index(int row, int column, const QModelIndex& /*parent*/) const
 {
     if (!isDataSet()) {
         return QModelIndex();
@@ -533,9 +555,9 @@ QModelIndex MvQKeyProfileModel::index(int row, int column, const QModelIndex& pa
 }
 
 
-QModelIndex MvQKeyProfileModel::parent(const QModelIndex& index) const
+QModelIndex MvQKeyProfileModel::parent(const QModelIndex& /*index*/) const
 {
-    return QModelIndex();
+    return {};
 }
 
 
@@ -547,14 +569,13 @@ bool MvQKeyProfileModel::isPossibleStringKey(const std::string& name) const
 
     QStringList lst = QString::fromStdString(name).split(".");
     if (lst.count() == 2) {
-       return possibleStringKeys_.contains(lst[1]);
+        return possibleStringKeys_.contains(lst[1]);
     }
 
     return false;
 }
 
 
-
 void MvQKeyProfileModel::loadKeyFilter()
 {
 #if 0
@@ -584,7 +605,7 @@ void MvQKeyProfileModel::loadKeyFilter()
 #endif
 }
 
-Qt::ItemFlags MvQKeyProfileModel::flags(const QModelIndex& index) const
+Qt::ItemFlags MvQKeyProfileModel::flags(const QModelIndex& /*index*/) const
 {
     Qt::ItemFlags defaultFlags;
 
@@ -612,7 +633,7 @@ QMimeData* MvQKeyProfileModel::mimeData(const QModelIndexList& indexes) const
 }
 
 bool MvQKeyProfileModel::dropMimeData(const QMimeData* data,
-                                      Qt::DropAction action, int row, int column, const QModelIndex& parent)
+                                      Qt::DropAction action, int /*row*/, int /*column*/, const QModelIndex& parent)
 {
     if (!profile_)
         return false;
@@ -623,7 +644,7 @@ bool MvQKeyProfileModel::dropMimeData(const QMimeData* data,
     if (!data->hasFormat("metview/mvkey"))
         return false;
 
-    const MvQKeyMimeData* keyData = qobject_cast<const MvQKeyMimeData*>(data);
+    const auto* keyData = qobject_cast<const MvQKeyMimeData*>(data);
 
     if (!keyData || keyData->keys().isEmpty())
         return false;
