@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQKeyProfileModel_H
-#define MvQKeyProfileModel_H
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QList>
@@ -54,8 +53,8 @@ public:
 
     enum CustomItemRole
     {
-        SortRole  = Qt::UserRole + 1,
-        ErrorRole = Qt::UserRole + 2,
+        SortRole    = Qt::UserRole + 1,
+        ErrorRole   = Qt::UserRole + 2,
         SubTextRole = Qt::UserRole + 3
     };
 
@@ -103,5 +102,3 @@ protected:
     bool shadeFirstColumn_;
     QStringList possibleStringKeys_;
 };
-
-#endif
