@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQKeyProfileTree_H
-#define MvQKeyProfileTree_H
+#pragma once
 
 
 #include "MvKeyProfile.h"
@@ -55,5 +54,3 @@ protected:
     bool editable_;
     bool predefinedKeysOnly_;
 };
-
-#endif
