@@ -17,18 +17,17 @@
 
 MvQLineEdit::MvQLineEdit(QWidget* parent) :
     QLineEdit(parent),
-    iconLabel_(0)
+    iconLabel_(nullptr)
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
     setClearButtonEnabled(true);
 #endif
 }
 
-void MvQLineEdit::setDecoration(QPixmap pix)
+void MvQLineEdit::setDecoration(QPixmap)
 {
 }
 
-
 void MvQLineEdit::adjustSize()
 {
     int frame    = style()->pixelMetric(QStyle::PM_DefaultFrameWidth);
