@@ -7,15 +7,13 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQLineEdit_H
-#define MvQLineEdit_H
+#pragma once
 
 #include <QLineEdit>
 
 class QLabel;
 class QToolButton;
 
-using namespace std;
 
 class MvQLineEdit : public QLineEdit
 {
@@ -38,6 +36,3 @@ protected:
     QToolButton* clearTb_;
     QLabel* iconLabel_;
 };
-
-
-#endif
