@@ -23,7 +23,7 @@ MvQLogPanel::MvQLogPanel(QWidget* parent) :
     QWidget(parent),
     viewAction_(nullptr)
 {
-    QVBoxLayout* logLayout = new QVBoxLayout;
+    auto* logLayout = new QVBoxLayout;
     logLayout->setContentsMargins(0, 0, 0, 0);
     logLayout->setSpacing(1);
 
@@ -32,12 +32,12 @@ MvQLogPanel::MvQLogPanel(QWidget* parent) :
     setLayout(logLayout);
 
     auto headerW = new MvQPanel(this);
-    QHBoxLayout* hb = new QHBoxLayout(headerW);
+    auto* hb     = new QHBoxLayout(headerW);
     hb->setContentsMargins(0, 0, 0, 0);
     logLayout->addWidget(headerW);
 
     //Label
-    QLabel* label = new QLabel(tr("Log"), this);
+    auto* label = new QLabel(tr("Log"), this);
     label->setProperty("panelStyle", "2");
 
     hb->addSpacing(4);
@@ -50,14 +50,14 @@ MvQLogPanel::MvQLogPanel(QWidget* parent) :
     hb->addWidget(clearMsgCb_);
 
     //Clear button
-    QToolButton* clearTb = new QToolButton(this);
+    auto* clearTb = new QToolButton(this);
     clearTb->setAutoRaise(true);
     clearTb->setIcon(QPixmap(":/examiner/wastebasket_orange.svg"));
     clearTb->setProperty("panelStyle", "2");
     clearTb->setToolTip(tr("Clear log"));
     hb->addWidget(clearTb);
 
-    QToolButton* closeTb = new QToolButton(this);
+    auto* closeTb = new QToolButton(this);
     closeTb->setAutoRaise(true);
     closeTb->setIcon(QPixmap(":/examiner/panel_close.svg"));
     closeTb->setToolTip(tr("Close log panel"));
