@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQLOGPANEL_H
-#define MVQLOGPANEL_H
+#pragma once
 
 #include <QSettings>
 #include <QWidget>
@@ -40,5 +39,3 @@ private:
     QAction* viewAction_;
     QCheckBox* clearMsgCb_;
 };
-
-#endif  // MVQLOGPANEL_H
