@@ -34,13 +34,13 @@ MvQMailDialog::MvQMailDialog(const std::string& fAttach, const std::string& fAtt
 
     QApplication::setWindowIcon(QIcon(MvQTheme::logo()));
 
-    QVBoxLayout* vb = new QVBoxLayout(this);
+    auto* vb = new QVBoxLayout(this);
 
-    QGridLayout* grid = new QGridLayout();
+    auto* grid = new QGridLayout();
     vb->addLayout(grid);
 
-    QLabel* label = new QLabel(tr("To:"), this);
-    toLe_         = new QLineEdit(this);
+    auto* label = new QLabel(tr("To:"), this);
+    toLe_       = new QLineEdit(this);
     grid->addWidget(label, 0, 0);
     grid->addWidget(toLe_, 0, 1);
 
@@ -77,7 +77,7 @@ MvQMailDialog::MvQMailDialog(const std::string& fAttach, const std::string& fAtt
         label->setWordWrap(true);
         vb->addWidget(label);
 
-        QPlainTextEdit* itemTe = new QPlainTextEdit(this);
+        auto* itemTe = new QPlainTextEdit(this);
         itemTe->setReadOnly(true);
         itemTe->setLineWrapMode(QPlainTextEdit::NoWrap);
 
@@ -98,7 +98,7 @@ MvQMailDialog::MvQMailDialog(const std::string& fAttach, const std::string& fAtt
     // Buttons
     //-----------------------
 
-    QDialogButtonBox* bb = new QDialogButtonBox(this);
+    auto* bb = new QDialogButtonBox(this);
     bb->addButton(new QPushButton(QPixmap(":/mail/mail_send.svg"), tr("Send"), this),
                   QDialogButtonBox::AcceptRole);
 
