@@ -33,10 +33,10 @@ MvQMainWindow::MvQMainWindow(QWidget* parent) :
     QApplication::setWindowIcon(QIcon(QPixmap(":/codes_ui/codes_ui.svg")));
 #endif
 
-//#ifdef __APPLE__
-//    // Set this to false if you want non-native menus on Mac OS X (i.e. menus are the same as under Linux)
-//    menuBar()->setNativeMenuBar(false);
-//#endif
+    //#ifdef __APPLE__
+    //    // Set this to false if you want non-native menus on Mac OS X (i.e. menus are the same as under Linux)
+    //    menuBar()->setNativeMenuBar(false);
+    //#endif
 
     menuName_[FileMenu]      = "&File";
     menuName_[ShareMenu]     = "Sha&re";
@@ -102,7 +102,7 @@ void MvQMainWindow::setupMenus(MenuItemMap items, MenuOption option)
         if (type == FileMenu && menu &&
             isActionPresent(items[type], "actionQuit") == false) {
             //Quit
-            QAction* actionQuit = new QAction(this);
+            auto* actionQuit = new QAction(this);
             actionQuit->setObjectName(QString::fromUtf8("actionQuit"));
             actionQuit->setText(tr("&Quit"));
             actionQuit->setShortcut(tr("Ctrl+Q"));
@@ -133,7 +133,7 @@ void MvQMainWindow::setupMenus(MenuItemMap items, MenuOption option)
         if (toolBars.count() > 0) {
             vm->addSeparator();
 
-            QMenu* subMenu = new QMenu(tr("ToolBars"), this);
+            auto* subMenu = new QMenu(tr("ToolBars"), this);
             vm->addMenu(subMenu);
 
             foreach (QToolBar* tb, toolBars) {
@@ -154,7 +154,7 @@ QMenu* MvQMainWindow::createMenu(QString name, QString objectName, QList<MvQMenu
 
 QMenu* MvQMainWindow::createMenu(QString name, QString objectName)
 {
-    QMenu* menu = new QMenu(name, this);
+    auto* menu = new QMenu(name, this);
     menu->setObjectName(objectName);
     menuBar()->addMenu(menu);
     return menu;
@@ -171,7 +171,7 @@ QToolBar* MvQMainWindow::createToolBar(QString name, QString objectName, QList<M
 
 QToolBar* MvQMainWindow::createToolBar(QString name, QString objectName, Qt::ToolBarAreas allowedAreas)
 {
-    QToolBar* toolBar = new QToolBar(name, this);
+    auto* toolBar = new QToolBar(name, this);
     toolBar->setObjectName(objectName);
     toolBar->setAllowedAreas(allowedAreas);
 
@@ -212,21 +212,22 @@ void MvQMainWindow::populate(QMenu* menu, QToolBar* toolBar, QList<MvQMenuItem*>
         QString type(type_char);
         if (type == "QAction" || type == "QUndoAction") {
             if (item->targets().testFlag(MvQMenuItem::SubMenuTarget)) {
-                QAction* action = static_cast<QAction*>(item->object());
+                auto* action = static_cast<QAction*>(item->object());
                 if (subMenu)
                     subMenu->addAction(action);
             }
             else if (item->targets().testFlag(MvQMenuItem::MenuTarget)) {
-                subMenu = nullptr;
-                QAction* action = static_cast<QAction*>(item->object());
+                subMenu      = nullptr;
+                auto* action = static_cast<QAction*>(item->object());
                 if (menu)
                     menu->addAction(action);
-            } else {
+            }
+            else {
                 subMenu = nullptr;
             }
 
             if (item->targets().testFlag(MvQMenuItem::ToolBarTarget)) {
-                QAction* action = static_cast<QAction*>(item->object());
+                auto* action = static_cast<QAction*>(item->object());
                 if (toolBar)
                     toolBar->addAction(action);
             }
@@ -236,7 +237,7 @@ void MvQMainWindow::populate(QMenu* menu, QToolBar* toolBar, QList<MvQMenuItem*>
             menu->addMenu(subMenu);
         }
         else if (toolBar && item->targets().testFlag(MvQMenuItem::ToolBarTarget)) {
-            QWidget* w = static_cast<QWidget*>(item->object());
+            auto* w = static_cast<QWidget*>(item->object());
             if (w)
                 toolBar->addWidget(w);
         }
@@ -278,7 +279,7 @@ bool MvQMainWindow::isActionPresent(QList<MvQMenuItem*> items, QString name)
         const char* type_char = item->object()->metaObject()->className();
         QString type(type_char);
         if (type == "QAction") {
-            QAction* action = static_cast<QAction*>(item->object());
+            auto* action = static_cast<QAction*>(item->object());
             if (action->objectName() == name) {
                 return true;
             }
@@ -360,7 +361,7 @@ void MvQMainWindow::setInitialSize(int w, int h)
 
 QAction* MvQMainWindow::createAction(ActionType type, QObject* parent)
 {
-    QAction* action = new QAction(parent);
+    auto* action = new QAction(parent);
     QIcon icon;
 
     switch (type) {
@@ -427,7 +428,7 @@ QAction* MvQMainWindow::createAction(ActionType type, QObject* parent)
 
 QAction* MvQMainWindow::createAction(QString text, QString shortcut, QString data, QObject* parent)
 {
-    QAction* ac = new QAction(parent);
+    auto* ac = new QAction(parent);
     ac->setText(text);
     ac->setShortcut(shortcut);
     ac->setData(data);
@@ -436,7 +437,7 @@ QAction* MvQMainWindow::createAction(QString text, QString shortcut, QString dat
 
 QAction* MvQMainWindow::createSeparator(QObject* parent)
 {
-    QAction* ac = new QAction(parent);
+    auto* ac = new QAction(parent);
     ac->setSeparator(true);
     return ac;
 }
