@@ -7,13 +7,11 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQMemoryWidget_H
-#define MvQMemoryWidget_H
+#pragma once
 
 #include <QFile>
 #include <QLabel>
 
-using namespace std;
 
 class MvQMemoryWidget : public QLabel
 {
@@ -40,6 +38,3 @@ protected:
     QString memFreeUnit_;
     long maxrss_;
 };
-
-
-#endif
\ No newline at end of file
