@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQMenuItem_H
-#define MvQMenuItem_H
+#pragma once
 
 #include <QMap>
 #include <QList>
@@ -40,6 +39,3 @@ private:
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(MvQMenuItem::Targets);
-
-
-#endif
