@@ -41,7 +41,7 @@ MvQOdbDataWidget::MvQOdbDataWidget(QWidget* parent) :
     currentChunk_     = -1;
     dataInitialised_  = false;
 
-    QVBoxLayout* dataLayout = new QVBoxLayout;
+    auto* dataLayout = new QVBoxLayout;
     dataLayout->setContentsMargins(0, 0, 0, 0);
     setLayout(dataLayout);
 
@@ -73,7 +73,7 @@ MvQOdbDataWidget::MvQOdbDataWidget(QWidget* parent) :
     dataLayout->addWidget(dataTree_);
 
     //Control at the bottom
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     dataLayout->addLayout(hb);
 
     hb->addSpacing(5);
@@ -140,11 +140,11 @@ MvQOdbDataWidget::~MvQOdbDataWidget()
 //Should be called only once
 bool MvQOdbDataWidget::init(QString path)
 {
-    vector<int> v;
+    std::vector<int> v;
     return init(path, v);
 }
 
-bool MvQOdbDataWidget::init(QString path, const vector<int>& filter)
+bool MvQOdbDataWidget::init(QString path, const std::vector<int>& filter)
 {
     if (dataInitialised_) {
         if (data_->path() == path.toStdString()) {
@@ -189,7 +189,7 @@ void MvQOdbDataWidget::loadData()
     loadStarted();
     //statusMessageLabel_->setText(tr("Counting number of rows in ODB data ..."));
 
-    int rowNum = data_->rowNum();
+    int rowNum      = data_->rowNum();
     int totSizeInMb = -1;
     if (maxChunkSizeInMb_ > 0) {
         totSizeInMb = data_->totalSizeInMb();
@@ -365,12 +365,12 @@ void MvQOdbDataWidget::loadFinished()
     QApplication::restoreOverrideCursor();
 }
 
-void MvQOdbDataWidget::setFilter(const vector<int>& filter)
+void MvQOdbDataWidget::setFilter(const std::vector<int>& filter)
 {
     dataModel_->setFilter(filter);
 }
 
-void MvQOdbDataWidget::setTmpFilter(const vector<int>& filter)
+void MvQOdbDataWidget::setTmpFilter(const std::vector<int>& filter)
 {
     dataModel_->setTmpFilter(filter);
 }
@@ -456,7 +456,7 @@ void MvQOdbDataWidget::slotHeaderContextMenu(const QPoint& position)
                 menu.addMenu(&subMenu);
             }
 
-            QAction* ac    = new QAction(this);
+            auto* ac       = new QAction(this);
             QString acText = dataModel_->headerData(i, Qt::Horizontal, Qt::DisplayRole).toString();
             if (actionShow.count() >= 6) {
                 ac->setText(acText);
@@ -472,11 +472,11 @@ void MvQOdbDataWidget::slotHeaderContextMenu(const QPoint& position)
 
     menu.addSeparator();
 
-    QAction* actionShowAll = new QAction(this);
+    auto* actionShowAll = new QAction(this);
     actionShowAll->setText(tr("Show all columns"));
     menu.addAction(actionShowAll);
 
-    QAction* actionHideAll = new QAction(this);
+    auto* actionHideAll = new QAction(this);
     actionHideAll->setText(tr("Hide all other columns"));
     menu.addAction(actionHideAll);
 
