@@ -13,9 +13,7 @@
 
 #include "MvOdb.h"
 
-MvQOdbVarModel::MvQOdbVarModel()
-{
-}
+MvQOdbVarModel::MvQOdbVarModel() = default;
 
 void MvQOdbVarModel::setBaseData(QList<MvQOdbVar*>& data)
 {
@@ -61,14 +59,8 @@ QVariant MvQOdbVarModel::headerData(const int section, const Qt::Orientation ori
     if (orient != Qt::Horizontal || role != Qt::DisplayRole)
         return QAbstractItemModel::headerData(section, orient, role);
 
-    switch (section) {
-        case 0:
-            return "Name";
-        case 1:
-            return "Value";
-    }
-
-    return QVariant();
+    return section == 0 ? "Name" : section == 1 ? "Value"
+                                                : QVariant();
 }
 
 
@@ -93,7 +85,7 @@ QModelIndex MvQOdbVarModel::index(int row, int column, const QModelIndex&) const
         return QModelIndex();
     }
 
-    return createIndex(row, column, static_cast<void*>(0));
+    return createIndex(row, column, static_cast<void*>(nullptr));
 }
 
 
@@ -297,7 +289,7 @@ QString MvQOdbColumnModel::label(MvQOdbBitfieldMember* bitfield, const int colum
             return bitfield->name();
         }
         case 1: {
-            QString s1 = QString("%1").arg(bitfield->pos(), 2, 10, QChar('0'));
+            QString s1  = QString("%1").arg(bitfield->pos(), 2, 10, QChar('0'));
             QString str = "Pos: ";
             str += s1;
             str += "  Width: ";
@@ -372,7 +364,7 @@ int MvQOdbColumnModel::idToParentRow(int id) const
 MvQOdbDataModel::MvQOdbDataModel() :
     hasTmpFilter_(false)
 {
-    data_ = 0;
+    data_ = nullptr;
 }
 
 void MvQOdbDataModel::dataIsAboutToChange()
@@ -408,7 +400,7 @@ void MvQOdbDataModel::setBaseData(MvAbstractOdb* data)
 
 int MvQOdbDataModel::columnCount(const QModelIndex& /* parent */) const
 {
-    if (data_ != 0)
+    if (data_ != nullptr)
         return data_->columnNum() + 1;
     else
         return 0;
@@ -422,7 +414,7 @@ int MvQOdbDataModel::rowCount(const QModelIndex& parent) const
     }
     //Root
 
-    if (data_ != 0) {
+    if (data_ != nullptr) {
         if (data_->chunkSize() == 0) {
             if (hasTmpFilter_) {
                 return tmpFilter_.size();
@@ -531,11 +523,11 @@ QVariant MvQOdbDataModel::headerData(const int section, const Qt::Orientation or
 
 QModelIndex MvQOdbDataModel::index(int row, int column, const QModelIndex& /*parent*/) const
 {
-    if (data_ == 0 || data_->rowNum() <= 0 || column < 0) {
+    if (data_ == nullptr || data_->rowNum() <= 0 || column < 0) {
         return QModelIndex();
     }
 
-    return createIndex(row, column, static_cast<void*>(0));
+    return createIndex(row, column, static_cast<void*>(nullptr));
 }
 
 
@@ -544,7 +536,7 @@ QModelIndex MvQOdbDataModel::parent(const QModelIndex& /*index */) const
     return QModelIndex();
 }
 
-void MvQOdbDataModel::setFilter(const vector<int>& filter)
+void MvQOdbDataModel::setFilter(const std::vector<int>& filter)
 {
     if (filter.size() == 0 && filter_.size() == 0)
         return;
@@ -564,7 +556,7 @@ void MvQOdbDataModel::setFilter(const vector<int>& filter)
     }
 }
 
-void MvQOdbDataModel::setTmpFilter(const vector<int>& tmpFilter)
+void MvQOdbDataModel::setTmpFilter(const std::vector<int>& tmpFilter)
 {
     if (filter_.size() == 0)
         return;
