@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQOdbModel_H
-#define MvQOdbModel_H
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QMap>
@@ -86,22 +85,20 @@ public:
 
     void dataIsAboutToChange();
     void setBaseData(MvAbstractOdb*);
-    void setFilter(const vector<int>&);
-    void setTmpFilter(const vector<int>&);
+    void setFilter(const std::vector<int>&);
+    void setTmpFilter(const std::vector<int>&);
     void clearTmpFilter();
     bool filtered() const;
     bool hasTmpFilter() const { return hasTmpFilter_; }
     int filterCount() const { return static_cast<int>(filter_.size()); }
-    const vector<int>& tmpFilter() const { return tmpFilter_; }
+    const std::vector<int>& tmpFilter() const { return tmpFilter_; }
 
 private:
     bool hasFilter() const;
 
     MvAbstractOdb* data_;
-    vector<int> filter_;
-    vector<int> tmpFilter_;
+    std::vector<int> filter_;
+    std::vector<int> tmpFilter_;
     bool hasTmpFilter_;
     QList<int> columnOrder_;
 };
-
-#endif
