@@ -37,8 +37,8 @@ MvQNodeItem::MvQNodeItem(MvQProfileItem* prof, bool editable, float yPos) :
     setZValue(-1);
 
     if (editable_) {
-        idleBrush_  = MvQTheme::brush("scmview","editable_curve");
-        hoverBrush_ = MvQTheme::brush("scmview","editable_curve_hover");
+        idleBrush_  = MvQTheme::brush("scmview", "editable_curve");
+        hoverBrush_ = MvQTheme::brush("scmview", "editable_curve_hover");
         moveBrush_  = hoverBrush_;
         brush_      = idleBrush_;
 
@@ -48,8 +48,8 @@ MvQNodeItem::MvQNodeItem(MvQProfileItem* prof, bool editable, float yPos) :
         pen_      = idlePen_;
     }
     else {
-        idleBrush_  = MvQTheme::brush("scmview","curve");
-        hoverBrush_ = MvQTheme::brush("scmview","curve_hover");
+        idleBrush_  = MvQTheme::brush("scmview", "curve");
+        hoverBrush_ = MvQTheme::brush("scmview", "curve_hover");
         moveBrush_  = hoverBrush_;
         brush_      = idleBrush_;
 
@@ -65,9 +65,7 @@ MvQNodeItem::MvQNodeItem(MvQProfileItem* prof, bool editable, float yPos) :
     size_      = idleSize_;
 }
 
-MvQNodeItem::~MvQNodeItem()
-{
-}
+MvQNodeItem::~MvQNodeItem() = default;
 
 void MvQNodeItem::addEdge(MvQEdgeItem* edge)
 {
@@ -174,10 +172,10 @@ MvQEdgeItem::MvQEdgeItem(MvQNodeItem* fromNode, MvQNodeItem* toNode) :
     toNode_(toNode)
 {
     if (fromNode->editable()) {
-        pen_ = QPen(MvQTheme::colour("scmview","editable_curve"), 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
+        pen_ = QPen(MvQTheme::colour("scmview", "editable_curve"), 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
     }
     else {
-        pen_ = QPen(MvQTheme::colour("scmview","curve"), 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
+        pen_ = QPen(MvQTheme::colour("scmview", "curve"), 1, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
     }
 #if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
     setAcceptedMouseButtons(Qt::MouseButtons());
@@ -262,8 +260,8 @@ MvQProfileItem::MvQProfileItem(MvQProfileView* view, MvProfileData* data, bool e
     gridPen_(MvQTheme::colour("scmview", "grid")),
     outsideBrush_(MvQTheme::colour("scmview", "outside")),
     sceneBgBrush_(MvQTheme::colour("scmview", "scenebg")),
-    editableColour_(MvQTheme::colour("scmview","editable_curve")),
-    standardColour_(MvQTheme::colour("scmview","curve"))
+    editableColour_(MvQTheme::colour("scmview", "editable_curve")),
+    standardColour_(MvQTheme::colour("scmview", "curve"))
 {
     if (!data_) {
         setEnabled(false);
@@ -280,9 +278,9 @@ MvQProfileItem::MvQProfileItem(MvQProfileView* view, MvProfileData* data, bool e
     adjustFrame();
 
     for (int i = 0; i < data_->count(); i++) {
-        float val         = data_->value(i);
-        float yp          = (i - firstIndex_) * yRatio_;
-        MvQNodeItem* node = new MvQNodeItem(this, editable, yp);
+        float val  = data_->value(i);
+        float yp   = (i - firstIndex_) * yRatio_;
+        auto* node = new MvQNodeItem(this, editable, yp);
         node->setParentItem(this);
         node->setPos((val - frameXMin_) * xRatio_, yp);
         if (editable) {
@@ -293,7 +291,7 @@ MvQProfileItem::MvQProfileItem(MvQProfileView* view, MvProfileData* data, bool e
     }
 
     for (int i = 0; i < data_->count() - 1; i++) {
-        MvQEdgeItem* edge = new MvQEdgeItem(nodes_[i], nodes_[i + 1]);
+        auto* edge = new MvQEdgeItem(nodes_[i], nodes_[i + 1]);
         edge->setParentItem(this);
         edges_ << edge;
     }
@@ -513,7 +511,7 @@ void MvQProfileItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, Q
     //Right axis
     if (data_->auxLevelDefined()) {
         for (int i = lastIndex_; i >= firstIndex_; i -= stepY) {
-            float xv = static_cast<float>(floor(data_->auxLevel(i) / 100.));
+            auto xv = static_cast<float>(floor(data_->auxLevel(i) / 100.));
 
             float xp = frameRect_.width();
             float yp = frameRect_.top() + (i - firstIndex_) * yRatio_;
@@ -872,7 +870,7 @@ MvQProfileView::MvQProfileView(QWidget* parent) :
     QGraphicsView(parent)
 {
     setRenderHints(QPainter::Antialiasing);
-    setBackgroundBrush(MvQTheme::brush("scmview","viewbg"));
+    setBackgroundBrush(MvQTheme::brush("scmview", "viewbg"));
     setAlignment(Qt::AlignCenter);
 
     scene_ = new QGraphicsScene(this);
