@@ -27,19 +27,19 @@ MvQRangeWidget::MvQRangeWidget(QWidget* parent) :
     rangeEndIndex_(-1),
     ignoreSpinChange_(false)
 {
-    QVBoxLayout* layout = new QVBoxLayout(this);
+    auto* layout = new QVBoxLayout(this);
 
-    QPushButton* allPb = new QPushButton(tr("Full range"), this);
+    auto* allPb = new QPushButton(tr("Full range"), this);
     layout->addWidget(allPb);
 
     connect(allPb, SIGNAL(clicked(bool)),
             this, SLOT(slotSelectWholeRange(bool)));
 
 
-    QHBoxLayout* minHb = new QHBoxLayout;
+    auto* minHb = new QHBoxLayout;
     layout->addLayout(minHb);
 
-    QLabel* label = new QLabel(tr("Top:"));
+    auto* label = new QLabel(tr("Top:"));
     minHb->addWidget(label);
     startSpin_ = new QSpinBox(this);
     minHb->addWidget(startSpin_);
@@ -47,7 +47,7 @@ MvQRangeWidget::MvQRangeWidget(QWidget* parent) :
     plot_ = new MvQRangePlotWidget(this);
     layout->addWidget(plot_, 1);
 
-    QHBoxLayout* maxHb = new QHBoxLayout;
+    auto* maxHb = new QHBoxLayout;
     layout->addLayout(maxHb);
 
     label = new QLabel(tr("Bottom:"));
@@ -246,11 +246,11 @@ MvQRangePlotWidget::MvQRangePlotWidget(MvQRangeWidget* parent) :
     hover_(NoHover),
     offset_(15),
     dragRadius_(10),
-    bgBrush_(MvQTheme::colour("rangeselector","bg")),
-    pen_(MvQTheme::colour("rangeselector","pen")),
-    selectorBrush_(MvQTheme::colour("rangeselector","selector_bg")),
-    selectorPen_(MvQTheme::colour("rangeselector","selector_pen")),
-    handlerBrush_(MvQTheme::brush("rangeselector","handler_bg"))
+    bgBrush_(MvQTheme::colour("rangeselector", "bg")),
+    pen_(MvQTheme::colour("rangeselector", "pen")),
+    selectorBrush_(MvQTheme::colour("rangeselector", "selector_bg")),
+    selectorPen_(MvQTheme::colour("rangeselector", "selector_pen")),
+    handlerBrush_(MvQTheme::brush("rangeselector", "handler_bg"))
 {
     setMouseTracking(true);
 }
