@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQStackedEditor_H
-#define MvQStackedEditor_H
+#pragma once
 
 #include <QDialog>
 #include <QIcon>
@@ -33,5 +32,3 @@ protected:
     QListWidget* list_;
     QStackedWidget* page_;
 };
-
-#endif
