@@ -23,7 +23,7 @@
 #include "MvQMethods.h"
 #include "MvQStyleDb.h"
 #include "MvQTheme.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 //==============================
 //
@@ -106,7 +106,7 @@ MvQStyleTreeWidget::MvQStyleTreeWidget(QWidget* parent) :
     QWidget(parent)
 {
     //Layout to hold tree and sidebar
-    QVBoxLayout* vb = new QVBoxLayout(this);
+    auto* vb = new QVBoxLayout(this);
 
     vb->setContentsMargins(0, 0, 0, 0);
 
@@ -131,7 +131,7 @@ MvQStyleTreeWidget::MvQStyleTreeWidget(QWidget* parent) :
     //Tree context menu
     tree_->setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    QAction* acCopyName = new QAction(this);
+    auto* acCopyName = new QAction(this);
     acCopyName->setText(tr("&Copy style name"));
     acCopyName->setShortcut(QKeySequence(tr("Ctrl+C")));
     tree_->addAction(acCopyName);
