@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef TREEEXPANDSTATE_HPP
-#define TREEEXPANDSTATE_HPP
+#pragma once
 
 #include <QList>
 #include <QString>
@@ -62,6 +61,3 @@ protected:
     ExpandNode* selectionParent_;
     QString selectionName_;
 };
-
-
-#endif  // TREEEXPANDSTATE_HPP
