@@ -40,27 +40,27 @@ MvQTreeViewDelegate::MvQTreeViewDelegate(QTreeView* parent) :
 
 void MvQTreeViewDelegate::setColours()
 {
-    QString group  = "treeview";
+    QString group = "treeview";
     // "block" here means and item with children
 
-    textPen_ = MvQTheme::pen(group, "text");
+    textPen_    = MvQTheme::pen(group, "text");
     subTextPen_ = MvQTheme::pen(group, "subtext");
 
-    selectTextPen_ = MvQTheme::pen(group, "select_text");
+    selectTextPen_    = MvQTheme::pen(group, "select_text");
     selectSubTextPen_ = MvQTheme::pen(group, "select_text");
-    selectBrush_ = MvQTheme::brush(group, "select_brush");
+    selectBrush_      = MvQTheme::brush(group, "select_brush");
     selectBrushBlock_ = selectBrush_;
 
-    blockBrush_ =  MvQTheme::brush(group, "block_brush");
-    blockTextPen_ =  MvQTheme::pen(group, "block_text");
+    blockBrush_   = MvQTheme::brush(group, "block_brush");
+    blockTextPen_ = MvQTheme::pen(group, "block_text");
 
-    errorSelectPen_ = MvQTheme::pen(group, "error_select_pen");
+    errorSelectPen_   = MvQTheme::pen(group, "error_select_pen");
     errorSelectBrush_ = MvQTheme::brush(group, "error_select_brush");
-    errorBrush_ = MvQTheme::brush(group, "error_brush");
-    borderPen_ = MvQTheme::pen(group, "border_pen");
+    errorBrush_       = MvQTheme::brush(group, "error_brush");
+    borderPen_        = MvQTheme::pen(group, "border_pen");
 }
 
-void MvQTreeViewDelegate::setStyleId(int id)
+void MvQTreeViewDelegate::setStyleId(int /*id*/)
 {
 }
 
@@ -101,20 +101,20 @@ void MvQTreeViewDelegate::paint(QPainter* painter, const QStyleOptionViewItem& o
             QRect selectRect;
             selectRect = bgRect.adjusted(0, 1, 0, 0);
             painter->fillRect(selectRect, selectBrushBlock_);
-//            painter->setPen(selectPen_);
-//            painter->drawLine(selectRect.topLeft(), selectRect.topRight());
-//            painter->drawLine(selectRect.bottomLeft(), selectRect.bottomRight());
+            //            painter->setPen(selectPen_);
+            //            painter->drawLine(selectRect.topLeft(), selectRect.topRight());
+            //            painter->drawLine(selectRect.bottomLeft(), selectRect.bottomRight());
         }
         else {
             QRect fullRect = bgRect;
             //painter->fillRect(fullRect, blockBrush_);
-//            painter->setPen(selectPen_);
+            //            painter->setPen(selectPen_);
             // painter->setPen(blockBorderPen_);
             fullRect.adjust(0, 1, 0, 0);
-//            painter->drawLine(fullRect.topLeft(), fullRect.topRight());
-//            painter->drawLine(fullRect.bottomLeft(), fullRect.bottomRight());
-//            if (index.column() == 0)
-//                painter->drawLine(fullRect.topLeft(), fullRect.bottomLeft());
+            //            painter->drawLine(fullRect.topLeft(), fullRect.topRight());
+            //            painter->drawLine(fullRect.bottomLeft(), fullRect.bottomRight());
+            //            if (index.column() == 0)
+            //                painter->drawLine(fullRect.topLeft(), fullRect.bottomLeft());
         }
     }
     else {
@@ -137,15 +137,15 @@ void MvQTreeViewDelegate::paint(QPainter* painter, const QStyleOptionViewItem& o
                 painter->fillRect(selectRect, selectBrush_);
                 //painter->setPen(selectPen_);
             }
-//            painter->drawLine(selectRect.topLeft(), selectRect.topRight());
-//            painter->drawLine(selectRect.bottomLeft(), selectRect.bottomRight());
+            //            painter->drawLine(selectRect.topLeft(), selectRect.topRight());
+            //            painter->drawLine(selectRect.bottomLeft(), selectRect.bottomRight());
         }
         else {
             if (hasError) {
                 painter->fillRect(bgRect, errorBrush_);
             }
             else {
-                QColor bg = index.data(Qt::BackgroundRole).value<QColor>();
+                auto bg = index.data(Qt::BackgroundRole).value<QColor>();
                 if (bg.isValid()) {
                     painter->fillRect(bgRect, bg);
                 }
@@ -163,14 +163,14 @@ void MvQTreeViewDelegate::paint(QPainter* painter, const QStyleOptionViewItem& o
     }
 
     //Display text
-    QString text = index.data(Qt::DisplayRole).toString();
+    QString text    = index.data(Qt::DisplayRole).toString();
     bool useSubText = index.data(MvQKeyProfileModel::SubTextRole).toBool();
     if (text.isEmpty() == false) {
         QRect textRect = style->subElementRect(QStyle::SE_ItemViewItemText, &vopt, widget);
         if (hasChild)
             textRect.adjust(3, 0, 3, 0);
 
-        QFont f= view_->font();
+        QFont f = view_->font();
         QFontMetrics fm(f);
 
 #ifndef METVIEW_ON_WINDOWS
@@ -185,12 +185,13 @@ void MvQTreeViewDelegate::paint(QPainter* painter, const QStyleOptionViewItem& o
 
         QPen fg;
         if (option.state & QStyle::State_Selected) {
-            fg = (useSubText)?selectSubTextPen_:selectTextPen_;
-        } else {
-//            if (hasChild) {
-//                fg = blockTextPen_;
-//            } else {
-                fg = (useSubText)?subTextPen_:textPen_;
+            fg = (useSubText) ? selectSubTextPen_ : selectTextPen_;
+        }
+        else {
+            //            if (hasChild) {
+            //                fg = blockTextPen_;
+            //            } else {
+            fg = (useSubText) ? subTextPen_ : textPen_;
             //}
         }
 
@@ -264,7 +265,7 @@ void MvQTreeView::selectionChanged(const QItemSelection& selected, const QItemSe
         Q_EMIT selectionChanged(lst[0]);
 }
 
-void MvQTreeView::keyboardSearch(const QString& search)
+void MvQTreeView::keyboardSearch(const QString& /*search*/)
 {
 }
 
@@ -298,7 +299,8 @@ void MvQTreeView::drawBranches(QPainter* painter, const QRect& rect, const QMode
             //Draw the branch with the default method
             QTreeView::drawBranches(painter, rect, index);
         }
-    } else {
+    }
+    else {
         QTreeView::drawBranches(painter, rect, index);
     }
 }
