@@ -30,7 +30,7 @@ PlainTextEdit::PlainTextEdit(QWidget* parent) :
     rightMargin_(2),
     hyperlinkEnabled_(false),
     gotoLineDialog_(0),
-    fontProp_(NULL)
+    fontProp_(nullptr)
 {
     setColours();
 
@@ -75,11 +75,11 @@ PlainTextEdit::~PlainTextEdit()
 
 void PlainTextEdit::setColours()
 {
-    QString group  = "textedit";
-    numAreaBgCol_ = MvQTheme::colour(group, "linenum_bg");
-    numAreaFontCol_ = MvQTheme::colour(group, "linenum_text");
+    QString group        = "textedit";
+    numAreaBgCol_        = MvQTheme::colour(group, "linenum_bg");
+    numAreaFontCol_      = MvQTheme::colour(group, "linenum_text");
     numAreaSeparatorCol_ = MvQTheme::colour(group, "linenum_separator");
-    numAreaCurrentCol_ = MvQTheme::colour(group, "linenum_current_text");
+    numAreaCurrentCol_   = MvQTheme::colour(group, "linenum_current_text");
 }
 
 void PlainTextEdit::setHyperlinkEnabled(bool h)
@@ -285,7 +285,7 @@ void PlainTextEdit::lineNumberAreaPaintEvent(QPaintEvent* event)
 
             if (blockNumber == currentRow - 1)  // is this the current line?
             {
-//                painter.setFont(fontBold);
+                //                painter.setFont(fontBold);
                 //painter.fillRect(0, top, lineNumArea_->width() - rightMargin_, fontMetrics().height(), numAreaCurrentCol_);  // highlight the background
                 painter.setPen(numAreaCurrentCol_);
             }
@@ -295,7 +295,7 @@ void PlainTextEdit::lineNumberAreaPaintEvent(QPaintEvent* event)
 
             if (blockNumber == currentRow - 1)  // is this the current line?
             {
-//                painter.setFont(fontNormal);  // reset the font to normal
+                //                painter.setFont(fontNormal);  // reset the font to normal
                 painter.setPen(numAreaFontCol_);
             }
         }
@@ -502,7 +502,7 @@ void PlainTextEdit::fontSizeChangedByZoom()
 void PlainTextEdit::updateFont()
 {
     if (fontProp_) {
-        QFont f = fontProp_->value().value<QFont>();
+        auto f = fontProp_->value().value<QFont>();
         if (font() != f)
             setFont(f);
     }
