@@ -17,7 +17,7 @@
 #include <QRegularExpression>
 
 PlainTextSearchInterface::PlainTextSearchInterface() :
-    editor_(NULL)
+    editor_(nullptr)
 {
 }
 
