@@ -8,8 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 
-#ifndef VIEWER_SRC_PLAINTEXTSEARCHINTERFACE_HPP_
-#define VIEWER_SRC_PLAINTEXTSEARCHINTERFACE_HPP_
+#pragma once
 
 #include "AbstractTextEditSearchInterface.h"
 
@@ -35,5 +34,3 @@ public:
 protected:
     QPlainTextEdit* editor_;
 };
-
-#endif /* VIEWER_SRC_PLAINTEXTSEARCHINTERFACE_HPP_ */
