@@ -8,8 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 
-#ifndef PLAINTEXTSEARCHLINE_HPP_
-#define PLAINTEXTSEARCHLINE_HPP_
+#pragma once
 
 #include <QPlainTextEdit>
 
@@ -28,5 +27,3 @@ private:
     //The interface is set internally
     void setSearchInterface(AbstractTextSearchInterface*) {}
 };
-
-#endif
