@@ -8,8 +8,7 @@
 //
 //============================================================================
 
-#ifndef CODEITEMWIDGET_HPP_
-#define CODEITEMWIDGET_HPP_
+#pragma once
 
 #include <QWidget>
 #include <QSettings>
@@ -43,5 +42,3 @@ Q_SIGNALS:
 protected:
     void removeSpacer();
 };
-
-#endif
