@@ -72,7 +72,7 @@ EditLineHeader::EditLineHeader(QString name, QGridLayout* grid, QWidget* parent)
 
     setProperty("lineEditHeader", "1");
 
-    QHBoxLayout* hb = new QHBoxLayout(this);
+    auto* hb = new QHBoxLayout(this);
     hb->setContentsMargins(0, 0, 0, 0);
     hb->setSpacing(0);
 
@@ -389,8 +389,8 @@ void EditLine::setCompleterForLe(const std::set<std::string>& coVals, QLineEdit*
     Q_ASSERT(le);
 
     QStringList lst;
-    for (std::set<std::string>::const_iterator it = coVals.begin(); it != coVals.end(); ++it) {
-        lst << QString::fromStdString(*it);
+    for (const auto& coVal : coVals) {
+        lst << QString::fromStdString(coVal);
     }
     le->setCompleter(0);
     le->setCompleter(new QCompleter(lst, le));
@@ -402,8 +402,8 @@ void EditLine::updateCompleterForLe(const std::set<std::string>& coVals,
     Q_ASSERT(le);
 
     QStringList lst;
-    for (std::set<std::string>::const_iterator it = coVals.begin(); it != coVals.end(); ++it) {
-        lst << QString::fromStdString(*it);
+    for (const auto& coVal : coVals) {
+        lst << QString::fromStdString(coVal);
     }
 
     if (QCompleter* c = le->completer()) {
@@ -715,7 +715,7 @@ EditAreaLine::EditAreaLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader*
     connect(sLe_, SIGNAL(textChanged(QString)),
             this, SLOT(currentChanged(QString)));
 
-    QGridLayout* gr = new QGridLayout(w_);
+    auto* gr = new QGridLayout(w_);
     gr->addWidget(new QLabel("N:", w_), 0, 2);
     gr->addWidget(nLe_, 0, 3);
     gr->addWidget(new QLabel("W:", w_), 1, 0);
@@ -748,7 +748,7 @@ void EditAreaLine::clear()
     sLe_->clear();
 }
 
-void EditAreaLine::currentChanged(QString s)
+void EditAreaLine::currentChanged(QString /*s*/)
 {
     checkState();
     Q_EMIT valueChanged(this, value());
@@ -898,8 +898,8 @@ EditAddRemoveLine::EditAddRemoveLine(MvQProperty* prop, QGridLayout* grid, EditL
 
     oriVal_ = QString::number(current_);
 
-    w_              = new QWidget(parent);
-    QHBoxLayout* hb = new QHBoxLayout(w_);
+    w_       = new QWidget(parent);
+    auto* hb = new QHBoxLayout(w_);
     hb->setContentsMargins(0, 0, 0, 0);
     hb->setSpacing(0);
 
@@ -1020,8 +1020,8 @@ EditBoolLine::EditBoolLine(MvQProperty* prop, QGridLayout* grid, EditLineHeader*
     oriVal_ = prop_->defaultValue().toString();
     Q_ASSERT(!oriVal_.isEmpty());
 
-    w_              = new QWidget(parent);
-    QHBoxLayout* hb = new QHBoxLayout(w_);
+    w_       = new QWidget(parent);
+    auto* hb = new QHBoxLayout(w_);
     hb->setContentsMargins(0, 0, 0, 0);
     hb->setSpacing(0);
 
@@ -1184,7 +1184,7 @@ EditConditionLine::EditConditionLine(MvQProperty* prop, QGridLayout* grid, EditL
     }
 
     //The layout
-    QHBoxLayout* hb = new QHBoxLayout(w_);
+    auto* hb = new QHBoxLayout(w_);
     hb->setContentsMargins(0, 0, 0, 0);
     hb->setSpacing(0);
 
@@ -1474,7 +1474,7 @@ EditMultiConditionLine::EditMultiConditionLine(MvQProperty* prop, QGridLayout* g
     }
 
     //The layout
-    QHBoxLayout* hb = new QHBoxLayout(w_);
+    auto* hb = new QHBoxLayout(w_);
     hb->setContentsMargins(0, 0, 0, 0);
     hb->setSpacing(0);
     hb->addWidget(paramLe_, 2);
