@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef PROPERTYLINEEDITOR_H
-#define PROPERTYLINEEDITOR_H
+#pragma once
 
 #include <set>
 
@@ -365,5 +364,3 @@ protected:
     QString condValueOriVal_;
     bool broadcastChange_;
 };
-
-#endif  // PROPERTYLINEEDITOR_H
