@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef STATUSPROGBARHANDLER_H
-#define STATUSPROGBARHANDLER_H
+#pragma once
 
 
 #include <QString>
@@ -37,5 +36,3 @@ private:
     QProgressBar* progBar_;
     QTime timer_;
 };
-
-#endif  // STATUSPROGBARHANDLER_H
