@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef VIEWER_SRC_STRINGMATCHCOMBO_HPP_
-#define VIEWER_SRC_STRINGMATCHCOMBO_HPP_
+#pragma once
 
 #include <QComboBox>
 #include <QToolButton>
@@ -30,5 +29,3 @@ public:
     StringMatchMode::Mode currentMatchMode() const;
     void setMatchMode(const StringMatchMode& mode);
 };
-
-#endif /* VIEWER_SRC_STRINGMATCHCOMBO_HPP_ */
