@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef VIEWER_SRC_STRINGMATCHMODE_HPP_
-#define VIEWER_SRC_STRINGMATCHMODE_HPP_
+#pragma once
 
 #include <string>
 #include <map>
@@ -41,6 +40,3 @@ private:
     Mode mode_;
     static std::map<Mode, std::string> matchOper_;
 };
-
-
-#endif /* VIEWER_SRC_STRINGMATCHMODE_HPP_ */
