@@ -23,16 +23,14 @@
 
 TextEditSearchLine::TextEditSearchLine(QWidget* parent) :
     AbstractSearchLine(parent),
-    interface_(0),
+    interface_(nullptr),
     lastFindSuccessful_(false)
 {
     connect(matchModeCb_, SIGNAL(currentIndexChanged(int)),
             this, SLOT(matchModeChanged(int)));
 }
 
-TextEditSearchLine::~TextEditSearchLine()
-{
-}
+TextEditSearchLine::~TextEditSearchLine() = default;
 
 void TextEditSearchLine::setSearchInterface(AbstractTextEditSearchInterface* e)
 {
@@ -55,7 +53,7 @@ void TextEditSearchLine::highlightMatches(QString txt)
 #if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
                        QTextDocument::FindFlags(),
 #else
-                       0,
+                       nullptr,
 #endif
                        QTextCursor::StartOfWord, 0);  // highlight all matches
         }
@@ -91,13 +89,13 @@ void TextEditSearchLine::slotFind(QString txt)
     }
 
     highlightAllTimer_.stop();
-    bool found          = findString(txt, false,
+    bool found = findString(txt, false,
 #if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
-                                     QTextDocument::FindFlags(),
+                            QTextDocument::FindFlags(),
 #else
-                                     0,
+                            nullptr,
 #endif
-                                     QTextCursor::StartOfWord, 0);  // find the next match
+                            QTextCursor::StartOfWord, 0);  // find the next match
     lastFindSuccessful_ = found;
 
     if (!isEmpty())  // there is a search term supplied by the user
@@ -126,7 +124,7 @@ void TextEditSearchLine::slotFindNext()
 #if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
                                      QTextDocument::FindFlags(),
 #else
-                                     0,
+                                     nullptr,
 #endif
                                      QTextCursor::NoMove, 0);
     updateButtons(lastFindSuccessful_);
@@ -187,7 +185,7 @@ void TextEditSearchLine::clearHighlights()
         interface_->clearHighlights();
 }
 
-void TextEditSearchLine::matchModeChanged(int notUsed)
+void TextEditSearchLine::matchModeChanged(int /*notUsed*/)
 {
     if (matchModeCb_->currentMatchMode() == StringMatchMode::ContainsMatch)
         actionWholeWords_->setEnabled(true);
