@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef TRANSPARENCYWIDGET_H
-#define TRANSPARENCYWIDGET_H
+#pragma once
 
 #include <QWidget>
 
@@ -18,11 +17,11 @@ class QSpinBox;
 class QToolButton;
 
 // Values are between 0-100
-class TransparencyWidget: public QWidget
+class TransparencyWidget : public QWidget
 {
     Q_OBJECT
 public:
-    TransparencyWidget(QWidget* parent, QFont f=QFont());
+    TransparencyWidget(QWidget* parent, QFont f = QFont());
     void init(int);
     void initAlpha(int);
     int value() const;
@@ -44,14 +43,10 @@ protected:
     int alphaToTr(int a) const;
 
     QSlider* slider_;
-    QSpinBox *sp_;
+    QSpinBox* sp_;
     QLabel* label_;
     QToolButton* resetTb_;
     bool ignoreChange_{false};
     bool useSp_{false};
     bool useLabel_{true};
 };
-
-#endif // TRANSPARENCYWIDGET_H
-
-
