@@ -12,18 +12,6 @@
 #include <QtGlobal>
 #include <QAbstractItemModel>
 #include <QDebug>
-#include <QRegularExpression>
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0)
-#include <QRegExp>
-#endif
-
-TreeModelMatchCollector::TreeModelMatchCollector() :
-    model_(0),
-    column_(0),
-    flags_(Qt::MatchRecursive),
-    startItemPos_(-1),
-    startItemFound_(false),
-    startIndexPassed_(false) {}
 
 void TreeModelMatchCollector::setModel(QAbstractItemModel* model)
 {
@@ -42,18 +30,18 @@ void TreeModelMatchCollector::clear()
     startItemFound_   = false;
     startIndexPassed_ = false;
     value_.clear();
-    column_ = 0;
-    flags_  = Qt::MatchRecursive;
+    columns_.clear();
+    flags_ = Qt::MatchRecursive;
     items_.clear();
 }
 
-void TreeModelMatchCollector::match(QString value, int column, Qt::MatchFlags flags,
+void TreeModelMatchCollector::match(QString value, QVector<int> columns, Qt::MatchFlags flags,
                                     const QModelIndex& startIndex)
 {
     if (!model_)
         clear();
 
-    if (value_ == value && column_ == column && flags_ == flags)
+    if (value_ == value && columns_ == columns && flags_ == flags)
         return;
 
     startIndex_       = startIndex;
@@ -61,63 +49,85 @@ void TreeModelMatchCollector::match(QString value, int column, Qt::MatchFlags fl
     startItemFound_   = false;
     startIndexPassed_ = false;
 
-    value_  = value;
-    column_ = column;
-    flags_  = flags;
+    value_   = value;
+    columns_ = columns;
+    flags_   = flags;
     items_.clear();
 
-    for (int i = 0; i < model_->rowCount(); i++)
-        findMatch(model_->index(i, column_));
+    buildRx();
+
+    for (int i = 0; i < model_->rowCount(); i++) {
+        findMatch(i, QModelIndex());
+    }
 
     if (startItemPos_ == -1 && items_.count() > 0)
         startItemPos_ = 0;
 }
 
-void TreeModelMatchCollector::findMatch(const QModelIndex& idx)
+void TreeModelMatchCollector::buildRx()
 {
-    QString s = idx.data(Qt::DisplayRole).toString();
-
-    bool found = false;
     if (flags_.testFlag(Qt::MatchWildcard)) {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
-        QRegularExpression rx;
-        rx.setPattern(QRegularExpression::wildcardToRegularExpression(value_));
+        wildcardRx_ = QRegularExpression();
+        wildcardRx_.setPattern(QRegularExpression::wildcardToRegularExpression(value_));
         if (!flags_.testFlag(Qt::MatchCaseSensitive))
-            rx.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
-        if (s.contains(rx))
-            found = true;
+            wildcardRx_.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
 #else
-        QRegExp rx(value_);
-        rx.setPatternSyntax(QRegExp::Wildcard);
+        wildcardRx_ = QRegExp(value_);
+        wildcardRx_.setPatternSyntax(QRegExp::Wildcard);
         Qt::CaseSensitivity cs = (flags_.testFlag(Qt::MatchCaseSensitive)) ? Qt::CaseSensitive : Qt::CaseInsensitive;
-        rx.setCaseSensitivity(cs);
-        if (s.contains(rx))
-            found = true;
+        wildcardRx_.setCaseSensitivity(cs);
 #endif
     }
 #if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
-    else if (flags_.testFlag(Qt::MatchRegularExpression) ){
+    else if (flags_.testFlag(Qt::MatchRegularExpression)) {
 #else
-    else if (flags_.testFlag(Qt::MatchRegExp) ){
+    else if (flags_.testFlag(Qt::MatchRegExp)) {
 #endif
-        QRegularExpression rx(value_);
+        rx_ = QRegularExpression(value_);
         if (!flags_.testFlag(Qt::MatchCaseSensitive))
-            rx.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
-        if (s.contains(rx))
-            found = true;
+            rx_.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
     }
-    else {
-        if (s.contains(value_,
-                       (flags_.testFlag(Qt::MatchCaseSensitive)) ? Qt::CaseSensitive : Qt::CaseInsensitive)) {            
-            found = true;
+}
+
+void TreeModelMatchCollector::findMatch(int row, const QModelIndex& parentIdx)
+{
+    bool found = false;
+    for (auto column : columns_) {
+        auto idx  = model_->index(row, column, parentIdx);
+        QString s = idx.data(Qt::DisplayRole).toString();
+        if (flags_.testFlag(Qt::MatchWildcard)) {
+            if (s.contains(wildcardRx_)) {
+                found = true;
+                break;
+            }
+        }
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+        else if (flags_.testFlag(Qt::MatchRegularExpression)) {
+#else
+        else if (flags_.testFlag(Qt::MatchRegExp)) {
+#endif
+            if (s.contains(rx_)) {
+                found = true;
+                break;
+            }
+        }
+        else {
+            if (s.contains(value_,
+                           (flags_.testFlag(Qt::MatchCaseSensitive)) ? Qt::CaseSensitive : Qt::CaseInsensitive)) {
+                found = true;
+                break;
+            }
         }
     }
 
+    auto refIdx = model_->index(row, 0, parentIdx);
+
     if (found) {
-        items_ << idx;
+        items_ << refIdx;
     }
 
-    if (idx == startIndex_) {
+    if (refIdx == startIndex_) {
         startItemPos_     = items_.count() - 1;
         startIndexPassed_ = true;
         if (found)
@@ -128,23 +138,27 @@ void TreeModelMatchCollector::findMatch(const QModelIndex& idx)
         startItemFound_ = true;
     }
 
-    int chNum = idx.model()->rowCount(idx);
+    int chNum = model_->rowCount(refIdx);
     for (int i = 0; i < chNum; i++) {
-        findMatch(idx.model()->index(i, column_, idx));
+        findMatch(i, refIdx);
     }
 }
 
 void TreeModelMatchCollector::allValues(QSet<QString>& vals) const
 {
     for (int i = 0; i < model_->rowCount(); i++)
-        allValues(model_->index(i, column_), vals);
+        allValues(i, QModelIndex(), vals);
 }
 
-void TreeModelMatchCollector::allValues(const QModelIndex& idx, QSet<QString>& vals) const
+void TreeModelMatchCollector::allValues(int row, const QModelIndex& parentIdx, QSet<QString>& vals) const
 {
-    vals << idx.data(Qt::DisplayRole).toString();
+    for (auto column : columns_) {
+        auto idx = model_->index(row, column, parentIdx);
+        vals << idx.data(Qt::DisplayRole).toString();
+    }
 
-    int chNum = idx.model()->rowCount(idx);
+    auto refIdx = model_->index(row, 0, parentIdx);
+    int chNum   = model_->rowCount(refIdx);
     for (int i = 0; i < chNum; i++)
-        allValues(idx.model()->index(i, column_, idx), vals);
+        allValues(i, refIdx, vals);
 }
