@@ -1209,7 +1209,7 @@ TextPagerCursor TextPagerDocument::findLine(int lineNum, const TextPagerCursor&
     int offset;
     Chunk* c = d->chunkAt(cursor.position(), &offset);
 
-    Q_ASSERT(c != NULL);
+    Q_ASSERT(c != nullptr);
 
     int pos = cursor.position() - offset;  //points to the chunks beginning
     d->updateChunkLineNumbers(c, pos);
@@ -1238,7 +1238,7 @@ TextPagerCursor TextPagerDocument::findLine(int lineNum, const TextPagerCursor&
 #endif
         }
 
-        Q_ASSERT(c != NULL && c->previous != NULL);
+        Q_ASSERT(c != nullptr && c->previous != nullptr);
 
         c = c->previous;
         pos -= c->size();
