@@ -12,8 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#ifndef TEXTPAGERDOCUMENT_HPP__
-#define TEXTPAGERDOCUMENT_HPP__
+#pragma once
 
 #include <QObject>
 #include <QString>
@@ -190,5 +189,3 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(TextPagerDocument::FindMode);
 Q_DECLARE_OPERATORS_FOR_FLAGS(TextPagerDocument::Options);
-
-#endif
