@@ -12,8 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#ifndef TEXTPAGERDOCUMENT_P_HPP__
-#define TEXTPAGERDOCUMENT_P_HPP__
+#pragma once
 
 #include <QString>
 #include <QApplication>
@@ -762,6 +761,3 @@ private:
     bool convert;
     const QChar newline;
 };
-
-
-#endif
