@@ -44,7 +44,7 @@ TextPagerEdit::TextPagerEdit(QWidget* parent) :
     d(new TextEditPrivate(this)),
     useSearchHighlight_(false),
     lineNumArea_(0),
-    fontProp_(NULL)
+    fontProp_(nullptr)
 {
     viewport()->setCursor(Qt::IBeamCursor);
 
