@@ -8,8 +8,7 @@
 //
 //============================================================================
 
-#ifndef VIEWER_SRC_TEXTPAGERWIDGET_HPP_
-#define VIEWER_SRC_TEXTPAGERWIDGET_HPP_
+#pragma once
 
 #include "TextPagerEdit.hpp"
 
@@ -47,6 +46,3 @@ private:
     TextPagerLineNumberArea* lineNumArea_;
     GotoLineDialog* gotoLineDialog_;
 };
-
-
-#endif /* VIEWER_SRC_TEXTPAGER_TEXTPAGERWIDGET_HPP_ */
