@@ -8,7 +8,7 @@
  ***************************** LICENSE END *************************************/
 
 #include "DocHighlighter.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 #include "MvQTheme.h"
 
 #include <QDebug>
@@ -25,14 +25,14 @@
 QString DocHighlighter::parFile_;
 
 
-DocHighlighter::DocHighlighter(QTextDocument *parent,QString id)
-     : QSyntaxHighlighter(parent)
+DocHighlighter::DocHighlighter(QTextDocument* parent, QString id) :
+    QSyntaxHighlighter(parent)
 {
     init();
     load(id);
 }
 
-DocHighlighter::HighlightingRule DocHighlighter::makeRule(QString pattern,QTextCharFormat format, bool caseSensitive)
+DocHighlighter::HighlightingRule DocHighlighter::makeRule(QString pattern, QTextCharFormat format, bool caseSensitive)
 {
     HighlightingRule rule;
 #if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
@@ -41,40 +41,39 @@ DocHighlighter::HighlightingRule DocHighlighter::makeRule(QString pattern,QTextC
         rule.pattern.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
     }
 #else
-    rule.pattern = QRegExp(pattern,(caseSensitive)?Qt::CaseSensitive:Qt::CaseInsensitive);
+    rule.pattern = QRegExp(pattern, (caseSensitive) ? Qt::CaseSensitive : Qt::CaseInsensitive);
 #endif
     rule.format = format;
     return rule;
 }
 
-void DocHighlighter::highlightBlock(const QString &text)
+void DocHighlighter::highlightBlock(const QString& text)
 {
-    Q_FOREACH(HighlightingRule rule, rules_) {
+    Q_FOREACH (HighlightingRule rule, rules_) {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
         QRegularExpression expression(rule.pattern);
         QRegularExpressionMatch rmatch;
         int index = text.indexOf(expression, 0, &rmatch);
         while (index >= 0) {
-             int length = rmatch.capturedLength();
-             setFormat(index, length, rule.format);
-             index = text.indexOf(expression, index + length, &rmatch);
-         }
+            int length = rmatch.capturedLength();
+            setFormat(index, length, rule.format);
+            index = text.indexOf(expression, index + length, &rmatch);
+        }
 #else
         QRegExp expression(rule.pattern);
         int index = text.indexOf(expression);
-        while (index >= 0)
-        {
-             int length = expression.matchedLength();
-             setFormat(index, length, rule.format);
-             index = text.indexOf(expression, index + length);
-         }
+        while (index >= 0) {
+            int length = expression.matchedLength();
+            setFormat(index, length, rule.format);
+            index = text.indexOf(expression, index + length);
+        }
 
 #endif
-     }
+    }
 
-     setCurrentBlockState(0);
+    setCurrentBlockState(0);
 
-     if (!commentStartRule_.pattern.pattern().isEmpty()) {
+    if (!commentStartRule_.pattern.pattern().isEmpty()) {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 5, 0)
         int startIndex = 0;
         QRegularExpressionMatch rmatch;
@@ -93,26 +92,26 @@ void DocHighlighter::highlightBlock(const QString &text)
             setFormat(startIndex, commentLength, commentStartRule_.format);
             startIndex = text.indexOf(commentStartRule_.pattern,
                                       startIndex + commentLength);
-         }
+        }
 #else
         int startIndex = 0;
         if (previousBlockState() != 1)
             startIndex = text.indexOf(commentStartRule_.pattern);
 
-         while (startIndex >= 0) {
-             int endIndex = text.indexOf(commentEndRule_.pattern, startIndex);
-             int commentLength;
-             if (endIndex == -1) {
-                 setCurrentBlockState(1);
-                 commentLength = text.length() - startIndex;
-             }
-             else {
-                 commentLength = endIndex - startIndex + commentEndRule_.pattern.matchedLength();
-             }
-             setFormat(startIndex, commentLength, commentStartRule_.format);
-             startIndex = text.indexOf(commentStartRule_.pattern,
-                                       startIndex + commentLength);
-         }
+        while (startIndex >= 0) {
+            int endIndex = text.indexOf(commentEndRule_.pattern, startIndex);
+            int commentLength;
+            if (endIndex == -1) {
+                setCurrentBlockState(1);
+                commentLength = text.length() - startIndex;
+            }
+            else {
+                commentLength = endIndex - startIndex + commentEndRule_.pattern.matchedLength();
+            }
+            setFormat(startIndex, commentLength, commentStartRule_.format);
+            startIndex = text.indexOf(commentStartRule_.pattern,
+                                      startIndex + commentLength);
+        }
 #endif
     }
 }
@@ -149,38 +148,44 @@ void DocHighlighter::load(QString id)
                 QTextCharFormat format;
                 bool caseSensitive = true;
                 for (QJsonObject::const_iterator itPar = parObj.constBegin();
-                     itPar != parObj.constEnd(); itPar++)  {
-                        QString parName = itPar.key();
+                     itPar != parObj.constEnd(); itPar++) {
+                    QString parName = itPar.key();
 
-                        if(parName == "name") {
-                            name=itPar.value().toString();
-                        } else if(parName == "colour") {
-                            format.setForeground(rgb(itPar.value().toString()));
-                        } else if(parName == "pattern") {
-                            pattern=itPar.value().toString();
-                        } else if(parName == "startPattern")  {
-                            startPattern=itPar.value().toString();
-                        } else if(parName == "endPattern")  {
-                            endPattern=itPar.value().toString();
-                        } else if(parName == "bold") {
-                            if(itPar.value().toString().toLower() == "true")
-                                format.setFontWeight(QFont::Bold);
-                        } else if(parName == "italic") {
-                            if(itPar.value().toString().toLower() == "true")
-                                format.setFontItalic(true);
-                        } else if(parName == "caseInsensitive") {
-                            if(itPar.value().toString().toLower() == "true")
-                                caseSensitive = false;
-
-                        }
+                    if (parName == "name") {
+                        name = itPar.value().toString();
+                    }
+                    else if (parName == "colour") {
+                        format.setForeground(rgb(itPar.value().toString()));
+                    }
+                    else if (parName == "pattern") {
+                        pattern = itPar.value().toString();
+                    }
+                    else if (parName == "startPattern") {
+                        startPattern = itPar.value().toString();
+                    }
+                    else if (parName == "endPattern") {
+                        endPattern = itPar.value().toString();
+                    }
+                    else if (parName == "bold") {
+                        if (itPar.value().toString().toLower() == "true")
+                            format.setFontWeight(QFont::Bold);
+                    }
+                    else if (parName == "italic") {
+                        if (itPar.value().toString().toLower() == "true")
+                            format.setFontItalic(true);
+                    }
+                    else if (parName == "caseInsensitive") {
+                        if (itPar.value().toString().toLower() == "true")
+                            caseSensitive = false;
+                    }
                 }
                 if (name != "multiLineComment") {
                     rules_.append(makeRule(pattern, format, caseSensitive));
-                } else {
-                    commentStartRule_ = makeRule(startPattern, format, false);
-                    commentEndRule_ = makeRule(endPattern, format, false);
                 }
-
+                else {
+                    commentStartRule_ = makeRule(startPattern, format, false);
+                    commentEndRule_   = makeRule(endPattern, format, false);
+                }
             }
             return;
         }
@@ -206,25 +211,24 @@ void DocHighlighter::toHtml(QString& html)
 
     // Apply the additional formats set by the syntax highlighter
     QTextBlock start = document()->findBlock(cursor.selectionStart());
-    QTextBlock end = document()->findBlock(cursor.selectionEnd());
-    end = end.next();
+    QTextBlock end   = document()->findBlock(cursor.selectionEnd());
+    end              = end.next();
 
     const int selectionStart = cursor.selectionStart();
-    const int endOfDocument = tmpDoc->characterCount() - 1;
-    for(QTextBlock current = start; current.isValid() and current not_eq end; current = current.next())
-    {
+    const int endOfDocument  = tmpDoc->characterCount() - 1;
+    for (QTextBlock current = start; current.isValid() and current not_eq end; current = current.next()) {
         const QTextLayout* layout(current.layout());
 
-        Q_FOREACH(const QTextLayout::FormatRange &range,
+        Q_FOREACH (const QTextLayout::FormatRange& range,
 #if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
-                  layout->formats())
+                   layout->formats())
 #else
-                  layout->additionalFormats())
+                   layout->additionalFormats())
 #endif
         {
             const int start = current.position() + range.start - selectionStart;
-            const int end = start + range.length;
-            if(end <= 0 or start >= endOfDocument)
+            const int end   = start + range.length;
+            if (end <= 0 or start >= endOfDocument)
                 continue;
             tmpCursor.setPosition(qMax(start, 0));
             tmpCursor.setPosition(qMin(end, endOfDocument), QTextCursor::KeepAnchor);
@@ -233,7 +237,7 @@ void DocHighlighter::toHtml(QString& html)
     }
 
     // Reset the user states since they are not interesting
-    for(QTextBlock block = tmpDoc->begin(); block.isValid(); block = block.next())
+    for (QTextBlock block = tmpDoc->begin(); block.isValid(); block = block.next())
         block.setUserState(-1);
 
     // Make sure the text appears pre-formatted, and set the background we want.
