@@ -20,7 +20,7 @@
 #include "MvKeyProfile.h"
 #include "LogHandler.h"
 #include "MvMessageMetaData.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 #define UI_THREAD
 
@@ -35,9 +35,9 @@ MvQAbstractMessageScanner::MvQAbstractMessageScanner(MvMessageMetaData* data, QO
     firstScan_(true),
     filterEnabled_(false),
     data_(data),
-    prof_(0),
-    profLocal_(0),
-    profToProcess_(0),
+    prof_(nullptr),
+    profLocal_(nullptr),
+    profToProcess_(nullptr),
     readyEmitted_(false),
     needToStop_(false),
     startedReceived_(false),
@@ -72,9 +72,7 @@ MvQAbstractMessageScanner::MvQAbstractMessageScanner(MvMessageMetaData* data, QO
             this, SLOT(timeout()));
 }
 
-MvQAbstractMessageScanner::~MvQAbstractMessageScanner()
-{
-}
+MvQAbstractMessageScanner::~MvQAbstractMessageScanner() = default;
 
 bool MvQAbstractMessageScanner::hasFinished() const
 {
@@ -115,7 +113,7 @@ void MvQAbstractMessageScanner::timeout()
     timer_->stop();
 
     runScan(profToProcess_);
-    profToProcess_ = 0;
+    profToProcess_ = nullptr;
 }
 
 //we are in the main thread!
@@ -201,8 +199,8 @@ void MvQAbstractMessageScanner::runScan(MvKeyProfile* prof)
 
         //Finish the load
         finishScan();
-
-     } else {
+    }
+    else {
         //Real thread!
         if (isRunning()) {
             if (!wait(5000)) {
@@ -224,10 +222,10 @@ void MvQAbstractMessageScanner::clear()
     broadcastStep_   = 0;
     firstScan_       = true;
     filterEnabled_   = false;
-    prof_            = 0;
+    prof_            = nullptr;
     if (profLocal_) {
         delete profLocal_;
-        profLocal_ = 0;
+        profLocal_ = nullptr;
     }
     readyEmitted_     = false;
     needToStop_       = false;
@@ -363,7 +361,7 @@ int MvQAbstractMessageScanner::computeTotalMessageNum()
     }
 
     int res = 0;
-    if (codes_count_in_file(0, fp, &res) != CODES_SUCCESS)
+    if (codes_count_in_file(nullptr, fp, &res) != CODES_SUCCESS)
         res = 0;
 
     fclose(fp);
@@ -371,12 +369,12 @@ int MvQAbstractMessageScanner::computeTotalMessageNum()
 
 #if 0
     int count=0;
-    void* mesg=NULL;
+    void* mesg=nullptr;
     size_t size=0;
     off_t offset=0;
     int err=GRIB_SUCCESS;
     typedef void* (*wmo_read_proc)(FILE *, int, size_t *, off_t *, int *);
-    wmo_read_proc wmo_read = NULL;
+    wmo_read_proc wmo_read = nullptr;
     grib_context* c=codes_context_get_default();
 
     if(messageType_ == GribType)
@@ -427,7 +425,7 @@ void MvQAbstractMessageScanner::readMessageFailed(MvKeyProfile* prof, int msgCnt
 //------------------------------
 // Format key "count"
 //------------------------------
-void MvQAbstractMessageScanner::formatKeyCount(MvKeyProfile* prof, int num)
+void MvQAbstractMessageScanner::formatKeyCount(MvKeyProfile* /*prof*/, int num)
 {
     char c[20];
     int n, c_format_id;
