@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQABSTRACTMESSAGESCANNER_H
-#define MVQABSTRACTMESSAGESCANNER_H
+#pragma once
 
 #include <QTimer>
 #include <QThread>
@@ -49,8 +48,8 @@ signals:
     void profileSizeComputed();
 
 protected:
-    virtual bool useThreadForScanning(qint64 fSize) const=0;
-    virtual bool precomputeMessageNum() const=0;
+    virtual bool useThreadForScanning(qint64 fSize) const = 0;
+    virtual bool precomputeMessageNum() const             = 0;
     void run();
     void runScan(MvKeyProfile* prof);
     void finishScan();
@@ -101,5 +100,3 @@ protected:
     bool finishedReceived_;
     QMutex mutex_;
 };
-
-#endif  // MVQABSTRACTMESSAGESCANNER_H
