@@ -44,13 +44,11 @@ BufrMessageScanner::BufrMessageScanner(MvMessageMetaData* data, QObject* parent)
             this, SLOT(slotProgress(int, MvKeyProfile*, int, int, std::vector<MvEccBufrMessage*>)));
 }
 
-BufrMessageScanner::~BufrMessageScanner()
-{
-}
+BufrMessageScanner::~BufrMessageScanner() = default;
 
 bool BufrMessageScanner::useThreadForScanning(qint64 fSize) const
 {
-    return fSize > 1024*1024;
+    return fSize > 1024 * 1024;
 }
 
 bool BufrMessageScanner::precomputeMessageNum() const
@@ -74,15 +72,15 @@ void BufrMessageScanner::loadKeyProfile(MvKeyProfile* prof)
 
 void BufrMessageScanner::readMessages(MvKeyProfile* profOri)
 {
-    int err = 0;
+    int err       = 0;
     int bufrCount = 0;
     int profIndex = 0;
     std::vector<MvEccBufrMessage*> msgVec;
-    int num_messages = 0;
-    codes_bufr_header* header_array = NULL;
+    int num_messages                = 0;
+    codes_bufr_header* header_array = nullptr;
 
     // we use non strict mode
-    err = codes_bufr_extract_headers_malloc(NULL, fileName_.c_str(), &header_array, &num_messages, 0);
+    err = codes_bufr_extract_headers_malloc(nullptr, fileName_.c_str(), &header_array, &num_messages, 0);
     if (err) {
         Q_EMIT guiLog(ErrorLogType,
                       "BufrMessageScanner::readMessages() --->  Errors were generated during header scan: " +
@@ -100,8 +98,8 @@ void BufrMessageScanner::readMessages(MvKeyProfile* profOri)
     Q_ASSERT(num_messages == totalMessageNum_);
     Q_ASSERT(messageNum_ == totalMessageNum_);
 
-    if(totalMessageNum_ <=0) {
-        if (header_array != NULL) {
+    if (totalMessageNum_ <= 0) {
+        if (header_array != nullptr) {
             free(header_array);
         }
         return;
@@ -118,16 +116,17 @@ void BufrMessageScanner::readMessages(MvKeyProfile* profOri)
     prof->preAllocate(broadcastStep_);
 
     Q_EMIT guiLog(TaskLogType, "Generating bufr key list for all the messages" +
-                  GuiLog::methodKey() + "ecCodes C interface");
+                                   GuiLog::methodKey() + "ecCodes C interface");
 
-    for (int i=0; i < num_messages; ++i) {
+    for (int i = 0; i < num_messages; ++i) {
         if (firstScan_) {
-            MvEccBufrMessage* m = new MvEccBufrMessage(&header_array[i], i);
+            auto* m = new MvEccBufrMessage(&header_array[i], i);
             msgVec.push_back(m);
             if (!m->isHeaderValid() || !m->isDataValid()) {
                 prof->markErrorRow(i);
             }
-        } else {
+        }
+        else {
             msgVec.push_back(nullptr);
         }
 
@@ -150,7 +149,6 @@ void BufrMessageScanner::readMessages(MvKeyProfile* profOri)
             profIndex = 0;
             msgVec.clear();
         }
-
     }
 
     if (profIndex > 0) {
@@ -165,10 +163,12 @@ void BufrMessageScanner::readMessages(MvKeyProfile* profOri)
 
 void BufrMessageScanner::readMessage(MvKeyProfile* prof, codes_bufr_header* bh, int profIndex)
 {
-    long centre = bh->bufrHeaderCentre;
-    bool hasLocal2 = (centre == 98 && bh->ecmwfLocalSectionPresent != 0);
-    size_t vlen = 0;
-    char value[512]={0,};
+    long centre     = bh->bufrHeaderCentre;
+    bool hasLocal2  = (centre == 98 && bh->ecmwfLocalSectionPresent != 0);
+    size_t vlen     = 0;
+    char value[512] = {
+        0,
+    };
 
     for (std::size_t i = 0; i < prof->size(); i++) {
         std::string strName = prof->at(i)->name();
@@ -177,7 +177,8 @@ void BufrMessageScanner::readMessage(MvKeyProfile* prof, codes_bufr_header* bh,
         if ((pos = strName.find(":98")) == strName.size() - 3) {
             if (hasLocal2) {
                 strName = strName.substr(0, strName.size() - 3);
-            } else {
+            }
+            else {
                 prof->at(i)->setStringValue(profIndex, "N/A");
                 continue;
             }
@@ -187,20 +188,23 @@ void BufrMessageScanner::readMessage(MvKeyProfile* prof, codes_bufr_header* bh,
             strName = "localSectionPresent";
         }
 
-        if (prof->at(i)->name() != "MV_Index") {
-            vlen = 0;
+        if (prof->at(i)->name() != "MV_Index" && prof->at(i)->name() != "MV_Frame") {
+            vlen     = 0;
             value[0] = '\n';
             if (codes_bufr_header_get_string(bh, strName.c_str(), value, &vlen) == CODES_SUCCESS) {
                 if (strName != "localSectionPresent") {
                     if (strcmp(value, "not_found") == 0) {
                         prof->at(i)->setStringValue(profIndex, "N/A");
-                    } else {
+                    }
+                    else {
                         prof->at(i)->setStringValue(profIndex, value);
                     }
-                } else {
+                }
+                else {
                     prof->at(i)->setStringValue(profIndex, (strcmp(value, "0") == 0) ? "0" : "1");
                 }
-            } else {
+            }
+            else {
                 prof->at(i)->setStringValue(profIndex, "N/A");
             }
         }
@@ -269,7 +273,7 @@ void BufrMessageScanner::slotTotalMessageNumComputed()
 void BufrMessageScanner::readMessages(MvKeyProfile* profOri)
 {
     FILE* fp;
-    codes_handle* ch = NULL;
+    codes_handle* ch = nullptr;
     int err          = 0;
     int bufr_count   = 0;
     int profIndex    = 0;
@@ -294,7 +298,7 @@ void BufrMessageScanner::readMessages(MvKeyProfile* profOri)
     }
 
     //Get messages form the file
-    while ((ch = codes_handle_new_from_file(NULL, fp, PRODUCT_BUFR, &err)) != NULL || err != CODES_SUCCESS) {
+    while ((ch = codes_handle_new_from_file(nullptr, fp, PRODUCT_BUFR, &err)) != nullptr || err != CODES_SUCCESS) {
         if (!ch) {
             Q_EMIT guiLog(ErrorLogType,
                           "BufrMessageScanner::readMessages() --->  Unable to create code handle for message count: " +
@@ -310,7 +314,7 @@ void BufrMessageScanner::readMessages(MvKeyProfile* profOri)
             }
         }
         else
-            msgVec.push_back(NULL);
+            msgVec.push_back(nullptr);
 
         readMessage(prof, ch, bufr_count, profIndex);
         bufr_count++;
@@ -378,7 +382,7 @@ void BufrMessageScanner::readMessage(MvKeyProfile* prof, codes_handle* ch, int m
     const int MAX_VAL_LEN = 1024;
     long longValue;
     char value[MAX_VAL_LEN];
-    string svalue;
+    std::string svalue;
     size_t vlen = MAX_VAL_LEN;
 
     long centre;
@@ -398,7 +402,7 @@ void BufrMessageScanner::readMessage(MvKeyProfile* prof, codes_handle* ch, int m
         long lDateValue;
         if(MV_CODES_CHECK(codes_get_long(ch,"typicalDate",&lDateValue),0))
         {
-            firstTypicalDate_ = metview::toString<long>(lDateValue);
+            firstTypicalDate_ = std::to_string<long>(lDateValue);
         }
         else
         {
