@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQFILEINFO_H
-#define MVQFILEINFO_H
+#pragma once
 
 #include <string>
 #include <QFileInfo>
@@ -30,5 +29,3 @@ public:
 private:
     static QString handleSizePrecision(double sizeInUnits, QString unitsString);
 };
-
-#endif  // MVQFILEINFO_H
