@@ -158,7 +158,7 @@ bool MvQFileList::add(QString s, QString& err, bool broadcast)
 
 MvQFileList::FileType MvQFileList::fileType(QString fname)
 {
-    codes_handle* h = NULL;
+    codes_handle* h = nullptr;
     int err = 0, cnt = 0;
     FileType retVal = OtherFile;
     QFileInfo fInfo(fname);
@@ -173,15 +173,15 @@ MvQFileList::FileType MvQFileList::fileType(QString fname)
         return BadFile;
     }
 
-    while ((h = codes_handle_new_from_file(NULL, in, PRODUCT_ANY, &err)) != NULL || err != CODES_SUCCESS) {
-        if (h == NULL) {
+    while ((h = codes_handle_new_from_file(nullptr, in, PRODUCT_ANY, &err)) != nullptr || err != CODES_SUCCESS) {
+        if (h == nullptr) {
             std::cerr << "Unable to create handle for message " << cnt << std::endl;
             cnt++;
             continue;
         }
 
         size_t len = 0;
-        CODES_CHECK(codes_get_length(h, "kindOfProduct", &len), 0);
+        CODES_CHECK(codes_get_length(h, "kindOfProduct", &len), nullptr);
         char* kind = (char*)malloc(len * sizeof(char));
 
         codes_get_string(h, "kindOfProduct", kind, &len);
