@@ -17,7 +17,8 @@
 #include "MvKeyProfile.h"
 #include "LogHandler.h"
 #include "GribMetaData.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
+#include "MvLog.h"
 
 #define UI_THREAD
 
@@ -38,13 +39,11 @@ GribMessageScanner::GribMessageScanner(MvMessageMetaData* data, QObject* parent)
             this, SLOT(slotProgress(int, MvKeyProfile*, int, int)));
 }
 
-GribMessageScanner::~GribMessageScanner()
-{
-}
+GribMessageScanner::~GribMessageScanner() = default;
 
 bool GribMessageScanner::useThreadForScanning(qint64 fSize) const
 {
-    return fSize > 10*1024*1024;
+    return fSize > 10 * 1024 * 1024;
 }
 
 bool GribMessageScanner::precomputeMessageNum() const
@@ -131,7 +130,7 @@ void GribMessageScanner::slotTotalMessageNumComputed()
 
 void GribMessageScanner::readMessages(MvKeyProfile* profOri)
 {
-    /*vector<char*> name_space;
+    /*std::vector<char*> name_space;
     name_space.push_back(0);
     name_space.push_back("geography");
     name_space.push_back("ls");== GRIB_SUCCESS
@@ -141,7 +140,7 @@ void GribMessageScanner::readMessages(MvKeyProfile* profOri)
     name_space.push_back("vertical");*/
 
     FILE* fp;
-    codes_handle* ch = NULL;
+    codes_handle* ch = nullptr;
     int err          = 0;
     int grib_count   = 0;
     int profIndex    = 0;
@@ -179,23 +178,23 @@ void GribMessageScanner::readMessages(MvKeyProfile* profOri)
         if (firstScan_) {
             //initialise filterCnt_
             size_t foundCnt = 0;
-            for (size_t i = 0; i < filterCnt_.size(); i++) {
-                filterCnt_[i] = -1;
+            for (int& i : filterCnt_) {
+                i = -1;
             }
 
             int msgCnt = 0;
-            while ((ch = codes_handle_new_from_file(0, fp, PRODUCT_GRIB, &err)) != NULL || err != CODES_SUCCESS) {
+            while ((ch = codes_handle_new_from_file(nullptr, fp, PRODUCT_GRIB, &err)) != nullptr || err != CODES_SUCCESS) {
                 if (!ch) {
                     Q_EMIT guiLog(ErrorLogType,
                                   "GribMetaData::readMessages() --->  Unable to create GRIB handle for message: " +
-                                      metview::toString<int>(msgCnt) + "\n");
+                                      std::to_string(msgCnt) + "\n");
                 }
 
                 msgCnt++;
                 totalCnt++;
 
                 if (totalCnt % broadcastStep_ == 0) {
-                    Q_EMIT progress(percentage(totalCnt, totalScanNum), 0, -1, -1);
+                    Q_EMIT progress(percentage(totalCnt, totalScanNum), nullptr, -1, -1);
                 }
 
                 if (totalCnt % 25 == 0) {
@@ -229,7 +228,7 @@ void GribMessageScanner::readMessages(MvKeyProfile* profOri)
                     else {
                         Q_EMIT guiLog(ErrorLogType,
                                       "GribMetaData::readMessages() --->  Cannot get offset for message count: " +
-                                          metview::toString<int>(msgCnt) + "\n");
+                                          std::to_string(msgCnt) + "\n");
 
                         codes_handle_delete(ch);
                         return;
@@ -245,15 +244,15 @@ void GribMessageScanner::readMessages(MvKeyProfile* profOri)
         }
 
         //Read the filtered messages
-        for (size_t i = 0; i < filterOffset_.size(); i++) {
-            fseek(fp, filterOffset_[i], SEEK_SET);
+        for (long i : filterOffset_) {
+            fseek(fp, i, SEEK_SET);
 
             int err;
-            ch = codes_handle_new_from_file(0, fp, PRODUCT_GRIB, &err);
+            ch = codes_handle_new_from_file(nullptr, fp, PRODUCT_GRIB, &err);
             if (!ch) {
                 Q_EMIT guiLog(ErrorLogType,
                               "GribMetaData::readMessages() --->  Unable to create grib handle for offset: " +
-                                  QString::number(filterOffset_[i]).toStdString() + "\n");
+                                  QString::number(i).toStdString() + "\n");
             }
 
             readMessage(prof, ch, grib_count, profIndex);
@@ -299,7 +298,7 @@ void GribMessageScanner::readMessages(MvKeyProfile* profOri)
     }
     else {
         //Get messages form the file
-        while ((ch = codes_handle_new_from_file(0, fp, PRODUCT_GRIB, &err)) != NULL || err != CODES_SUCCESS) {
+        while ((ch = codes_handle_new_from_file(nullptr, fp, PRODUCT_GRIB, &err)) != nullptr || err != CODES_SUCCESS) {
             if (!ch) {
                 Q_EMIT guiLog(ErrorLogType,
                               "GribMetaData::readMessages() --->  Unable to create grib handle for message count: " +
@@ -374,14 +373,14 @@ void GribMessageScanner::readMessage(MvKeyProfile* prof, grib_handle* ch, int ms
     const int MAX_VAL_LEN = 1024;
     long longValue;
     char value[MAX_VAL_LEN];
-    string svalue;
+    std::string svalue;
     size_t vlen = MAX_VAL_LEN;
 
     for (unsigned int i = 0; i < prof->size(); i++) {
         size_t len;
         int keyType;
-        const string& name = prof->at(i)->name();
-        bool foundValue    = false;
+        const std::string& name = prof->at(i)->name();
+        bool foundValue         = false;
 
         if (grib_get_native_type(ch, name.c_str(), &keyType) == CODES_SUCCESS &&
             grib_get_size(ch, name.c_str(), &len) == CODES_SUCCESS &&
@@ -391,7 +390,7 @@ void GribMessageScanner::readMessage(MvKeyProfile* prof, grib_handle* ch, int ms
                 if (prof->at(i)->readIntAsString() == false &&
                     keyType == CODES_TYPE_LONG) {
                     if (codes_get_long(ch, name.c_str(), &longValue) == CODES_SUCCESS) {
-                        stringstream s;
+                        std::stringstream s;
                         s << longValue;
                         prof->at(i)->setStringValue(profIndex, s.str().c_str());
                         foundValue = true;
@@ -409,7 +408,7 @@ void GribMessageScanner::readMessage(MvKeyProfile* prof, grib_handle* ch, int ms
                      keyType == CODES_TYPE_LONG) {
                 if (prof->at(i)->readIntAsString() == false) {
                     if (codes_get_long(ch, name.c_str(), &longValue) == CODES_SUCCESS) {
-                        stringstream s;
+                        std::stringstream s;
                         s << longValue;
                         prof->at(i)->setStringValue(profIndex, s.str().c_str());
                         foundValue = true;
@@ -424,7 +423,7 @@ void GribMessageScanner::readMessage(MvKeyProfile* prof, grib_handle* ch, int ms
                 }
             }
             else {
-                stringstream s;
+                std::stringstream s;
                 s << len;
                 svalue = "Array (" + s.str() + ")";
                 prof->at(i)->setStringValue(profIndex, svalue);
@@ -434,8 +433,11 @@ void GribMessageScanner::readMessage(MvKeyProfile* prof, grib_handle* ch, int ms
 
 
         if (!foundValue) {
-            if (prof->at(i)->name() != "MV_Index")
-                prof->at(i)->setStringValue(profIndex, "N/A");
+            if (prof->at(i)->name() != "MV_Index" && prof->at(i)->name() != "MV_Frame") {
+                if (prof->at(i)->valueType() == MvKey::StringType) {
+                    prof->at(i)->setStringValue(profIndex, "N/A");
+                }
+            }
         }
     }
 }
