@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQGRIBMESSAGESCANNER_H
-#define MVQGRIBMESSAGESCANNER_H
+#pragma once
 
 #include "MvQAbstractMessageScanner.h"
 
@@ -35,5 +34,3 @@ protected:
 
     bool hasMultiMessage_;
 };
-
-#endif  // MVQGRIBMESSAGESCANNER_H
