@@ -15,7 +15,7 @@
 
 #include "MvQKeyManager.h"
 #include "MvKeyProfile.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 #ifdef METVIEW
 #include "mars.h"
@@ -23,7 +23,7 @@
 
 QMap<MvQKeyManager::KeyType, QString> MvQKeyManager::keyTypeName_;
 
-MvQKeyManager::MvQKeyManager(KeyType t, string fProfUser) :
+MvQKeyManager::MvQKeyManager(KeyType t, std::string fProfUser) :
     fProfUser_(fProfUser),
     keyType_(t),
     systemProfOnly_(false),
@@ -102,8 +102,8 @@ MvQKeyManager::MvQKeyManager(const MvQKeyManager& copy)
     keyType_            = copy.keyType_;
     systemProfOnly_     = copy.systemProfOnly_;
     predefinedKeysOnly_ = copy.predefinedKeysOnly_;
-    for (vector<MvKeyProfile*>::const_iterator it = copy.data().begin(); it != copy.data().end(); it++) {
-        data_.push_back((*it)->clone());
+    for (auto it : copy.data()) {
+        data_.push_back(it->clone());
     }
 }
 
@@ -119,15 +119,15 @@ QString MvQKeyManager::keyTypeName(KeyType t) const
 
 MvQKeyManager* MvQKeyManager::clone()
 {
-    MvQKeyManager* cp = new MvQKeyManager(*this);
+    auto* cp = new MvQKeyManager(*this);
     return cp;
 }
 
 void MvQKeyManager::clear()
 {
-    for (vector<MvKeyProfile*>::iterator it = data_.begin(); it != data_.end(); it++) {
-        delete (*it);
-        (*it) = 0;
+    for (auto& it : data_) {
+        delete it;
+        it = 0;
     }
 
     data_.clear();
@@ -136,14 +136,14 @@ void MvQKeyManager::clear()
 void MvQKeyManager::update(MvQKeyManager* m)
 {
     clear();
-    for (vector<MvKeyProfile*>::const_iterator it = m->data().begin(); it != m->data().end(); it++) {
-        data_.push_back((*it)->clone());
+    for (auto it : m->data()) {
+        data_.push_back(it->clone());
     }
 }
 
-MvKeyProfile* MvQKeyManager::addProfile(const string& name)
-{    
-    MvKeyProfile* profile = new MvKeyProfile(name);
+MvKeyProfile* MvQKeyManager::addProfile(const std::string& name)
+{
+    auto* profile = new MvKeyProfile(name);
     createDefaultProfile(profile);
     data_.push_back(profile);
     return profile;
@@ -154,7 +154,7 @@ void MvQKeyManager::addProfile(MvKeyProfile* profile)
     data_.push_back(profile);
 }
 
-MvKeyProfile* MvQKeyManager::addProfile(const string& name, MvKeyProfile* oriProf)
+MvKeyProfile* MvQKeyManager::addProfile(const std::string& name, MvKeyProfile* oriProf)
 {
     MvKeyProfile* newProf = oriProf->clone();
     newProf->setName(name);
@@ -166,7 +166,7 @@ MvKeyProfile* MvQKeyManager::addProfile(const string& name, MvKeyProfile* oriPro
 }
 
 
-MvKeyProfile* MvQKeyManager::addProfile(const string& name, MvKeyProfile* oriProf, KeyType /*oriKeyType*/)
+MvKeyProfile* MvQKeyManager::addProfile(const std::string& name, MvKeyProfile* oriProf, KeyType /*oriKeyType*/)
 {
     MvKeyProfile* newProf = oriProf->clone();
     newProf->setName(name);
@@ -182,28 +182,28 @@ MvKeyProfile* MvQKeyManager::addProfile(const string& name, MvKeyProfile* oriPro
                 key->setName("MV_Frame");
                 key->setDescription("Frame index");
             }
-       }
+        }
     }
 
     return newProf;
 }
 
-void MvQKeyManager::changeProfile(const string& name, MvKeyProfile* prof)
+void MvQKeyManager::changeProfile(const std::string& name, MvKeyProfile* prof)
 {
     if (!prof || prof->systemProfile())
         return;
 
-    for (vector<MvKeyProfile*>::iterator it = data_.begin(); it != data_.end(); it++) {
-        if ((*it)->name() == name) {
-            delete *it;
-            *it = prof->clone();
+    for (auto& it : data_) {
+        if (it->name() == name) {
+            delete it;
+            it = prof->clone();
         }
     }
 }
 
 void MvQKeyManager::deleteProfile(int index)
 {
-    vector<MvKeyProfile*>::iterator it = data_.begin() + index;
+    auto it = data_.begin() + index;
 
     if ((*it)->systemProfile())
         return;
@@ -212,11 +212,11 @@ void MvQKeyManager::deleteProfile(int index)
     data_.erase(it);
 }
 
-MvKeyProfile* MvQKeyManager::findProfile(string name)
+MvKeyProfile* MvQKeyManager::findProfile(std::string name)
 {
-    for (vector<MvKeyProfile*>::iterator it = data_.begin(); it != data_.end(); it++) {
-        if ((*it)->name() == name) {
-            return *it;
+    for (auto& it : data_) {
+        if (it->name() == name) {
+            return it;
         }
     }
 
@@ -228,17 +228,17 @@ void MvQKeyManager::loadProfiles()
 {
     MvKeyProfile* firstSysProf = 0;
     loadProfiles(fProfDefault_, data_);
-    for (vector<MvKeyProfile*>::iterator it = data_.begin(); it != data_.end(); it++) {
-        (*it)->setSystemProfile(true);
+    for (auto& it : data_) {
+        it->setSystemProfile(true);
         if (!firstSysProf) {
-            firstSysProf = *it;
+            firstSysProf = it;
         }
     }
 
     if (predefinedKeysOnly_) {
         loadAllKeys(dataAll_);
-        for (vector<MvKeyProfile*>::iterator itProf = data_.begin(); itProf != data_.end(); ++itProf) {
-            (*itProf)->expand(dataAll_);
+        for (auto& itProf : data_) {
+            itProf->expand(dataAll_);
         }
     }
 
@@ -262,7 +262,7 @@ void MvQKeyManager::loadProfiles()
     }
 }
 
-void MvQKeyManager::loadAllKeys(vector<MvKeyProfile*>& target)
+void MvQKeyManager::loadAllKeys(std::vector<MvKeyProfile*>& target)
 {
     if (systemProfOnly_)
         return;
@@ -270,7 +270,7 @@ void MvQKeyManager::loadAllKeys(vector<MvKeyProfile*>& target)
     loadProfiles(fProfAll_, target);
 }
 
-bool MvQKeyManager::loadProfiles(string fileName, vector<MvKeyProfile*>& target)
+bool MvQKeyManager::loadProfiles(std::string fileName, std::vector<MvKeyProfile*>& target)
 {
     if (fileName.empty())
         return false;
@@ -288,58 +288,58 @@ bool MvQKeyManager::loadProfiles(string fileName, vector<MvKeyProfile*>& target)
     QString xmlConf(file.readAll());
     file.close();
 
-//    qDebug() << xmlConf;
+    //    qDebug() << xmlConf;
 
     auto doc = QDomDocument("prof");
     doc.setContent(xmlConf);
     QDomElement docElem = doc.documentElement();
-//    qDebug() << "root" << docElem.text() << docElem.tagName();
+    //    qDebug() << "root" << docElem.text() << docElem.tagName();
 
     QDomNode n = docElem.firstChild();
-    while(!n.isNull()) {
+    while (!n.isNull()) {
         if (n.nodeName() == "Profile" && n.isElement()) {
-            auto attr = n.attributes();
+            auto attr    = n.attributes();
             QString name = attr.namedItem("name").toAttr().value();
-            name = name.simplified();
+            name         = name.simplified();
             if (!name.isEmpty()) {
                 //Create new profile
-                MvKeyProfile* prof = new MvKeyProfile(name.toStdString());
+                auto* prof = new MvKeyProfile(name.toStdString());
                 target.push_back(prof);
 
-                auto item =  n.firstChild();
-                while(!item.isNull()) {
-//                    qDebug() << "item:" << item.nodeName();
-                    auto itemAttr = item.attributes();
-                    QString keyName = itemAttr.namedItem("name").toAttr().value();
+                auto item = n.firstChild();
+                while (!item.isNull()) {
+                    //                    qDebug() << "item:" << item.nodeName();
+                    auto itemAttr        = item.attributes();
+                    QString keyName      = itemAttr.namedItem("name").toAttr().value();
                     QString keyShortName = itemAttr.namedItem("shortName").toAttr().value();
-                    QString keyDesc = itemAttr.namedItem("desc").toAttr().value();
-                    QString keyEditable = itemAttr.namedItem("editable").toAttr().value();
+                    QString keyDesc      = itemAttr.namedItem("desc").toAttr().value();
+                    QString keyEditable  = itemAttr.namedItem("editable").toAttr().value();
                     if (keyEditable.isEmpty()) {
                         keyEditable = "true";
                     }
 
                     if (!keyName.isEmpty() || !keyShortName.isEmpty()) {
-                        MvKey* key = new MvKey(keyName.toStdString(),
-                                                keyShortName.toStdString(),
-                                                keyDesc.toStdString());
+                        auto* key = new MvKey(keyName.toStdString(),
+                                              keyShortName.toStdString(),
+                                              keyDesc.toStdString());
 
                         if (keyEditable == "false" || keyEditable == "0" || predefinedKeysOnly_) {
                             key->setEditable(false);
                         }
 
-                        if (key->name() == "MV_Index") {
+                        if (key->name() == "MV_Index" || key->name() == "MV_Frame") {
                             key->setValueType(MvKey::IntType);
                         }
 
                         prof->push_back(key);
 
                         // get data tag
-                        auto dataItem =  item.firstChild();
-                        while(!dataItem.isNull()) {
+                        auto dataItem = item.firstChild();
+                        while (!dataItem.isNull()) {
                             auto dataAttr = dataItem.attributes();
                             //qDebug() << "key:" << keyName;
                             for (int i = 0; i < dataAttr.size(); i++) {
-                                auto da = dataAttr.item(i).toAttr();                              
+                                auto da = dataAttr.item(i).toAttr();
                                 if (!da.isNull()) {
                                     //qDebug() << "  " << da.name() << da.value();
                                     key->setMetaData(da.name().toStdString(),
@@ -376,10 +376,7 @@ void MvQKeyManager::saveProfiles()
     s = "<MetviewKeyProfile type=\"" + keyTypeName_[keyType_] + "\">\n";
     out.write(s.toUtf8());
 
-    for (vector<MvKeyProfile*>::iterator it = data_.begin(); it != data_.end(); it++) {
-        MvKeyProfile* prof = *it;
-
-
+    for (auto prof : data_) {
         //We do not save system profiles into the user profile file
         if (prof->systemProfile())
             continue;
@@ -388,9 +385,8 @@ void MvQKeyManager::saveProfiles()
         s = "\t<Profile name=\"" + QString(prof->name().c_str()) + "\">\n";
         out.write(s.toUtf8());
 
-        for (vector<MvKey*>::iterator it1 = prof->begin(); it1 != prof->end(); it1++) {
-            MvKey* key = *it1;
-            s          = "\t\t<Key name=\"" + QString::fromStdString(key->name()) + "\"" +
+        for (auto key : *prof) {
+            s = "\t\t<Key name=\"" + QString::fromStdString(key->name()) + "\"" +
                 " shortName=\"" + QString::fromStdString(key->shortName()) + "\"" +
                 " desc=\"" + QString::fromStdString(key->description()) + "\"";
 
@@ -400,9 +396,8 @@ void MvQKeyManager::saveProfiles()
                 s = ">\n";
                 out.write(s.toUtf8());
 
-                for (map<string, string>::const_iterator it2 = key->metaData().begin();
-                     it2 != key->metaData().end(); it2++) {
-                    s = "\t\t\t<Data " + QString::fromStdString(it2->first) + "=\"" + QString::fromStdString(it2->second) + "\"/>\n";
+                for (const auto& it2 : key->metaData()) {
+                    s = "\t\t\t<Data " + QString::fromStdString(it2.first) + "=\"" + QString::fromStdString(it2.second) + "\"/>\n";
                     out.write(s.toUtf8());
                 }
 
@@ -445,8 +440,8 @@ void MvQKeyManager::createDefaultProfile(MvKeyProfile* prof)
 QString MvQKeyManager::findUniqueProfileName(QString profName)
 {
     int cnt = 0;
-    for (vector<MvKeyProfile*>::const_iterator it = data_.begin(); it != data_.end(); it++) {
-        QString qsName((*it)->name().c_str());
+    for (auto it : data_) {
+        QString qsName(it->name().c_str());
 
         if (qsName == profName) {
             if (cnt == 0)
