@@ -7,13 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQKeyManager_H
-#define MvQKeyManager_H
+#pragma once
 
-#include <iostream>
-#include <map>
 #include <vector>
-#include <list>
+#include <string>
 
 #include <QtGlobal>
 #include <QMap>
@@ -25,11 +22,8 @@
 //#include <QXmlQuery>
 //#endif
 
-using namespace std;
-
 class MvKeyProfile;
 
-
 class MvQKeyManager
 {
 public:
@@ -43,28 +37,28 @@ public:
         BookmarkType
     };
 
-    MvQKeyManager(KeyType t, string fProfUser = string());
+    MvQKeyManager(KeyType t, std::string fProfUser = std::string());
     MvQKeyManager(const MvQKeyManager&);
     ~MvQKeyManager();
 
     MvQKeyManager* clone();
-    MvKeyProfile* addProfile(const string&);
+    MvKeyProfile* addProfile(const std::string&);
     void addProfile(MvKeyProfile*);
-    MvKeyProfile* addProfile(const string&, MvKeyProfile*);
-    MvKeyProfile* addProfile(const string&, MvKeyProfile*, KeyType);
-    void changeProfile(const string&, MvKeyProfile*);
+    MvKeyProfile* addProfile(const std::string&, MvKeyProfile*);
+    MvKeyProfile* addProfile(const std::string&, MvKeyProfile*, KeyType);
+    void changeProfile(const std::string&, MvKeyProfile*);
     KeyType keyType() { return keyType_; }
     QString keyTypeName(KeyType t) const;
-    const string& profilePath() const { return fProfUser_; }
+    const std::string& profilePath() const { return fProfUser_; }
 
-    const vector<MvKeyProfile*>& data() const { return data_; }
-    MvKeyProfile* findProfile(string);
+    const std::vector<MvKeyProfile*>& data() const { return data_; }
+    MvKeyProfile* findProfile(std::string);
     bool isEmpty() { return (data_.size() == 0) ? true : false; }
     void update(MvQKeyManager*);
     void deleteProfile(int);
     void loadProfiles();
-    bool loadProfiles(string, vector<MvKeyProfile*>&);
-    void loadAllKeys(vector<MvKeyProfile*>&);
+    bool loadProfiles(std::string, std::vector<MvKeyProfile*>&);
+    void loadAllKeys(std::vector<MvKeyProfile*>&);
     void saveProfiles();
     void clear();
     QString findUniqueProfileName(QString);
@@ -74,17 +68,15 @@ public:
 private:
     void createDefaultProfile(MvKeyProfile*);
 
-    string fProfDefault_;
-    string fProfAll_;
-    string fProfUser_;
+    std::string fProfDefault_;
+    std::string fProfAll_;
+    std::string fProfUser_;
 
-    vector<MvKeyProfile*> data_;
-    vector<MvKeyProfile*> dataAll_;
+    std::vector<MvKeyProfile*> data_;
+    std::vector<MvKeyProfile*> dataAll_;
 
     KeyType keyType_;
     static QMap<KeyType, QString> keyTypeName_;
     bool systemProfOnly_;
     bool predefinedKeysOnly_;
 };
-
-#endif
