@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQLOCALSOCKETSERVER_H
-#define MVQLOCALSOCKETSERVER_H
+#pragma once
 
 #include <QObject>
 
@@ -34,5 +33,3 @@ protected:
     QLocalServer* server_;
     QString serverId_;
 };
-
-#endif  // MVQLOCALSOCKETSERVER
