@@ -69,7 +69,7 @@ void MvQScatterItem::computeMeanForColumns(QVector<float>& meanX, QVector<float>
 
 void MvQScatterItem::writeDataMatrixToNc(QString outFile, bool swapAxes)
 {
-    vector<float> x, y, value;
+    std::vector<float> x, y, value;
 
     /*for(int j=0; j < nY_; j++)
 	{
@@ -113,7 +113,7 @@ void MvQScatterItem::writeDataMatrixToNc(QString outFile, bool swapAxes)
     writeDataMatrixToNc(outFile.toStdString(), x, y, value);
 }
 
-void MvQScatterItem::writeDataMatrixToNc(string outFile, vector<float>& x, vector<float>& y, vector<float>& value)
+void MvQScatterItem::writeDataMatrixToNc(string outFile, std::vector<float>& x, std::vector<float>& y, std::vector<float>& value)
 {
     int num, nx, ny;
 
@@ -132,7 +132,7 @@ void MvQScatterItem::writeDataMatrixToNc(string outFile, vector<float>& x, vecto
     num = value.size();
 
 
-    cout << "num: " << num << endl;
+    std::cout << "num: " << num << std::endl;
 
     // Now we build the Netcdf file!
     NcFile netcdf = NcFile(outFile.c_str(), NcFile::Replace);
@@ -147,7 +147,7 @@ void MvQScatterItem::writeDataMatrixToNc(string outFile, vector<float>& x, vecto
     NcDim* dim_ny = netcdf.add_dim("ny", ny);
 
     //Define the netcdf vars
-    map<int, NcVar*> nc_vars;
+    std::map<int, NcVar*> nc_vars;
     nc_vars[0] = netcdf.add_var("x", ncFloat, dim_nx);
     nc_vars[1] = netcdf.add_var("y", ncFloat, dim_ny);
     nc_vars[2] = netcdf.add_var("val", ncFloat, dim_nx, dim_ny);
