@@ -7,6 +7,8 @@
 
  ***************************** LICENSE END *************************************/
 
+#include "MvQOdbMetaData.h"
+
 #include <QtGlobal>
 #include <QDebug>
 #include <QDir>
@@ -14,13 +16,9 @@
 #include <QStringList>
 #include <QTextStream>
 
-#include "MvQOdbMetaData.h"
-
 #include <odc/api/ColumnType.h>
 #include <odc/Reader.h>
 
-//using namespace odb;
-
 
 static QMap<odc::api::ColumnType, MvQOdbColumn::OdbColumnType> typeIdMap;
 static QMap<odc::api::ColumnType, QString> typeIdNameMap;
@@ -41,7 +39,7 @@ void MvQOdbTable::findLinks()
 }
 
 
-MvQOdbMetaData::MvQOdbMetaData(string path, string odbVersion)
+MvQOdbMetaData::MvQOdbMetaData(std::string path, std::string odbVersion)
 {
     path_ = QString::fromStdString(path);
 
@@ -154,9 +152,9 @@ void MvQOdbMetaData::loadSchemaFile()
         if (line.startsWith("SET")) {
             QStringList lst = line.split(" ",
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-                Qt::SkipEmptyParts);
+                                         Qt::SkipEmptyParts);
 #else
-                QString::SkipEmptyParts);
+                                         QString::SkipEmptyParts);
 #endif
 
             if (lst.count() == 4 && lst[2] == "=") {
@@ -190,9 +188,9 @@ void MvQOdbMetaData::loadSchemaFile()
 
             QStringList lst = str.split(" ",
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-                Qt::SkipEmptyParts);
+                                        Qt::SkipEmptyParts);
 #else
-                QString::SkipEmptyParts);
+                                        QString::SkipEmptyParts);
 #endif
 
             if (lst.size() < 3) {
@@ -230,9 +228,9 @@ void MvQOdbMetaData::loadSchemaFile()
 
             QStringList lst = str.split(" ",
 #if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-                Qt::SkipEmptyParts);
+                                        Qt::SkipEmptyParts);
 #else
-                QString::SkipEmptyParts);
+                                        QString::SkipEmptyParts);
 #endif
 
             if (lst.size() < 3) {
@@ -241,14 +239,14 @@ void MvQOdbMetaData::loadSchemaFile()
 
             //qDebug() <<  lst;
 
-            QString tableName  = lst[2];
-            MvQOdbTable* table = new MvQOdbTable(tableName);
+            QString tableName = lst[2];
+            auto* table       = new MvQOdbTable(tableName);
             for (int i = 5; i < lst.size(); i += 2) {
                 name = lst[i] + "@" + tableName;
                 //qDebug() << "table: " << name;
                 if (i + 1 < lst.size() && lst[i + 1].endsWith(",")) {
-                    type              = lst[i + 1].remove(lst[i + 1].size() - 1, 1);
-                    MvQOdbColumn* col = new MvQOdbColumn(name, type, tableName);
+                    type      = lst[i + 1].remove(lst[i + 1].size() - 1, 1);
+                    auto* col = new MvQOdbColumn(name, type, tableName);
                     columns_.push_back(col);
                     table->addColumn(col);
                 }
@@ -369,17 +367,17 @@ void MvQOdbMetaData::getTableTree()
 
 	//For each table find the position (x,y) in the tree!	
 	int posX=1;
-	vector<int> posY(100,0);
+	std::vector<int> posY(100,0);
 	QStack<QList<OdbTable*>::iterator> itActStack, itEndStack;		
-	list<OdbTable*>::iterator itAct=root_->linksTo().begin();
-	list<OdbTable*>::iterator itEnd=root_->linksTo().end();
+	std::list<OdbTable*>::iterator itAct=root_->linksTo().begin();
+	std::list<OdbTable*>::iterator itEnd=root_->linksTo().end();
 	
 	while(itAct != itEnd)
 	{						
 		(*itAct)->treePosX(posX);
 		(*itAct)->treePosY(posY[posX]); 		
 		
-		//cout << "table: " << (*itAct)->name_ <<   " x: " << (*itAct)->treePosX_  << " y: "  << (*itAct)->treePosY_ << endl;
+		//std::cout << "table: " << (*itAct)->name_ <<   " x: " << (*itAct)->treePosX_  << " y: "  << (*itAct)->treePosY_ << std::endl;
 		
 		posY[posX]=posY[posX]++;
 		
@@ -388,9 +386,9 @@ void MvQOdbMetaData::getTableTree()
 			itActStack.push(itAct);
 			itEndStack.push(itEnd);
 			
-			//cout << " to stack: " << (*itAct)->name_ << endl;
+			//std::cout << " to stack: " << (*itAct)->name_ << std::endl;
 			
-			list<OdbTable*>::iterator itTmp=itAct;			
+			std::list<OdbTable*>::iterator itTmp=itAct;			
 			itAct=(*itTmp)->linksTo().begin();
 			itEnd=(*itTmp)->linksTo().end();			
 			posX++;
@@ -410,7 +408,7 @@ void MvQOdbMetaData::getTableTree()
 			itActStack.pop();
 			itEndStack.pop();
 			
-			//cout << " rom stack: " << (*itAct)->name_ << endl;
+			//std::cout << " rom stack: " << (*itAct)->name_ << std::endl;
 			
 			itAct++;
 			posX--;
@@ -465,10 +463,10 @@ void MvQOdbMetaData::loadOdbHeader()
 
     odc::Reader::iterator it = oda.begin();
 
-    for (odc::core::MetaData::const_iterator itc = it->columns().begin(); itc != it->columns().end(); ++itc) {
-        MvQOdbColumn* acol = new MvQOdbColumn;
+    for (auto itc : it->columns()) {
+        auto* acol = new MvQOdbColumn;
 
-        string s = (*itc)->name();
+        std::string s = itc->name();
 
         QString colName(s.c_str());
         QStringList lst = colName.split("@");
@@ -478,25 +476,25 @@ void MvQOdbMetaData::loadOdbHeader()
         }
 
         acol->setName(QString(s.c_str()));
-        acol->setConstant((*itc)->isConstant());
-        acol->setMin((*itc)->min());
-        acol->setMax((*itc)->max());
+        acol->setConstant(itc->isConstant());
+        acol->setMin(itc->min());
+        acol->setMax(itc->max());
 
-        if ((*itc)->hasMissing()) {
-            acol->setHasMissingValue((*itc)->hasMissing());
-            acol->setMissingValue((*itc)->missingValue());
+        if (itc->hasMissing()) {
+            acol->setHasMissingValue(itc->hasMissing());
+            acol->setMissingValue(itc->missingValue());
         }
 
-        if (typeIdMap.contains((*itc)->type())) {
-            acol->setTypeId(typeIdMap[(*itc)->type()]);
-            acol->setType(typeIdNameMap[(*itc)->type()]);
+        if (typeIdMap.contains(itc->type())) {
+            acol->setTypeId(typeIdMap[itc->type()]);
+            acol->setType(typeIdNameMap[itc->type()]);
         }
 
         if (acol->typeId() == MvQOdbColumn::Bitfield) {
             int pos = 0;
-            for (unsigned int i = 0; i < (*itc)->bitfieldDef().first.size(); i++) {
-                string name = (*itc)->bitfieldDef().first.at(i);
-                int size    = (*itc)->bitfieldDef().second.at(i);
+            for (unsigned int i = 0; i < itc->bitfieldDef().first.size(); i++) {
+                std::string name = itc->bitfieldDef().first.at(i);
+                int size         = itc->bitfieldDef().second.at(i);
                 acol->addBitfieldMember(new MvQOdbBitfieldMember(QString(name.c_str()), pos, size));
                 pos += size;
             }
