@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQOdbMetaData_H
-#define MvQOdbMetaData_H
+#pragma once
 
 #include <QDebug>
 #include <QList>
@@ -22,14 +21,12 @@
 #include <assert.h>
 
 
-using namespace std;
-
 class MvQOdbVar
 {
 public:
     MvQOdbVar(QString name, QString value) :
         name_(name),
-        value_(value){};
+        value_(value) {}
 
     QString name() { return name_; }
     QString value() { return value_; }
@@ -77,7 +74,7 @@ public:
     };
 
     MvQOdbColumn() :
-        typeId_(None){};
+        typeId_(None) {}
     MvQOdbColumn(QString name, QString type, QString table) :
         name_(name),
         type_(type),
@@ -85,13 +82,13 @@ public:
         typeId_(None),
         constant_(false),
         hasMissingValue_(false),
-        missingValue_(-999999.){};
+        missingValue_(-999999.) {}
 
     ~MvQOdbColumn()
     {
         foreach (MvQOdbBitfieldMember* bf, bitfield_) {
             delete bf;
-        };
+        }
     }
 
     QString name() { return name_; }
@@ -112,8 +109,8 @@ public:
     void setType(QString s) { type_ = s; }
     void setTypeId(OdbColumnType s) { typeId_ = s; }
     void setUnit(QString s) { unit_ = s; }
-    void addBitfieldMember(MvQOdbBitfieldMember* b) { bitfield_.push_back(b); };
-    void setBitfield(QList<MvQOdbBitfieldMember*> b) { bitfield_ = b; };
+    void addBitfieldMember(MvQOdbBitfieldMember* b) { bitfield_.push_back(b); }
+    void setBitfield(QList<MvQOdbBitfieldMember*> b) { bitfield_ = b; }
     void setConstant(bool b) { constant_ = b; }
     void setMin(double min) { min_ = min; }
     void setMax(double max) { max_ = max; }
@@ -141,20 +138,20 @@ public:
     MvQOdbTable(QString name) :
         name_(name),
         treePosX_(0),
-        treePosY_(0){};
+        treePosY_(0) {}
 
-    QString name() { return name_; };
+    QString name() { return name_; }
     void addColumn(MvQOdbColumn* col) { columns_.push_back(col); }
     QList<MvQOdbColumn*>& columns() { return columns_; }
 
-    QStringList& linksTo() { return linksTo_; };
-    QStringList& linksFrom() { return linksFrom_; };
+    QStringList& linksTo() { return linksTo_; }
+    QStringList& linksFrom() { return linksFrom_; }
     void findLinks();
     void addToLinksFrom(QString lnk) { linksFrom_.push_back(lnk); }
-    int treePosX() { return treePosX_; };
-    void setTreePosX(int i) { treePosX_ = i; };
-    int treePosY() { return treePosY_; };
-    void setTreePosY(int i) { treePosY_ = i; };
+    int treePosX() { return treePosX_; }
+    void setTreePosX(int i) { treePosX_ = i; }
+    int treePosY() { return treePosY_; }
+    void setTreePosY(int i) { treePosY_ = i; }
 
 private:
     QString name_;
@@ -175,7 +172,7 @@ public:
         InvalidVersion
     };
     //MvQOdbMetaData(QString);
-    MvQOdbMetaData(string, string);
+    MvQOdbMetaData(std::string, std::string);
     //MvQOdbMetaData(QString,QString,QString);
     ~MvQOdbMetaData();
     void init();
@@ -218,5 +215,3 @@ protected:
     QList<MvQOdbColumn*> columns_;
     QList<MvQOdbVar*> vars_;
 };
-
-#endif
