@@ -51,7 +51,9 @@ public:
 
     static std::string toString(QColor);
     static QString toRgbString(QColor);
+    static QString toRgbIntString(QColor col);
     static QString toHslString(QColor);
+    static QString toHslIntString(QColor);
     static QString toStringAsList(QList<QColor> colLst);
     static QList<QColor> toColourList(QString txt);
     static QColor magics(const std::string&);
@@ -59,8 +61,17 @@ public:
     static void scan(PaletteScanner&);
     static void load(request*);
     static bool isPseudo(const std::string& name);
-    static void toHclF(QColor c, float& hue, float& chroma, float& luminance);
-    static QColor fromHclF(float hue, float chroma, float luminance);
+
+    static void toHclLabF(QColor c, float& hue, float& chroma, float& luminance);
+    static void toHclLab(QColor c, int& hue, int& chroma, int& luminance);
+    static QColor fromHclLabF(float hue, float chroma, float luminance);
+    static QColor fromHclLab(int hue,int chroma, int luminance);
+
+    static void toHclLuvF(QColor c, float& hue, float& chroma, float& luminance);
+    static void toHclLuv(QColor c, int& hue, int& chroma, int& luminance);
+    static QColor fromHclLuvF(float hue, float chroma, float luminance);
+    static QColor fromHclLuv(int hue,int chroma, int luminance);
+
     static void paintAlphaBg(QPainter* painter, QRect area);
 
 protected:
