@@ -145,7 +145,11 @@ void MvQProperty::setValue(const std::string& val)
     }
 
     if (!defaultValue_.isNull() &&
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        defaultValue_.typeId() != value_.typeId()) {
+#else
         defaultValue_.type() != value_.type()) {
+#endif
         changed = true;
         value_  = defaultValue_;
         //An error message should be shown!
@@ -161,7 +165,11 @@ void MvQProperty::setValue(QVariant val)
         return;
 
     if (!defaultValue_.isNull() &&
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        defaultValue_.typeId() != val.typeId()) {
+#else
         defaultValue_.type() != val.type()) {
+#endif
         return;
     }
 
@@ -305,13 +313,13 @@ MvQProperty* MvQProperty::findChild(QString name)
     return 0;
 }
 
-MvQProperty* MvQProperty::find(const std::string& fullPath)
+MvQProperty* MvQProperty::find(const std::string& /*fullPath*/)
 {
-    //TODO: implement it witout using boost
-    return NULL;
+    //TODO: implement it without using boost
+    return nullptr;
 #if 0
     if(fullPath.empty())
-		return NULL;
+		return nullptr;
 
 	if(fullPath == strName_)
 		return this;
@@ -322,7 +330,7 @@ MvQProperty* MvQProperty::find(const std::string& fullPath)
 	if(pathVec.size() > 0)
 	{
 		if(pathVec.at(0) != strName_)
-			return NULL;
+			return nullptr;
 	}
 
     return MvQProperty::find(pathVec);
@@ -332,7 +340,7 @@ MvQProperty* MvQProperty::find(const std::string& fullPath)
 MvQProperty* MvQProperty::find(const std::vector<std::string>& pathVec)
 {
     if (pathVec.size() == 0) {
-        return NULL;
+        return nullptr;
     }
 
     if (pathVec.size() == 1) {
@@ -344,7 +352,7 @@ MvQProperty* MvQProperty::find(const std::vector<std::string>& pathVec)
     std::vector<std::string> rest(pathVec.begin() + 1, pathVec.end());
     MvQProperty* n = findChild(QString::fromStdString(pathVec.at(1)));
 
-    return n ? n->find(rest) : NULL;
+    return n ? n->find(rest) : nullptr;
 }
 
 void MvQProperty::collectChildren(std::vector<MvQProperty*>& chVec) const
@@ -404,7 +412,7 @@ void MvQProperty::setUseMaster(bool b)
 
 MvQProperty* MvQProperty::clone(bool addLink, bool setMaster, bool useMaster)
 {
-    MvQProperty* cp = new MvQProperty(strName_);
+    auto* cp = new MvQProperty(strName_);
 
     cp->value_        = value_;
     cp->defaultValue_ = defaultValue_;
@@ -453,7 +461,7 @@ bool MvQProperty::isFont(const std::string& val)
     return QString::fromStdString(val).simplified().startsWith("font(");
 }
 
-bool MvQProperty::isSound(const std::string& val)
+bool MvQProperty::isSound(const std::string& /*val*/)
 {
     //TODO: implement it
     return false;
@@ -520,9 +528,10 @@ QFont MvQProperty::toFont(const std::string& name)
     return f;
 }
 
-QDate MvQProperty::toDate(const std::string& name)
+QDate MvQProperty::toDate(const std::string& /*name*/)
 {
-    return QDate();
+    // TODO: implement it
+    return {};
 }
 
 int MvQProperty::toNumber(const std::string& name)
