@@ -23,6 +23,7 @@ class QRect;
 class QRegion;
 class QString;
 class QVariant;
+class QColor;
 
 //Overload ostringstream for qt objects
 std::ostream& operator<<(std::ostream&, const QString&);
@@ -34,3 +35,4 @@ std::ostream& operator<<(std::ostream&, const QRect&);
 std::ostream& operator<<(std::ostream&, const QPoint&);
 std::ostream& operator<<(std::ostream&, const QDateTime&);
 std::ostream& operator<<(std::ostream&, QGraphicsItem*);
+std::ostream& operator<<(std::ostream&, const QColor&);
