@@ -20,7 +20,7 @@
 
 #include "mars.h"
 #include "MvQPaletteDb.h"
-#include "MvMiscelaneous.h"
+#include "MvMiscellaneous.h"
 
 MvQStyleDb* MvQStyleDb::instance_ = 0;
 
@@ -156,7 +156,7 @@ void MvQStyleDb::load()
     for (QJsonObject::const_iterator it = jsonob.constBegin(); it != jsonob.constEnd(); it++) {
         QString name = it.key();
         //qDebug() << name;
-        MvQStyleDbItem* item = new MvQStyleDbItem(name);
+        auto* item = new MvQStyleDbItem(name);
 
         Q_ASSERT(it.value().isObject());
 
