@@ -220,7 +220,7 @@ void CartesianView::UpdateAxisTypeView(MvRequest& reqData)
     // with sufix equals to "_X_TYPE"
     MvRequest reqAux("XY_TYPE");
     std::string sufix = "_X_TYPE";
-    CopySomeParameters(reqData, reqAux, sufix);
+    metview::CopySomeParameters(reqData, reqAux, sufix);
     const char* param = (const char*)reqAux.getParameter(0);
     if (param && strcmp(reqAux(param), "DATE") == 0)
         viewRequest_("X_AXIS_TYPE") = "DATE";
@@ -230,7 +230,7 @@ void CartesianView::UpdateAxisTypeView(MvRequest& reqData)
     reqAux.clean();
     reqAux.setVerb("XY_TYPE");
     sufix = "_Y_TYPE";
-    CopySomeParameters(reqData, reqAux, sufix);
+    metview::CopySomeParameters(reqData, reqAux, sufix);
     param = (const char*)reqAux.getParameter(0);
     if (param && strcmp(reqAux(param), "DATE") == 0)
         viewRequest_("Y_AXIS_TYPE") = "DATE";
