@@ -80,7 +80,7 @@ bool CommonXSectView::callServiceInternal(const MvRequest& dataReq, PmContext& c
     MvRequest appRequest(ApplicationName().c_str());
     if ((const char*)dataReq("_CONTEXT")) {
         MvRequest auxReq(dataReq.getVerb());
-        metview::CopySomeParameters(dataReq, auxReq, "_CONTEXT");
+        metview::CopyAndRemoveParameters(dataReq, auxReq, "_CONTEXT");
         appRequest("DATA") = auxReq;
     }
     else
