@@ -42,8 +42,7 @@
 // .REFERENCES:
 //
 //
-#ifndef Counted_H
-#define Counted_H
+#pragma once
 
 
 class Counted
@@ -77,5 +76,3 @@ private:
     // Members
     int refCount_;
 };
-
-#endif
