@@ -28,12 +28,12 @@ DataBuilder::Execute(PmContext& context)
 
     // Make sure the macro is generated in current dir, even when defaults are used.
     const char* fullName = (const char*)dataReq("_NAME");
-    const char* path     = 0;
+    const char* path     = nullptr;
     if (fullName)
         path = mdirname(fullName);
 
     // Creation of a new PlotPage and associated pages
-    Presentable* superpage     = 0;
+    Presentable* superpage     = nullptr;
     MvRequest defaultSuperPage = ObjectList::CreateDefaultRequest("PLOT_SUPERPAGE", 0, path);
 
     // Create default page and add view to this request
@@ -57,7 +57,7 @@ DataBuilder::Execute(PmContext& context)
     defaultSuperPage("PAGES") = pageRequest;
 
     superpage = new SuperPage(defaultSuperPage);
-    ensure(superpage != 0);
+    ensure(superpage != nullptr);
 
     // Put the new branch in the tree
     Root::Instance().Insert(superpage);
