@@ -32,8 +32,7 @@
 // .ASCENDENT:
 //  PlotModBuilder
 //
-#ifndef DataBuilder_H
-#define DataBuilder_H
+#pragma once
 
 #include "PlotModBuilder.h"
 
@@ -56,4 +55,3 @@ private:
     DataBuilder(const DataBuilder&);
     DataBuilder& operator=(const DataBuilder&);
 };
-#endif
