@@ -393,7 +393,7 @@ void DataObject::GetTitle(MvRequest& rqst, int* order)
             rqst(titlePackageName) += titleText_[i];
 
         // Add title information related to the Grib ('GRIB_TEXT_...')
-        CopySomeParameters(titleRequest_, rqst, "GRIB_TEXT");
+        metview::CopySomeParameters(titleRequest_, rqst, "GRIB_TEXT");
 
         (*order)++;
     }
@@ -414,10 +414,10 @@ void DataObject::GetTitle(MvRequest& rqst, int* order)
             }
 
             // Copy TEXT parameters
-            CopySomeParameters(myRequest_, rqst, "TEXT_", (bool)false);
+            metview::CopySomeParameters(myRequest_, rqst, "TEXT_", (bool)false);
         }
         else if (origin == Cached("BOTH") || origin == Cached("MERGE"))
-            MergeTextParameters(myRequest_, rqst, false);
+            metview::MergeTextParameters(myRequest_, rqst, false);
 
         ///F		( *order ) = rqst("TEXT_LINE_COUNT");
 
@@ -434,7 +434,7 @@ void DataObject::GetTitle(MvRequest& rqst, int* order)
 void DataObject::SetTextOrigin(MvRequest& request)
 {
     // If TEXT_ORIGIN has already been set, return.
-    if (IsParameterSet(request, "TEXT_ORIGIN")) {
+    if ( metview::IsParameterSet(request, "TEXT_ORIGIN")) {
         std::string val = (const char*)request("TEXT_ORIGIN");
         if (val != "NOTSET")
             return;
@@ -445,17 +445,17 @@ void DataObject::SetTextOrigin(MvRequest& request)
     // must not be sent to Magics)
     MvRequest reqAux = request;
     bool expand      = false;
-    if (IsParameterSet(reqAux, "TEXT_AUTOMATIC"))
+    if ( metview::IsParameterSet(reqAux, "TEXT_AUTOMATIC"))
         request.unsetParam("TEXT_AUTOMATIC");
     else
         expand = true;
 
-    if (IsParameterSet(reqAux, "TEXT_USER"))
+    if ( metview::IsParameterSet(reqAux, "TEXT_USER"))
         request.unsetParam("TEXT_USER");
     else
         expand = true;
 
-    if (IsParameterSet(reqAux, "TEXT_MERGE"))
+    if ( metview::IsParameterSet(reqAux, "TEXT_MERGE"))
         request.unsetParam("TEXT_MERGE");
     else
         expand = true;
