@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef DATATOOLMANAGER_H
-#define DATATOOLMANAGER_H
+#pragma once
 
 /************************************
   Application DataToolManager
@@ -55,4 +54,3 @@ private:
     // Constructors
     DataToolService();  // no external access point
 };
-#endif
