@@ -17,12 +17,14 @@
 //
 //
 
-#ifndef DrawingPriority_H
-#define DrawingPriority_H
+#pragma once
 
 #include <set>
+#include <string>
 #include <map>
 
+class Cached;
+class MvRequest;
 class ObjectInfo;
 
 class DrawingPriority
@@ -37,9 +39,9 @@ public:
     // Methods
     int Priority(MvRequest&);
     void SetPriority(MvRequest&);
-    int GetPriority(string);
+    int GetPriority(std::string);
 
-    string DescribeYourself(ObjectInfo&, string);
+    std::string DescribeYourself(ObjectInfo&, std::string);
 
     Cached DrawSegmentName(int, MvRequest&, int);
 
@@ -51,11 +53,9 @@ private:
         return *this;
     }
 
-    int IsValidKey(string);
+    int IsValidKey(std::string);
 
     // Members
-    std::set<string> mySet_;
-    std::map<string, int> myMap_;
+    std::set<std::string> mySet_;
+    std::map<std::string, int> myMap_;
 };
-
-#endif
