@@ -9,6 +9,7 @@
 
 #include "ErrorAction.h"
 #include "PlotMod.h"
+#include "MvLog.h"
 
 // This is the exemplar object for the Error Action class
 static ErrorAction errorActionInstance("Error");
@@ -25,11 +26,11 @@ ErrorAction::Instance()
 void ErrorAction::Execute(PmContext& context)
 {
     // Get error request and message
-    MvRequest req        = context.InRequest().justOneRequest();
-    string error_message = (const char*)req("MESSAGE");
+    MvRequest req             = context.InRequest().justOneRequest();
+    std::string error_message = (const char*)req("MESSAGE");
 
     // Send the error message
-    PlotMod::Instance().MetviewError(error_message.c_str(), "Error");
+    MvLog().popup().err() << error_message;
 
     context.Advance();
 }
