@@ -31,6 +31,7 @@
 #include "MvQPlotView.h"
 #include "MvQZoomStackWidget.h"
 #include "MvQMethods.h"
+#include "MvLog.h"
 
 GeoTool::GeoTool(MvRequest& req, QWidget* parent) :
     uPlotBase(parent)
@@ -44,21 +45,21 @@ GeoTool::GeoTool(MvRequest& req, QWidget* parent) :
     setInitialSize(600, 400);
 
     //uPlot area. Define the whole lot as central widget
-    QWidget* w = new QWidget;
+    auto* w = new QWidget;
     setCentralWidget(w);
-    QVBoxLayout* vlay = new QVBoxLayout(w);
+    auto* vlay = new QVBoxLayout(w);
     vlay->addWidget(plotView_);
 
     //Setup the bottom layout (coordinates + buttons)
-    QHBoxLayout* hlay = new QHBoxLayout();
+    auto* hlay = new QHBoxLayout();
     vlay->addLayout(hlay);
-    QLabel* coordLabel = new QLabel(tr("S/W/N/E:"));
-    coordEdit_         = new QLineEdit();
+    auto* coordLabel = new QLabel(tr("S/W/N/E:"));
+    coordEdit_       = new QLineEdit();
     coordEdit_->setMinimumSize(170, 0);
     coordEdit_->setText(tr(coord.toStdString().c_str()));
-    QPushButton* okPb = new QPushButton(tr("&OK"));
+    auto* okPb = new QPushButton(tr("&OK"));
     okPb->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogOkButton));
-    QPushButton* cancelPb = new QPushButton(tr("&Cancel"));
+    auto* cancelPb = new QPushButton(tr("&Cancel"));
     cancelPb->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
     hlay->addWidget(coordLabel);
     hlay->addWidget(coordEdit_);
@@ -120,7 +121,7 @@ GeoTool::~GeoTool()
 void GeoTool::setupInputSelectionActions()
 {
     //Selection action
-    QAction* actionSelection = new QAction(this);
+    auto* actionSelection = new QAction(this);
     actionSelection->setObjectName(QString::fromUtf8("actionSelection"));
     actionSelection->setCheckable(true);
 
@@ -303,7 +304,7 @@ QString GeoTool::InitializeParams(MvRequest& req)
     // Problem: request MapView comes with MAP and Average with AREA
     // Use input type tag AREA always
     if (const char* cv = req("INPUT_TYPE"))
-        inputType_ = string(cv);
+        inputType_ = std::string(cv);
     else
         return QString("ERROR");
 
@@ -312,7 +313,7 @@ QString GeoTool::InitializeParams(MvRequest& req)
 
     //Get the paramater name
     if (const char* cv = req("INPUT_PARAM"))
-        inputPar_ = string(cv);
+        inputPar_ = std::string(cv);
 
     // Update size
     spRequest_("CUSTOM_WIDTH")  = req("CUSTOM_WIDTH");
@@ -343,7 +344,7 @@ QString GeoTool::InitializeParams(MvRequest& req)
             else if (static_cast<const char*>(req("POSITION")))
                 inputPar_ = "POSITION";
             else {
-                PlotMod::Instance().MetviewError("GeoTool-> Invalid parameter value. Valid values: POINT/POSITION", "Error");
+                MvLog().popup().err() << "GeoTool-> Invalid parameter value. Valid values: POINT/POSITION";
                 return QString("ERROR");
             }
         }
@@ -358,7 +359,7 @@ QString GeoTool::InitializeParams(MvRequest& req)
             if (static_cast<const char*>(req("LINE")))
                 inputPar_ = "LINE";
             else {
-                PlotMod::Instance().MetviewError("GeoTool-> No parameter is specified for line helper", "Error");
+                MvLog().popup().err() << "GeoTool-> No parameter is specified for line helper";
                 return QString("ERROR");
             }
         }
@@ -379,7 +380,7 @@ QString GeoTool::InitializeParams(MvRequest& req)
             else if (static_cast<const char*>(req("area")))
                 inputPar_ = "area";
             else {
-                PlotMod::Instance().MetviewError("GeoTool-> No parameter is specified for area helper", "Error");
+                MvLog().popup().err() << "GeoTool-> No parameter is specified for area helper";
                 return QString("ERROR");
             }
         }
@@ -425,7 +426,7 @@ void GeoTool::UpdateCoordinates(QString& coord)
     QStringList clist = coord.split("/");
     if (inputType_ == "POINT") {
         if (clist.size() != 2) {
-            PlotMod::Instance().MetviewError("GeoTool-> POINT coordinates must have two values", "Error");
+            MvLog().popup().err() << "GeoTool-> POINT coordinates must have two values";
             return;
         }
         geoRequest_(inputPar_.c_str()) = clist.at(0).toDouble();
@@ -433,14 +434,14 @@ void GeoTool::UpdateCoordinates(QString& coord)
     }
     else if (inputType_ == "LINE") {
         if (clist.size() != 4) {
-            PlotMod::Instance().MetviewError("GeoTool-> LINE coordinates must have 4 values", "Error");
+            MvLog().popup().err() << "GeoTool-> LINE coordinates must have 4 values";
             return;
         }
         coordToRequest(coord, geoRequest_, inputPar_.c_str());
     }
     else {
         if (clist.size() != 4) {
-            PlotMod::Instance().MetviewError("GeoTool UpdateCoordinates-> Expected 4 values for list of coordinates", "Error");
+            MvLog().popup().err() << "GeoTool UpdateCoordinates-> Expected 4 values for list of coordinates";
             return;
         }
         coordToRequest(coord, geoRequest_, inputPar_.c_str());
