@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef GEOGRAPHYTOOL_H
-#define GEOGRAPHYTOOL_H
+#pragma once
 
 #include <QLineEdit>
 
@@ -52,7 +51,7 @@ private:
     QString InitializeParams(MvRequest&);
 
     bool setDropTarget(QPoint) override;
-    bool setDropTargetInView(QPoint) override ;
+    bool setDropTargetInView(QPoint) override;
     int currentStep() override { return 0; }
     int stepNum() override { return 0; }
 
@@ -66,13 +65,11 @@ private:
     void readSettings() override;
     void writeSettings() override;
 
-    QLineEdit* coordEdit_;  // geographical coordinates area
-    QString coord_;         // coordinates
-    MvRequest geoRequest_;  // request to be sent out to the caller
-    MvRequest spRequest_;   // superpage request
-    string inputType_;      // AREA, LINE, POINT
-    string inputPar_;
+    QLineEdit* coordEdit_;   // geographical coordinates area
+    QString coord_;          // coordinates
+    MvRequest geoRequest_;   // request to be sent out to the caller
+    MvRequest spRequest_;    // superpage request
+    std::string inputType_;  // AREA, LINE, POINT
+    std::string inputPar_;
     bool isFirstMap_;
 };
-
-#endif
