@@ -23,6 +23,7 @@
 #include "PlotMod.h"
 #include "PlotModTask.h"
 #include "SubPage.h"
+#include "MvLog.h"
 
 class GeoViewFactory : public PlotModViewFactory
 {
@@ -93,6 +94,8 @@ string GeoView::Name()
 // them to ensure that all the VisDefs are always after each DataUnit
 void GeoView::Drop(PmContext& context)
 {
+    MvLog().dbg() << "GeoView::Drop";
+
     // Check if GeoLayers are already registered in the DB
     // There are 2 reasons for not having any GeoLayers in the DB:
     // 1) There are no GeoLayers associated to this View
@@ -110,6 +113,7 @@ void GeoView::Drop(PmContext& context)
         // VisDefs are processed in one single goal. This is because the processing
         // of a single or a group of visdefs is different. It is assumed that
         // visdefs always come after a dataunit (if it exists).
+        MvLog().dbg() << " -> REQ";
         MvRequest vdRequestList;
         if (this->RetrieveVisdefList(dropRequest, vdRequestList)) {
             Owner().InsertVisDef(vdRequestList, dataUnit);
@@ -137,14 +141,16 @@ void GeoView::Drop(PmContext& context)
             Owner().InitMatching();
             DecodeDataUnit(dataUnit);
         }
-
-        // Update view (if applicable)
-        else if (ObjectList::IsView(verb) == true)
-            this->UpdateView(request);
-
-        else if (ObjectList::IsVisDefCoastlines(verb))
+        else if (ObjectList::IsWeatherSymbol(verb)) {
+            PlotMod::Instance().addWeatherSymbol(request);
+            // Update view (if applicable)
+        }
+        else if (ObjectList::IsView(verb) == true) {
+            this->UpdateViewWithReq(request);
+        }
+        else if (ObjectList::IsVisDefCoastlines(verb)) {
             this->UpdateCoastlines(request);
-
+        }
         else if (ObjectList::IsService(verb, "visualise", true)) {
             // Call the service to process the request.
             // After CallService is finished, function PlotModService::endOfTask
@@ -165,8 +171,9 @@ void GeoView::Drop(PmContext& context)
             context.AdvanceTo(NEWPAGE);
             return;
         }
-        else
+        else {
             Owner().InsertCommonIcons(request);
+        }
 
         dropRequest.advance();
     }
@@ -271,7 +278,7 @@ void GeoView::DecodeDataUnit(MvIcon& dataUnit)
         const char* repres = decRequest ( "REPRES" );
         if ( ObjectList::IsImage(repres) )
         {
-            string myName = this->Name ();
+            std::string myName = this->Name ();
             if ( myName != "Satellite" )
             {
                 MvRequest ownerReq = Owner ().Request ();
@@ -324,7 +331,7 @@ void GeoView::DrawBackground()
     MvRequest expRequest   = ObjectList::ExpandRequest(coastRequest, EXPAND_DEFAULTS);
 
     // Split coastline request according to the foreground and background default rules
-    string name = (const char*)coastRequest("_NAME");
+    std::string name = (const char*)coastRequest("_NAME");
     MvIconList iconList;
     {
         //this->CoastGetBackground(iconList);
@@ -340,7 +347,7 @@ void GeoView::DrawBackground()
             newRequest("MAP_GRID")      = "OFF";
 
             // Update icon name
-            string newName      = name + "_LandShade";
+            std::string newName = name + "_LandShade";
             newRequest("_NAME") = newName.c_str();
 
             // Add to the list
@@ -360,7 +367,7 @@ void GeoView::DrawBackground()
             newRequest("MAP_GRID")      = "OFF";
 
             // Update icon name
-            string newName      = name + "_SeaShade";
+            std::string newName = name + "_SeaShade";
             newRequest("_NAME") = newName.c_str();
 
             // Add to the list
@@ -386,7 +393,7 @@ void GeoView::DrawBackground()
 
 /*
    bool draw = false;
-   string ON = "ON";
+   std::string ON = "ON";
 
    // Get DrawingPriority from Page
    //DrawingPriority& tmpDrawingPriority = Owner().GetDrawPriority ();
@@ -397,7 +404,7 @@ void GeoView::DrawBackground()
 expRequest.print();
    // Account for land-sea shading and for the drawing order
    // Check if Coastline Land Shade is to be drawn on the background
-   string onoff = (const char*)expRequest ( "MAP_COASTLINE_LAND_SHADE" );
+   std::string onoff = (const char*)expRequest ( "MAP_COASTLINE_LAND_SHADE" );
    if ( onoff == ON )
    {
       //int drawPrior = tmpDrawingPriority.GetPriority ( "COASTLINE_LAND_SHADE" );
@@ -540,7 +547,7 @@ void GeoView::DrawForeground()
     MvRequest expRequest   = ObjectList::ExpandRequest(coastRequest, EXPAND_DEFAULTS);
 
     // Split coastline request according to the foreground default rules
-    string name = (const char*)coastRequest("_NAME");
+    std::string name = (const char*)coastRequest("_NAME");
     MvIconList iconList;
     {
         //this->CoastGetForeground(iconList);
@@ -557,7 +564,7 @@ void GeoView::DrawForeground()
             newRequest("MAP_LABEL")                = "OFF";
 
             // Update icon name
-            string newName      = name + "_Coastline";
+            std::string newName = name + "_Coastline";
             newRequest("_NAME") = newName.c_str();
 
             // Add to the list
@@ -579,7 +586,7 @@ void GeoView::DrawForeground()
             newRequest("MAP_GRID")      = "OFF";
 
             // Update icon name
-            string newName      = name + "_Boundaries";
+            std::string newName = name + "_Boundaries";
             newRequest("_NAME") = newName.c_str();
 
             // Add to the list
@@ -599,7 +606,7 @@ void GeoView::DrawForeground()
             newRequest("MAP_GRID")      = "OFF";
 
             // Update icon name
-            string newName      = name + "_Cities";
+            std::string newName = name + "_Cities";
             newRequest("_NAME") = newName.c_str();
 
             // Add to the list
@@ -619,7 +626,7 @@ void GeoView::DrawForeground()
             newRequest("MAP_GRID")      = "OFF";
 
             // Update icon name
-            string newName      = name + "_Rivers";
+            std::string newName = name + "_Rivers";
             newRequest("_NAME") = newName.c_str();
 
             // Add to the list
@@ -638,7 +645,7 @@ void GeoView::DrawForeground()
             newRequest("MAP_LABEL")     = "OFF";
 
             // Update icon name
-            string newName      = name + "_Grid";
+            std::string newName = name + "_Grid";
             newRequest("_NAME") = newName.c_str();
 
             // Add to the list
@@ -657,7 +664,7 @@ void GeoView::DrawForeground()
             newRequest("MAP_GRID")      = "OFF";
 
             // Update icon name
-            string newName      = name + "_Label";
+            std::string newName = name + "_Label";
             newRequest("_NAME") = newName.c_str();
 
             // Add to the list
@@ -682,8 +689,8 @@ void GeoView::DrawForeground()
 
     /*
 bool draw   = false;
-   string ON   = "ON";
-   string LAST = "LAST";
+   std::string ON   = "ON";
+   std::string LAST = "LAST";
 
    // Retrieve the graphics Engine
    GraphicsEngine& ge = Owner().GetGraphicsEngine();
@@ -697,7 +704,7 @@ bool draw   = false;
 
    // Account for land-sea shading and for the drawing order
    // Check if Coastline Land Shade is to be drawn on the foreground
-   string onoff = (const char*)expRequest ( "MAP_COASTLINE_LAND_SHADE" );
+   std::string onoff = (const char*)expRequest ( "MAP_COASTLINE_LAND_SHADE" );
    if ( onoff == ON )
    {
       //int drawPrior = tmpDrawingPriority.GetPriority ( "COASTLINE_LAND_SHADE" );
@@ -774,9 +781,9 @@ int drawPrior = 999;
 void GeoView::DescribeYourself(ObjectInfo& description)
 {
     // convert my request to macro
-    string defView = DEFAULTVIEW;
+    std::string defView = DEFAULTVIEW;
     std::transform(defView.begin(), defView.end(), defView.begin(), ::tolower);
-    set<Cached> skipSet;
+    std::set<Cached> skipSet;
     description.ConvertRequestToMacro(viewRequest_, PUT_END, MacroName().c_str(), defView.c_str(), skipSet);
 }
 
@@ -786,7 +793,7 @@ bool GeoView::CallService(const MvRequest& req, PmContext& context)
     appRequest("_CONTEXT") = viewRequest_;
 
     // Find service name
-    string service = ObjectList::FindService(appRequest.getVerb(), "visualise");
+    std::string service = ObjectList::FindService(appRequest.getVerb(), "visualise");
 
     // Call service
     if (service.size()) {
@@ -794,7 +801,7 @@ bool GeoView::CallService(const MvRequest& req, PmContext& context)
         return true;
     }
     else {
-        PlotMod::Instance().MetviewError("GeoView CallService-> Service not found", "Error");
+        MvLog().popup().err() << "GeoView CallService-> Service not found";
         return false;
     }
 }
@@ -816,7 +823,7 @@ bool GeoView::CheckAddGeoLayers(MvRequest& glReq)
     return geoUpdated;
 }
 
-void GeoView::UpdateView(MvRequest& viewRequest)
+void GeoView::UpdateViewWithReq(MvRequest& viewRequest)
 {
     if (strcmp(viewRequest_.getVerb(), viewRequest.getVerb()) == 0)
     //ObjectList::IsGeographicalView( viewRequest.getVerb() ) )
@@ -838,7 +845,7 @@ void GeoView::UpdateView(MvRequest& viewRequest)
     }
     else {
         // Changing GeoView to another view is disabled at the moment.
-        PlotMod::Instance().UserErrorMessage("Changing GeoView to another View is currently disabled");
+        MvLog().popup().err() << "Changing GeoView to another View is currently disabled";
     }
 }
 
@@ -920,7 +927,7 @@ void GeoView::DecodeGeoLayers(const MvRequest& glReq, MvRequest& outReq)
         }
 
         // Build the icon path/filename
-        string fn = MakeUserDefPath(glReq(param));
+        std::string fn = MakeUserDefPath(glReq(param));
 
         // Read the icon contents
         req.read(fn.c_str());
