@@ -9,9 +9,12 @@
 
 #include <MvGeoPoints.h>
 
+#include <iomanip>
+
 #include "GeopointsDecoder.h"
 #include "MatchingInfo.h"
 #include "PlotMod.h"
+#include "MvLog.h"
 
 
 // =====================================================
@@ -45,10 +48,7 @@ GeopointsDecoder::GeopointsDecoder(const MvRequest& dataUnitRequest) :
     metadataRequest_ = dataUnitRequest;
 }
 
-GeopointsDecoder::~GeopointsDecoder()
-{
-    // Empty
-}
+GeopointsDecoder::~GeopointsDecoder() = default;
 
 // Read Next Data
 //
@@ -88,19 +88,18 @@ GeopointsDecoder::CreateMatchingInfo()
         long myTime = gpts.time(0);
         if (myTime < 24 && myTime != 0)  //-- simple check for format HH
         {
-            PlotMod::Instance().MetviewError(
-                "Suspicuous geopoints time; HHMM needed for overlay matching!", "WARN");
+            MvLog().popup().warn() << "Suspicuous geopoints time; HHMM needed for overlay matching!";
         }
 
         //-- overlay matching checks strings, add leading zeros to make format 'HHMM'
-        ostringstream os;
-        os << setfill('0') << setw(4) << myTime;
+        std::ostringstream os;
+        os << std::setfill('0') << std::setw(4) << myTime;
         matchingRequest("TIME") = os.str().c_str();
     }
     else if (myDate != 0)  //-- date 0 is probably format XYV
     {
         //-- not adding DATE/TIME will prevent overlay matching --//
-        PlotMod::Instance().MetviewError("Invalid geopoints date; no overlay matching!", "WARN");
+        MvLog().popup().warn() << "Invalid geopoints date; no overlay matching!";
     }
 
     // Save format info
