@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef ICONCLASS_H
-#define ICONCLASS_H
+#pragma once
 
 #include <string>
 #include <map>
@@ -25,13 +24,10 @@ public:
     IconClass(const std::string&, request*);
     ~IconClass() {}
 
-    static const std::map<std::string, IconClass*>& items() {return items_;}
+    static const std::map<std::string, IconClass*>& items() { return items_; }
     static void load(request*);
     static IconClass* find(const std::string&);
 
 private:
     static std::map<std::string, IconClass*> items_;
 };
-
-
-#endif // ICONCLASS_H
