@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef LAYERCONTROLWIDGET_HPP
-#define LAYERCONTROLWIDGET_HPP
+#pragma once
 
 #include <QWidget>
 
@@ -22,7 +21,7 @@ class LayerControlWidget : public QWidget
     Q_OBJECT
 
 public:
-    LayerControlWidget(MvQLayerWidget *,MvQDataWidget*, QWidget* parent = 0);
+    LayerControlWidget(MvQLayerWidget*, MvQDataWidget*, QWidget* parent = 0);
     ~LayerControlWidget() {}
 
 public slots:
@@ -30,10 +29,12 @@ public slots:
     void showLayerInfo(MgQLayerItem*);
 
 protected:
-    enum ViewIndex {ListViewIndex=0,InfoViewIndex=1};
+    enum ViewIndex
+    {
+        ListViewIndex = 0,
+        InfoViewIndex = 1
+    };
     MvQLayerWidget* layerListW_;
     MvQDataWidget* layerInfoW_;
     QStackedWidget* stackedW_;
 };
-
-#endif // LAYERCONTROLWIDGET_HPP
