@@ -42,8 +42,7 @@
 //  by Myers, "More Effective C+", page 130.
 //
 
-#ifndef MagPlusBatchService_H
-#define MagPlusBatchService_H
+#pragma once
 
 #include "MagPlusService.h"
 
@@ -55,5 +54,3 @@ public:
 
     void CallMagPlus(MvRequest&);
 };
-
-#endif
