@@ -47,9 +47,7 @@ MagicsGraphicsEngine::MagicsGraphicsEngine(Presentable& owner) :
 {
 }
 
-MagicsGraphicsEngine::~MagicsGraphicsEngine()
-{
-}
+MagicsGraphicsEngine::~MagicsGraphicsEngine() = default;
 
 #if 0
 PSCanvas * 
@@ -88,7 +86,7 @@ MagicsGraphicsEngine::MakeCanvas(Device& device,
                                  const PaperSize& size,
                                  int subpageId) const
 {
-    Canvas* xc = new Canvas(device, rect, size, subpageId);
+    auto* xc = new Canvas(device, rect, size, subpageId);
     ensure(xc != 0);
 
     return xc;
@@ -132,7 +130,7 @@ void MagicsGraphicsEngine::DrawDataVisDef(
     // e.g. MCONT to 1D fields, MWIND to 2d fields.
     MvRequest dataUnitReq = dataUnit.Request();
     MvRequest vdRequest;
-    vector<string> vstr;
+    std::vector<std::string> vstr;
     ObjectList::VisDefNDimFlags(nDimFlag, vstr);
 
     // Define Visdefs
@@ -162,16 +160,16 @@ void MagicsGraphicsEngine::DrawDataVisDef(
         MvIconList vdList;
         const char* verb = dataUnitReq.getVerb();
         bool vdDefault   = false;
-        for (unsigned int i = 0; i < vstr.size(); i++) {
+        for (auto& i : vstr) {
             MvIconList laux  = visdefList;
-            const char* caux = vstr[i].c_str();
+            const char* caux = i.c_str();
 
             // No valid visdef found in the list. Create a default visdef.
             if (!ObjectList::CheckValidVisDefList(verb, laux, caux)) {
                 // Get the first default nD-visdef
-                string lvd = (const char*)ObjectList::Find("dataunit", verb, caux);
-                size_t pos = lvd.find('/');
-                if (pos != string::npos)
+                std::string lvd = (const char*)ObjectList::Find("dataunit", verb, caux);
+                size_t pos      = lvd.find('/');
+                if (pos != std::string::npos)
                     lvd = lvd.substr(0, pos);
 
                 // Build a default visdef request
@@ -282,7 +280,7 @@ void MagicsGraphicsEngine::DrawGeoLayersBack ( MvRequest& viewRequest )
       this->Draw ( landReq );
 
 #if 0
-   string onoff = (const char*)expRequest ( "MAP_COASTLINE_LAND_SHADE" );
+   std::string onoff = (const char*)expRequest ( "MAP_COASTLINE_LAND_SHADE" );
    if ( onoff == ON )
 	{
       int drawPrior = tmpDrawingPriority.GetPriority ( "COASTLINE_LAND_SHADE" );
