@@ -940,16 +940,17 @@ ThermoGridTranslator::Execute(const MvRequest& req)
 
 MvRequest InputBoxplotTranslator::Execute(const MvRequest& inReq)
 {
-    MvRequest magReq("BOXPLOT_DECODER");
+    MvRequest magReq("INPUT_BOXPLOT");
 
     std::cout << "BOXPLOT TRANSLATOR" << std::endl;
     static std::map<std::string, std::string> params= {
         {"INPUT_X_VALUES", "BOXPLOT_POSITIONS"},
+        {"INPUT_DATE_X_VALUES", "BOXPLOT_DATE_POSITIONS"},
         {"INPUT_MINIMUM_VALUES","BOXPLOT_MINIMUM_VALUES"},
         {"INPUT_MAXIMUM_VALUES","BOXPLOT_MAXIMUM_VALUES"},
         {"INPUT_MEDIAN_VALUES","BOXPLOT_MEDIAN_VALUES"},
-        {"INPUT_BOX_UPPER_VALUES","BOXPLOT_UPPER_VALUES"},
-        {"INPUT_BOX_UPPER_VALUES","BOXPLOT_LOWER_VALUES"}
+        {"INPUT_BOX_UPPER_VALUES","BOXPLOT_BOX_UPPER_VALUES"},
+        {"INPUT_BOX_LOWER_VALUES","BOXPLOT_BOX_LOWER_VALUES"}
     };
 
     for (auto it: params) {
