@@ -501,6 +501,20 @@ public:
     MvRequest Execute(const MvRequest&, const MvRequest&, const MvRequest&) override { return MvRequest("EMPTY"); }
 };
 
+class InputBoxplotTranslator : public MagicsTranslator
+{
+public:
+    using MagicsTranslator::MagicsTranslator;
+    ~InputBoxplotTranslator() = default;
+
+    MvRequest Execute(const MvRequest&) override;
+    MvRequest Execute(const MvRequest& req, const MvRequest&) override {return Execute(req);}
+    MvRequest Execute(const MvRequest& req, const MvRequest&, const MvRequest&) override
+    {
+        return Execute(req);
+    }
+};
+
 
 class TableTranslator : public MagicsTranslator
 {
