@@ -76,7 +76,7 @@ GribDecoder::CreateMatchingInfo()
     MvRequest matchingRequest("MATCHING_INFO");
 
     matchingRequest("PARAM") = metadataRequest_("PARAM");
-    SetIfValue(matchingRequest, "LEVEL", metadataRequest_("LEVELIST"));
+    metview::SetIfValue(matchingRequest, "LEVEL", metadataRequest_("LEVELIST"));
 
     // XXX this might not be necessary since we're not interested in
     // IDENT for identifying satellite images anymore.
