@@ -991,7 +991,7 @@ void MvIconDataBase::InsertIcon(const int iconRelType, const int iconRelId, MvIc
                     // The icon exists in list. Update it taking into consideration the
                     // drawing order info.
                     MvRequest req;
-                    CopyParametersAndStackingOrder(tmpIcon.Request(), icon.Request(), index, req);
+                    metview::CopyParametersAndStackingOrder(tmpIcon.Request(), icon.Request(), index, req);
                     (*listCursor).SaveRequest(req);
 
                     return;
@@ -1074,7 +1074,7 @@ void MvIconDataBase::InsertIconText(const int iconRelId, MvIcon& icon, int index
                     // The icon exists in list. Update it taking into consideration the
                     // drawing order info.
                     MvRequest req;
-                    CopyParametersAndStackingOrder(tmpIcon.Request(), iconRequest, index, req);
+                    metview::CopyParametersAndStackingOrder(tmpIcon.Request(), iconRequest, index, req);
                     (*listCursor).SaveRequest(req);
 
                     return;
