@@ -24,7 +24,7 @@ MvQAreaSelection::MvQAreaSelection(MgQPlotScene* scene, MvQPlotView* view, QGrap
 
     brush_         = QBrush(QColor(164, 219, 255, 180));
     currentAction_ = NoAction;
-    zoomLayout_    = 0;
+    zoomLayout_    = nullptr;
     rect_          = QRectF();
 
     selectionPen_ = pen_;
@@ -41,9 +41,7 @@ MvQAreaSelection::MvQAreaSelection(MgQPlotScene* scene, MvQPlotView* view, QGrap
     handleHover_ = -1;
 }
 
-MvQAreaSelection::~MvQAreaSelection()
-{
-}
+MvQAreaSelection::~MvQAreaSelection() = default;
 
 QRectF MvQAreaSelection::boundingRect() const
 {
@@ -106,7 +104,7 @@ void MvQAreaSelection::mousePressEventFromView(QMouseEvent* event)
         //Get scene position
         zoomRectOrigin_ = mapFromScene(plotView_->mapToScene(event->pos()));
 
-        if ((zoomLayout_ = plotScene_->findProjectorItem(mapToScene(zoomRectOrigin_))) == 0) {
+        if ((zoomLayout_ = plotScene_->findProjectorItem(mapToScene(zoomRectOrigin_))) == nullptr) {
             currentAction_ = NoAction;
         }
         else {
@@ -124,7 +122,7 @@ void MvQAreaSelection::mousePressEventFromView(QMouseEvent* event)
 
         dragPos_ = mapFromScene(plotView_->mapToScene(event->pos()));
 
-        if ((zoomLayout_ = plotScene_->findProjectorItem(mapToScene(cRect.center()))) != 0 &&
+        if ((zoomLayout_ = plotScene_->findProjectorItem(mapToScene(cRect.center()))) != nullptr &&
             cRect.adjusted(-dh, -dh, dh, dh).contains(dragPos_)) {
             QPointF xp = dragPos_ - cRect.topLeft();
 
@@ -330,7 +328,7 @@ void MvQAreaSelection::mouseReleaseEventFromView(QMouseEvent* event)
         getAreaGeoCorners(gp1, gp2);
 
         currentAction_ = NoAction;
-        zoomLayout_    = 0;
+        zoomLayout_    = nullptr;
         coordPoint_.clear();
         coordPoint_ << gp1 << gp2;
 
@@ -358,7 +356,7 @@ void MvQAreaSelection::mouseReleaseEventFromView(QMouseEvent* event)
         getAreaGeoCorners(gp1, gp2);
 
         currentAction_ = NoAction;
-        zoomLayout_    = 0;
+        zoomLayout_    = nullptr;
         coordPoint_.clear();
         coordPoint_ << gp1 << gp2;
         dragPos_ = QPointF();
@@ -386,7 +384,7 @@ void MvQAreaSelection::mouseReleaseEventFromView(QMouseEvent* event)
         getAreaGeoCorners(gp1, gp2);
 
         currentAction_ = NoAction;
-        zoomLayout_    = 0;
+        zoomLayout_    = nullptr;
         coordPoint_.clear();
         coordPoint_ << gp1 << gp2;
         dragPos_ = QPointF();
@@ -408,14 +406,14 @@ void MvQAreaSelection::setArea(double blLat, double blLon, double trLat, double
     QPointF sp1, sp2;
 
     if (rect_.isEmpty()) {
-        if ((zoomLayout_ = plotScene_->firstProjectorItem()) == 0) {
+        if ((zoomLayout_ = plotScene_->firstProjectorItem()) == nullptr) {
             return;
         }
     }
     else {
         sp1.setX(rect_.x());
         sp1.setY(rect_.y());
-        if ((zoomLayout_ = plotScene_->findProjectorItem(mapToScene(sp1))) == 0) {
+        if ((zoomLayout_ = plotScene_->findProjectorItem(mapToScene(sp1))) == nullptr) {
             return;
         }
     }
@@ -482,7 +480,7 @@ void MvQAreaSelection::reset()
     //We need to find the projectorItem!!
     QPointF sp0, sp1;
 
-    if ((zoomLayout_ = plotScene_->firstProjectorItem()) == 0) {
+    if ((zoomLayout_ = plotScene_->firstProjectorItem()) == nullptr) {
         clearArea();
         return;
     }
@@ -515,7 +513,7 @@ void MvQAreaSelection::reset()
 
 void MvQAreaSelection::selectAllArea()
 {
-    if ((zoomLayout_ = plotScene_->firstProjectorItem()) != 0) {
+    if ((zoomLayout_ = plotScene_->firstProjectorItem()) != nullptr) {
         prepareGeometryChange();
         rect_ = mapRectFromScene(zoomLayout_->mapRectToScene(zoomLayout_->boundingRect()));
 
@@ -525,7 +523,7 @@ void MvQAreaSelection::selectAllArea()
         coordPoint_ << gp1 << gp2;
 
         currentAction_ = NoAction;
-        zoomLayout_    = 0;
+        zoomLayout_    = nullptr;
         dragPos_       = QPointF();
 
         showHandles_ = false;
@@ -670,7 +668,6 @@ QRectF MvQAreaSelection::updateControlRect(CurrentAction action, QPointF& dp)
         !zoomLayout_->containsSceneCoords(p2)) {
         //qDebug() << "false";
         return QRectF();
-        ;
     }
 
     return r;
