@@ -30,7 +30,7 @@
 MvQCursorData::MvQCursorData(MgQPlotScene* scene, MvQPlotView* view, QGraphicsItem* parent) :
     MvQPlotItem(scene, view, parent)
 {
-    QGraphicsDropShadowEffect* effect = new QGraphicsDropShadowEffect;
+    auto* effect = new QGraphicsDropShadowEffect;
     effect->setXOffset(3.);
     effect->setYOffset(3.);
     setGraphicsEffect(effect);
@@ -104,7 +104,7 @@ void MvQCursorData::changePositionMode(QPointF& cursor)
     }
 }
 
-void MvQCursorData::changeProbeMode(QPointF& cursor)
+void MvQCursorData::changeProbeMode(QPointF& /*cursor*/)
 {
     if (probeMode_ == AnchoredProbe) {
         probeMode_ = FollowCursorProbe;
@@ -147,7 +147,7 @@ void MvQCursorData::setText(QPointF coord, QList<ValuesCollector> layerData, QSt
     bool hasValue             = false;
     bool hasScaledValue       = false;
     bool hasVector            = false;
-    for(auto d: layerData) {
+    for (auto d : layerData) {
         if (d.collected()) {
             collectedLayerExists = true;
             if (d.hasValue())
@@ -204,7 +204,7 @@ void MvQCursorData::setText(QPointF coord, QList<ValuesCollector> layerData, QSt
 
 
     //Loop for each layer
-    for(auto d: layerData) {
+    for (auto d : layerData) {
         if (d.collected() == false)
             continue;
 
@@ -443,7 +443,6 @@ void MvQCursorData::setData(QPointF pos)
 
         QList<QPointF> posL;
         posL << coord;
-        ;
 
         QList<ValuesCollector> layerData;
 
