@@ -7,8 +7,9 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQCursorData_H
-#define MvQCursorData_H
+#pragma once
+
+#include <vector>
 
 #include <QBrush>
 #include <QGraphicsItem>
@@ -23,8 +24,6 @@ class QTextDocument;
 class MgQLayoutItem;
 class MgQSceneItem;
 
-using namespace std;
-
 class MvQCursorData : public MvQPlotItem, public ValuesCollectorVisitor
 {
     Q_OBJECT
@@ -97,7 +96,5 @@ private:
     QPointF magnifierScenePos_;
     float magnifierZoomFactor_{1.};
     bool zoomWasPerformedAfterMouseRelease_{true};
-    vector<float> currentValues_;
+    std::vector<float> currentValues_;
 };
-
-#endif
