@@ -7,14 +7,13 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQEcChartsDialog_H
-#define MvQEcChartsDialog_H
+#pragma once
+
+#include <string>
 
 #include <QDialog>
 #include <QLineEdit>
 
-using namespace std;
-
 class MvQEcChartsDialog : public QDialog
 {
     Q_OBJECT
@@ -24,12 +23,12 @@ public:
     ~MvQEcChartsDialog();
 
     // Get info from the user interface
-    string getLayerName()
+    std::string getLayerName()
     {
         return leLayerNameSelection_->text().toStdString();
     }
 
-    string getOutputFileName()
+    std::string getOutputFileName()
     {
         return leOutputFileNameSelection_->text().toStdString();
     }
@@ -50,8 +49,6 @@ private:
     QLineEdit* leLayerNameSelection_;
     QLineEdit* leOutputFileNameSelection_;
 
-    string layerName_;
-    string outputFileName_;
+    std::string layerName_;
+    std::string outputFileName_;
 };
-
-#endif
