@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQFEATURECONTEXTMENU_H
-#define MVQFEATURECONTEXTMENU_H
+#pragma once
 
 #include <vector>
 
@@ -25,10 +24,14 @@ class MvQFeatureMenuItem
 {
 public:
     MvQFeatureMenuItem(bool node, QString name, QString label);
+    MvQFeatureMenuItem(const MvQFeatureMenuItem&) = delete;
+    MvQFeatureMenuItem& operator=(const MvQFeatureMenuItem&) = delete;
+    ~MvQFeatureMenuItem()                                    = default;
 
     static void add(const MvRequest& r);
     static void setupShortcut(QObject* receiver, QWidget* w, const std::string& view);
     static QString execute(const MvQFeatureCommandTarget& sel, QList<QAction*> extraActions, QPoint globalPos);
+    static void init();
 
 protected:
     QShortcut* createShortcut(QWidget* parent, const std::string& view);
@@ -45,6 +48,3 @@ protected:
     static std::vector<MvQFeatureMenuItem*> items_;
     static bool shortcutInited_;
 };
-
-
-#endif // MVQFEATURECONTEXTMENU_H
