@@ -1,4 +1,4 @@
-﻿/***************************** LICENSE START ***********************************
+/***************************** LICENSE START ***********************************
 
  Copyright 2012 ECMWF and INPE. This software is distributed under the terms
  of the Apache License version 2.0. In applying this license, ECMWF does not
@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQFEATURECURVEITEM_H
-#define MVQFEATURECURVEITEM_H
+#pragma once
 
 #include <QGraphicsItem>
 #include <QIcon>
@@ -20,15 +19,13 @@
 #include "MvRequest.h"
 #include "Spline.h"
 
-
-static const double MIN_SAMPLE_DS = 3;  // maximum spline segment lenght
-
+class QJsonObject;
 class MvQFeatureCurveBaseItem;
 
 class MvQFeatureLineEdgeShape
 {
 public:
-    MvQFeatureLineEdgeShape();
+    MvQFeatureLineEdgeShape() = default;
     void paint(QPainter* painter, const QPen& pen);
     bool update(const std::string& type, float angle, float len);
     void build(const QPointF& p1, const QPointF& p2);
@@ -47,7 +44,7 @@ private:
 
     // Intersection point of two lines: line joining the arrow's ends and
     // the orthogonal line
-    QPointF crossPoint_{QPointF(0.,0.)};
+    QPointF crossPoint_{QPointF(0., 0.)};
 };
 
 //-----------------------------------------------------------
@@ -59,6 +56,7 @@ class MvQFeatureCurvePointItem : public MvQFeatureItem
     friend class MvQFeatureGeoPolylineItem;
     friend class MvQFeatureGeoQuadItem;
     friend class MvQFeatureMoveNodeCommand;
+
 public:
     MvQFeatureCurvePointItem(MvQFeatureCurveBaseItem* owner);
 
@@ -68,9 +66,9 @@ public:
     void enterCreateMode();
     void enterInsertMode();
     bool containsInHalo(QPointF pp);
-    bool isPoint() const override {return true;}
+    bool isPoint() const override { return true; }
     void resetHover();
-    void projectionChanged(MgQLayoutItem*) override {}
+    void projectionChanged(MgQLayoutItem*, bool) override {}
     QString describe() const override;
 
 private:
@@ -81,7 +79,7 @@ private:
     void hoverEnterEvent(QGraphicsSceneHoverEvent*) override;
     void hoverLeaveEvent(QGraphicsSceneHoverEvent*) override;
     QVariant itemChange(GraphicsItemChange change, const QVariant& value) override;
-    void reproject() override;
+    void reproject(bool init) override;
 
     MvQFeatureCurveBaseItem* curve_;
     QBrush brush_{Qt::white};
@@ -93,37 +91,40 @@ private:
 };
 
 //-----------------------------------------------------------------
-// The baseclass for polyline/curve items
+// The base class for polyline/curve items
 // (= collection of points with line/curve between them)
 //-----------------------------------------------------------------
 class MvQFeatureCurveBaseItem : public MvQFeatureItem
-{   
+{
     friend class MvQFeatureCurvePointItem;
+
 public:
-    MvQFeatureCurveBaseItem(MvQFeatureType*, MvQPlotView*, bool closed, QGraphicsItem* parent = nullptr);
+    void init(const QJsonObject& d) override;
+    //    void toJson(QJsonObject&) override;
 
     void paint(QPainter*, const QStyleOptionGraphicsItem*, QWidget*) override;
     void resize(QRectF rect) override;
     void resizeTo(const MvQFeatureGeometry& geom) override;
-    void reproject() override;
+    void reproject(bool init) override;
     void moveBy(QPointF) override;
     void moveTo(const MvQFeatureGeometry& g) override;
     void createNext();
     void createStop();
-    bool hasPoints() const override {return true;}
+    bool hasPoints() const override { return true; }
     int nodeIndex(const MvQFeatureCurvePointItem* p) const;
     void adjustHover(MvQFeatureCurvePointItem* p);
     bool hasHoveredPoints() const;
-    QPainterPath shape() const override {return bShape_;}
-    QStringList disabledCommands(int nodeIdx=-1) const override;
+    QPainterPath shape() const override { return bShape_; }
+    QStringList disabledCommands(int nodeIdx = -1) const override;
     MvQFeatureGeometry getGeometry() const override;
     QString describe() const override;
+    QList<QPointF> geoCoords() const override;
 
-    bool canBeCreatedOutOfView() const override { return false;}
-    bool canBePastedOutOfView() const override { return true;}
+    bool canBeCreatedOutOfView() const override { return false; }
+    bool canBePastedOutOfView() const override { return false; }
 
 protected:
-    MvQFeatureCurveBaseItem(const MvQFeatureCurveBaseItem&);
+    MvQFeatureCurveBaseItem(WsType*, bool closed);
     virtual void createStart();
     QRectF pointBoundingBox() const;
     virtual void updateRect();
@@ -138,26 +139,27 @@ protected:
     void startPointEdit() override;
     void leavePointEdit() override;
     bool hasEditedPoint() override;
-    virtual void buildCurve() =0;
+    virtual void buildCurve() = 0;
     QRectF curveBoundingBox();
     void parallelCurves(const std::vector<double>& px, const std::vector<double>& py, QVector<QPointF>& pLeft, QVector<QPointF>& pRight, float distLeft, float distRight) const;
     void buildShapeCore(const std::vector<double>& px, const std::vector<double>& py, float distLeft, float distRight);
     virtual void buildShape();
     void generateCurvePath();
     virtual QPointF extrapolatePoint(bool before) const = 0;
-    virtual QPointF midPoint(int idx1, int idx2) const = 0;
+    virtual QPointF midPoint(int idx1, int idx2) const  = 0;
     virtual void adjustPointsInResize(QList<QPointF> delta);
     virtual void adjustSelectorIfNeeded() const {}
     bool getRequestParameters() override;
-    double halo() const override {return 8;}
+    double halo() const override { return 8; }
     bool isFilled() const;
-    virtual void prepareForPointRemove(int idx) {}
+    virtual void prepareForPointRemove(int /*idx*/) {}
     double realZValue() const override;
     void setRealZValue(double z) override;
     void initAtGeoCoord(QPointF) override;
     void initAtScenePos(const QPointF&) override;
     void buildArrow();
 
+    // the MvQFeatureCurvePointItem pointers must not be used ouside this class!!!
     QVector<MvQFeatureCurvePointItem*> points_;
     bool closed_{false};
     int maxPoints_{-1};
@@ -189,12 +191,11 @@ protected:
 class MvQFeaturePolylineItem : public MvQFeatureCurveBaseItem
 {
 public:
-    MvQFeaturePolylineItem(MvQFeatureType* feature, MvQPlotView* view, bool closed);
     double halo() const override;
     QSizeF minSize() const override;
 
 protected:
-    MvQFeaturePolylineItem(const MvQFeaturePolylineItem&);
+    using MvQFeatureCurveBaseItem::MvQFeatureCurveBaseItem;
     void buildCurve() override;
     QPointF extrapolatePoint(bool before) const override;
     QPointF midPoint(int idx1, int idx2) const override;
@@ -206,23 +207,21 @@ protected:
 //----------------------------------------------------------------------
 class MvQFeaturePolylineLineItem : public MvQFeaturePolylineItem
 {
-public:
-    MvQFeaturePolylineLineItem(MvQFeatureType* feature, MvQPlotView* view);
-    MvQFeatureItem* clone() const override;
+    friend class MvQFeatureMaker<MvQFeaturePolylineLineItem>;
 
 protected:
-    MvQFeaturePolylineLineItem(const MvQFeaturePolylineLineItem&);
+    MvQFeaturePolylineLineItem(WsType* feature);
 };
 
 class MvQFeatureLineItem : public MvQFeaturePolylineLineItem
 {
+    friend class MvQFeatureMaker<MvQFeatureLineItem>;
+
 public:
-    MvQFeatureLineItem(MvQFeatureType* feature, MvQPlotView* view);
-    MvQFeatureItem* clone() const override;
-    bool isLine() const override {return true;}
+    bool isLine() const override { return true; }
 
 protected:
-    MvQFeatureLineItem(const MvQFeatureLineItem&);
+    MvQFeatureLineItem(WsType* feature);
 };
 
 //----------------------------------------------------------------------
@@ -230,11 +229,10 @@ protected:
 //----------------------------------------------------------------------
 class MvQFeatureClosedPolylineItem : public MvQFeaturePolylineItem
 {
-public:
-    MvQFeatureClosedPolylineItem(MvQFeatureType* feature, MvQPlotView* view);
-    MvQFeatureItem* clone() const override;
+    friend class MvQFeatureMaker<MvQFeatureClosedPolylineItem>;
+
 protected:
-    MvQFeatureClosedPolylineItem(const MvQFeatureClosedPolylineItem&);
+    MvQFeatureClosedPolylineItem(WsType* feature);
 };
 
 //----------------------------------------------------------------------
@@ -243,31 +241,28 @@ protected:
 class MvQFeatureGeoPolylineItem : public MvQFeaturePolylineItem
 {
 public:
-    MvQFeatureGeoPolylineItem(MvQFeatureType* feature, MvQPlotView* view, bool closed);
-    void reproject() override;
+    void init(const QJsonObject& d) override;
+    void toJson(QJsonObject&) override;
+    void reproject(bool init) override;
     void moveBy(QPointF) override;
     void moveTo(const MvQFeatureGeometry& g) override;
-    bool canBeCreatedOutOfView() const override { return false;}
-    bool canBePastedOutOfView() const override { return false;}
-    //double halo() const override;
-    //QSizeF minSize() const override;
 
 protected:
-    MvQFeatureGeoPolylineItem(const MvQFeatureGeoPolylineItem&);
+    using MvQFeaturePolylineItem::MvQFeaturePolylineItem;
     void pointMoved(MvQFeatureCurvePointItem* p) override;
     void adjustPointsInResize(QList<QPointF> delta) override;
-    virtual void adjustGeoShapeToMove(QPointF delta, QList<QPointF> &gc);
-    virtual void adjustGeoShapeToDelta(QList<QPointF> delta, QList<QPointF> &gc);
-    virtual bool adjustGeoShape(MvQFeatureCurvePointItem*, QList<QPointF> &gc);
+    virtual void adjustGeoShapeToMove(QPointF delta, QList<QPointF>& gc);
+    virtual void adjustGeoShapeToDelta(QList<QPointF> delta, QList<QPointF>& gc);
+    virtual bool adjustGeoShape(MvQFeatureCurvePointItem*, QList<QPointF>& gc);
     void buildCurve() override;
     void prepareForPointRemove(int idx) override;
     void checkDateLineCrossing(QPointF& c1, QPointF& c2, int idx);
-    void checkGeoRange(QList<QPointF> &gc);
+    void checkGeoRange(QList<QPointF>& gc);
     void initAtGeoCoord(QPointF) override;
 
-//    QPointF extrapolatePoint(bool before) const override;
-//    QPointF midPoint(int idx1, int idx2) const override;
-//    QPointF computeBRectMargin(const QRectF& itemRect) const;
+    //    QPointF extrapolatePoint(bool before) const override;
+    //    QPointF midPoint(int idx1, int idx2) const override;
+    //    QPointF computeBRectMargin(const QRectF& itemRect) const;
 
     double latlonIncr_{0.5};
     std::vector<double> segmentDx_;
@@ -276,45 +271,40 @@ protected:
 
 class MvQFeatureGeoPolylineLineItem : public MvQFeatureGeoPolylineItem
 {
-public:
-    MvQFeatureGeoPolylineLineItem(MvQFeatureType* feature, MvQPlotView* view);
-    MvQFeatureItem* clone() const override;
+    friend class MvQFeatureMaker<MvQFeatureGeoPolylineLineItem>;
 
 protected:
-    MvQFeatureGeoPolylineLineItem(const MvQFeatureGeoPolylineLineItem&);
+    MvQFeatureGeoPolylineLineItem(WsType* feature);
 };
 
 class MvQFeatureClosedGeoPolylineItem : public MvQFeatureGeoPolylineItem
 {
-public:
-    MvQFeatureClosedGeoPolylineItem(MvQFeatureType* feature, MvQPlotView* view);
-    MvQFeatureItem* clone() const override;
+    friend class MvQFeatureMaker<MvQFeatureClosedGeoPolylineItem>;
+
 protected:
-    MvQFeatureClosedGeoPolylineItem(const MvQFeatureClosedGeoPolylineItem&);
+    MvQFeatureClosedGeoPolylineItem(WsType* feature);
 };
 
 class MvQFeatureGeoLineItem : public MvQFeatureGeoPolylineLineItem
 {
+    friend class MvQFeatureMaker<MvQFeatureGeoLineItem>;
+
 public:
-    MvQFeatureGeoLineItem(MvQFeatureType* feature, MvQPlotView* view);
-    MvQFeatureItem* clone() const override;
-    bool isLine() const override {return true;}
+    bool isLine() const override { return true; }
 
 protected:
-    MvQFeatureGeoLineItem(const MvQFeatureGeoLineItem&);
+    MvQFeatureGeoLineItem(WsType* feature);
 };
 
 class MvQFeatureGeoQuadItem : public MvQFeatureGeoPolylineItem
 {
-public:
-    MvQFeatureGeoQuadItem(MvQFeatureType* feature, MvQPlotView* view);
-    MvQFeatureItem* clone() const override;
+    friend class MvQFeatureMaker<MvQFeatureGeoQuadItem>;
 
 protected:
-    MvQFeatureGeoQuadItem(const MvQFeatureGeoQuadItem&);
+    MvQFeatureGeoQuadItem(WsType* feature);
     void createStart() override;
-    void adjustGeoShapeToDelta(QList<QPointF> delta, QList<QPointF> &gc) override;
-    bool adjustGeoShape(MvQFeatureCurvePointItem*, QList<QPointF> &gc) override;
+    void adjustGeoShapeToDelta(QList<QPointF> delta, QList<QPointF>& gc) override;
+    bool adjustGeoShape(MvQFeatureCurvePointItem*, QList<QPointF>& gc) override;
     void adjustSelectorIfNeeded() const override;
 };
 
@@ -325,14 +315,12 @@ protected:
 class MvQFeatureCurveItem : public MvQFeatureCurveBaseItem
 {
 public:
-    MvQFeatureCurveItem(MvQFeatureType* feature, MvQPlotView* view, bool closed) :
-        MvQFeatureCurveBaseItem(feature, view, closed) {}
-
     double halo() const override;
     QSizeF minSize() const override;
 
 protected:
-    MvQFeatureCurveItem(const MvQFeatureCurveItem&);
+    MvQFeatureCurveItem(WsType* feature, bool closed);
+    static constexpr double MIN_SAMPLE_DS = 3;  // maximum spline segment lenght
     void buildCurve() override;
     QPointF extrapolatePoint(bool before) const override;
     QPointF midPoint(int idx1, int idx2) const override;
@@ -340,7 +328,7 @@ protected:
     SplineParam spline_;
     int splineNum_{100};
     double sampleDs_{MIN_SAMPLE_DS};
-    float ds_{0.};      // line segment size
+    float ds_{0.};  // line segment size
 };
 
 //----------------------------------------------------------------------
@@ -348,12 +336,10 @@ protected:
 //----------------------------------------------------------------------
 class MvQFeatureCurveLineItem : public MvQFeatureCurveItem
 {
-public:
-    MvQFeatureCurveLineItem(MvQFeatureType* feature, MvQPlotView* view);
-    MvQFeatureItem* clone() const override;
+    friend class MvQFeatureMaker<MvQFeatureCurveLineItem>;
 
 protected:
-    MvQFeatureCurveLineItem(const MvQFeatureCurveLineItem&);
+    MvQFeatureCurveLineItem(WsType* feature);
 };
 
 //----------------------------------------------------------------------
@@ -361,11 +347,8 @@ protected:
 //----------------------------------------------------------------------
 class MvQFeatureClosedCurveItem : public MvQFeatureCurveItem
 {
-public:
-    MvQFeatureClosedCurveItem(MvQFeatureType* feature, MvQPlotView* view);
-    MvQFeatureItem* clone() const override;
-protected:
-    MvQFeatureClosedCurveItem(const MvQFeatureClosedCurveItem&);
-};
+    friend class MvQFeatureMaker<MvQFeatureClosedCurveItem>;
 
-#endif // MVQFEATURECURVEITEM_H
+protected:
+    MvQFeatureClosedCurveItem(WsType* feature);
+};
