@@ -7,42 +7,43 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MVQFEATUREFACTORY_H
-#define MVQFEATUREFACTORY_H
+#pragma once
 
 #include <string>
 
-class MvQFeatureType;
-class MvQFeatureItem;
+#include "MvQFeatureFwd.h"
+
+class WsType;
 class MvQPlotView;
 class QGraphicsItem;
+class QJsonObject;
 
 class MvQFeatureFactory
 {
 public:
     MvQFeatureFactory(const std::string&);
-    virtual ~MvQFeatureFactory() {}
+    MvQFeatureFactory(const MvQFeatureFactory&) = delete;
+    MvQFeatureFactory& operator=(const MvQFeatureFactory&) = delete;
+    virtual ~MvQFeatureFactory()                           = default;
 
-    virtual MvQFeatureItem* make(MvQFeatureType*, MvQPlotView* v) = 0;
-    static MvQFeatureItem* create(MvQFeatureType*, MvQPlotView*);
+    static MvQFeatureItemPtr create(WsType*);
+    static MvQFeatureItemPtr create(const QJsonObject& d);
+    static MvQFeatureItemPtr clone(MvQFeatureItemPtr);
 
 private:
-    // No copy allowed
-    MvQFeatureFactory(const MvQFeatureFactory&);
-    MvQFeatureFactory& operator=(const MvQFeatureFactory&);
+    virtual MvQFeatureItemPtr make(WsType*) = 0;
+    static MvQFeatureItemPtr createInner(WsType*);
 };
 
 template <class T>
 class MvQFeatureMaker : public MvQFeatureFactory
 {
 public:
-    MvQFeatureMaker(const std::string& name) :
-        MvQFeatureFactory(name) {}
+    using MvQFeatureFactory::MvQFeatureFactory;
+
 private:
-    MvQFeatureItem* make(MvQFeatureType* f, MvQPlotView* v)
+    MvQFeatureItemPtr make(WsType* f) override
     {
-        return new T(f, v);
+        return MvQFeatureItemPtr(new T(f));
     }
 };
-
-#endif // MVQFEATUREFACTORY_H
