@@ -1040,7 +1040,7 @@ ColourSelector::ColourSelector(QString idKey, QWidget* parent) :
         items << MvQColourItem(QColor(i, i, i), "grey");
     }
 
-    auto grid = new MvQCompactColourGrid(128, items, true, this);
+    auto grid = new MvQCompactColourGrid(128, items, MvQCompactColourGrid::SingleRowMode, this);
     vb->addWidget(grid);
 
     connect(grid, SIGNAL(selected(QColor)),
@@ -1060,7 +1060,7 @@ ColourSelector::ColourSelector(QString idKey, QWidget* parent) :
     items << MvQColourItem(QColor(147, 112, 219), "violet", {-60, -44, -29, -10, 10, 50});
     items << MvQColourItem(QColor(255, 1, 255), "magenta", {-85, -74, -45, 5, 20, 50});
 
-    grid = new MvQCompactColourGrid(128, items, false, this);
+    grid = new MvQCompactColourGrid(128, items, MvQCompactColourGrid::ColumnMode, this);
     vb->addWidget(grid);
 
     connect(grid, SIGNAL(selected(QColor)),
@@ -1084,7 +1084,7 @@ ColourSelector::ColourSelector(QString idKey, QWidget* parent) :
     items << MvQColourItem(QColor(138, 43, 226), "violet");
     items << MvQColourItem(QColor(255, 0, 255), "magenta");
 
-    grid = new MvQCompactColourGrid(128, items, true, this);
+    grid = new MvQCompactColourGrid(128, items, MvQCompactColourGrid::SingleRowMode, this);
     vb->addWidget(grid);
 
     connect(grid, SIGNAL(selected(QColor)),
@@ -1097,7 +1097,7 @@ ColourSelector::ColourSelector(QString idKey, QWidget* parent) :
     vb->addWidget(label);
 
     items.clear();
-    recentGrid_ = new MvQCompactColourGrid(128, items, true, this);
+    recentGrid_ = new MvQCompactColourGrid(128, items, MvQCompactColourGrid::SingleRowMode, this);
     vb->addWidget(recentGrid_);
 
     connect(recentGrid_, SIGNAL(selected(QColor)),
