@@ -26,7 +26,6 @@
 #include "MvQPlotView.h"
 #include "MvQFeatureCommand.h"
 #include "MvQFeatureItem.h"
-#include "MvQFeatureType.h"
 #include "MvQFeatureCommandTarget.h"
 #include "MvQMethods.h"
 
@@ -43,10 +42,10 @@ class MvQFeatureSelectorPoint : public QGraphicsItem
 {
 public:
     MvQFeatureSelectorPoint(MvQFeatureSelector*, QString pixName, QString hoverPixName,
-                          double xDeltaFactor, double yDeltaFactor);
+                            double xDeltaFactor, double yDeltaFactor);
     QRectF boundingRect() const;
     void paint(QPainter*, const QStyleOptionGraphicsItem*, QWidget*);
-    virtual void updatePosition()=0;
+    virtual void updatePosition() = 0;
 
 protected:
     QVariant itemChange(GraphicsItemChange, const QVariant&);
@@ -55,7 +54,7 @@ protected:
     void mouseReleaseEvent(QGraphicsSceneMouseEvent*);
     void hoverEnterEvent(QGraphicsSceneHoverEvent*);
     void hoverLeaveEvent(QGraphicsSceneHoverEvent*);
-    virtual void handleMouseMove(QPointF ep, QRectF& r)=0;
+    virtual void handleMouseMove(QPointF ep, QRectF& r) = 0;
 
     MvQFeatureSelector* selector_;
     QRectF bRect_;
@@ -154,19 +153,19 @@ protected:
 //========================================
 
 MvQFeatureSelectorPoint::MvQFeatureSelectorPoint(MvQFeatureSelector* selector, QString pixName, QString hoverPixName,
-                                             double xDeltaFactor, double yDeltaFactor) :
+                                                 double xDeltaFactor, double yDeltaFactor) :
     selector_(selector)
 {
     // The pixmap is always twice as large as the itemrect so that we can allow for the
     // scaling in the plot window (it can go up to 200% at the moment)
-    int rSize = 12;
+    int rSize     = 12;
     int pixFactor = 4;
-    pix_ = MvQ::makePixmap(pixName, pixFactor*rSize, pixFactor*rSize);
-    pixHover_ = MvQ::makePixmap(hoverPixName,pixFactor*rSize, pixFactor*rSize);
+    pix_          = MvQ::makePixmap(pixName, pixFactor * rSize, pixFactor * rSize);
+    pixHover_     = MvQ::makePixmap(hoverPixName, pixFactor * rSize, pixFactor * rSize);
 
-    bRect_ = QRectF(0, 0, rSize, rSize);
-    double delta = rSize/2;
-    bRect_.moveTo(xDeltaFactor*delta, yDeltaFactor*delta);
+    bRect_       = QRectF(0, 0, rSize, rSize);
+    double delta = rSize / 2;
+    bRect_.moveTo(xDeltaFactor * delta, yDeltaFactor * delta);
 
     setFlag(ItemIsMovable);
     setFlag(ItemSendsGeometryChanges);
@@ -203,7 +202,7 @@ void MvQFeatureSelectorPoint::mousePressEvent(QGraphicsSceneMouseEvent* event)
 
 void MvQFeatureSelectorPoint::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
 {
-    QRectF r   = selector_->boundingRect();
+    QRectF r = selector_->boundingRect();
     handleMouseMove(event->pos(), r);
     selector_->controlPointMoved(this, r);
 }
@@ -252,9 +251,9 @@ void MvQTopLeftFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
         QPointF dp = mapToScene(ep) - dragPos_;
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
         qDebug() << "(topLeft) handleMouseMove ------>";
-        qDebug() << " event pos in parent:" <<  mapToParent(ep) << "in scene:" << mapToScene(ep) << "dragPos_ in scene" << dragPos_;
+        qDebug() << " event pos in parent:" << mapToParent(ep) << "in scene:" << mapToScene(ep) << "dragPos_ in scene" << dragPos_;
         qDebug() << " event pos change in scene:" << dp;
-        qDebug() << " topLeft:" << r.topLeft()  << "in scene:" << selector_->mapToScene(r.topLeft());
+        qDebug() << " topLeft:" << r.topLeft() << "in scene:" << selector_->mapToScene(r.topLeft());
 #endif
         dragPos_ = mapToScene(ep);
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
@@ -265,32 +264,33 @@ void MvQTopLeftFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
         double eps = 1E-4;
         if (fabs(dp.x()) < eps && fabs(dp.y()) < eps) {
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
-            qDebug() <<  " --> NO change";
+            qDebug() << " --> NO change";
 #endif
             r = QRectF();
             return;
         }
 
-        auto ratio = fabs(r.height()/r.width());
-        double x = dp.x();
-        double y = dp.y();
-        bool grow = !(x >= 0. && y >= 0.);
-        double factor = (grow)?-1.0:1.0;
+        auto ratio    = fabs(r.height() / r.width());
+        double x      = dp.x();
+        double y      = dp.y();
+        bool grow     = !(x >= 0. && y >= 0.);
+        double factor = (grow) ? -1.0 : 1.0;
         if (fabs(x) >= fabs(y)) {
-            x = factor*fabs(x);
-            y = factor*fabs(x)*ratio;
-        } else {
-            y = factor*fabs(y);
-            x = factor*fabs(y)/ratio;
+            x = factor * fabs(x);
+            y = factor * fabs(x) * ratio;
+        }
+        else {
+            y = factor * fabs(y);
+            x = factor * fabs(y) / ratio;
         }
         r.setTopLeft(r.topLeft() + QPointF(x, y));
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
         qDebug() << " grow:" << grow << "ratio:" << ratio << "delta:" << QPointF(x, y) << "topLeft:" << r.topLeft();
 #endif
-    } else {
+    }
+    else {
         r.setTopLeft(mapToParent(ep));
     }
-
 }
 
 //========================================
@@ -346,9 +346,9 @@ void MvQTopRightFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
         QPointF dp = mapToScene(ep) - dragPos_;
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
         qDebug() << "(topRight) handleMouseMove ------>";
-        qDebug() << " event pos in parent:" <<  mapToParent(ep) << "in scene:" << mapToScene(ep) << "dragPos_ in scene" << dragPos_;
+        qDebug() << " event pos in parent:" << mapToParent(ep) << "in scene:" << mapToScene(ep) << "dragPos_ in scene" << dragPos_;
         qDebug() << " event pos change in scene:" << dp;
-        qDebug() << " topRight:" << r.topRight()  << "in scene:" << selector_->mapToScene(r.topRight());
+        qDebug() << " topRight:" << r.topRight() << "in scene:" << selector_->mapToScene(r.topRight());
 #endif
         dragPos_ = mapToScene(ep);
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
@@ -359,30 +359,33 @@ void MvQTopRightFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
         double eps = 1E-4;
         if (fabs(dp.x()) < eps && fabs(dp.y()) < eps) {
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
-            qDebug() <<  " --> NO change";
+            qDebug() << " --> NO change";
 #endif
             r = QRectF();
             return;
         }
-        auto ratio = fabs(r.height()/r.width());
-        double x = dp.x();
-        double y = dp.y();
-        bool grow = !(x >= 0. && y < 0.);
+        auto ratio = fabs(r.height() / r.width());
+        double x   = dp.x();
+        double y   = dp.y();
+        bool grow  = !(x >= 0. && y < 0.);
         if (fabs(x) >= fabs(y)) {
             if (grow) {
                 x = -fabs(x);
-                y = fabs(x)*ratio;
-            } else {
-                x = fabs(x);
-                y = -fabs(x)*ratio;
+                y = fabs(x) * ratio;
             }
-        } else {
+            else {
+                x = fabs(x);
+                y = -fabs(x) * ratio;
+            }
+        }
+        else {
             if (grow) {
                 y = fabs(y);
-                x = -fabs(y)/ratio;
-            } else {
+                x = -fabs(y) / ratio;
+            }
+            else {
                 y = -fabs(y);
-                x = fabs(y)/ratio;
+                x = fabs(y) / ratio;
             }
         }
 
@@ -390,7 +393,8 @@ void MvQTopRightFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
         qDebug() << " grow:" << grow << "ratio:" << ratio << "delta:" << QPointF(x, y) << "topRight:" << r.topRight();
 #endif
-    } else {
+    }
+    else {
         r.setTopRight(mapToParent(ep));
     }
 }
@@ -439,7 +443,6 @@ void MvQBottomRightFeatureSelectorPoint::updatePosition()
 {
     QRectF r = selector_->boundingRect();
     setPos(r.left() + r.width(), r.top() + r.height());
-
 }
 
 void MvQBottomRightFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
@@ -449,9 +452,9 @@ void MvQBottomRightFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
         QPointF dp = mapToScene(ep) - dragPos_;
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
         qDebug() << "(bottomRight) handleMouseMove ------>";
-        qDebug() << " event pos in parent:" <<  mapToParent(ep) << "in scene:" << mapToScene(ep) << "dragPos_ in scene" << dragPos_;
+        qDebug() << " event pos in parent:" << mapToParent(ep) << "in scene:" << mapToScene(ep) << "dragPos_ in scene" << dragPos_;
         qDebug() << " event pos change in scene:" << dp;
-        qDebug() << " bottomRight:" << r.bottomRight()  << "in scene:" << selector_->mapToScene(r.bottomRight());
+        qDebug() << " bottomRight:" << r.bottomRight() << "in scene:" << selector_->mapToScene(r.bottomRight());
 #endif
         dragPos_ = mapToScene(ep);
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
@@ -462,29 +465,31 @@ void MvQBottomRightFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
         double eps = 1E-4;
         if (fabs(dp.x()) < eps && fabs(dp.y()) < eps) {
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
-            qDebug() <<  " --> NO change";
+            qDebug() << " --> NO change";
 #endif
             r = QRectF();
             return;
         }
 
-        auto ratio = fabs(r.height()/r.width());
-        double x = dp.x();
-        double y = dp.y();
-        bool grow = !(x >= 0. && y >= 0.);
-        double factor = (grow)?-1.0:1.0;
+        auto ratio    = fabs(r.height() / r.width());
+        double x      = dp.x();
+        double y      = dp.y();
+        bool grow     = !(x >= 0. && y >= 0.);
+        double factor = (grow) ? -1.0 : 1.0;
         if (fabs(x) >= fabs(y)) {
-            x = factor*fabs(x);
-            y = factor*fabs(x)*ratio;
-        } else {
-            y = factor*fabs(y);
-            x = factor*fabs(y)/ratio;
+            x = factor * fabs(x);
+            y = factor * fabs(x) * ratio;
+        }
+        else {
+            y = factor * fabs(y);
+            x = factor * fabs(y) / ratio;
         }
         r.setBottomRight(r.bottomRight() + QPointF(x, y));
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
         qDebug() << " grow:" << grow << "ratio:" << ratio << "delta:" << QPointF(x, y) << "bottomRight:" << r.bottomRight();
 #endif
-    } else {
+    }
+    else {
         r.setBottomRight(mapToParent(ep));
     }
 }
@@ -526,7 +531,7 @@ void MvQBottomMidFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
 MvQBottomLeftFeatureSelectorPoint::MvQBottomLeftFeatureSelectorPoint(MvQFeatureSelector* selector) :
     MvQFeatureSelectorPoint(selector, ":/uPlot/cursor_fdiag.svg", ":/uPlot/cursor_fdiag_hover.svg", -2, 0)
 {
-     updatePosition();
+    updatePosition();
 }
 
 void MvQBottomLeftFeatureSelectorPoint::updatePosition()
@@ -542,9 +547,9 @@ void MvQBottomLeftFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
         QPointF dp = mapToScene(ep) - dragPos_;
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
         qDebug() << "(bottomLeft) handleMouseMove ------>";
-        qDebug() << " event pos in parent:" <<  mapToParent(ep) << "in scene:" << mapToScene(ep) << "dragPos_ in scene" << dragPos_;
+        qDebug() << " event pos in parent:" << mapToParent(ep) << "in scene:" << mapToScene(ep) << "dragPos_ in scene" << dragPos_;
         qDebug() << " event pos change in scene:" << dp;
-        qDebug() << " bottomLeft:" << r.bottomLeft()  << "in scene:" << selector_->mapToScene(r.bottomLeft());
+        qDebug() << " bottomLeft:" << r.bottomLeft() << "in scene:" << selector_->mapToScene(r.bottomLeft());
 #endif
         dragPos_ = mapToScene(ep);
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
@@ -555,38 +560,42 @@ void MvQBottomLeftFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
         double eps = 1;
         if (fabs(dp.x()) < eps && fabs(dp.y()) < eps) {
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
-            qDebug() <<  " --> NO change";
+            qDebug() << " --> NO change";
 #endif
             r = QRectF();
             return;
         }
 
-        auto ratio = fabs(r.height()/r.width());
-        double x = dp.x();
-        double y = dp.y();
-        bool grow = !(x >= 0. && y < 0.);
+        auto ratio = fabs(r.height() / r.width());
+        double x   = dp.x();
+        double y   = dp.y();
+        bool grow  = !(x >= 0. && y < 0.);
         if (fabs(x) >= fabs(y)) {
             if (grow) {
                 x = -fabs(x);
-                y = fabs(x)*ratio;
-            } else {
-                x = fabs(x);
-                y = -fabs(x)*ratio;
+                y = fabs(x) * ratio;
             }
-        } else {
+            else {
+                x = fabs(x);
+                y = -fabs(x) * ratio;
+            }
+        }
+        else {
             if (grow) {
                 y = fabs(y);
-                x = -fabs(y)/ratio;
-            } else {
+                x = -fabs(y) / ratio;
+            }
+            else {
                 y = -fabs(y);
-                x = fabs(y)/ratio;
+                x = fabs(y) / ratio;
             }
         }
         r.setBottomLeft(r.bottomLeft() + QPointF(x, y));
 #ifdef MVQFEATURESELECTORPOINT_DEBUG_
         qDebug() << " grow:" << grow << "ratio:" << ratio << "delta:" << QPointF(x, y) << "bottomLeft:" << r.bottomLeft();
 #endif
-    } else {
+    }
+    else {
         r.setBottomLeft(mapToParent(ep));
     }
 }
@@ -628,100 +637,100 @@ void MvQLeftMidFeatureSelectorPoint::handleMouseMove(QPointF ep, QRectF& r)
 class SelectorState
 {
 public:
-    SelectorState() {}
-    virtual ~SelectorState() {}
-    virtual void setSelector(MvQFeatureSelector*)=0;
-    const QList<MvQFeatureItem*>& managedItems() const {return managedItems_;}
-    virtual QList<MvQFeatureItem*> allItems() const {return managedItems_;}
+    SelectorState()                               = default;
+    virtual ~SelectorState()                      = default;
+    virtual void setSelector(MvQFeatureSelector*) = 0;
+    const QList<MvQFeatureItemPtr>& managedItems() const { return managedItems_; }
+    virtual QList<MvQFeatureItemPtr> allItems() const { return managedItems_; }
 
     virtual void handleClear();
     virtual void handleCheckClick() {}
     virtual void handleDoubleClick() {}
     virtual void handleMousePress(QGraphicsSceneMouseEvent*) {}
-    virtual void handleSelectionChanged(QList<MvQFeatureItem*>) {}
-    virtual bool handleIdentifyCommandTarget(MvQFeatureCommandTarget*) {return false;}
+    virtual void handleSelectionChanged(QList<MvQFeatureItemPtr>) {}
+    virtual bool handleIdentifyCommandTarget(MvQFeatureCommandTarget*) { return false; }
     virtual void handleRemoveAll() {}
-    virtual void handleItemStyleChanged(MvQFeatureItem*) {}
+    virtual void handleItemStyleChanged(MvQFeatureItemPtr) {}
     virtual void handleSuspend(bool);
 
 protected:
     MvQFeatureSelector* selector_{nullptr};
-    QList<MvQFeatureItem*> managedItems_;
+    QList<MvQFeatureItemPtr> managedItems_;
 };
 
-class SelectorSuspendState: public SelectorState
+class SelectorSuspendState : public SelectorState
 {
 public:
-    SelectorSuspendState() {}
+    SelectorSuspendState() = default;
     void setSelector(MvQFeatureSelector*) override;
     void handleSuspend(bool) override;
 };
 
-class SelectorIdleState: public SelectorState
+class SelectorIdleState : public SelectorState
 {
 public:
-    SelectorIdleState() {}
+    SelectorIdleState() = default;
     void setSelector(MvQFeatureSelector*) override;
-    void handleSelectionChanged(QList<MvQFeatureItem*> items) override;
+    void handleSelectionChanged(QList<MvQFeatureItemPtr> items) override;
 };
 
-class SelectorNormalState: public SelectorState
+class SelectorNormalState : public SelectorState
 {
 public:
-    SelectorNormalState(QList<MvQFeatureItem*>);
+    SelectorNormalState(QList<MvQFeatureItemPtr>);
     void setSelector(MvQFeatureSelector*) override;
     void handleDoubleClick() override;
     void handleMousePress(QGraphicsSceneMouseEvent*) override;
-    void handleSelectionChanged(QList<MvQFeatureItem*> items) override;
+    void handleSelectionChanged(QList<MvQFeatureItemPtr> items) override;
     bool handleIdentifyCommandTarget(MvQFeatureCommandTarget* s) override;
     //void handleRemoveAll() override;
-    void handleItemStyleChanged(MvQFeatureItem*) override;
+    void handleItemStyleChanged(MvQFeatureItemPtr) override;
 };
 
-class SelectorPointEditState: public SelectorState
+class SelectorPointEditState : public SelectorState
 {
 public:
-    SelectorPointEditState(MvQFeatureItem*);
+    SelectorPointEditState(MvQFeatureItemPtr);
     void setSelector(MvQFeatureSelector*) override;
-    QList<MvQFeatureItem*> allItems() const override {return {item_};}
+    QList<MvQFeatureItemPtr> allItems() const override { return {item_}; }
 
     void handleCheckClick() override;
-    void handleSelectionChanged(QList<MvQFeatureItem*> items) override;
+    void handleSelectionChanged(QList<MvQFeatureItemPtr> items) override;
     bool handleIdentifyCommandTarget(MvQFeatureCommandTarget* s) override;
     void handleClear() override;
 
 protected:
-    MvQFeatureItem* item_{nullptr};
+    MvQFeatureItemPtr item_;
 };
 
-class SelectorTextEditState: public SelectorState
+class SelectorTextEditState : public SelectorState
 {
 public:
-    SelectorTextEditState(MvQFeatureItem*);
+    SelectorTextEditState(MvQFeatureItemPtr);
     void setSelector(MvQFeatureSelector*) override;
-    QList<MvQFeatureItem*> allItems() const override {return {item_};}
+    QList<MvQFeatureItemPtr> allItems() const override { return {item_}; }
 
-    void handleSelectionChanged(QList<MvQFeatureItem*> items) override;
+    void handleSelectionChanged(QList<MvQFeatureItemPtr> items) override;
     bool handleIdentifyCommandTarget(MvQFeatureCommandTarget* s) override;
 
 protected:
-    MvQFeatureItem* item_{nullptr};
+    MvQFeatureItemPtr item_{nullptr};
 };
 
-class SelectorLineState: public SelectorState
+class SelectorLineState : public SelectorState
 {
 public:
-    SelectorLineState(MvQFeatureItem*);
+    SelectorLineState(MvQFeatureItemPtr);
     void setSelector(MvQFeatureSelector*) override;
-    QList<MvQFeatureItem*> allItems() const override {return {item_};}
+    QList<MvQFeatureItemPtr> allItems() const override { return {item_}; }
 
-    void handleSelectionChanged(QList<MvQFeatureItem*> items) override;
+    void handleSelectionChanged(QList<MvQFeatureItemPtr> items) override;
     bool handleIdentifyCommandTarget(MvQFeatureCommandTarget* s) override;
     //void handleRemoveAll() override;
     void handleClear() override;
 
 protected:
-    MvQFeatureItem* item_{nullptr};
+    MvQFeatureItemPtr item_{nullptr};
 };
 
 //========================================
@@ -735,7 +744,7 @@ void SelectorState::handleClear()
     selector_->transitionTo(new SelectorIdleState());
 }
 
-void SelectorState::handleSuspend(bool  st)
+void SelectorState::handleSuspend(bool st)
 {
     if (st) {
         selector_->transitionTo(new SelectorSuspendState());
@@ -754,7 +763,7 @@ void SelectorSuspendState::setSelector(MvQFeatureSelector* selector)
     selector_->hide();
 }
 
-void SelectorSuspendState::handleSuspend(bool  st)
+void SelectorSuspendState::handleSuspend(bool st)
 {
     if (!st) {
         selector_->transitionTo(new SelectorIdleState());
@@ -773,16 +782,18 @@ void SelectorIdleState::setSelector(MvQFeatureSelector* selector)
     selector_->hide();
     selector_->controlPointUsed_ = false;
     selector_->controlPointMove_ = false;
-    selector_->dragPos_ = QPointF();
+    selector_->dragPos_          = QPointF();
 }
 
-void SelectorIdleState::handleSelectionChanged(QList<MvQFeatureItem*> items)
+void SelectorIdleState::handleSelectionChanged(QList<MvQFeatureItemPtr> items)
 {
     if (items.size() == 0) {
         selector_->hide();
-    } else if (items.size() == 1 && items[0]->isLine()) {
+    }
+    else if (items.size() == 1 && items[0]->isLine()) {
         selector_->transitionTo(new SelectorLineState(items[0]));
-    } else {
+    }
+    else {
         selector_->transitionTo(new SelectorNormalState(items));
     }
 }
@@ -793,7 +804,7 @@ void SelectorIdleState::handleSelectionChanged(QList<MvQFeatureItem*> items)
 //
 //========================================
 
-SelectorNormalState::SelectorNormalState(QList<MvQFeatureItem*> items)
+SelectorNormalState::SelectorNormalState(QList<MvQFeatureItemPtr> items)
 {
     managedItems_ = items;
 }
@@ -810,7 +821,8 @@ void SelectorNormalState::handleDoubleClick()
         auto item = managedItems_[0];
         if (item->hasPoints()) {
             selector_->transitionTo(new SelectorPointEditState(item));
-        } else if (item->hasEditableText()) {
+        }
+        else if (item->hasEditableText()) {
             selector_->transitionTo(new SelectorTextEditState(item));
         }
     }
@@ -832,13 +844,15 @@ void SelectorNormalState::handleMousePress(QGraphicsSceneMouseEvent* event)
     selector_->registerMousePress(event);
 }
 
-void SelectorNormalState::handleSelectionChanged(QList<MvQFeatureItem*> items)
+void SelectorNormalState::handleSelectionChanged(QList<MvQFeatureItemPtr> items)
 {
     if (items.size() == 0) {
         selector_->transitionTo(new SelectorIdleState());
-    } else if (items.size() == 1 && items[0]->isLine()) {
+    }
+    else if (items.size() == 1 && items[0]->isLine()) {
         selector_->transitionTo(new SelectorLineState(items[0]));
-    } else {
+    }
+    else {
         managedItems_ = items;
         selector_->managedItemsChanged();
     }
@@ -853,8 +867,9 @@ bool SelectorNormalState::handleIdentifyCommandTarget(MvQFeatureCommandTarget* s
         if (managedItems_.size() == 1) {
             s->setTargetItem(managedItems_[0]);
             return true;
-        // the whole selector will receive the context event
-        } else if (managedItems_.size() > 1) {
+            // the whole selector will receive the context event
+        }
+        else if (managedItems_.size() > 1) {
             s->setTargetItem(nullptr);
             return true;
         }
@@ -871,10 +886,10 @@ void SelectorNormalState::handleRemoveAll()
 }
 #endif
 
-void SelectorNormalState::handleItemStyleChanged(MvQFeatureItem* item)
+void SelectorNormalState::handleItemStyleChanged(MvQFeatureItemPtr item)
 {
     if (managedItems_.contains(item)) {
-       selector_->adjust(selector_->computeBRect());
+        selector_->adjust(selector_->computeBRect());
     }
 }
 
@@ -884,7 +899,7 @@ void SelectorNormalState::handleItemStyleChanged(MvQFeatureItem* item)
 //
 //========================================
 
-SelectorPointEditState::SelectorPointEditState(MvQFeatureItem* item) :
+SelectorPointEditState::SelectorPointEditState(MvQFeatureItemPtr item) :
     item_(item)
 {
     Q_ASSERT(item_);
@@ -902,16 +917,17 @@ void SelectorPointEditState::handleCheckClick()
 {
     if (item_->currentAction_ == MvQFeatureItem::PointEditAction &&
         !item_->hasEditedPoint()) {
-            item_->leavePointEdit();
+        item_->leavePointEdit();
     }
 }
 
-void SelectorPointEditState::handleSelectionChanged(QList<MvQFeatureItem*> items)
+void SelectorPointEditState::handleSelectionChanged(QList<MvQFeatureItemPtr> items)
 {
     item_->leavePointEdit();
     if (items.size() != 0) {
         selector_->transitionTo(new SelectorNormalState(items));
-    } else {
+    }
+    else {
         selector_->transitionTo(new SelectorIdleState());
     }
 }
@@ -919,7 +935,7 @@ void SelectorPointEditState::handleSelectionChanged(QList<MvQFeatureItem*> items
 bool SelectorPointEditState::handleIdentifyCommandTarget(MvQFeatureCommandTarget* s)
 {
     QPointF itemPos = item_->mapFromScene(s->scenePos());
-    int nodeIndex = item_->nodeForContextMenu(itemPos);
+    int nodeIndex   = item_->nodeForContextMenu(itemPos);
     if (nodeIndex != -1) {
         s->setInSelector(true);
         s->setTargetNodeItem(item_, nodeIndex);
@@ -941,7 +957,7 @@ void SelectorPointEditState::handleClear()
 //
 //========================================
 
-SelectorTextEditState::SelectorTextEditState(MvQFeatureItem* item) :
+SelectorTextEditState::SelectorTextEditState(MvQFeatureItemPtr item) :
     item_(item)
 {
     Q_ASSERT(item_);
@@ -954,19 +970,19 @@ void SelectorTextEditState::setSelector(MvQFeatureSelector* selector)
     item_->editText();
 }
 
-void SelectorTextEditState::handleSelectionChanged(QList<MvQFeatureItem*> items)
+void SelectorTextEditState::handleSelectionChanged(QList<MvQFeatureItemPtr> items)
 {
     if (items.size() >= 1) {
         selector_->transitionTo(new SelectorNormalState(items));
-    } else {
+    }
+    else {
         selector_->transitionTo(new SelectorIdleState());
     }
 }
 
-bool SelectorTextEditState::handleIdentifyCommandTarget(MvQFeatureCommandTarget* s)
+bool SelectorTextEditState::handleIdentifyCommandTarget(MvQFeatureCommandTarget*)
 {
     return false;
-    //return item_->identifyCommandTarget(s);
 }
 
 //========================================
@@ -975,7 +991,7 @@ bool SelectorTextEditState::handleIdentifyCommandTarget(MvQFeatureCommandTarget*
 //
 //========================================
 
-SelectorLineState::SelectorLineState(MvQFeatureItem* item) :
+SelectorLineState::SelectorLineState(MvQFeatureItemPtr item) :
     item_(item)
 {
     Q_ASSERT(item_);
@@ -989,17 +1005,19 @@ void SelectorLineState::setSelector(MvQFeatureSelector* selector)
     item_->enterPointEdit();
 }
 
-void SelectorLineState::handleSelectionChanged(QList<MvQFeatureItem*> items)
+void SelectorLineState::handleSelectionChanged(QList<MvQFeatureItemPtr> items)
 {
     if (items.size() == 1 && items[0] == item_) {
         return;
-    } else {
+    }
+    else {
         if (item_) {
             item_->leavePointEdit();
         }
         if (items.size() != 0) {
             selector_->transitionTo(new SelectorNormalState(items));
-        } else {
+        }
+        else {
             selector_->transitionTo(new SelectorIdleState());
         }
     }
@@ -1019,7 +1037,7 @@ bool SelectorLineState::handleIdentifyCommandTarget(MvQFeatureCommandTarget* s)
 #if 0
 void SelectorLineState::handleRemoveAll()
 {
-    QList<MvQFeatureItem*> lst;
+    QList<MvQFeatureItemPtr> lst;
     lst << item_;
     selector_->view()->removeFeatures(lst);
 }
@@ -1072,30 +1090,30 @@ void MvQFeatureSelector::paint(QPainter* painter, const QStyleOptionGraphicsItem
         painter->setPen(Qt::red);
         //painter->drawRect(mapRectFromParent(computeBRect()));
 #endif
-    } else {
-        for (auto item: managedItems()) {
+    }
+    else {
+        for (auto item : managedItems()) {
             auto br = item->mapToParent(item->boundingRect()).boundingRect();
-            br = mapFromParent(br).boundingRect();
+            br      = mapFromParent(br).boundingRect();
             painter->drawRect(br);
         }
     }
 }
 
-const QList<MvQFeatureItem*>& MvQFeatureSelector::managedItems() const
+const QList<MvQFeatureItemPtr>& MvQFeatureSelector::managedItems() const
 {
     return state_->managedItems();
 }
 
-
-QList<MvQFeatureItem*> MvQFeatureSelector::allItems() const
+QList<MvQFeatureItemPtr> MvQFeatureSelector::allItems() const
 {
     return state_->allItems();
 }
 
-MvQFeatureItem* MvQFeatureSelector::firstItem() const
+MvQFeatureItemPtr MvQFeatureSelector::firstItem() const
 {
     auto lst = allItems();
-    return (lst.size() > 0)?lst[0]:nullptr;
+    return (lst.size() > 0) ? lst[0] : nullptr;
 }
 
 void MvQFeatureSelector::adjust(QRectF r)
@@ -1103,8 +1121,9 @@ void MvQFeatureSelector::adjust(QRectF r)
     prepareGeometryChange();
     bRect_ = QRectF(0, 0, r.width(), r.height());
     setPos(r.topLeft());
-    foreach(MvQFeatureSelectorPoint* h, controlPoints_)
+    for (auto h : controlPoints_) {
         h->updatePosition();
+    }
     update();
 }
 
@@ -1124,12 +1143,12 @@ void MvQFeatureSelector::createControlPoints()
 
 void MvQFeatureSelector::controlPointPressed(MvQFeatureSelectorPoint*)
 {
-    oriRect_ = bRect_;
+    oriRect_          = bRect_;
     controlPointUsed_ = true;
     controlPointMove_ = false;
 }
 
-//Here rect is in item coordiantes
+//Here rect is in item coordinates
 void MvQFeatureSelector::controlPointMoved(MvQFeatureSelectorPoint*, QRectF rect)
 {
     if (!controlPointUsed_)
@@ -1141,16 +1160,15 @@ void MvQFeatureSelector::controlPointMoved(MvQFeatureSelectorPoint*, QRectF rect
 
     if (rect.isValid()) {
         QRectF oriRect = mapRectToParent(bRect_);
-        auto xSign = (rect.left() - rect.right()) *  (oriRect.left() - oriRect.right());
-        auto ySign = (rect.top() - rect.bottom()) *  (oriRect.top() - oriRect.bottom());
-        auto mSize = minSize();
+        auto xSign     = (rect.left() - rect.right()) * (oriRect.left() - oriRect.right());
+        auto ySign     = (rect.top() - rect.bottom()) * (oriRect.top() - oriRect.bottom());
+        auto mSize     = minSize();
 #ifdef MVQFEATURESELECTORITEM_DEBUG_
         qDebug() << "xSign:" << xSign << "ySign:" << ySign << "mSize:" << mSize << "rectSize:" << rect.size();
 #endif
         // we cannot shrink the selector below a certain size, no flip allowed
         if (fabs(rect.width()) >= mSize.width() && fabs(rect.height()) >= mSize.height() &&
             xSign >= 0. && ySign >= 0.) {
-
             prepareGeometryChange();
 #ifdef MVQFEATURESELECTORITEM_DEBUG_
             qDebug() << " bRect_(parent):" << oriRect << "rect:" << rect;
@@ -1163,9 +1181,9 @@ void MvQFeatureSelector::controlPointMoved(MvQFeatureSelectorPoint*, QRectF rect
 #endif
             QRectF newRect = mapToParent(bRect_).boundingRect();
 #ifdef MVQFEATURESELECTORITEM_DEBUG_
-        qDebug() << " --> bRect_ in parent" << newRect;
+            qDebug() << " --> bRect_ in parent" << newRect;
 #endif
-            foreach (MvQFeatureSelectorPoint* h, controlPoints_) {
+            for (MvQFeatureSelectorPoint* h : controlPoints_) {
                 h->updatePosition();
             }
 
@@ -1175,7 +1193,7 @@ void MvQFeatureSelector::controlPointMoved(MvQFeatureSelectorPoint*, QRectF rect
         }
     }
 
-    foreach (MvQFeatureSelectorPoint* h, controlPoints_) {
+    for (MvQFeatureSelectorPoint* h : controlPoints_) {
         h->updatePosition();
     }
 }
@@ -1184,7 +1202,7 @@ void MvQFeatureSelector::controlPointReleased(MvQFeatureSelectorPoint*)
 {
     controlPointUsed_ = false;
     controlPointMove_ = false;
-    foreach (MvQFeatureItem* item, managedItems()) {
+    for (MvQFeatureItemPtr item : managedItems()) {
         item->resizeFinished();
     }
 }
@@ -1212,15 +1230,14 @@ void MvQFeatureSelector::mousePressEvent(QGraphicsSceneMouseEvent* event)
 
 void MvQFeatureSelector::registerMousePress(QGraphicsSceneMouseEvent* event)
 {
-    dragPos_ = mapToParent(event->pos());
+    dragPos_            = mapToParent(event->pos());
     currentMouseAction_ = MousePressedAction;
 }
 
 void MvQFeatureSelector::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
 {
 #ifdef MVQFEATURESELECTORITEM_DEBUG_
-    qDebug() << "MvQFeatureSelectorItem::mouseMoveEvent event.pos" << mapToParent(event->pos()) <<
-                "dragPos:" << dragPos_ << "pos:" << pos() << "items.size=" << managedItems().size();
+    qDebug() << "MvQFeatureSelectorItem::mouseMoveEvent event.pos" << mapToParent(event->pos()) << "dragPos:" << dragPos_ << "pos:" << pos() << "items.size=" << managedItems().size();
     qDebug() << "  event.lastPos" << mapToParent(event->lastPos());
 #endif
 
@@ -1229,23 +1246,32 @@ void MvQFeatureSelector::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
     }
 
     QPointF prevPos = pos();
-    auto evtPos = mapToParent(event->pos());
-    auto delta = evtPos - dragPos_;
+    auto evtPos     = mapToParent(event->pos());
+    auto delta      = evtPos - dragPos_;
 
     // we came here without having a mouse press event on the selector
-    if (currentMouseAction_ == NoMouseAction ) {
+    if (currentMouseAction_ == NoMouseAction) {
         delta = QPointF();
-        handler_->moveBy(managedItems(), delta, true);
-    } else {
+        handler_->moveBy(nonGeoLockedManagedItems(), delta, true);
+    }
+    else {
+        MvQFeatureItemList nonGlItems = nonGeoLockedManagedItems();
+        if (nonGlItems.size() == 0) {
+            return;
+        }
+        //        if (std::all_of(items.cbegin(), items.cend(), [](auto v) {return v->isGeoLocked();})) {
+        //            return;
+        //        }
+
         QPointF pp = pos() + delta;
         setPos(pp);
         update();
 #ifdef MVQFEATURESELECTORITEM_DEBUG_
         qDebug() << " delta=" << delta;
 #endif
-
         delta = pos() - prevPos;
-        handler_->moveBy(managedItems(), delta, currentMouseAction_ != MouseMoveAction);
+        //        handler_->moveBy(managedItems(), delta, currentMouseAction_ != MouseMoveAction);
+        handler_->moveBy(nonGlItems, delta, currentMouseAction_ != MouseMoveAction);
     }
 
     dragPos_ += delta;
@@ -1277,11 +1303,10 @@ void MvQFeatureSelector::clear()
     auto allIt = allItems();
     state_->handleClear();
     suspend(true);
-    for (auto it: allIt) {
+    for (auto it : allIt) {
         it->setSelected(false);
     }
     suspend(false);
-
 }
 
 #if 0
@@ -1300,20 +1325,20 @@ void MvQFeatureSelector::selectionChanged()
     state_->handleSelectionChanged(currentSelection());
 }
 
-QList<MvQFeatureItem*> MvQFeatureSelector::currentSelection() const
+QList<MvQFeatureItemPtr> MvQFeatureSelector::currentSelection() const
 {
     Q_ASSERT(parentItem());
-    QList<MvQFeatureItem*> it;
-    for (auto item: parentItem()->childItems()) {
+    QList<MvQFeatureItemPtr> it;
+    for (auto item : parentItem()->childItems()) {
         if (item->isSelected() && item->type() == MvQ::FeatureItemType) {
-            MvQFeatureItem* f = static_cast<MvQFeatureItem*>(item);
+            auto* f = static_cast<MvQFeatureItem*>(item);
             Q_ASSERT(f);
             if (!f->isPoint()) {
-            //if (f->currentAction_ != MvQFeatureItem::PointEditAction) {
+                //if (f->currentAction_ != MvQFeatureItem::PointEditAction) {
 #ifdef MVQFEATURESELECTORITEM_DEBUG_
                 qDebug() << "   selected:" << f->typeName() << f;
 #endif
-                it << f;
+                it << f->getptr();
             }
         }
     }
@@ -1326,12 +1351,13 @@ void MvQFeatureSelector::managedItemsChanged()
 
     if (items.count() == 0) {
         hide();
-    } else {
+    }
+    else {
         // construct the bounding rect
         auto br = computeBRect();
         adjust(br);
 
-        for (auto h: controlPoints_) {
+        for (auto h : controlPoints_) {
             h->show();
         }
         // hide mid control points when aspect ratio is kept
@@ -1348,17 +1374,17 @@ void MvQFeatureSelector::managedItemsChanged()
         // we need it if we immediately drag the selected item. In this case first the item receives a
         // a mousePress event, then the current function is called followed by a mouseMove event
         // on the selector. dragPos is in parent coordinates!
-        dragPos_ = mapToParent(mapFromItem(items[0], items[0]->lastPressedPos_));
+        dragPos_ = mapToParent(mapFromItem(items[0].get(), items[0]->lastPressedPos_));
 
-    #ifdef MVQFEATURESELECTORITEM_DEBUG_
+#ifdef MVQFEATURESELECTORITEM_DEBUG_
         qDebug() << "   pos:" << pos() << " dragPos:" << dragPos_;
-    #endif
+#endif
         setSelected(true);
         grabMouse();
     }
 }
 
-void MvQFeatureSelector::itemStyleChanged(MvQFeatureItem* item)
+void MvQFeatureSelector::itemStyleChanged(MvQFeatureItemPtr item)
 {
     state_->handleItemStyleChanged(item);
 }
@@ -1373,12 +1399,12 @@ QRectF MvQFeatureSelector::computeBRect() const
     QRectF br;
     if (managedItems().size() > 0) {
         auto item = managedItems()[0];
-        QRectF p = item->boundingRect();
-        br = item->mapToParent(p).boundingRect();
+        QRectF p  = item->boundingRect();
+        br        = item->mapToParent(p).boundingRect();
         for (int i = 1; i < managedItems().count(); i++) {
             item = managedItems()[i];
-            p  = item->boundingRect();
-            br = br.united(item->mapToParent(p).boundingRect());
+            p    = item->boundingRect();
+            br   = br.united(item->mapToParent(p).boundingRect());
         }
     }
     return br;
@@ -1388,7 +1414,7 @@ QSizeF MvQFeatureSelector::minSize() const
 {
     double minSizeX = 8.;
     double minSizeY = 8.;
-    for (auto it: managedItems()) {
+    for (auto it : managedItems()) {
         auto m = it->minSize();
         if (m.width() > minSizeX) {
             minSizeX = m.width();
@@ -1413,14 +1439,26 @@ bool MvQFeatureSelector::keepAspectRatio() const
     return false;
 }
 
-void MvQFeatureSelector::transitionTo(SelectorState *state)
+MvQFeatureItemList MvQFeatureSelector::nonGeoLockedManagedItems() const
+{
+    const auto& items = managedItems();
+    MvQFeatureItemList nonGlItems;
+    for (auto it : items) {
+        if (!it->isGeoLocked()) {
+            nonGlItems << it;
+        }
+    }
+    return nonGlItems;
+}
+
+void MvQFeatureSelector::transitionTo(SelectorState* state)
 {
 #ifdef MVQFEATURESELECTORITEM_DEBUG_
-   std::cout << " MvQFeatureSelectorItem::transitionTo " << typeid(*state).name() << "\n";
+    std::cout << " MvQFeatureSelectorItem::transitionTo " << typeid(*state).name() << "\n";
 #endif
-   if (state_ != nullptr) {
-       delete state_;
-   }
-   state_ = state;
-   state_->setSelector(this);
+    if (state_ != nullptr) {
+        delete state_;
+    }
+    state_ = state;
+    state_->setSelector(this);
 }
