@@ -16,13 +16,15 @@
 #include <QDebug>
 #include <QGraphicsSceneMouseEvent>
 #include <QImage>
+#include <QJsonArray>
 #include <QMouseEvent>
 #include <QStyle>
 
 #include "GenAppService.hpp"
+#include "MvQJson.h"
 #include "MvQPlotView.h"
 #include "MvQFeatureFactory.h"
-#include "MvQFeatureType.h"
+#include "WsType.h"
 #include "MvQMethods.h"
 #include "ObjectList.h"
 #include "MvSci.h"
@@ -41,19 +43,23 @@
 //
 //========================================
 
-MvQFeatureShapeItem::MvQFeatureShapeItem(MvQFeatureType* feature, MvQPlotView* view, QGraphicsItem* parent) :
-    MvQFeatureItem(feature, view, parent)
+MvQFeatureShapeItem::MvQFeatureShapeItem(WsType* feature) :
+    MvQFeatureItem(feature)
 {
 }
 
-MvQFeatureShapeItem::MvQFeatureShapeItem(const MvQFeatureShapeItem& o) :
-     MvQFeatureItem(o)
+void MvQFeatureShapeItem::init(const QJsonObject& obj)
 {
-    width_ = o.width_;
-    height_ = o.height_;
-    shape_ = o.shape_;
-    shapePath_ = o.shapePath_;
-    initStyle();
+    QJsonObject g = obj["geometry"].toObject();
+    auto gcLst    = MvQJson::toPointFList(g["coordinates"].toArray(), g["type"].toString());
+    if (!gcLst.isEmpty()) {
+        geoCoord_         = gcLst[0];
+        hasValidGeoCoord_ = isValidPoint(geoCoord_);
+    }
+    else {
+        hasValidGeoCoord_ = false;
+    }
+    MvQFeatureItem::init(obj);
 }
 
 void MvQFeatureShapeItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*)
@@ -66,7 +72,8 @@ void MvQFeatureShapeItem::paint(QPainter* painter, const QStyleOptionGraphicsIte
 
     if (shapePath_.isEmpty()) {
         painter->drawPolygon(shape_);
-    } else {
+    }
+    else {
         painter->drawPath(shapePath_);
     }
 
@@ -78,7 +85,8 @@ void MvQFeatureShapeItem::paint(QPainter* painter, const QStyleOptionGraphicsIte
         painter->setBrush(Qt::NoBrush);
         if (shapePath_.isEmpty()) {
             painter->drawPolygon(shape_);
-        } else {
+        }
+        else {
             painter->drawPath(shapePath_);
         }
     }
@@ -101,20 +109,22 @@ void MvQFeatureShapeItem::resize(QRectF targetRectInParent)
     auto w = targetRect.width();
     auto h = targetRect.height();
     if (anchorPos_ == CentreAnchor) {
-        itemRect_ = QRectF(-w/2., -h/2., w, h);
+        itemRect_ = QRectF(-w / 2., -h / 2., w, h);
         setPos(targetRectInParent.center());
-    } else if (anchorPos_ == BottomCentreAnchor) {
-        itemRect_ = QRectF(-w/2., -h, w, h);
+    }
+    else if (anchorPos_ == BottomCentreAnchor) {
+        itemRect_ = QRectF(-w / 2., -h, w, h);
         setPos(QPointF(targetRectInParent.center().x(),
                        targetRectInParent.y()));
-    } else {
-       Q_ASSERT(0);
+    }
+    else {
+        Q_ASSERT(0);
     }
 #ifdef MVQFEATURESHAPE_DEBUG_
     qDebug() << "ItemRect:" << itemRect_ << "pos:" << pos();
 #endif
-    bRect_ = itemRect_;
-    width_ = itemRect_.width();
+    bRect_  = itemRect_;
+    width_  = itemRect_.width();
     height_ = itemRect_.height();
     adjustBRect();
     adjustGeoCoord();
@@ -127,9 +137,9 @@ void MvQFeatureShapeItem::resizeTo(const MvQFeatureGeometry& geom)
     prepareGeometryChange();
     setPos(geom.pos_);
     itemRect_ = geom.itemRect_;
-    bRect_ = itemRect_;
-    width_ = itemRect_.width();
-    height_ = itemRect_.height();
+    bRect_    = itemRect_;
+    width_    = itemRect_.width();
+    height_   = itemRect_.height();
     adjustBRect();
     adjustGeoCoord();
     buildShape();
@@ -139,9 +149,10 @@ void MvQFeatureShapeItem::resizeTo(const MvQFeatureGeometry& geom)
 void MvQFeatureShapeItem::adjustSizeInReq()
 {
     if (keepAspectRatio_) {
-        req_("SIZE") = width_;
-    } else {
         req_("WIDTH") = width_;
+    }
+    else {
+        req_("WIDTH")  = width_;
         req_("HEIGHT") = height_;
     }
     broadcastRequestChanged();
@@ -204,10 +215,12 @@ void MvQFeatureShapeItem::updateRect()
 {
     prepareGeometryChange();
     if (anchorPos_ == CentreAnchor) {
-        itemRect_ = QRectF(-width_/2.,-height_/2., width_, height_);
-    } else if (anchorPos_ == BottomCentreAnchor) {
-        itemRect_ = QRectF(-width_/2.,-height_, width_, height_);
-    } else {
+        itemRect_ = QRectF(-width_ / 2., -height_ / 2., width_, height_);
+    }
+    else if (anchorPos_ == BottomCentreAnchor) {
+        itemRect_ = QRectF(-width_ / 2., -height_, width_, height_);
+    }
+    else {
         Q_ASSERT(0);
     }
     bRect_ = itemRect_;
@@ -215,16 +228,16 @@ void MvQFeatureShapeItem::updateRect()
 
 void MvQFeatureShapeItem::adjustBRect()
 {
-   if (fabs(halo() > 1E-5)) {
-       prepareGeometryChange();
-       bRect_ = itemRect_.adjusted(-halo(), -halo(), halo(), halo());
-   }
+    if (fabs(halo() > 1E-5)) {
+        prepareGeometryChange();
+        bRect_ = itemRect_.adjusted(-halo(), -halo(), halo(), halo());
+    }
 }
 
 double MvQFeatureShapeItem::halo() const
 {
     auto w = pen_.width();
-    return (w <=1)?0:1+w/2;
+    return (w <= 1) ? 0 : 1 + w / 2;
 }
 
 bool MvQFeatureShapeItem::getRequestParameters()
@@ -232,7 +245,7 @@ bool MvQFeatureShapeItem::getRequestParameters()
     if (!req_)
         return false;
 
-    req_ = ObjectList::ExpandRequest(req_, EXPAND_DEFAULTS);
+    expandStyleRequest();
 
     std::string val;
 
@@ -240,18 +253,20 @@ bool MvQFeatureShapeItem::getRequestParameters()
     req_.getValue("LINE", val);
     if (val == "OFF") {
         pen_ = QPen(Qt::NoPen);
-    } else {
+    }
+    else {
         pen_ = MvQ::makePen((const char*)req_("LINE_STYLE"),
-                              (int)req_("LINE_THICKNESS"),
-                              (const char*)req_("LINE_COLOUR"),
-                              Qt::SquareCap, Qt::MiterJoin);
+                            (int)req_("LINE_THICKNESS"),
+                            (const char*)req_("LINE_COLOUR"),
+                            Qt::SquareCap, Qt::MiterJoin);
     }
 
     // Set fill parameters
     req_.getValue("FILL", val);
     if (val == "OFF") {
         brush_ = QBrush(Qt::NoBrush);
-    } else {
+    }
+    else {
         brush_ = MvQ::makeBrush("SOLID",
                                 (const char*)req_("FILL_COLOUR"));
     }
@@ -259,25 +274,27 @@ bool MvQFeatureShapeItem::getRequestParameters()
     // size
     bool sizeChanged = false;
     if (keepAspectRatio_) {
-        req_.getValue("SIZE", val);
+        req_.getValue("WIDTH", val);
         int iv = 0;
         try {
             iv = std::stoi(val);
-        } catch (...) {
+        }
+        catch (...) {
             iv = 0;
         }
         if (iv > 0 && iv != width_) {
             sizeChanged = true;
-            width_ =iv;
-            height_ = iv;
+            width_      = iv;
+            height_     = iv;
         }
-    } else {
+    }
+    else {
         int iw = (int)req_("WIDTH");
         int ih = (int)req_("HEIGHT");
         if (iw > 0 && ih > 0 && (iw != width_ || ih != height_)) {
             sizeChanged = true;
-            width_ = iw;
-            height_ = ih;
+            width_      = iw;
+            height_     = ih;
         }
     }
 
@@ -290,7 +307,6 @@ bool MvQFeatureShapeItem::getRequestParameters()
     return true;
 }
 
-
 QString MvQFeatureShapeItem::describe() const
 {
     QString txt = MvQFeatureItem::describe();
@@ -300,38 +316,33 @@ QString MvQFeatureShapeItem::describe() const
     return txt + ds.text();
 }
 
+// this makes sure the geometry is properly initialised
+void MvQFeatureShapeItem::initGeometry()
+{
+    if (bRect_.isNull() || itemRect_.isNull()) {
+        updateRect();
+        adjustBRect();
+    }
+
+    if (shape_.isEmpty() && shapePath_.isEmpty()) {
+        buildShape();
+    }
+}
+
 //========================================
 //
 // MvQFeatureRectItem
 //
 //========================================
 
-MvQFeatureRectItem::MvQFeatureRectItem(MvQFeatureType* feature, MvQPlotView* view) :
-     MvQFeatureShapeItem(feature, view)
-{
-    req_ = MvRequest("FEATURESHAPE");
-    initStyle();
-}
-
-MvQFeatureRectItem::MvQFeatureRectItem(const MvQFeatureRectItem& o) :
-     MvQFeatureShapeItem(o)
-{
-}
-
-MvQFeatureItem* MvQFeatureRectItem::clone() const
-{
-    return new MvQFeatureRectItem(*this);
-}
-
 // Note: we have to use a QPainterPath for the painting. If we simply use a polygon in
 // Qt 6.2 a rectangle shape is not filled correctly.
 void MvQFeatureRectItem::buildShape()
 {
-    auto w = width_/2.;
-    auto h = height_/2;
+    auto w = width_ / 2.;
+    auto h = height_ / 2;
     QPolygonF p;
-    p << QPointF(-w, -h) << QPointF(w, -h) <<
-         QPointF(w, h) << QPointF(-w, h);
+    p << QPointF(-w, -h) << QPointF(w, -h) << QPointF(w, h) << QPointF(-w, h);
 
     shapePath_ = QPainterPath();
     shapePath_.addPolygon(p);
@@ -344,29 +355,11 @@ void MvQFeatureRectItem::buildShape()
 //
 //========================================
 
-MvQFeatureTriangleItem::MvQFeatureTriangleItem(MvQFeatureType* feature, MvQPlotView* view) :
-     MvQFeatureShapeItem(feature, view)
-{
-    req_ = MvRequest("FEATURESHAPE");
-    initStyle();
-}
-
-MvQFeatureTriangleItem::MvQFeatureTriangleItem(
-                                         const MvQFeatureTriangleItem& o) :
-     MvQFeatureShapeItem(o)
-{
-}
-
-MvQFeatureItem* MvQFeatureTriangleItem::clone() const
-{
-    return new MvQFeatureTriangleItem(*this);
-}
-
 void MvQFeatureTriangleItem::buildShape()
 {
     shape_.clear();
-    auto w = width_/2.;
-    auto h = height_/2;
+    auto w = width_ / 2.;
+    auto h = height_ / 2;
     shape_ << QPointF(-w, h) << QPointF(w, h) << QPointF(0., -h);
 }
 
@@ -376,30 +369,12 @@ void MvQFeatureTriangleItem::buildShape()
 //
 //========================================
 
-MvQFeatureDiamondItem::MvQFeatureDiamondItem(MvQFeatureType* feature, MvQPlotView* view) :
-     MvQFeatureShapeItem(feature, view)
-{
-    req_ = MvRequest("FEATURESHAPE");
-    initStyle();
-}
-
-MvQFeatureDiamondItem::MvQFeatureDiamondItem(const MvQFeatureDiamondItem& o) :
-     MvQFeatureShapeItem(o)
-{
-}
-
-MvQFeatureItem* MvQFeatureDiamondItem::clone() const
-{
-    return new MvQFeatureDiamondItem(*this);
-}
-
 void MvQFeatureDiamondItem::buildShape()
 {
     shape_.clear();
-    auto w = width_/2.;
-    auto h = height_/2;
-    shape_ << QPointF(-w, 0.) << QPointF(0., -h) << QPointF(w, 0.) <<
-                  QPointF(0., h);
+    auto w = width_ / 2.;
+    auto h = height_ / 2;
+    shape_ << QPointF(-w, 0.) << QPointF(0., -h) << QPointF(w, 0.) << QPointF(0., h);
 }
 
 //========================================
@@ -408,36 +383,24 @@ void MvQFeatureDiamondItem::buildShape()
 //
 //========================================
 
-MvQFeatureStarItem::MvQFeatureStarItem(MvQFeatureType* feature, MvQPlotView* view) :
-     MvQFeatureShapeItem(feature, view)
+MvQFeatureStarItem::MvQFeatureStarItem(WsType* feature) :
+    MvQFeatureShapeItem(feature)
 {
     keepAspectRatio_ = true;
-    req_ = MvRequest("FEATURESHAPEKEEPASPECT");
-    initStyle();
-}
-
-MvQFeatureStarItem::MvQFeatureStarItem(const MvQFeatureStarItem& o) :
-     MvQFeatureShapeItem(o)
-{
-}
-
-MvQFeatureItem* MvQFeatureStarItem::clone() const
-{
-    return new MvQFeatureStarItem(*this);
 }
 
 void MvQFeatureStarItem::buildShape()
 {
     shape_.clear();
 
-    auto outerRadius = height_/(1. + cos(MvSci::degToRad(36)));
-    QPointF cp(0, outerRadius -height_/2);
-    auto innerRadius = outerRadius/2.;
+    auto outerRadius = height_ / (1. + cos(MvSci::degToRad(36)));
+    QPointF cp(0, outerRadius - height_ / 2);
+    auto innerRadius = outerRadius / 2.;
     for (int i = 0; i < 5; i++) {
-        float outer = 2. * i* M_PI/5. +  M_PI/2.;
-        float inner = outer + M_PI/5.;
-        shape_ << cp + QPointF(outerRadius * cos(outer), -outerRadius*sin(outer));
-        shape_ << cp + QPointF(innerRadius * cos(inner), -innerRadius*sin(inner));
+        float outer = 2. * i * M_PI / 5. + M_PI / 2.;
+        float inner = outer + M_PI / 5.;
+        shape_ << cp + QPointF(outerRadius * cos(outer), -outerRadius * sin(outer));
+        shape_ << cp + QPointF(innerRadius * cos(inner), -innerRadius * sin(inner));
     }
 }
 
@@ -447,23 +410,6 @@ void MvQFeatureStarItem::buildShape()
 //
 //========================================
 
-MvQFeatureEllipseItem::MvQFeatureEllipseItem(MvQFeatureType* feature, MvQPlotView* view) :
-     MvQFeatureShapeItem(feature, view)
-{
-    req_ = MvRequest("FEATURESHAPE");
-    initStyle();
-}
-
-MvQFeatureEllipseItem::MvQFeatureEllipseItem(const MvQFeatureEllipseItem& o) :
-     MvQFeatureShapeItem(o)
-{
-}
-
-MvQFeatureItem* MvQFeatureEllipseItem::clone() const
-{
-    return new MvQFeatureEllipseItem(*this);
-}
-
 void MvQFeatureEllipseItem::buildShape()
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
@@ -471,7 +417,7 @@ void MvQFeatureEllipseItem::buildShape()
 #else
     shapePath_ = QPainterPath();
 #endif
-    shapePath_.addEllipse(QRectF(-width_/2., -height_/2., width_, height_));
+    shapePath_.addEllipse(QRectF(-width_ / 2., -height_ / 2., width_, height_));
 }
 
 //========================================
@@ -480,30 +426,23 @@ void MvQFeatureEllipseItem::buildShape()
 //
 //========================================
 
-MvQFeaturePlacemarkerItem::MvQFeaturePlacemarkerItem(MvQFeatureType* feature, MvQPlotView* view) :
-     MvQFeatureShapeItem(feature, view)
+MvQFeaturePlacemarkerItem::MvQFeaturePlacemarkerItem(WsType* feature) :
+    MvQFeatureShapeItem(feature)
 {
-    anchorPos_ = BottomCentreAnchor;
+    anchorPos_       = BottomCentreAnchor;
     keepAspectRatio_ = true;
-    width_ = 25;
-    height_ = 25;
-    req_ = MvRequest("FEATUREPLACEMARK");
-    initStyle();
+    width_           = 25;
+    height_          = 25;
 }
 
-MvQFeaturePlacemarkerItem::MvQFeaturePlacemarkerItem(
-                                         const MvQFeaturePlacemarkerItem& o) :
-     MvQFeatureShapeItem(o)
-{
-    fillHole_ = o.fillHole_;
-    holeBrush_ = o.holeBrush_;
-    holePath_ = o.holePath_;
-}
-
-MvQFeatureItem* MvQFeaturePlacemarkerItem::clone() const
-{
-    return new MvQFeaturePlacemarkerItem(*this);
-}
+//MvQFeaturePlacemarkerItem::MvQFeaturePlacemarkerItem(
+//                                         const MvQFeaturePlacemarkerItem& o) :
+//     MvQFeatureShapeItem(o)
+//{
+//    fillHole_ = o.fillHole_;
+//    holeBrush_ = o.holeBrush_;
+//    holePath_ = o.holePath_;
+//}
 
 void MvQFeaturePlacemarkerItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
@@ -542,31 +481,32 @@ void MvQFeaturePlacemarkerItem::paint(QPainter* painter, const QStyleOptionGraph
 void MvQFeaturePlacemarkerItem::buildShape()
 {
     shapePath_ = QPainterPath();
-    holePath_ = QPainterPath();
+    holePath_  = QPainterPath();
 
     // the origo is at the bottom-centre of the itemRect_!
 
     // Build an arc (bigger than a semi-circle)
-    auto radius = 0.6*height_;
-    QRectF rect(-radius/2.,-height_/2.-radius/2.,radius,radius);
-    rect.moveTopLeft(QPointF(-radius/2.,-height_));
+    auto radius = 0.6 * height_;
+    QRectF rect(-radius / 2., -height_ / 2. - radius / 2., radius, radius);
+    rect.moveTopLeft(QPointF(-radius / 2., -height_));
     shapePath_.arcTo(rect, 330., 240.);
 
     // Initial point is (0,0), replace it with the arc's initial point
     QPointF p1 = shapePath_.elementAt(1);
-    shapePath_.setElementPositionAt(0,p1.x(),p1.y());
+    shapePath_.setElementPositionAt(0, p1.x(), p1.y());
 
     // Build bottom part of the placemarker
     shapePath_.lineTo(0., 0);
     shapePath_.closeSubpath();
 
     // Build the inner circle
-    auto innerRadius = radius/4.;
-    auto c = rect.center();
-    auto innerRect = QRectF(c.x() - innerRadius, c.y()-innerRadius, 2*innerRadius, 2*innerRadius);
+    auto innerRadius = radius / 4.;
+    auto c           = rect.center();
+    auto innerRect   = QRectF(c.x() - innerRadius, c.y() - innerRadius, 2 * innerRadius, 2 * innerRadius);
     if (fillHole_) {
         holePath_.addEllipse(innerRect);
-    } else {
+    }
+    else {
         shapePath_.addEllipse(innerRect);
     }
 }
@@ -576,7 +516,7 @@ bool MvQFeaturePlacemarkerItem::getRequestParameters()
     if (!req_)
         return false;
 
-    req_ = ObjectList::ExpandRequest(req_, EXPAND_DEFAULTS);
+    expandStyleRequest();
 
     std::string val;
 
@@ -584,18 +524,20 @@ bool MvQFeaturePlacemarkerItem::getRequestParameters()
     req_.getValue("LINE", val);
     if (val == "OFF") {
         pen_ = QPen(Qt::NoPen);
-    } else {
+    }
+    else {
         pen_ = MvQ::makePen((const char*)req_("LINE_STYLE"),
-                              (int)req_("LINE_THICKNESS"),
-                              (const char*)req_("LINE_COLOUR"),
-                              Qt::SquareCap, Qt::MiterJoin);
+                            (int)req_("LINE_THICKNESS"),
+                            (const char*)req_("LINE_COLOUR"),
+                            Qt::SquareCap, Qt::MiterJoin);
     }
 
     // Set fill parameters
     req_.getValue("FILL", val);
     if (val == "OFF") {
         brush_ = QBrush(Qt::NoBrush);
-    } else {
+    }
+    else {
         brush_ = MvQ::makeBrush("SOLID",
                                 (const char*)req_("FILL_COLOUR"));
     }
@@ -603,26 +545,28 @@ bool MvQFeaturePlacemarkerItem::getRequestParameters()
     req_.getValue("INNER_FILL", val);
     if (val == "" || val == "OFF") {
         holeBrush_ = QBrush(Qt::NoBrush);
-        fillHole_ = false;
-    } else {
+        fillHole_  = false;
+    }
+    else {
         holeBrush_ = MvQ::makeBrush("SOLID",
-                       (const char*)req_("INNER_FILL_COLOUR"));
-        fillHole_ = true;
+                                    (const char*)req_("INNER_FILL_COLOUR"));
+        fillHole_  = true;
     }
 
     // size
     bool sizeChanged = false;
-    req_.getValue("SIZE", val);
+    req_.getValue("WIDTH", val);
     int iv = 0;
     try {
         iv = std::stoi(val);
-    } catch (...) {
+    }
+    catch (...) {
         iv = 0;
     }
     if (iv > 0 && iv != width_) {
         sizeChanged = true;
-        width_ =iv;
-        height_ = iv;
+        width_      = iv;
+        height_     = iv;
     }
 
     buildShape();
@@ -641,19 +585,49 @@ bool MvQFeaturePlacemarkerItem::getRequestParameters()
 //
 //========================================
 
-MvQFeatureGeoShapeItem::MvQFeatureGeoShapeItem(MvQFeatureType* feature, MvQPlotView* view, QGraphicsItem* parent) :
-    MvQFeatureItem(feature, view, parent)
+MvQFeatureGeoShapeItem::MvQFeatureGeoShapeItem(WsType* feature) :
+    MvQFeatureItem(feature)
 {
-    req_ = MvRequest("FEATUREPOLYGON");
-    initStyle();
+    // NOTE: do not implement initGeometry! Since the shape is
+    // based on the projection we do it by calling reproject.
+    // What important here is that the object should have a meaningful
+    // initial width and height.
 }
 
-MvQFeatureGeoShapeItem::MvQFeatureGeoShapeItem(const MvQFeatureGeoShapeItem& o) :
-     MvQFeatureItem(o)
+void MvQFeatureGeoShapeItem::init(const QJsonObject& obj)
 {
-    width_ = o.width_;
-    height_ = o.height_;
-    initStyle();
+    // coord and size must be extracted before the base-class
+    // implementation is called
+    QJsonObject g = obj["geometry"].toObject();
+    auto gcLst    = MvQJson::toPointFList(g["coordinates"].toArray(), g["type"].toString());
+    if (!gcLst.isEmpty()) {
+        geoCoord_         = gcLst[0];
+        hasValidGeoCoord_ = isValidPoint(geoCoord_);
+    }
+
+    QJsonObject p = obj["properties"].toObject();
+    auto w        = p["width"].toInt();
+    auto h        = p["height"].toInt();
+    if (w > 0 && w < 5000 && h > 0 && h < 5000) {
+        width_  = w;
+        height_ = h;
+    }
+    MvQFeatureItem::init(obj);
+}
+
+void MvQFeatureGeoShapeItem::toJson(QJsonObject& obj)
+{
+    MvQFeatureItem::toJson(obj);
+
+    //    QJsonObject g;
+    //    g["type"] = "Polygon";
+    //    g["coordinates"] = MvQJson::fromPointF(geoCoord());
+    //    obj["geometry"] = g;
+
+    QJsonObject p     = obj["properties"].toObject();
+    p["width"]        = width_;
+    p["height"]       = height_;
+    obj["properties"] = p;
 }
 
 // Note: we have to use a QPainterPath for the painting. If we simply use a polygon in
@@ -676,7 +650,7 @@ void MvQFeatureGeoShapeItem::paint(QPainter* painter, const QStyleOptionGraphics
         painter->setPen(pen);
         painter->setBrush(Qt::NoBrush);
         painter->drawPath(shapePath_);
-      }
+    }
 #endif
     painter->restore();
 }
@@ -692,12 +666,12 @@ void MvQFeatureGeoShapeItem::resize(QRectF targetRectInParent)
     // reduce the targetRect with the halo. We want to fit the itemRect into it!!!
     targetRect.adjust(halo(), halo(), -halo(), -halo());
 
-    auto w = targetRect.width();
-    auto h = targetRect.height();
-    itemRect_ = QRectF(-w/2., -h/2., w, h);
-    bRect_ = itemRect_;
-    width_ = itemRect_.width();
-    height_ = itemRect_.height();
+    auto w    = targetRect.width();
+    auto h    = targetRect.height();
+    itemRect_ = QRectF(-w / 2., -h / 2., w, h);
+    bRect_    = itemRect_;
+    width_    = itemRect_.width();
+    height_   = itemRect_.height();
     setPos(targetRectInParent.center());
     adjustBRect();
     adjustGeoCoord();
@@ -709,9 +683,9 @@ void MvQFeatureGeoShapeItem::resizeTo(const MvQFeatureGeometry& geom)
     prepareGeometryChange();
     setPos(geom.pos_);
     itemRect_ = geom.itemRect_;
-    bRect_ = itemRect_;
-    width_ = itemRect_.width();
-    height_ = itemRect_.height();
+    bRect_    = itemRect_;
+    width_    = itemRect_.width();
+    height_   = itemRect_.height();
     adjustBRect();
     adjustGeoCoord();
     buildShape();
@@ -759,15 +733,20 @@ void MvQFeatureGeoShapeItem::initAtGeoCoord(QPointF co)
 }
 
 // Recompute the position of the item using the current geoCoord
-void MvQFeatureGeoShapeItem::reproject()
+void MvQFeatureGeoShapeItem::reproject(bool init)
 {
     if (dataLayout_) {
         QPointF scPos;
         dataLayout_->mapFromGeoToSceneCoords(geoCoord_, scPos);
         setPos(parentItem()->mapFromScene(scPos));
-        reprojectShape();
         // qDebug() << "REPROJECT -> pos:" << pos() << "gc:" << geoCoord_;
-        adjustShape();
+        if (init) {
+            buildShape();
+        }
+        else {
+            reprojectShape();
+            adjustShape();
+        }
         // qDebug() << " geoCoords" << geoCoords_;
         updateRect();
         adjustBRect();
@@ -776,19 +755,19 @@ void MvQFeatureGeoShapeItem::reproject()
 
 void MvQFeatureGeoShapeItem::updateRect()
 {
-    prepareGeometryChange(); 
+    prepareGeometryChange();
     itemRect_ = shapeBoundingRect();
-    width_ = itemRect_.width();
-    height_ = itemRect_.height();
-    bRect_ = itemRect_;
+    width_    = itemRect_.width();
+    height_   = itemRect_.height();
+    bRect_    = itemRect_;
 }
 
 void MvQFeatureGeoShapeItem::adjustBRect()
 {
-   if (fabs(halo() > 1E-5)) {
-       prepareGeometryChange();
-       bRect_ = itemRect_.adjusted(-halo(), -halo(), halo(), halo());
-   }
+    if (fabs(halo() > 1E-5)) {
+        prepareGeometryChange();
+        bRect_ = itemRect_.adjusted(-halo(), -halo(), halo(), halo());
+    }
 }
 
 QRectF MvQFeatureGeoShapeItem::shapeBoundingRect()
@@ -799,7 +778,7 @@ QRectF MvQFeatureGeoShapeItem::shapeBoundingRect()
 double MvQFeatureGeoShapeItem::halo() const
 {
     auto w = pen_.width();
-    return (w <=1)?0:1+w/2;
+    return (w <= 1) ? 0 : 1 + w / 2;
 }
 
 bool MvQFeatureGeoShapeItem::getRequestParameters()
@@ -807,7 +786,7 @@ bool MvQFeatureGeoShapeItem::getRequestParameters()
     if (!req_)
         return false;
 
-    req_ = ObjectList::ExpandRequest(req_, EXPAND_DEFAULTS);
+    expandStyleRequest();
 
     std::string val;
 
@@ -815,18 +794,20 @@ bool MvQFeatureGeoShapeItem::getRequestParameters()
     req_.getValue("LINE", val);
     if (val == "OFF") {
         pen_ = QPen(Qt::NoPen);
-    } else {
+    }
+    else {
         pen_ = MvQ::makePen((const char*)req_("LINE_STYLE"),
-                              (int)req_("LINE_THICKNESS"),
-                              (const char*)req_("LINE_COLOUR"),
-                              Qt::SquareCap, Qt::MiterJoin);
+                            (int)req_("LINE_THICKNESS"),
+                            (const char*)req_("LINE_COLOUR"),
+                            Qt::SquareCap, Qt::MiterJoin);
     }
 
     // Set fill parameters
     req_.getValue("FILL", val);
     if (val == "OFF") {
         brush_ = QBrush(Qt::NoBrush);
-    } else {
+    }
+    else {
         brush_ = MvQ::makeBrush("SOLID",
                                 (const char*)req_("FILL_COLOUR"));
     }
@@ -848,21 +829,16 @@ QString MvQFeatureGeoShapeItem::describe() const
 //
 //========================================
 
-MvQFeatureGeoRectItem::MvQFeatureGeoRectItem(const MvQFeatureGeoRectItem& o) :
-     MvQFeatureGeoShapeItem(o)
+MvQFeatureGeoRectItem::MvQFeatureGeoRectItem(WsType* feature) :
+    MvQFeatureGeoShapeItem(feature)
 {
 }
 
-MvQFeatureItem* MvQFeatureGeoRectItem::clone() const
-{
-    return new MvQFeatureGeoRectItem(*this);
-}
-
-void  MvQFeatureGeoRectItem::reprojectShape()
+void MvQFeatureGeoRectItem::reprojectShape()
 {
     shape_.clear();
     shapePath_ = QPainterPath();
-    for (auto p: geoCoords_) {
+    for (auto p : geoCoords_) {
         QPointF scPos;
         dataLayout_->mapFromGeoToSceneCoords(p, scPos);
         shape_ << mapFromScene(scPos);
@@ -871,7 +847,7 @@ void  MvQFeatureGeoRectItem::reprojectShape()
     }
 
     if (shape_.size() == 4) {
-        width_ = fabs(shape_[1].x() - shape_[0].x());
+        width_  = fabs(shape_[1].x() - shape_[0].x());
         height_ = fabs(shape_[3].y() - shape_[0].y());
     }
 }
@@ -882,10 +858,9 @@ void MvQFeatureGeoRectItem::buildShape()
     shapePath_ = QPainterPath();
     geoCoords_.clear();
     if (dataLayout_) {
-        auto w = width_/2.;
-        auto h = height_/2;
-        shape_ << QPointF(-w, -h) << QPointF(w, -h) <<
-             QPointF(w, h) << QPointF(-w, h);
+        auto w = width_ / 2.;
+        auto h = height_ / 2;
+        shape_ << QPointF(-w, -h) << QPointF(w, -h) << QPointF(w, h) << QPointF(-w, h);
 
         shapePath_.addPolygon(shape_);
         shapePath_.closeSubpath();
@@ -898,17 +873,17 @@ void MvQFeatureGeoRectItem::adjustShape()
     if (shape_.size() == 4) {
         double eps = 1E-6;
         if ((fabs(shape_[0].y() - shape_[1].y()) > eps) ||
-           (fabs(shape_[2].y() - shape_[3].y()) > eps) ||
-           (fabs(shape_[0].x() - shape_[3].x()) > eps) ||
-           (fabs(shape_[1].x() - shape_[2].x()) > eps)) {
+            (fabs(shape_[2].y() - shape_[3].y()) > eps) ||
+            (fabs(shape_[0].x() - shape_[3].x()) > eps) ||
+            (fabs(shape_[1].x() - shape_[2].x()) > eps)) {
             buildShape();
-       }
+        }
     }
 }
 
 void MvQFeatureGeoRectItem::updateGeoCoordsFromShape()
 {
-    for (auto sp: shape_) {
+    for (auto sp : shape_) {
         QPointF pp = mapToScene(sp);
         QPointF co;
         dataLayout_->mapFromSceneToGeoCoords(pp, co);
@@ -923,4 +898,4 @@ static MvQFeatureMaker<MvQFeatureTriangleItem> triangleMaker("triangle");
 static MvQFeatureMaker<MvQFeatureDiamondItem> diamondMaker("diamond");
 static MvQFeatureMaker<MvQFeatureStarItem> starMaker("star");
 static MvQFeatureMaker<MvQFeatureEllipseItem> ellipseMaker("ellipse");
-static MvQFeatureMaker<MvQFeaturePlacemarkerItem> placemarkerMaker("placemarker");
+static MvQFeatureMaker<MvQFeaturePlacemarkerItem> placemarMaker("placemark");
