@@ -24,15 +24,16 @@
 #include <QStyle>
 #include <QVBoxLayout>
 
+#include "MvQJson.h"
 #include "MvQPlotView.h"
 #include "MvQFeatureFactory.h"
 #include "MvQFeatureCommand.h"
-#include "MvQFeatureType.h"
 #include "MvQMethods.h"
 #include "MvQPalette.h"
 #include "MvQPanel.h"
 #include "MgQLayoutItem.h"
 #include "ObjectList.h"
+#include "WsDecoder.h"
 
 #include <assert.h>
 
@@ -44,17 +45,15 @@
 //
 //================================================================
 
-MvQFeatureTextEditor::MvQFeatureTextEditor(MvQFeatureTextItem* item, QGraphicsItem* parent) :
+MvQFeatureTextEditor::MvQFeatureTextEditor(MvQFeatureTextItemPtr item, QGraphicsItem* parent) :
     QGraphicsProxyWidget(parent),
     item_(item)
 {
     Q_ASSERT(item_);
 
-    featureHandler_ = item_->plotView()->featureHandler();
-
     holderW_ = new MvQPanel();
-    auto vb =  new QVBoxLayout(holderW_);
-    vb->setContentsMargins(5,5,5,5);
+    auto vb  = new QVBoxLayout(holderW_);
+    vb->setContentsMargins(5, 5, 5, 5);
 
     QString sh = "QWidget {background-color: transparent;}";
     holderW_->setStyleSheet(sh);
@@ -77,14 +76,14 @@ MvQFeatureTextEditor::MvQFeatureTextEditor(MvQFeatureTextItem* item, QGraphicsIt
     tr.scale(1, -1);
     setTransform(tr);
 
-//    setAcceptHoverEvents(true);
+    //    setAcceptHoverEvents(true);
 
     connect(editor_, SIGNAL(textChanged()),
             this, SLOT(textChanged()));
 
     item_->textEditStarted(this);
 
-//    holderW_->setCursor(QCursor(Qt::SizeAllCursor));
+    //    holderW_->setCursor(QCursor(Qt::SizeAllCursor));
 }
 
 void MvQFeatureTextEditor::paint(QPainter* painter, const QStyleOptionGraphicsItem* o, QWidget* w)
@@ -97,63 +96,63 @@ void MvQFeatureTextEditor::paint(QPainter* painter, const QStyleOptionGraphicsIt
     painter->save();
 
     // fill frame
-    auto fr = r.adjusted(0,0,0,-(r.height()-frame_));
+    auto fr = r.adjusted(0, 0, 0, -(r.height() - frame_));
     painter->fillRect(fr, frameBrush_);
 
-    fr = r.adjusted(0,0,-(r.width()-frame_),0);
+    fr = r.adjusted(0, 0, -(r.width() - frame_), 0);
     painter->fillRect(fr, frameBrush_);
 
-    fr = r.adjusted(0, r.height()-frame_,0,0);
-    painter->fillRect(fr,  frameBrush_);
+    fr = r.adjusted(0, r.height() - frame_, 0, 0);
+    painter->fillRect(fr, frameBrush_);
 
-    fr = r.adjusted(r.width()-frame_,0,0,0);
-    painter->fillRect(fr,  frameBrush_);
+    fr = r.adjusted(r.width() - frame_, 0, 0, 0);
+    painter->fillRect(fr, frameBrush_);
 
     // borders
     painter->setPen(outerPen_);
     painter->drawRect(r);
     painter->setPen(innerPen_);
-    painter->drawRect(r.adjusted(frame_,frame_,-frame_,-frame_));
+    painter->drawRect(r.adjusted(frame_, frame_, -frame_, -frame_));
 
     // corners
     painter->setRenderHint(QPainter::Antialiasing, true);
     painter->setPen(cornerPen_);
-    MvQ::safeDrawLine(r.topLeft(), r.topLeft()+QPointF(frame_,frame_),painter);
-    MvQ::safeDrawLine(r.topRight(), r.topRight()+QPointF(-frame_,frame_),painter);
-    MvQ::safeDrawLine(r.bottomRight(), r.bottomRight()+QPointF(-frame_,-frame_),painter);
-    MvQ::safeDrawLine(r.bottomLeft(), r.bottomLeft()+QPointF(frame_,-frame_),painter);
+    MvQ::safeDrawLine(r.topLeft(), r.topLeft() + QPointF(frame_, frame_), painter);
+    MvQ::safeDrawLine(r.topRight(), r.topRight() + QPointF(-frame_, frame_), painter);
+    MvQ::safeDrawLine(r.bottomRight(), r.bottomRight() + QPointF(-frame_, -frame_), painter);
+    MvQ::safeDrawLine(r.bottomLeft(), r.bottomLeft() + QPointF(frame_, -frame_), painter);
     painter->setRenderHint(QPainter::Antialiasing, false);
 
     // border inner shadow
     painter->setPen(shadowPen_);
-    MvQ::safeDrawLine(QPointF(r.x()+frame_, r.y()+frame_),
-                      QPointF(r.x()+frame_, r.y() + r.height() - frame_), painter);
-    MvQ::safeDrawLine(QPointF(r.x()+frame_, r.y() + frame_),
-                      QPointF(r.x()+r.width()-frame_, r.y() + frame_), painter);
+    MvQ::safeDrawLine(QPointF(r.x() + frame_, r.y() + frame_),
+                      QPointF(r.x() + frame_, r.y() + r.height() - frame_), painter);
+    MvQ::safeDrawLine(QPointF(r.x() + frame_, r.y() + frame_),
+                      QPointF(r.x() + r.width() - frame_, r.y() + frame_), painter);
 
     // border outer shadow
     painter->setPen(shadowPen_);
-    MvQ::safeDrawLine(QPointF(r.x()+r.width()-1, r.y()),
-                      QPointF(r.x()+r.width()-1, r.y() + r.height()), painter);
-    MvQ::safeDrawLine(QPointF(r.x(), r.y()+r.height()-1),
-                      QPointF(r.x()+r.width(), r.y()+r.height()-1), painter);
+    MvQ::safeDrawLine(QPointF(r.x() + r.width() - 1, r.y()),
+                      QPointF(r.x() + r.width() - 1, r.y() + r.height()), painter);
+    MvQ::safeDrawLine(QPointF(r.x(), r.y() + r.height() - 1),
+                      QPointF(r.x() + r.width(), r.y() + r.height() - 1), painter);
 
     painter->restore();
 }
 
-QTextEdit* MvQFeatureTextEditor::editor()
+QTextEdit* MvQFeatureTextEditor::editor() const
 {
     return editor_;
 }
 
-MvQFeatureTextItem* MvQFeatureTextEditor::item()
+MvQFeatureTextItemPtr MvQFeatureTextEditor::item() const
 {
     return item_;
 }
 
 void MvQFeatureTextEditor::initPos()
 {
-    if(item_) {
+    if (item_) {
         QPointF scPos = item_->parentItem()->mapToScene(item_->textPos());
         setPos(scPos + QPointF(-frame_, frame_));
     }
@@ -167,15 +166,15 @@ void MvQFeatureTextEditor::textChanged()
         item_->setTextFromEditor(text);
     }
     QSize eSize = item_->itemRect().size().toSize();
-    auto wSize = eSize + QSize(2*frame_,2*frame_);
+    auto wSize  = eSize + QSize(2 * frame_, 2 * frame_);
 
     holderW_->resize(wSize);
-    holderW_->setMaximumWidth(wSize.width()+1);
-    holderW_->setMaximumHeight(wSize.height()+1);
+    holderW_->setMaximumWidth(wSize.width() + 1);
+    holderW_->setMaximumHeight(wSize.height() + 1);
 
     editor_->resize(eSize);
-    editor_->setMaximumWidth(eSize.width()+1);
-    editor_->setMaximumHeight(eSize.height()+1);
+    editor_->setMaximumWidth(eSize.width() + 1);
+    editor_->setMaximumHeight(eSize.height() + 1);
 }
 
 void MvQFeatureTextEditor::finish()
@@ -191,17 +190,18 @@ void MvQFeatureTextEditor::updateFromItem()
         auto bgCol = item_->boxBrush().color();
         if (bgCol.alpha() != 255) {
             colStr = "rgba(" + QString::number(bgCol.red()) + "," +
-                    QString::number(bgCol.green()) + "," +
-                    QString::number(bgCol.blue()) + "," +
-                    QString::number(bgCol.alpha()) + ")";
-        } else {
+                     QString::number(bgCol.green()) + "," +
+                     QString::number(bgCol.blue()) + "," +
+                     QString::number(bgCol.alpha()) + ")";
+        }
+        else {
             colStr = bgCol.name();
         }
     }
 
     QString sh = "QTextEdit {color: " + item_->fontPen().color().name() +
-        "; background-color: " + colStr +
-        "; border: none;}";
+                 "; background-color: " + colStr +
+                 "; border: none;}";
 
     editor_->setStyleSheet(sh);
     editor_->setFont(item_->font());
@@ -209,23 +209,23 @@ void MvQFeatureTextEditor::updateFromItem()
     adjustAlignment();
 
     QSize eSize = item_->itemRect().size().toSize();
-    auto wSize = eSize + QSize(2*frame_,2*frame_);
-    holderW_->setMaximumWidth(wSize.width()+1);
-    holderW_->setMaximumHeight(wSize.height()+1);
-    editor_->setMaximumWidth(eSize.width()+1);
-    editor_->setMaximumHeight(eSize.height()+1);
+    auto wSize  = eSize + QSize(2 * frame_, 2 * frame_);
+    holderW_->setMaximumWidth(wSize.width() + 1);
+    holderW_->setMaximumHeight(wSize.height() + 1);
+    editor_->setMaximumWidth(eSize.width() + 1);
+    editor_->setMaximumHeight(eSize.height() + 1);
     doNotNotifyItem_ = false;
 }
 
 void MvQFeatureTextEditor::adjustAlignment()
 {
-    auto tc = editor_->textCursor();
+    auto tc    = editor_->textCursor();
     auto oriTc = tc;
     tc.movePosition(QTextCursor::Start);
     editor_->setTextCursor(tc);
     editor_->setAlignment(item_->alignment());
     //qDebug() << "block=" << tc.blockNumber() << tc.block().text();
-    while(tc.movePosition(QTextCursor::NextBlock, QTextCursor::MoveAnchor)) {
+    while (tc.movePosition(QTextCursor::NextBlock, QTextCursor::MoveAnchor)) {
         editor_->setTextCursor(tc);
         editor_->setAlignment(item_->alignment());
         //qDebug() << "block=" << tc.blockNumber() << tc.block().text();
@@ -235,17 +235,17 @@ void MvQFeatureTextEditor::adjustAlignment()
 
 void MvQFeatureTextEditor::itemChanged()
 {
-    doNotNotifyItem_=true;
+    doNotNotifyItem_ = true;
     updateFromItem();
-    doNotNotifyItem_=false;
+    doNotNotifyItem_ = false;
 }
 
 void MvQFeatureTextEditor::itemTextChanged()
 {
     if (item_->text() != editor_->toPlainText()) {
-        doNotNotifyItem_=true;
+        doNotNotifyItem_ = true;
         updateFromItem();
-        doNotNotifyItem_=false;
+        doNotNotifyItem_ = false;
     }
 }
 
@@ -255,20 +255,20 @@ void MvQFeatureTextEditor::adjustCursorToMouseLeave(QMouseEvent* viewEvent)
     if (dragCursor_ && !containsScenePos(item_->plotView()->mapToScene(viewEvent->pos()))) {
         dragCursor_ = false;
         qDebug() << "ADJUST CURSOR";
-        featureHandler_->resetCursor();
+        MvQFeatureHandler::Instance()->resetCursor();
     }
 }
 
 bool MvQFeatureTextEditor::containsScenePos(const QPointF& scenePos) const
 {
-     return contains(mapFromScene(scenePos));
+    return contains(mapFromScene(scenePos));
 }
 
 bool MvQFeatureTextEditor::canBeDraggedAt(const QPointF& scPos) const
 {
-    if (!item_->plotView()->hasFeatureTypeToAdd()) {
+    if (!item_->plotView()->inFeatureAddMode()) {
         auto p = mapFromScene(scPos);
-        return !boundingRect().adjusted(frame_+1, frame_+1, -frame_-1, -frame_-1).contains(p);
+        return !boundingRect().adjusted(frame_ + 1, frame_ + 1, -frame_ - 1, -frame_ - 1).contains(p);
     }
     return false;
 }
@@ -277,9 +277,9 @@ void MvQFeatureTextEditor::mousePressEvent(QGraphicsSceneMouseEvent* event)
 {
     // When we click on the frame the texteditor will be closed and
     // deleted and we start dragging the text item
-    if (featureHandler_->canAcceptMouseEvent()) {
+    if (MvQFeatureHandler::Instance()->canAcceptMouseEvent()) {
         if (canBeDraggedAt(event->scenePos())) {
-            featureHandler_->dragTextEditor(this);
+            MvQFeatureHandler::Instance()->dragTextEditor(this);
             return;
         }
     }
@@ -287,20 +287,21 @@ void MvQFeatureTextEditor::mousePressEvent(QGraphicsSceneMouseEvent* event)
 }
 
 // NOTE: hover events did not work on MacOS so we implemented the
-// cursor handling using the mouse events.
+// cursor handling by using mouse events.
 void MvQFeatureTextEditor::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
 {
-    // On MacOS the mouseMoveEventt is called even if the cursor is outside this
-    // widget! So we need to be sure it is inside to handle the cursor change
-    if (featureHandler_->canAcceptMouseEvent() && containsScenePos(event->scenePos())) {
+    // On MacOS mouseMoveEvent is called even if the cursor is outside this
+    // widget! So we need to be sure it is inside the widget to handle the cursor change
+    if (MvQFeatureHandler::Instance()->canAcceptMouseEvent() && containsScenePos(event->scenePos())) {
         if (canBeDraggedAt(event->scenePos())) {
             if (!dragCursor_) {
                 dragCursor_ = true;
-                featureHandler_->setDragCursor();
-             }
-        } else if (dragCursor_) {
+                MvQFeatureHandler::Instance()->setDragCursor();
+            }
+        }
+        else if (dragCursor_) {
             dragCursor_ = false;
-            featureHandler_->resetCursor();
+            MvQFeatureHandler::Instance()->resetCursor();
         }
     }
     QGraphicsProxyWidget::mouseMoveEvent(event);
@@ -312,36 +313,39 @@ void MvQFeatureTextEditor::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
 //
 //================================================================
 
-MvQFeatureTextItem::MvQFeatureTextItem(MvQFeatureType* feature, MvQPlotView* view, QGraphicsItem* parent) :
-    MvQFeatureItem(feature, view, parent)
+void MvQFeatureTextItem::init(const QJsonObject& obj)
 {
-    Q_ASSERT(feature_);
-    req_ = MvRequest("FEATURETEXT");
+    QJsonObject g = obj["geometry"].toObject();
+    auto gcLst    = MvQJson::toPointFList(g["coordinates"].toArray(), g["type"].toString());
+    if (!gcLst.isEmpty()) {
+        geoCoord_         = gcLst[0];
+        hasValidGeoCoord_ = isValidPoint(geoCoord_);
+    }
+    else {
+        hasValidGeoCoord_ = false;
+    }
 
-    initStyle();
+    double w, h;
+    WsDecoder::styleValue(obj, "WIDTH", w);
+    WsDecoder::styleValue(obj, "HEIGHT", h);
+    if (w > 0 && w < 10000 && h > 0 && h < 10000) {
+        textRect_ =  QRectF(0, 0, w, h);
+    }
+
+    MvQFeatureItem::init(obj);
 }
 
-MvQFeatureTextItem::~MvQFeatureTextItem()
+void MvQFeatureTextItem::toJson(QJsonObject& obj)
 {
+    MvQFeatureItem::toJson(obj);
+    WsDecoder::setStyleValue(obj, "WIDTH", textRect_.width());
+    WsDecoder::setStyleValue(obj, "HEIGHT", textRect_.height());
 }
 
-MvQFeatureTextItem::MvQFeatureTextItem(const MvQFeatureTextItem& o) :
-     MvQFeatureItem(o)
-{
-    // this will copy the text
-    initStyle();
-}
-
-MvQFeatureItem* MvQFeatureTextItem::clone() const
-{
-    return new MvQFeatureTextItem(*this);
-}
-
-
 void MvQFeatureTextItem::paint(QPainter* painter, const QStyleOptionGraphicsItem* /*o*/, QWidget* /*w*/)
 {
     if (!inTextEdit_) {
-        // we draw a rect as a path because line and recr rendering
+        // we draw a rect as a path because line and rect rendering
         // has a problem in Qt 6.2 on MacOS
         QPainterPath p;
         p.addRect(itemRect_);
@@ -372,11 +376,11 @@ void MvQFeatureTextItem::resize(QRectF targetRectInParent)
     prepareGeometryChange();
 
     // textRect_ is the at (0,0) !!!
-    auto w = targetRect.width();
-    auto h = targetRect.height();
+    auto w    = targetRect.width();
+    auto h    = targetRect.height();
     textRect_ = QRectF(0, 0, w, h);
     itemRect_ = textRect_.adjusted(-margin_, -margin_, margin_, margin_);
-    bRect_ = itemRect_;
+    bRect_    = itemRect_;
     setPos(targetRectInParent.bottomLeft() + QPointF(halo() + margin_, -halo() - margin_));
     adjustBRect();
 
@@ -392,8 +396,8 @@ void MvQFeatureTextItem::resizeTo(const MvQFeatureGeometry& geom)
     prepareGeometryChange();
     setPos(geom.pos_);
     itemRect_ = geom.itemRect_;
-    textRect_ = itemRect_.adjusted(margin_, margin_, -margin_, -margin_);;
-    bRect_ = itemRect_;
+    textRect_ = itemRect_.adjusted(margin_, margin_, -margin_, -margin_);
+    bRect_    = itemRect_;
     adjustBRect();
     adjustGeoCoord();
 }
@@ -416,9 +420,9 @@ void MvQFeatureTextItem::adjustBRect()
     }
 }
 
-void MvQFeatureTextItem::setStyle(const MvRequest& req)
+void MvQFeatureTextItem::setStyle(const MvRequest& req, bool init)
 {
-    if(req) {
+    if (req) {
         req_ = req;
     }
 
@@ -426,10 +430,18 @@ void MvQFeatureTextItem::setStyle(const MvRequest& req)
         return;
     }
     prepareGeometryChange();
-    adjustText();
+    adjustGeoLocked();
+
+    if (init && textRect_.isValid()) {
+        itemRect_ = textRect_.adjusted(-margin_, -margin_, margin_, margin_);
+        bRect_    = itemRect_;
+    }
+    else {
+        adjustText();
+    }
     adjustBRect();
 
-    if(editor_) {
+    if (editor_) {
         editor_->itemChanged();
     }
 }
@@ -439,7 +451,7 @@ bool MvQFeatureTextItem::getRequestParameters()
     if (!req_)
         return false;
 
-    req_ = ObjectList::ExpandRequest(req_, EXPAND_DEFAULTS);
+    expandStyleRequest();
 
     std::string val;
     fontPen_ = MvQ::makePen("SOLID", 0, (const char*)req_("FONT_COLOUR"));
@@ -447,17 +459,19 @@ bool MvQFeatureTextItem::getRequestParameters()
     req_.getValue("LINE", val);
     if (val == "OFF") {
         pen_ = QPen(Qt::NoPen);
-    } else {
+    }
+    else {
         pen_ = MvQ::makePen((const char*)req_("LINE_STYLE"),
-                              (int)req_("LINE_THICKNESS"),
-                              (const char*)req_("LINE_COLOUR"),
-                              Qt::SquareCap, Qt::MiterJoin);
+                            (int)req_("LINE_THICKNESS"),
+                            (const char*)req_("LINE_COLOUR"),
+                            Qt::SquareCap, Qt::MiterJoin);
     }
 
     req_.getValue("FILL", val);
     if (val == "OFF") {
         brush_ = QBrush(Qt::NoBrush);
-    } else {
+    }
+    else {
         brush_ = MvQ::makeBrush("SOLID",
                                 (const char*)req_("FILL_COLOUR"));
     }
@@ -479,8 +493,8 @@ bool MvQFeatureTextItem::getRequestParameters()
     req_.getValue("FONT_UNDERLINE_STYLE", val);
     bool underline = (val == "ON");
 
-    font_ = MvQ::makeFont(family,  bold, italic, underline, fontSize);
-    fontPen_ = MvQ::makePen("SOLID", 1,  (const char*)req_("FONT_COLOUR"));
+    font_    = MvQ::makeFont(family, bold, italic, underline, fontSize);
+    fontPen_ = MvQ::makePen("SOLID", 1, (const char*)req_("FONT_COLOUR"));
 
     req_.getValue("TEXT_ALIGNMENT", val);
     if (val == "LEFT")
@@ -498,7 +512,7 @@ bool MvQFeatureTextItem::getRequestParameters()
 // only the handler can call it
 void MvQFeatureTextItem::setText(QString t)
 {
-    text_ = t;
+    text_        = t;
     req_("TEXT") = text_.toStdString().c_str();
 
     prepareGeometryChange();
@@ -513,7 +527,7 @@ void MvQFeatureTextItem::setText(QString t)
 void MvQFeatureTextItem::setTextFromEditor(QString t)
 {
     if (t != text_) {
-        featureHandler_->setText(this, t);
+        MvQFeatureHandler::Instance()->setText(getptr(), t);
     }
 }
 
@@ -525,8 +539,9 @@ void MvQFeatureTextItem::adjustText()
     // a resonable default size at the very beginning
     if (text_.isEmpty() && !textRect_.isValid()) {
         textRect_ = QRectF(0, 0, MvQ::textWidth(fm, "AAAAAAAA"), fm.height());
-    // otherwise we just adjust the text height
-    } else {
+        // otherwise we just adjust the text height
+    }
+    else {
         auto tr = estimateTextRect();
 #ifdef MVQFEATURETEXT_DEBUG_
         qDebug() << "esitmate:" << tr.size() << "textRect:" << textRect_.size();
@@ -539,17 +554,17 @@ void MvQFeatureTextItem::adjustText()
             tr.setHeight(minTextSize_.height());
         }
 
-//        if (tr.width() < textSizeHint.width() ) {
-//             tr.setWidth(textSizeHint.width());
-//        }
-//        if (tr.height() < textSizeHint.width() ) {
-//             tr.setWidth(textSizeHint.width());
-//        }
+        //        if (tr.width() < textSizeHint.width() ) {
+        //             tr.setWidth(textSizeHint.width());
+        //        }
+        //        if (tr.height() < textSizeHint.width() ) {
+        //             tr.setWidth(textSizeHint.width());
+        //        }
 
-//        textRect_.setWidth(tr.width());
-//        textRect_.setHeight(tr.height());
+        //        textRect_.setWidth(tr.width());
+        //        textRect_.setHeight(tr.height());
 
-//        // textRect_ can only grow by setting the text
+        //        // textRect_ can only grow by setting the text
         if (textRect_.width() < tr.width()) {
             textRect_.setWidth(tr.width());
         }
@@ -560,20 +575,20 @@ void MvQFeatureTextItem::adjustText()
 
     // textRect_ is always the at (0,0) !!!
     itemRect_ = textRect_.adjusted(-margin_, -margin_, margin_, margin_);
-    bRect_ = itemRect_;
+    bRect_    = itemRect_;
 }
 
 QRectF MvQFeatureTextItem::estimateTextRect() const
 {
     QFontMetrics fm(font_);
-    QRect r(0,0,textRect_.width()-1,1000);
+    QRect r(0, 0, textRect_.width() - 1, 1000);
     return fm.boundingRect(r, alignment_ | Qt::AlignTop | Qt::TextWordWrap,
-                          (text_.isEmpty()?"A":text_));
+                           (text_.isEmpty() ? "A" : text_));
 }
 
 void MvQFeatureTextItem::editText()
 {
-    featureHandler_->editText(this);
+    MvQFeatureHandler::Instance()->editText(getptr());
 }
 
 void MvQFeatureTextItem::initContents()
@@ -581,17 +596,17 @@ void MvQFeatureTextItem::initContents()
     editText();
 }
 
-void MvQFeatureTextItem::textEditStarted(MvQFeatureTextEditor *editor)
+void MvQFeatureTextItem::textEditStarted(MvQFeatureTextEditor* editor)
 {
     inTextEdit_ = true;
-    editor_ = editor;
+    editor_     = editor;
     update();
 }
 
 void MvQFeatureTextItem::textEditFinished()
 {
     inTextEdit_ = false;
-    editor_ = nullptr;
+    editor_     = nullptr;
     update();
     setSelected(false);
 }
@@ -600,12 +615,12 @@ void MvQFeatureTextItem::textEditFinished()
 double MvQFeatureTextItem::halo() const
 {
     auto w = pen_.width();
-    return (w <=1)?0:1+w/2;
+    return (w <= 1) ? 0 : 1 + w / 2;
 }
 
 QSizeF MvQFeatureTextItem::minSize() const
 {
-   return minTextSize_ +  QSizeF(2*halo()+2*margin_, 2*halo()+2*margin_);
+    return minTextSize_ + QSizeF(2 * halo() + 2 * margin_, 2 * halo() + 2 * margin_);
 }
 
 static MvQFeatureMaker<MvQFeatureTextItem> textMaker("text");
