@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQLayerContentsIcon_H
-#define MvQLayerContentsIcon_H
+#pragma once
 
 #include <QPixmap>
 
@@ -71,12 +70,10 @@ protected:
 
 
 private:
-    string getPixmapPath(const string&);
+    std::string getPixmapPath(const std::string&);
 
     // Members related to the icon hidden parameters.
     // They are used between functions startEditor() and edited()
     // because the "editor" does not send forward the hidden parameters
-    string nameOrg_;       // original icon name
+    std::string nameOrg_;  // original icon name
 };
-
-#endif
