@@ -47,9 +47,9 @@ MvQLayerDataWidget::MvQLayerDataWidget(MgQPlotScene* plotScene, MvQPlotView* plo
     panelLayout_ = new QStackedLayout;
     layout_->addLayout(panelLayout_);
 
-    QWidget* emptyWidget = new QWidget(this);
-    QVBoxLayout* emptyVb = new QVBoxLayout(emptyWidget);
-    QLabel* label        = new QLabel(tr("No data is available for this layer!"), this);
+    auto* emptyWidget = new QWidget(this);
+    auto* emptyVb     = new QVBoxLayout(emptyWidget);
+    auto* label       = new QLabel(tr("No data is available for this layer!"), this);
     emptyVb->addWidget(label);
     emptyVb->addStretch(1);
     panelLayout_->addWidget(emptyWidget);
@@ -59,7 +59,7 @@ MvQLayerDataWidget::MvQLayerDataWidget(MgQPlotScene* plotScene, MvQPlotView* plo
 
     //Data probe
 
-    QHBoxLayout* probeHb = new QHBoxLayout();
+    auto* probeHb = new QHBoxLayout();
     probeHb->setSpacing(1);
     probeHb->setContentsMargins(1, 1, 1, 1);
     layout_->addLayout(probeHb);
@@ -111,9 +111,7 @@ MvQLayerDataWidget::MvQLayerDataWidget(MgQPlotScene* plotScene, MvQPlotView* plo
     checkButtonStatus();
 }
 
-MvQLayerDataWidget::~MvQLayerDataWidget()
-{
-}
+MvQLayerDataWidget::~MvQLayerDataWidget() = default;
 
 void MvQLayerDataWidget::updateData()
 {
@@ -148,12 +146,12 @@ void MvQLayerDataWidget::updateData()
     layerMetaData(md);
 
     //Get datatype and path
-    map<string, string>::iterator it = md.find("_datatype");
+    auto it = md.find("_datatype");
     if (it == md.end()) {
         panelLayout_->setCurrentIndex(0);
         return;
     }
-    string dataType = it->second;
+    std::string dataType = it->second;
 
     QString dataPath;
     it = md.find("path");
@@ -490,7 +488,7 @@ void MvQLayerDataWidget::setIndexForPanel(const std::vector<int>& indexVec, Pane
 
     if (type == OdbPanel) {
 #ifdef METVIEW_ODB_NEW
-        MvQOdbDataWidget* data = static_cast<MvQOdbDataWidget*>(panel);
+        auto* data = static_cast<MvQOdbDataWidget*>(panel);
         if (data) {
             if (isProbeFiltered()) {
                 data->setTmpFilter(indexVec);
@@ -629,7 +627,7 @@ void MvQLayerDataWidget::storePanelProperties()
     QWidget* panel = findActivePanel(OdbPanel);
     if (panel) {
 #ifdef METVIEW_ODB_NEW
-        MvQOdbDataWidget* data = static_cast<MvQOdbDataWidget*>(panel);
+        auto* data = static_cast<MvQOdbDataWidget*>(panel);
         if (data) {
             visibleOdbColumns_ = data->visibleColumns();
         }
