@@ -16,8 +16,8 @@
 #include "Presentable.h"
 #include "Root.h"
 
-MvQLayerDialog::MvQLayerDialog(int iconId, QWidget* parent) :
-    QFileDialog(parent, "Save As"),
+MvQLayerDialog::MvQLayerDialog(int iconId, QString startDir, QWidget* parent) :
+    MvQFileDialog(startDir, "Save as", parent),
     iconId_(iconId)
 {
     // Set widget mode behaviour to "Save As"
@@ -46,7 +46,7 @@ void MvQLayerDialog::accept()
         std::string fullPath  = MakeUserPath(siconName);
 
         // Remove all hiden parameters before saving the icon
-        RemoveParameters(iconReq, "_");
+        metview::RemoveParameters(iconReq, "_");
         iconReq.save(fullPath.c_str());
     }
 
