@@ -47,7 +47,7 @@ MvQLayerMetaDataWidget::MvQLayerMetaDataWidget(QWidget* parent) :
              << "MWIND"
              << "PWIND";
 
-    QVBoxLayout* layout = new QVBoxLayout;
+    auto* layout = new QVBoxLayout;
     layout->setContentsMargins(0, 0, 0, 0);
     setLayout(layout);
 
@@ -61,7 +61,7 @@ MvQLayerMetaDataWidget::MvQLayerMetaDataWidget(QWidget* parent) :
 
     //Stats + histo row
 
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     layout->addLayout(hb);
 
     //Stats button
@@ -133,10 +133,10 @@ void MvQLayerMetaDataWidget::updateData()
 
     QString str;
     QString txt("<table><tbody>");
-    string dataType, description;
+    std::string dataType, description;
 
     //Identifiy datatype
-    map<string, string>::const_iterator it = infoMap.find("_datatype");
+    auto it = infoMap.find("_datatype");
     if (it != infoMap.end()) {
         dataType = "System::" + it->second;
     }
@@ -150,7 +150,7 @@ void MvQLayerMetaDataWidget::updateData()
     }
 
     //qDebug() << "layer info";
-    //for(map<string,string>::iterator it=infoMap.begin(); it!= infoMap.end(); it++)
+    //for(map<std::string,string>::iterator it=infoMap.begin(); it!= infoMap.end(); it++)
     //qDebug() << it->first.c_str() << it->second.c_str();
 
     //Get key profile
@@ -169,8 +169,8 @@ void MvQLayerMetaDataWidget::updateData()
         QString key   = QString::fromStdString(prof->at(i)->name());
         QString label = QString::fromStdString(prof->at(i)->shortName());
 
-        string group  = prof->at(i)->metaData("group");
-        string source = prof->at(i)->metaData("source");
+        std::string group  = prof->at(i)->metaData("group");
+        std::string source = prof->at(i)->metaData("source");
 
         if (group == "stats" && !statsEnabled_)
             continue;
@@ -178,7 +178,7 @@ void MvQLayerMetaDataWidget::updateData()
             continue;
 
         //Get keyType
-        string keyType = prof->at(i)->metaData("type");
+        std::string keyType = prof->at(i)->metaData("type");
 
         //qDebug() << key << "type:" << keyType.c_str();
 
@@ -225,7 +225,7 @@ void MvQLayerMetaDataWidget::updateData()
     }
 
     if (prof->size() == 0) {
-        for (map<string, string>::const_iterator it = infoMap.begin(); it != infoMap.end(); it++) {
+        for (auto it = infoMap.begin(); it != infoMap.end(); it++) {
             if (it->first != "_datatype" && it->first != "_description") {
                 QString key(it->first.c_str());
                 QString label(it->first.c_str());
@@ -243,7 +243,7 @@ void MvQLayerMetaDataWidget::updateData()
             if (key == "_datatype" || key == "_layertype")
                 continue;
 
-            string group = prof->at(i)->metaData("group");
+            std::string group = prof->at(i)->metaData("group");
 
             if (group == "stats" && !statsEnabled_)
                 continue;
@@ -251,7 +251,7 @@ void MvQLayerMetaDataWidget::updateData()
             if (group == "histo" && !histoEnabled_)
                 continue;
 
-            string dep = prof->at(i)->metaData("dependency");
+            std::string dep = prof->at(i)->metaData("dependency");
             if (!dep.empty() &&
                 (infoMap.find(dep) == infoMap.end() || infoMap[dep].empty())) {
                 continue;
@@ -259,17 +259,17 @@ void MvQLayerMetaDataWidget::updateData()
 
 
             //Get keyType
-            string keyType = prof->at(i)->metaData("type");
+            std::string keyType = prof->at(i)->metaData("type");
 
             if (keyType == "table") {
-                string subType        = prof->at(i)->metaData("subType");
+                std::string subType   = prof->at(i)->metaData("subType");
                 QStringList keyLst    = QString::fromStdString(prof->at(i)->metaData("column")).split("/");
                 QStringList headerLst = QString::fromStdString(prof->at(i)->metaData("header")).split("/");
                 addTableInfoRow(label, keyLst, headerLst, QString::fromStdString(subType), infoMap, txt, colSpan);
             }
             else if (keyType == "list") {
-                string subType     = prof->at(i)->metaData("subType");
-                QStringList keyLst = QString::fromStdString(prof->at(i)->metaData("item")).split("/");
+                std::string subType = prof->at(i)->metaData("subType");
+                QStringList keyLst  = QString::fromStdString(prof->at(i)->metaData("item")).split("/");
                 addListInfoRow(label, keyLst, QString::fromStdString(subType), infoMap, txt);
             }
             else if (keyType == "image") {
@@ -286,7 +286,7 @@ void MvQLayerMetaDataWidget::updateData()
                         layerMetaData(infoMap);
 
                         //qDebug() << "histo";
-                        //for(map<string,string>::iterator it=infoMap.begin(); it!= infoMap.end(); it++)
+                        //for(map<std::string,string>::iterator it=infoMap.begin(); it!= infoMap.end(); it++)
                         //	qDebug() << it->first.c_str() << it->second.c_str();
                     }
                 }
@@ -328,9 +328,9 @@ void MvQLayerMetaDataWidget::addTitleInfoRow(QString label, QString& info, int c
     info += "<tr><td class=\"title\" align=\"center\" colspan=\"" + QString::number(colSpan + 1) + +"\">" + label + "</td></tr>";
 }
 
-void MvQLayerMetaDataWidget::addTextInfoRow(QString label, QString key, const map<string, string>& infoMap, QString& info, int colSpan)
+void MvQLayerMetaDataWidget::addTextInfoRow(QString label, QString key, const std::map<std::string, std::string>& infoMap, QString& info, int colSpan)
 {
-    map<string, string>::const_iterator it = infoMap.find(key.toStdString());
+    auto it = infoMap.find(key.toStdString());
     if (it == infoMap.end())
         return;
     QString str = QString::fromStdString(it->second);
@@ -349,9 +349,9 @@ void MvQLayerMetaDataWidget::addTextInfoRow(QString label, QString value, QStrin
 }
 
 
-void MvQLayerMetaDataWidget::addImageInfoRow(QString label, QString key, const map<string, string>& infoMap, QString& info, int colSpan)
+void MvQLayerMetaDataWidget::addImageInfoRow(QString label, QString key, const std::map<std::string, std::string>& infoMap, QString& info, int colSpan)
 {
-    map<string, string>::const_iterator it = infoMap.find(key.toStdString());
+    auto it = infoMap.find(key.toStdString());
     if (it == infoMap.end())
         return;
     QString str = QString::fromStdString(it->second);
@@ -363,7 +363,7 @@ void MvQLayerMetaDataWidget::addImageInfoRow(QString label, QString key, const m
 
 
 void MvQLayerMetaDataWidget::addListInfoRow(QString label, QStringList keys, QString listType,
-                                            const map<string, string>& infoMap, QString& info)
+                                            const std::map<std::string, std::string>& infoMap, QString& info)
 {
     if (keys.count() <= 0)
         return;
@@ -373,7 +373,7 @@ void MvQLayerMetaDataWidget::addListInfoRow(QString label, QStringList keys, QSt
         keyVal = keys;
     }
     else {
-        map<string, string>::const_iterator it;
+        std::map<std::string, std::string>::const_iterator it;
         foreach (QString key, keys) {
             it = infoMap.find(key.toStdString());
             if (it != infoMap.end()) {
@@ -401,12 +401,12 @@ void MvQLayerMetaDataWidget::addListInfoRow(QString label, QStringList keys, QSt
 }
 
 void MvQLayerMetaDataWidget::addTableInfoRow(QString label, QStringList keys, QStringList headers, QString tableType,
-                                             const map<string, string>& infoMap, QString& info, int colSpan)
+                                             const std::map<std::string, std::string>& infoMap, QString& info, int colSpan)
 {
     if (keys.count() <= 0)
         return;
 
-    map<string, string>::const_iterator it;
+    std::map<std::string, std::string>::const_iterator it;
 
     //Loop for the columns
     QList<QStringList> keyVal;
@@ -560,29 +560,29 @@ void MvQLayerMetaDataWidget::addTableInfoRow(QString label, QStringList keys, QS
     }
 }
 
-int MvQLayerMetaDataWidget::getColSpan(MvKeyProfile* prof, const map<string, string>& infoMap)
+int MvQLayerMetaDataWidget::getColSpan(MvKeyProfile* prof, const std::map<std::string, std::string>& infoMap)
 {
     //Find out colspan for 2nd column
     int colSpan = 1;
     for (unsigned int i = 0; i < prof->size(); i++) {
-        string group = prof->at(i)->metaData("group");
+        std::string group = prof->at(i)->metaData("group");
         if (group == "histo" && !histoEnabled_)
             continue;
 
         if (group == "stats" && !statsEnabled_)
             continue;
 
-        string dep = prof->at(i)->metaData("dependency");
+        std::string dep = prof->at(i)->metaData("dependency");
         if (!dep.empty()) {
-            map<string, string>::const_iterator it = infoMap.find(dep);
+            auto it = infoMap.find(dep);
             if (it == infoMap.end() || it->second.empty()) {
                 continue;
             }
         }
 
-        string keyType = prof->at(i)->metaData("type");
+        std::string keyType = prof->at(i)->metaData("type");
         if (keyType == "table") {
-            string subType = prof->at(i)->metaData("subType");
+            std::string subType = prof->at(i)->metaData("subType");
 
             int colNum = QString::fromStdString(prof->at(i)->metaData("column")).split("/").count();
             if (subType == "histogram") {
@@ -609,26 +609,16 @@ int MvQLayerMetaDataWidget::getColSpan(MvKeyProfile* prof, const map<string, str
 
 void MvQLayerMetaDataWidget::layerMetaData(MetaDataCollector& md)
 {
-    if (!layer_)
-        return;
-
-    if (sceneItem_) {
-        bool prevExitOnErrorState = PlotMod::Instance().exitOnErrorMessage();
-        bool prevPopupOnErrorState = PlotMod::Instance().popupErrorMessage();
-
+    if (layer_ && sceneItem_) {
+        // it's not the end of the world if Magics has a problem at this point
+        bool prevMagErrorState = PlotMod::Instance().setMagicsErrorIgnored(true);
         try {
-            // it's not the end of the world if Magics has a problem at this point
-            PlotMod::Instance().setExitOnErrorMessage(false);
-            PlotMod::Instance().setPopupErrorMessage(false);
-
             sceneItem_->layerMetaDataForCurrentStep(layer_, md);
         }
         catch (MagicsException& e) {
-            // don't want to do anything with this exception
         }
 
-        PlotMod::Instance().setExitOnErrorMessage(prevExitOnErrorState);
-        PlotMod::Instance().setPopupErrorMessage(prevPopupOnErrorState);
+        PlotMod::Instance().setMagicsErrorIgnored(prevMagErrorState);
     }
 }
 
@@ -638,8 +628,8 @@ QString MvQLayerMetaDataWidget::layerMetaData(QString key)
         return QString();
 
     MetaDataCollector md;
-    string keyStr = key.toStdString();
-    md[keyStr]    = "";
+    std::string keyStr = key.toStdString();
+    md[keyStr]         = "";
 
     sceneItem_->layerMetaDataForCurrentStep(layer_, md);
 
@@ -660,21 +650,15 @@ QPixmap MvQLayerMetaDataWidget::layerInfoImage(QString /*key*/)
     }
 
     QPixmap p;
-    bool prevExitOnErrorState = PlotMod::Instance().exitOnErrorMessage();
-    bool prevPopupOnErrorState = PlotMod::Instance().popupErrorMessage();
-
+    // it's not the end of the world if Magics has a problem at this point
+    bool prevMagErrorState = PlotMod::Instance().setMagicsErrorIgnored(true);
     try {
-        // it's not the end of the world if Magics has a problem at this point
-        PlotMod::Instance().setExitOnErrorMessage(false);
-        PlotMod::Instance().setPopupErrorMessage(false);
         p = sceneItem_->layerInfoImageForCurrentStep(layer_, vdef);
     }
     catch (MagicsException& e) {
-        // there was a problem - return an empty pixmap
     }
 
-    PlotMod::Instance().setExitOnErrorMessage(prevExitOnErrorState);
-    PlotMod::Instance().setPopupErrorMessage(prevPopupOnErrorState);
+    PlotMod::Instance().setMagicsErrorIgnored(prevMagErrorState);
 
     return p;
 }
@@ -742,12 +726,12 @@ void MvQLayerMetaDataWidget::setLayer(MgQLayerItem* layer)
     histoVisdefCb_->clear();
     histoVisdefCb_->addItem(tr("Data values"));
 
-    for (int i = 0; i < icons.size(); i++) {
-        QString vdefClass = icons.at(i).class_;
+    for (const auto& icon : icons) {
+        QString vdefClass = icon.class_;
 
         if (visdefs_.contains(vdefClass)) {
             QString str;
-            QStringList lst = icons.at(i).name_.split("/");
+            QStringList lst = icon.name_.split("/");
             if (!lst.isEmpty()) {
                 str = lst.last();
             }
@@ -755,7 +739,7 @@ void MvQLayerMetaDataWidget::setLayer(MgQLayerItem* layer)
             histoVisdefCb_->addItem(str);
 
             lst.clear();
-            lst << icons.at(i).name_ << vdefClass;
+            lst << icon.name_ << vdefClass;
             histoVisdefCb_->setItemData(histoVisdefCb_->count() - 1, lst);
 
 
