@@ -1018,7 +1018,12 @@ void MvQLayerView::dragMoveEvent(QDragMoveEvent* event)
 {
     if ((event->proposedAction() == Qt::CopyAction ||
          event->proposedAction() == Qt::MoveAction)) {
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        QModelIndex idx = this->indexAt(event->position().toPoint());
+#else
         QModelIndex idx = this->indexAt(event->pos());
+#endif
         if (!idx.isValid())  // mouse is not under the layers
         {
             removeDropTarget();
@@ -1058,7 +1063,11 @@ void MvQLayerView::dropEvent(QDropEvent* event)
     MvQDrop drop(event);
     if (drop.hasData()) {
         // Get index from the dropped position (the target icon)
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        QModelIndex index = filterModel_->mapToSource(this->indexAt(event->position().toPoint()));
+#else
         QModelIndex index = filterModel_->mapToSource(this->indexAt(event->pos()));
+#endif
         if (!index.isValid()) {
             MvLog().popup().warn() << "uPlot MvQLayerView::dropEvent-> Drop not accepted";
             return;
@@ -1079,7 +1088,11 @@ void MvQLayerView::dropEvent(QDropEvent* event)
 void MvQLayerView::checkDropTarget(QDropEvent* event)
 {
     // Get the layer name
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QModelIndex idx   = this->indexAt(event->position().toPoint());
+#else
     QModelIndex idx   = this->indexAt(event->pos());
+#endif
     QModelIndex index = filterModel_->mapToSource(idx);
     QString lname     = model_->layerName(index);
     if (lname.isEmpty()) {
@@ -1088,10 +1101,13 @@ void MvQLayerView::checkDropTarget(QDropEvent* event)
     }
 
     MvQDropTarget::Instance()->reset(lname, QString("Apply to layer "));
-    if (window())
+    if (window()) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        MvQDropTarget::Instance()->move(mapToGlobal(event->position().toPoint()) + QPoint(20, 20));
+#else
         MvQDropTarget::Instance()->move(mapToGlobal(event->pos()) + QPoint(20, 20));
-
-    return;
+#endif
+    }
 }
 
 void MvQLayerView::removeDropTarget()
