@@ -7,8 +7,9 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQLayerModel_H
-#define MvQLayerModel_H
+#pragma once
+
+#include <string>
 
 #include <QAbstractItemModel>
 #include <QList>
@@ -25,8 +26,6 @@ class MgQPlotScene;
 class MgQSceneItem;
 class MvQLayerContentsIcon;
 
-using namespace std;
-
 class MvQLayerDelegate : public QStyledItemDelegate
 {
 public:
@@ -69,7 +68,7 @@ public:
     MgQLayerItem* layer(const QModelIndex&) const;
     MgQLayerItem* layerFromAnyLevel(const QModelIndex&) const;
 
-    string layerId(const QModelIndex&);
+    std::string layerId(const QModelIndex&);
     QString layerName(const QModelIndex&);
     void layerMetaData(const QModelIndex&, MetaDataCollector&);
     QString layerMetaData(const QModelIndex&, QString);
@@ -181,5 +180,3 @@ protected:
 signals:
     void iconDropped(const MvQDrop&, const QModelIndex&);
 };
-
-#endif
