@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQLayerViewLevel_H
-#define MvQLayerViewLevel_H
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QListView>
@@ -17,8 +16,6 @@
 #include "MvQDragDrop.h"
 #include "MvQLayerContentsIcon.h"
 
-using namespace std;
-
 class MvQLayerViewLevelModel : public QAbstractItemModel
 {
     Q_OBJECT
@@ -116,5 +113,3 @@ protected:
     QAction* actionSaveAs_;
     QAction* actionDelete_;
 };
-
-#endif
