@@ -420,7 +420,7 @@ void MvQLayerWidget::slotContextMenu(const QPoint& position)
         //Insert Save key
         auto* actionSave = new QAction(this);
         actionSave->setObjectName(QString::fromUtf8("actionSave"));
-        actionSave->setText(tr("Save to Disk"));
+        actionSave->setText(tr("Overwrite on disk"));
         actionSave->setShortcut(QKeySequence::Save);
         actions.append(actionSave);
         if (!icon->canBeSaved())
@@ -429,7 +429,7 @@ void MvQLayerWidget::slotContextMenu(const QPoint& position)
         //Insert Save As key
         auto* actionSaveAs = new QAction(this);
         actionSaveAs->setObjectName(QString::fromUtf8("actionSaveAs"));
-        actionSaveAs->setText(tr("Save As"));
+        actionSaveAs->setText(tr("Save as ..."));
         actionSaveAs->setShortcut(QKeySequence::SaveAs);
         actions.append(actionSaveAs);
         if (!icon->canBeSavedAs())
