@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQLayerWidget_H
-#define MvQLayerWidget_H
+#pragma once
 
 #include <QModelIndex>
 #include <QWidget>
@@ -116,5 +115,3 @@ protected:
     QModelIndexList expandList_;
     QString lastSelectedLayerText_;
 };
-
-#endif
