@@ -26,7 +26,7 @@ MvQLineSelection::MvQLineSelection(MgQPlotScene* scene, MvQPlotView* view, QGrap
     //pen_=QPen(QColor(103,140,168),2);
     brush_         = QBrush(QColor(164, 219, 255, 180));
     currentAction_ = NoAction;
-    zoomLayout_    = 0;
+    zoomLayout_    = nullptr;
     line_          = QLine();
 
     arrowPen_ = QPen(QColor(0, 0, 0));
@@ -51,9 +51,7 @@ MvQLineSelection::MvQLineSelection(MgQPlotScene* scene, MvQPlotView* view, QGrap
     arrowSize_ = 10.;
 }
 
-MvQLineSelection::~MvQLineSelection()
-{
-}
+MvQLineSelection::~MvQLineSelection() = default;
 
 QRectF MvQLineSelection::boundingRect() const
 {
@@ -170,7 +168,7 @@ void MvQLineSelection::mousePressEventFromView(QMouseEvent* event)
         //Get item position
         lineOrigin_ = mapFromScene(plotView_->mapToScene(event->pos()));
 
-        if ((zoomLayout_ = plotScene_->findProjectorItem(mapToScene(lineOrigin_))) == 0) {
+        if ((zoomLayout_ = plotScene_->findProjectorItem(mapToScene(lineOrigin_))) == nullptr) {
             currentAction_ = NoAction;
         }
         else {
@@ -189,7 +187,7 @@ void MvQLineSelection::mousePressEventFromView(QMouseEvent* event)
 
         dragPos_ = mapFromScene(plotView_->mapToScene(event->pos()));
 
-        if ((zoomLayout_ = plotScene_->firstProjectorItem()) != 0 &&
+        if ((zoomLayout_ = plotScene_->firstProjectorItem()) != nullptr &&
             checkPointInLineArea(dragPos_) == true) {
             QPointF xp = dragPos_ - line_.p1();
             updateHandles();
@@ -344,7 +342,7 @@ void MvQLineSelection::mouseReleaseEventFromView(QMouseEvent* event)
         zoomLayout_->mapFromSceneToGeoCoords(mapToScene(sp2), gp2);
 
         currentAction_ = NoAction;
-        zoomLayout_    = 0;
+        zoomLayout_    = nullptr;
         coordPoint_.clear();
         coordPoint_ << gp1 << gp2;
 
@@ -384,7 +382,7 @@ void MvQLineSelection::mouseReleaseEventFromView(QMouseEvent* event)
         zoomLayout_->mapFromSceneToGeoCoords(mapToScene(sp2), gp2);
 
         currentAction_ = NoAction;
-        zoomLayout_    = 0;
+        zoomLayout_    = nullptr;
         dragPos_       = QPointF();
         coordPoint_.clear();
         coordPoint_ << gp1 << gp2;
@@ -411,7 +409,7 @@ void MvQLineSelection::mouseReleaseEventFromView(QMouseEvent* event)
         zoomLayout_->mapFromSceneToGeoCoords(mapToScene(sp2), gp2);
 
         currentAction_ = NoAction;
-        zoomLayout_    = 0;
+        zoomLayout_    = nullptr;
         dragPos_       = QPointF();
         coordPoint_.clear();
         coordPoint_ << gp1 << gp2;
@@ -438,13 +436,13 @@ void MvQLineSelection::setLine(double lat1, double lon1, double lat2, double lon
     QPointF sp0, sp1;
 
     if (line_.isNull() || line_.p1() == line_.p2()) {
-        if ((zoomLayout_ = plotScene_->firstProjectorItem()) == 0) {
+        if ((zoomLayout_ = plotScene_->firstProjectorItem()) == nullptr) {
             return;
         }
     }
     else {
         sp0 = line_.p1();
-        if ((zoomLayout_ = plotScene_->findProjectorItem(mapToScene(sp0))) == 0) {
+        if ((zoomLayout_ = plotScene_->findProjectorItem(mapToScene(sp0))) == nullptr) {
             return;
         }
     }
@@ -506,7 +504,7 @@ void MvQLineSelection::reset()
     //We need to find the projectorItem!!
     QPointF sp0, sp1;
 
-    if ((zoomLayout_ = plotScene_->firstProjectorItem()) == 0) {
+    if ((zoomLayout_ = plotScene_->firstProjectorItem()) == nullptr) {
         clearLine();
         return;
     }
@@ -541,7 +539,7 @@ void MvQLineSelection::changeDirection()
     if (coordPoint_.isEmpty() || line_.isNull())
         return;
 
-    if ((zoomLayout_ = plotScene_->firstProjectorItem()) == 0) {
+    if ((zoomLayout_ = plotScene_->firstProjectorItem()) == nullptr) {
         return;
     }
 
