@@ -29,10 +29,10 @@ static bool sceneRendering = false;
 MvQMagnifierSlider::MvQMagnifierSlider(QList<float>& values, int actIndex, QColor colour)
 {
     actCellIndex_ = actIndex;
-    cellHeight_ = 13.;
-    cellWidth_  = 6.;
-    handlerSize_ = cellWidth_ + 4;
-    panelWidth_ = cellWidth_ + 10;
+    cellHeight_   = 13.;
+    cellWidth_    = 6.;
+    handlerSize_  = cellWidth_ + 4;
+    panelWidth_   = cellWidth_ + 10;
 
     for (int i = 0; i < values.count(); i++) {
         int lightFactor = 100 + static_cast<int>(100. * static_cast<float>(i) / static_cast<float>(values.count()));
@@ -172,7 +172,7 @@ MagnifierFrameData::MagnifierFrameData(float w, float minr, float maxr, int n) :
 MvQMagnifier::MvQMagnifier(MgQPlotScene* scene, MvQPlotView* view, QGraphicsItem* parent) :
     MvQPlotItem(scene, view, parent)
 {
-    frameWidth_      = innerFrameWidth_ + outerFrameWidth_;
+    frameWidth_ = innerFrameWidth_ + outerFrameWidth_;
 
     //Default geometry
     centreX_ = radius_ + 250.;
@@ -201,7 +201,7 @@ MvQMagnifier::MvQMagnifier(MgQPlotScene* scene, MvQPlotView* view, QGraphicsItem
     QPixmap pxm(QString::fromUtf8(":/uPlot/magnifier_handler"));
     handlerPixmap_ = new QPixmap(pxm.scaledToWidth(slider->handlerSize(), Qt::SmoothTransformation));  //!!
 
-    actSlider_       = sliders_[magnifierMode_];
+    actSlider_ = sliders_[magnifierMode_];
 
     //Set frame data
     frames_.push_back(MagnifierFrameData(6., 20., 150., 60));
@@ -216,9 +216,7 @@ MvQMagnifier::MvQMagnifier(MgQPlotScene* scene, MvQPlotView* view, QGraphicsItem
     setFlag(QGraphicsItem::ItemIsMovable);
 }
 
-MvQMagnifier::~MvQMagnifier()
-{
-}
+MvQMagnifier::~MvQMagnifier() = default;
 
 bool MvQMagnifier::checkCircleInWindow(const float x, const float y, const float r) const
 {
@@ -696,11 +694,11 @@ void MvQMagnifier::prepareForReset()
     //main scene
 
     if (magnifierMode_ == DataMode) {
-        if (dataScene_ != 0 && dataItem_ != 0) {
+        if (dataScene_ != nullptr && dataItem_ != nullptr) {
             dataScene_->removeItem(dataItem_);
             dataItem_->clearPlotContents();
             dataItem_->addToMainScene();
-            dataItem_ = 0;
+            dataItem_ = nullptr;
         }
     }
 }
@@ -712,10 +710,10 @@ void MvQMagnifier::reset()
 
         if (!dataScene_) {
             dataScene_ = new QGraphicsScene;
-            dataItem_  = 0;
+            dataItem_  = nullptr;
         }
 
-        if (dataItem_ != 0) {
+        if (dataItem_ != nullptr) {
             dataScene_->removeItem(dataItem_);
             dataItem_->clearPlotContents();
             dataItem_->addToMainScene();
@@ -725,7 +723,7 @@ void MvQMagnifier::reset()
 
         //To be implemented!!!
         //dataItem_=plotScene_->updateMagnifier(zoom);
-        dataItem_ = 0;
+        dataItem_ = nullptr;
 
         if (dataItem_) {
             plotScene_->removeItem(dataItem_);
