@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQMagnifier_H
-#define MvQMagnifier_H
+#pragma once
 
 #include <vector>
 
@@ -23,14 +22,12 @@ class QPixmap;
 
 class MgQMagnifierLayoutItem;
 
-using namespace std;
-
 class MvQMagnifierFactorCell
 {
 public:
     MvQMagnifierFactorCell(float value, QColor colour) :
         value_(value),
-        colour_(colour){}
+        colour_(colour) {}
     float value_;
     QColor colour_;
 };
@@ -104,8 +101,8 @@ public:
     float width_;
     float minRadius_;
     float maxRadius_;
-    vector<float> coeffCos_;
-    vector<float> coeffSin_;
+    std::vector<float> coeffCos_;
+    std::vector<float> coeffSin_;
     int ptNum_;
 };
 
@@ -190,7 +187,7 @@ private:
     QMap<MagnifierMode, MvQMagnifierSlider*> sliders_;
     int actCellIndexAtHandlerActionStart_{0};
     int actFrameIndex_{0};
-    vector<MagnifierFrameData> frames_;
+    std::vector<MagnifierFrameData> frames_;
 
     QPointF dragPos_;
     float radius_{100.};
@@ -217,9 +214,6 @@ private:
     MgQMagnifierLayoutItem* dataItem_{nullptr};
     QImage* device_{nullptr};
     QPainter* painter_{nullptr};
-    QPen cellPen_{QColor(50,50,50)};
+    QPen cellPen_{QColor(50, 50, 50)};
     QPixmap* handlerPixmap_{nullptr};
 };
-
-
-#endif
