@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQOdbStat_H
-#define MvQOdbStat_H
+#pragma once
 
 #include <QStringList>
 
@@ -38,5 +37,3 @@ protected:
     QList<QStringList> resultData_;
     bool loaded_;
 };
-
-#endif
