@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQOdbStatModel_H
-#define MvQOdbStatModel_H
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QSortFilterProxyModel>
@@ -43,5 +42,3 @@ public:
 private:
     QList<MvQOdbStat*> data_;
 };
-
-#endif
