@@ -417,10 +417,10 @@ void MvQPlaceMarkItem::reset()
 
 MvQPlaceMark::MvQPlaceMark(MgQPlotScene* scene, MvQPlotView* view, QGraphicsItem* parent) :
     MvQPlotItem(scene, view, parent),
-    magnifier_(0)
+    magnifier_(nullptr)
 {
     currentAction_ = NoAction;
-    dataLayout_    = 0;
+    dataLayout_    = nullptr;
     coordinates_   = QPointF(0., 0.);
 
     //pix_=QPixmap::fromImage(pm_->pixmap().toImage().mirrored(false,true));
@@ -438,9 +438,7 @@ MvQPlaceMark::MvQPlaceMark(MgQPlotScene* scene, MvQPlotView* view, QGraphicsItem
     highlighted_ = false;
 }
 
-MvQPlaceMark::~MvQPlaceMark()
-{
-}
+MvQPlaceMark::~MvQPlaceMark() = default;
 
 QRectF MvQPlaceMark::boundingRect() const
 {
