@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQPlotItem_H
-#define MvQPlotItem_H
+#pragma once
 
 #include <QGraphicsObject>
 
@@ -25,32 +24,29 @@ public:
         plotScene_(scene),
         plotView_(view),
         activated_(false),
-        acceptMouseEvents_(true){}
+        acceptMouseEvents_(true) {}
 
     bool activated() { return activated_; }
     virtual void setActivated(bool b) { activated_ = b; }
     void setAcceptMouseEvents(bool b) { acceptMouseEvents_ = b; }
 
-    virtual void mousePressEventFromView(QMouseEvent*){}
-    virtual void mouseMoveEventFromView(QMouseEvent*){}
-    virtual void mouseReleaseEventFromView(QMouseEvent*){}
+    virtual void mousePressEventFromView(QMouseEvent*) {}
+    virtual void mouseMoveEventFromView(QMouseEvent*) {}
+    virtual void mouseReleaseEventFromView(QMouseEvent*) {}
 
-    virtual void prepareForReset(){}
-    virtual void reset(){}
+    virtual void prepareForReset() {}
+    virtual void reset() {}
 
-    MgQPlotScene* plotScene() const {return plotScene_;}
-    MvQPlotView* plotView() const {return plotView_;}
+    MgQPlotScene* plotScene() const { return plotScene_; }
+    MvQPlotView* plotView() const { return plotView_; }
 
 protected:
-    virtual void mousePressEvent(QGraphicsSceneMouseEvent*){}
-    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent*){}
-    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent*){}
+    virtual void mousePressEvent(QGraphicsSceneMouseEvent*) {}
+    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent*) {}
+    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent*) {}
 
     MgQPlotScene* plotScene_;
     MvQPlotView* plotView_;
     bool activated_;
     bool acceptMouseEvents_;
 };
-
-
-#endif
