@@ -50,26 +50,15 @@
 #include "MvQFeatureFactory.h"
 #include "MvQFeatureItem.h"
 #include "MvQFeatureSelector.h"
-#include "MvQFeatureType.h"
 #include "MvQFeatureContextMenu.h"
 
 #define METVIEW_MULTIPAGE
 
 //#define PLOTVIEWFEATURE_DEBUG_
 
-
 MvQPlotView::MvQPlotView(QGraphicsScene* scene, QWidget* parent) :
     QGraphicsView(scene, parent)
 {
-    zoom_                    = 0;
-    magnifier_               = 0;
-    cursorData_              = 0;
-    area_                    = 0;
-    line_                    = 0;
-    point_                   = 0;
-    dataProbe_               = 0;
-    sceneIsBeingSelected_    = false;
-
     plotScene_ = static_cast<MgQPlotScene*>(scene);
 
     resetTransform();
@@ -78,12 +67,7 @@ MvQPlotView::MvQPlotView(QGraphicsScene* scene, QWidget* parent) :
 
     setAcceptDrops(true);
 
-    featureHandler_ = new MvQFeatureHandler(this);
-}
-
-MvQPlotView::~MvQPlotView()
-{
-    delete featureHandler_;
+    MvQFeatureHandler::Instance()->setView(this);
 }
 
 void MvQPlotView::slotSetEnableZoom(bool flag)
@@ -101,13 +85,13 @@ void MvQPlotView::slotSetEnableZoom(bool flag)
     }
     else {
         if (!zoom_) {
-            zoom_ = new MvQZoom(plotScene_, this, 0);
+            zoom_ = new MvQZoom(plotScene_, this, nullptr);
             //zoom_->setVisible(true);
             zoom_->setZValue(2.5);
             plotScene_->addItem(zoom_);
 
-            connect(zoom_, SIGNAL(zoomRectangleIsDefined(const string&, const string&)),
-                    this, SIGNAL(zoomRectangleIsDefined(const string&, const string&)));
+            connect(zoom_, SIGNAL(zoomRectangleIsDefined(const std::string&, const std::string&)),
+                    this, SIGNAL(zoomRectangleIsDefined(const std::string&, const std::string&)));
 
             connect(zoom_, SIGNAL(mousePressInSceneItem(MgQSceneItem*)),
                     this, SIGNAL(zoomActionStarted(MgQSceneItem*)));
@@ -119,10 +103,10 @@ void MvQPlotView::slotSetEnableZoom(bool flag)
         viewport()->setCursor(QCursor(Qt::CrossCursor));
 
         // feature selector needs to be cleared
-        featureHandler_->clearSelection();
-//        if (selector_) {
-//            selector_->clear();
-//        }
+        MvQFeatureHandler::Instance()->clearSelection();
+        //        if (selector_) {
+        //            selector_->clear();
+        //        }
     }
 }
 
@@ -142,7 +126,7 @@ void MvQPlotView::slotSetEnableMagnifier(bool flag)
     else {
         emit zoomIsEnabledProgramatically(false);
         if (!magnifier_) {
-            magnifier_ = new MvQMagnifier(plotScene_, this, 0);
+            magnifier_ = new MvQMagnifier(plotScene_, this, nullptr);
             //zoom_->setVisible(true);
             magnifier_->setZValue(1.5);
             plotScene_->addItem(magnifier_);
@@ -169,7 +153,7 @@ void MvQPlotView::slotMagnifierChanged()
     //Update dataprobe
     if (dataProbe_ && dataProbe_->activated()) {
         dataProbe_->setMagnifier(magnifier_);
-    } 
+    }
 }
 
 void MvQPlotView::slotSetEnableCursorData(bool flag)
@@ -186,7 +170,7 @@ void MvQPlotView::slotSetEnableCursorData(bool flag)
     }
     else {
         if (!cursorData_) {
-            cursorData_ = new MvQCursorData(plotScene_, this, 0);
+            cursorData_ = new MvQCursorData(plotScene_, this, nullptr);
             cursorData_->setVisible(true);
             cursorData_->setZValue(2.);
             plotScene_->addItem(cursorData_);
@@ -213,7 +197,7 @@ void MvQPlotView::slotSetEnableAreaSelection(bool flag)
     }
     else {
         if (!area_) {
-            area_ = new MvQAreaSelection(plotScene_, this, 0);
+            area_ = new MvQAreaSelection(plotScene_, this, nullptr);
             area_->setParentItem(plotScene_->annotationRootItem());
             area_->setZValue(2.);
 
@@ -267,7 +251,7 @@ void MvQPlotView::slotSetEnableLineSelection(bool flag)
     }
     else {
         if (!line_) {
-            line_ = new MvQLineSelection(plotScene_, this, 0);
+            line_ = new MvQLineSelection(plotScene_, this, nullptr);
             line_->setParentItem(plotScene_->annotationRootItem());
             line_->setZValue(2.);
 
@@ -320,7 +304,7 @@ void MvQPlotView::slotSetEnablePointSelection(bool flag)
     }
     else {
         if (!point_) {
-            point_ = new MvQPointSelection(plotScene_, this, 0);
+            point_ = new MvQPointSelection(plotScene_, this, nullptr);
             point_->setParentItem(plotScene_->annotationRootItem());
             point_->setZValue(2.);
 
@@ -364,82 +348,38 @@ void MvQPlotView::setDataProbe(MvQPlaceMark* p)
     dataProbe_ = p;
 }
 
-void MvQPlotView::enterFeatureAddMode(QString name)
+void MvQPlotView::enterFeatureAddMode()
 {
-    if (!name.isEmpty()) {
-        emit zoomIsEnabledProgramatically(false);
-        featureTypeToAdd_ = name;
-        viewport()->setCursor(QCursor(Qt::CrossCursor));
-
-        // This is the right time to init the feature shortcuts. It is
-        // guaranteed (internally) to be done only once.
-        MvQFeatureMenuItem::setupShortcut(this, this, "view");
-
-        // This is a one-off action
-        if (!featureRibbonEditor_) {
-            featureRibbonEditor_ = new MvQFeatureRibbonEditor(this);
-            emit addRibbonEditor(featureRibbonEditor_);
-            featureHandler_->setRibbonEditor(featureRibbonEditor_);
-        }
-
-        featureHandler_->clearSelection();
-    }
+    emit zoomIsEnabledProgramatically(false);
+    inFeatureAddMode_ = true;
+    viewport()->setCursor(QCursor(Qt::CrossCursor));
+    MvQFeatureHandler::Instance()->clearSelection();
 }
 
 void MvQPlotView::leaveFeatureAddMode()
 {
-    if (!featureTypeToAdd_.isEmpty()) {
-        featureTypeToAdd_.clear();
+    if (inFeatureAddMode_) {
+        inFeatureAddMode_ = false;
         viewport()->setCursor(QCursor());
-     }
-}
-
-#if 0
-void MvQPlotView::removeFeature(MvQFeatureItem* item)
-{
-    selector_->clear();
-    selector_->suspend(true);
-    features_.removeOne(item);
-    scene()->removeItem(item);
-    selector_->suspend(false);
-    // TODO: do we need to call it?
-    checkSelection();
-    delayedRemoveFeatures_ << item;
-    // we cannot delete the item right here because this function might have been called from
-    // a context menu handler, so the item must exist when we return from here. Instead
-    // we use a delayed delete mechanism.
-    QTimer::singleShot(0, this, SLOT(delayedRemoveFeatures()));
-}
-#endif
-
-#if 0
-void MvQPlotView::removeFeatures(QList<MvQFeatureItem*> items)
-{
-    selector()->clear();
-    selector_->suspend(true);
-    for (auto item: items) {
-        features_.removeOne(item);
-        // NOTE: after calling removeItem the item is still selected!
-        scene()->removeItem(item);
-        delayedRemoveFeatures_ << item;
     }
-    // we cannot delete the item right here because this function might have been called from
-    // a context menu handler, so the item must exist when we return from here. Instead
-    // we use a delayed delete mechanism.
-    QTimer::singleShot(0, this, SLOT(delayedRemoveFeatures()));
-    selector_->suspend(false);
 }
-#endif
 
-void MvQPlotView::delayedRemoveFeatures()
+void MvQPlotView::initFeatureInterface()
 {
-    qDeleteAll(delayedRemoveFeatures_);
-    delayedRemoveFeatures_.clear();
+    //  It is guaranteed (internally) to be done only once.
+    MvQFeatureMenuItem::setupShortcut(this, this, "view");
+
+    // This is a one-off action
+    if (!featureRibbonEditor_) {
+        featureRibbonEditor_ = new MvQFeatureRibbonEditor(this);
+        emit addRibbonEditor(featureRibbonEditor_);
+        MvQFeatureHandler::Instance()->setRibbonEditor(featureRibbonEditor_);
+    }
 }
 
 bool MvQPlotView::hasFeatures() const
 {
-    return featureHandler_->features().size() > 0;
+    return MvQFeatureHandler::Instance()->features().size() > 0;
 }
 
 void MvQPlotView::resetBegin()
@@ -459,7 +399,7 @@ void MvQPlotView::resetBegin()
     if (dataProbe_)
         dataProbe_->prepareForReset();
 
-    featureHandler_->resetBegin();
+    MvQFeatureHandler::Instance()->resetBegin();
 }
 
 void MvQPlotView::resetEnd()
@@ -479,14 +419,15 @@ void MvQPlotView::resetEnd()
     if (dataProbe_)
         dataProbe_->reset();
 
-    featureHandler_->resetEnd();
+    MvQFeatureHandler::Instance()->resetEnd();
 }
 
 void MvQPlotView::mouseDoubleClickEvent(QMouseEvent* event)
 {
     if (zoom_ && zoom_->activated()) {
         return;
-    } else {
+    }
+    else {
         QGraphicsView::mouseDoubleClickEvent(event);
     }
 }
@@ -494,7 +435,7 @@ void MvQPlotView::mouseDoubleClickEvent(QMouseEvent* event)
 void MvQPlotView::mousePressEvent(QMouseEvent* event)
 {
     bool eventProcessed = false;
-    QPointF scenePos = mapToScene(event->pos());
+    QPointF scenePos    = mapToScene(event->pos());
 
     if (sceneIsBeingSelected_) {
         viewport()->unsetCursor();
@@ -505,15 +446,14 @@ void MvQPlotView::mousePressEvent(QMouseEvent* event)
     }
 
     // add new feature
-    if (!featureTypeToAdd_.isEmpty()) {
-        QString fname = featureTypeToAdd_;
+    if (inFeatureAddMode_) {
         leaveFeatureAddMode();
-        featureHandler_->add(fname, event->pos());
+        MvQFeatureHandler::Instance()->addFromView(event->pos());
         return;
-     }
+    }
 
     // close feature text editor if we click outside the editor
-    if (featureHandler_->checkMousePressForTextEditor(scenePos)) {
+    if (MvQFeatureHandler::Instance()->checkMousePressForTextEditor(scenePos)) {
         return;
     }
 
@@ -557,11 +497,11 @@ void MvQPlotView::mousePressEvent(QMouseEvent* event)
         point_->mousePressEventFromView(event);
     }
     // symbols/features
-    else if (featureHandler_->features().size() >0) {
+    else if (MvQFeatureHandler::Instance()->features().size() > 0) {
         // indicate that a feature control point edit can be started
-//        if (selector_) {
-//            selector_->startPointEdit();
-//        } 
+        //        if (selector_) {
+        //            selector_->startPointEdit();
+        //        }
         QGraphicsView::mousePressEvent(event);
         eventProcessed = true;
 #if 0
@@ -589,7 +529,7 @@ void MvQPlotView::mousePressEvent(QMouseEvent* event)
         (!zoom_ || zoom_->activated() == false)) {
         cursorData_->mousePressEventFromView(event);
     }
-    else if (!eventProcessed){
+    else if (!eventProcessed) {
         QGraphicsView::mousePressEvent(event);
     }
 }
@@ -634,7 +574,7 @@ void MvQPlotView::mouseMoveEvent(QMouseEvent* event)
         magnifier_->mouseMoveEventFromView(event);
     }
     else {
-        featureHandler_->checkMouseMove(event);
+        MvQFeatureHandler::Instance()->checkMouseMove(event);
         QGraphicsView::mouseMoveEvent(event);
     }
 
@@ -660,8 +600,9 @@ void MvQPlotView::mouseReleaseEvent(QMouseEvent* event)
     }
     else if (dataProbe_ && dataProbe_->activated()) {
         dataProbe_->mouseReleaseEventFromView(event);
-    } else {
-         QGraphicsView::mouseReleaseEvent(event);
+    }
+    else {
+        QGraphicsView::mouseReleaseEvent(event);
     }
 
     if (cursorData_ && cursorData_->activated()) {
@@ -678,38 +619,9 @@ void MvQPlotView::mouseReleaseEvent(QMouseEvent* event)
     return;
 }
 
-MvQFeatureSelector* MvQPlotView::selector()
-{
-    return featureHandler_->selector();
-}
-
-
-QTimer* MvQPlotView::delayedFeatureSelectionTimer()
-{
-    if (!delayedFeatureSelectionTimer_) {
-        delayedFeatureSelectionTimer_ = new QTimer(this);
-        delayedFeatureSelectionTimer_->setInterval(0);
-        connect(delayedFeatureSelectionTimer_, SIGNAL(timeout()),
-                this, SLOT(delayedFeatureSelection()));
-    }
-    return delayedFeatureSelectionTimer_;
-}
-
-
 void MvQPlotView::itemSelected(MvQFeatureItem*)
 {
-    featureHandler_->checkSelection();
-
-//    //qDebug() << "MvQPlotView::itemSelected";
-//    if (!delayedFeatureSelectionTimer()->isActive()) {
-//        delayedFeatureSelectionTimer()->start();
-//    }
-}
-
-void MvQPlotView::delayedFeatureSelection()
-{
-    delayedFeatureSelectionTimer()->stop();
-    featureHandler_->checkSelection();
+    MvQFeatureHandler::Instance()->checkSelection();
 }
 
 //===========================
@@ -739,7 +651,7 @@ void MvQPlotView::dropEvent(QDropEvent* event)
     if (drop.hasData()) {
         QPoint p(horizontalScrollBar()->value(), verticalScrollBar()->value());
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-        p +=  event->position().toPoint();
+        p += event->position().toPoint();
 #else
         p += event->pos();
 #endif
@@ -759,10 +671,10 @@ void MvQPlotView::slotCommandShortcut()
 #ifdef PLOTVIEWFEATURE_DEBUG_
         qDebug() << "shortcut command:" << cmd;
 #endif
-        MvQFeatureCommandTarget sel(MvQFeatureCommandTarget::ShortcutMode, featureHandler_);
+        MvQFeatureCommandTarget sel(MvQFeatureCommandTarget::ShortcutMode);
         sel.eval(mapToScene(mapFromGlobal(QCursor::pos())));
         //featureSelection(&sel);
-        featureHandler_->runCommand(sel, cmd);
+        MvQFeatureHandler::Instance()->runCommand(sel, cmd);
         //runCommand(sel, cmd);
     }
 }
@@ -780,26 +692,27 @@ QAction* MvQPlotView::handleContextMenu(QList<QAction*> topLevelActions, const Q
     //  qDebug() << " inSelector" << inSelector << "featureMode:" << featureMode << "featureType:" << featureType << "targetItem" << targetItem;
 #endif
 
-    MvQFeatureCommandTarget sel(MvQFeatureCommandTarget::ContextMenuMode, featureHandler_);
+    MvQFeatureCommandTarget sel(MvQFeatureCommandTarget::ContextMenuMode);
     sel.eval(scenePos);
     QString cmd = MvQFeatureMenuItem::execute(sel, topLevelActions, globalPos);
     if (cmd.startsWith("extra:")) {
         int idx = cmd.mid(6).toInt();
-        return (idx >=0 && idx < topLevelActions.size())?topLevelActions[idx]:nullptr;
-    } else {
-        featureHandler_->runCommand(sel, cmd);
+        return (idx >= 0 && idx < topLevelActions.size()) ? topLevelActions[idx] : nullptr;
+    }
+    else {
+        MvQFeatureHandler::Instance()->runCommand(sel, cmd);
     }
     return nullptr;
 }
 
-void MvQPlotView::setUndoStack(QUndoStack *s)
+void MvQPlotView::setUndoStack(QUndoStack* s)
 {
-    featureHandler_->setUndoStack(s);
+    MvQFeatureHandler::Instance()->setUndoStack(s);
 }
 
 void MvQPlotView::setFeatureInfoWidget(QPlainTextEdit* w)
 {
-    featureHandler_->setInfoWidget(w);
+    MvQFeatureHandler::Instance()->setInfoWidget(w);
 }
 
 void MvQPlotView::resizeEvent(QResizeEvent* event)
@@ -811,16 +724,16 @@ void MvQPlotView::resizeEvent(QResizeEvent* event)
 
 void MvQPlotView::keyPressEvent(QKeyEvent* event)
 {
-//    if (selector_) {
-//        switch (event->key()) {
-//            case Qt::Key_Backspace:
-//                selector()->removeAllItems();
-//                event->accept();
-//                break;
-//            default:
-//                break;
-//        }
-//    }
+    //    if (selector_) {
+    //        switch (event->key()) {
+    //            case Qt::Key_Backspace:
+    //                selector()->removeAllItems();
+    //                event->accept();
+    //                break;
+    //            default:
+    //                break;
+    //        }
+    //    }
     QGraphicsView::keyPressEvent(event);
 }
 
