@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQProgressBarPanel_H
-#define MvQProgressBarPanel_H
+#pragma once
 
 #include <QWidget>
 
@@ -35,5 +34,3 @@ private:
     QWidgetAction* acToolBar_;
     QProgressBar* progressBar_;
 };
-
-#endif
