@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQProgressManager_H
-#define MvQProgressManager_H
+#pragma once
 
 #include <QWidget>
 
@@ -52,5 +51,3 @@ private:
     int ntotalframes_;
     int nframes_;
 };
-
-#endif
