@@ -41,7 +41,7 @@ void MvQStepDelegate::paint(QPainter* painter, const QStyleOptionViewItem& optio
 MvQStepModel::MvQStepModel(QObject* parent) :
     MvQKeyProfileModel(parent)
 {
-    stepData_ = 0;
+    stepData_ = nullptr;
     cachedBg_ = MvQTheme::colour("treeview", "cached_bg");
 }
 
@@ -65,13 +65,13 @@ QVariant MvQStepModel::data(const QModelIndex& index, int role) const
     if (role == Qt::BackgroundRole) {
         if (stepData_ && stepData_->stepCached(index.row())) {
             return cachedBg_;
-//            if (index.row() % 2 == 0)
-//                return QColor("#FFE6BF");
-//            else
-//                return QColor("#FFF2DE");
+            //            if (index.row() % 2 == 0)
+            //                return QColor("#FFE6BF");
+            //            else
+            //                return QColor("#FFF2DE");
         }
         else {
-            return {}; //QBrush(Qt::white);
+            return {};  //QBrush(Qt::white);
         }
     }
 
