@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQStepModel_H
-#define MvQStepModel_H
+#pragma once
 
 #include <QAbstractItemModel>
 #include <QColor>
@@ -53,6 +52,3 @@ private:
     MgQSceneItem* stepData_;
     QColor cachedBg_;
 };
-
-
-#endif
