@@ -28,6 +28,7 @@
 #include "MvQStepWidget.h"
 #include "MvQTreeView.h"
 #include "MvQTheme.h"
+#include "MvVariant.h"
 
 #include "MgQPlotScene.h"
 #include "MgQSceneItem.h"
@@ -40,7 +41,7 @@ MvQStepWidget::MvQStepWidget(QWidget* parent) :
 {
     activeScene_ = 0;
 
-    QVBoxLayout* layout = new QVBoxLayout;
+    auto* layout = new QVBoxLayout;
     setLayout(layout);
 
     //Create model
@@ -65,9 +66,9 @@ MvQStepWidget::MvQStepWidget(QWidget* parent) :
 
     //Buttons at the bottom
 
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
 
-    QToolButton* tbEdit = new QToolButton(this);
+    auto* tbEdit = new QToolButton(this);
     tbEdit->setIcon(QIcon(QPixmap(QString::fromUtf8(":/keyDialog/profile_manage.svg"))));
     tbEdit->setToolTip(tr("Manage key profiles"));
     tbEdit->setAutoRaise(true);
@@ -79,8 +80,8 @@ MvQStepWidget::MvQStepWidget(QWidget* parent) :
 
     //Combo box
     //We will add items + signal/slots later in "init"!
-    QLabel* keyLabel = new QLabel(tr("Key profile:"));
-    keyCombo_        = new QComboBox;
+    auto* keyLabel = new QLabel(tr("Key profile:"));
+    keyCombo_      = new QComboBox;
     keyLabel->setBuddy(keyCombo_);
 
     hb->addWidget(keyLabel);
@@ -130,10 +131,10 @@ void MvQStepWidget::init(MgQPlotScene* scene, QString keyProfileName)
     keyCombo_->setCurrentIndex(currentProfileIndex);
 
     //Get all keys
-    vector<MvKeyProfile*> allKeyProf;
+    std::vector<MvKeyProfile*> allKeyProf;
     keyManager_->loadAllKeys(allKeyProf);
-    for (vector<MvKeyProfile*>::iterator it = allKeyProf.begin(); it != allKeyProf.end(); it++) {
-        allKeys_ << *it;
+    for (auto& it : allKeyProf) {
+        allKeys_ << it;
     }
 }
 
@@ -166,10 +167,10 @@ void MvQStepWidget::init(QString keyProfileName)
     keyCombo_->setCurrentIndex(currentProfileIndex);
 
     //Get all keys
-    vector<MvKeyProfile*> allKeyProf;
+    std::vector<MvKeyProfile*> allKeyProf;
     keyManager_->loadAllKeys(allKeyProf);
-    for (vector<MvKeyProfile*>::iterator it = allKeyProf.begin(); it != allKeyProf.end(); it++) {
-        allKeys_ << *it;
+    for (auto& it : allKeyProf) {
+        allKeys_ << it;
     }
 }
 
@@ -249,7 +250,7 @@ void MvQStepWidget::collectKeyProfileData(MvKeyProfile* prof)
     prof->clearKeyData();
 
     //Get metadata
-    MgQStepMetaData* metaData = new MgQStepMetaData(keys);
+    auto* metaData = new MgQStepMetaData(keys);
 
     if (activeScene_)
         activeScene_->stepMetaData(metaData);
@@ -261,18 +262,20 @@ void MvQStepWidget::collectKeyProfileData(MvKeyProfile* prof)
             if (str.endsWith('\n')) {
                 str.remove(str.size() - 1, 1);
             }
-            if (keys[i] == "MV_Frame") {
-                str = QString::number(step);
-            }
-            else if (keys[i] == "MV_Index") {
-                str = QString();
+
+            if (keys[i] == "MV_Frame" || keys[i] == "MV_Index") {
+                if (kd->valueType() == MvKey::IntType) {
+                    kd->addValue(step);
+                } else {
+                    kd->addValue(MvVariant(QString::number(step).toStdString()));
+                }
             }
             else if (keys[i] == "MV_Value") {
-                str = QString();
+                kd->addValue(std::string());
+            } else {
+                kd->addValue(str.toStdString());
             }
 
-            kd->addValue(str.toStdString());
-
             step++;
         }
     }
@@ -503,7 +506,7 @@ void MvQStepWidget::slotManageKeyProfiles()
 
     if (profDialog.exec() == QDialog::Accepted) {
         //Save the current profile name
-        string currentProfName = keyCombo_->currentText().toStdString();
+        std::string currentProfName = keyCombo_->currentText().toStdString();
 #if 0
         messageModel_->keyProfileIsAboutToChange();
         messageModel_->setKeyProfile(0);
@@ -520,7 +523,7 @@ void MvQStepWidget::slotManageKeyProfiles()
 
         int i     = 0;
         int index = -1;
-        for (vector<MvKeyProfile*>::const_iterator it = keyManager_->data().begin(); it != keyManager_->data().end(); it++) {
+        for (auto it = keyManager_->data().begin(); it != keyManager_->data().end(); it++) {
             keyCombo_->addItem(QString((*it)->name().c_str()));
             if ((*it)->name() == currentProfName) {
                 index = i;
