@@ -304,7 +304,7 @@ bool MvQVideoWallServer::parseWallLayout(QString& response)
 
                 // For each tag in the current cell
                 for (ptree::const_iterator itCols = row.begin(); itCols != row.end(); ++itCols) {
-                    string cellStr = itCols->second.get<string>("name", "no-nameX");
+                    std::string cellStr = itCols->second.get<std::string>("name", "no-nameX");
                     if (cellStr != "no-nameX") {
                         int colSpan = itCols->second.get<int>("colspan", 1);
                         int rowSpan = itCols->second.get<int>("rowspan", 1);
@@ -332,7 +332,7 @@ bool MvQVideoWallServer::parseWallLayout(QString& response)
 }
 
 // Returns -1 if a wall of that name does not exist
-int MvQVideoWallServer::wallInfoIndexFromName(const string& wallName)
+int MvQVideoWallServer::wallInfoIndexFromName(const std::string& wallName)
 {
     if (wallName.empty())
         return -1;
@@ -347,7 +347,7 @@ int MvQVideoWallServer::wallInfoIndexFromName(const string& wallName)
 }
 
 // If the wallName does not exist, returns the first Id
-string MvQVideoWallServer::wallInfoId(const string& wallName)
+std::string MvQVideoWallServer::wallInfoId(const std::string& wallName)
 {
     int index = wallInfoIndexFromName(wallName);
 
@@ -506,7 +506,7 @@ MvQWeatherRoomDialog::MvQWeatherRoomDialog(int currentFrame, int totalFrames, QW
     //Cell selector
     cellSelector_ = new MvQVideoWallWidget(this);
     vb->addWidget(cellSelector_, 1);
-    cellSelector_->setWall(NULL);
+    cellSelector_->setWall(nullptr);
     cellSelector_->setEnabled(false);
 
     // Cell selection text box (for if the layout plot is not sufficient)
@@ -613,14 +613,14 @@ int MvQWeatherRoomDialog::getCell()
     return cell;
 }
 
-string MvQWeatherRoomDialog::getWallName()
+std::string MvQWeatherRoomDialog::getWallName()
 {
     return wallCb_->currentText().toStdString();
 }
 
-string MvQWeatherRoomDialog::getWallId()
+std::string MvQWeatherRoomDialog::getWallId()
 {
-    string name = this->getWallName();
+    std::string name = this->getWallName();
     return wallServer_->wallInfoId(name);
 }
 
