@@ -7,8 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef MvQWeatherRoomDialog_H
-#define MvQWeatherRoomDialog_H
+#pragma once
+
+#include <string>
+#include <vector>
 
 #include <QDialog>
 #include <QWidget>
@@ -22,8 +24,6 @@ class QNetworkReply;
 class QRadioButton;
 class QLineEdit;
 
-using namespace std;
-
 // ----------------------------------------------------------
 // MvQVideoWallCellInfo
 // Contains information for a single cell within a video wall
@@ -58,7 +58,7 @@ class MvQVideoWallInfo
 {
 public:
     MvQVideoWallInfo(){};
-    vector<MvQVideoWallCellInfo>& cellInfos() { return cellInfos_; }
+    std::vector<MvQVideoWallCellInfo>& cellInfos() { return cellInfos_; }
 
     QString& name() { return name_; }
     void setName(QString& name) { name_ = name; }
@@ -73,7 +73,7 @@ public:
 private:
     QString name_;    // title name
     QString nameId_;  // base name
-    vector<MvQVideoWallCellInfo> cellInfos_;
+    std::vector<MvQVideoWallCellInfo> cellInfos_;
     //   QString wallURL_;
     //   QString wallToken_;
 };
@@ -94,11 +94,11 @@ public:
     MvQVideoWallInfo* wallInfo() { return wallInfo_; }
     void createWallLayout(int);
     size_t numWalls() { return wallNames_.size(); }
-    int wallInfoIndexFromName(const string&);
+    int wallInfoIndexFromName(const std::string&);
 
-    string wallInfoName(int i) { return wallNames_[i]; }
-    string wallInfoId(int i) { return wallIds_[i]; }
-    string wallInfoId(const string&);
+    std::string wallInfoName(int i) { return wallNames_[i]; }
+    std::string wallInfoId(int i) { return wallIds_[i]; }
+    std::string wallInfoId(const std::string&);
 
     QString& URL() { return URL_; }
     QString& token() { return token_; }
@@ -118,9 +118,9 @@ protected slots:
     void slotWallLayoutReply(QNetworkReply*);
 
 private:
-    MvQVideoWallInfo* wallInfo_;  // hold one wall information
-    vector<string> wallNames_;    // list of wall names
-    vector<string> wallIds_;      // list of wall ids
+    MvQVideoWallInfo* wallInfo_;          // hold one wall information
+    std::vector<std::string> wallNames_;  // list of wall names
+    std::vector<std::string> wallIds_;    // list of wall ids
     QString URL_;
     QString token_;
 };
@@ -167,8 +167,8 @@ public:
 
     // Get info from the user interface
     int getCell();
-    string getWallName();
-    string getWallId();
+    std::string getWallName();
+    std::string getWallId();
 
 public slots:
     //   void slotRangeFrameSelection(bool);
@@ -196,7 +196,7 @@ private:
     int currentFrame_;  // Current frame
     int totalFrames_;   // Total number of frames
 
-    string lastWall_;          // last wall used
+    std::string lastWall_;     // last wall used
     int lastCell_;             // last cell used
     bool updatingFromServer_;  // to avoid the wall listwallCB_
 
@@ -205,5 +205,3 @@ private:
     QRadioButton* cbFs2_;  // Frame selection: All radio button
     QRadioButton* cbFs3_;  // Frame selection: Range radio button
 };
-
-#endif
