@@ -23,13 +23,11 @@ MvQZoom::MvQZoom(MgQPlotScene* scene, MvQPlotView* view, QGraphicsItem* parent)
     pen_                               = QPen(QColor(110, 110, 110), 2);
     brush_                             = QBrush(QColor(230, 230, 230, 180));
     currentAction_                     = NoAction;
-    zoomLayout_                        = 0;
+    zoomLayout_                        = nullptr;
     zoomWasPerformedAfterMouseRelease_ = false;
 }
 
-MvQZoom::~MvQZoom()
-{
-}
+MvQZoom::~MvQZoom() = default;
 
 QRectF MvQZoom::boundingRect() const
 {
@@ -57,7 +55,7 @@ void MvQZoom::mousePressEventFromView(QMouseEvent* event)
         //Get scene position
         zoomRectOrigin_ = plotView_->mapToScene(event->pos());
 
-        MgQSceneItem* sceneItem = 0;
+        MgQSceneItem* sceneItem = nullptr;
 
         if (plotScene_->identifyPos(zoomRectOrigin_, &sceneItem, &zoomLayout_)) {
             currentAction_ = ZoomAction;
@@ -117,7 +115,7 @@ void MvQZoom::mouseReleaseEventFromView(QMouseEvent* event)
             //Reset zoom data
             currentAction_                     = NoAction;
             zoomWasPerformedAfterMouseRelease_ = false;
-            zoomLayout_                        = 0;
+            zoomLayout_                        = nullptr;
         }
         else {
             //Get geo coordinates of rect corners
@@ -126,7 +124,7 @@ void MvQZoom::mouseReleaseEventFromView(QMouseEvent* event)
             //zoomLayout_->mapFromSceneToGeoCoords(sp1,gp1);
             //zoomLayout_->mapFromSceneToGeoCoords(sp2,gp2);
 
-            string trDef = zoomLayout_->mapFromSceneToTransformationDefinition(sp1, sp2);
+            std::string trDef = zoomLayout_->mapFromSceneToTransformationDefinition(sp1, sp2);
 
             QString layoutId(zoomLayout_->layout().id().c_str());
             setVisible(false);
@@ -134,7 +132,7 @@ void MvQZoom::mouseReleaseEventFromView(QMouseEvent* event)
             //Reset zoom data
             currentAction_                     = NoAction;
             zoomWasPerformedAfterMouseRelease_ = true;
-            zoomLayout_                        = 0;
+            zoomLayout_                        = nullptr;
 
             //			qDebug() << "zoom def:" << QString(trDef.c_str());
 
