@@ -26,7 +26,7 @@
 #include "MagPlusService.h"
 
 
-const QSize MvQZoomStackLevel::pixSize_{96,48};
+const QSize MvQZoomStackLevel::pixSize_{96, 48};
 
 //=========================
 //   MvQZoomStackLevel
@@ -38,8 +38,8 @@ void MvQZoomStackLevel::setImage(QImage& img)
     float h = img.height();
 
     //We copy the image into a pixmap with the maximum size of 92x46
-    float hMax = pixSize_.height()-6;
-    float wMax = 2*hMax;
+    float hMax = pixSize_.height() - 6;
+    float wMax = 2 * hMax;
     QPixmap pix;
     if (h * wMax / w <= hMax) {
         pix = QPixmap::fromImage(img).scaledToWidth(wMax, Qt::SmoothTransformation);
@@ -133,7 +133,7 @@ int MvQZoomStackData::update(int levelNum, int actLevel, MgQLayoutItem* item)
         if (levelNum_ == 0 && actLevel_ == -1) {
             if (levels_.count() == 0)  // && currentLayout_ != 0)
             {
-                MvQZoomStackLevel* level = new MvQZoomStackLevel;
+                auto* level = new MvQZoomStackLevel;
                 generatePreview(level, item);
                 //level->tb()->setChecked(true);
                 levels_.push_back(level);
@@ -168,8 +168,8 @@ int MvQZoomStackData::update(int levelNum, int actLevel, MgQLayoutItem* item)
 
         //If there are more levels
         else if (levelNumOri < levelNum_) {
-            MvQZoomStackLevel* level = new MvQZoomStackLevel;
-            generatePreview(level, item);           
+            auto* level = new MvQZoomStackLevel;
+            generatePreview(level, item);
             levels_.push_back(level);
             selectedLevel_ = levels_.count() - 1;
         }
@@ -218,7 +218,7 @@ void MvQZoomStackData::generatePreview(MvQZoomStackLevel* level, MgQLayoutItem*
     QRectF targetRect(0, 0, device.width(), device.height());
 
     //Create the painter
-    QPainter* painter = new QPainter(&device);
+    auto* painter = new QPainter(&device);
 
     //Fill the target device with with colour
     painter->fillRect(0, 0, device.width(), device.height(),
@@ -269,7 +269,7 @@ void MvQZoomStackData::slotStepTo(int level)
 //==================================================================
 
 MvQZoomStackModel::MvQZoomStackModel(QObject* parent) :
-     QAbstractItemModel(parent)
+    QAbstractItemModel(parent)
 {
 }
 
@@ -286,43 +286,35 @@ void MvQZoomStackModel::clearData()
     endResetModel();
 }
 
-int MvQZoomStackModel::columnCount( const QModelIndex& parent) const
+int MvQZoomStackModel::columnCount(const QModelIndex& parent) const
 {
-   return parent.isValid() ? 0 : 1;
+    return parent.isValid() ? 0 : 1;
 }
 
-int MvQZoomStackModel::rowCount( const QModelIndex& index) const
+int MvQZoomStackModel::rowCount(const QModelIndex& index) const
 {
-   if (!index.isValid() && data_)
-      return data_->levels().count();
-   else
-      return  0;
+    if (!index.isValid() && data_)
+        return data_->levels().count();
+    else
+        return 0;
 }
 
-QVariant MvQZoomStackModel::data( const QModelIndex& index, int role ) const
+QVariant MvQZoomStackModel::data(const QModelIndex& index, int role) const
 {
-   if( !data_ || index.row() < 0 || index.row() >= data_->levels().count() )
-      return {};
+    if (!data_ || index.row() < 0 || index.row() >= data_->levels().count())
+        return {};
 
-   switch(role) {
-      case Qt::DecorationRole:
-         return data_->levels()[index.row()]->pixmap();
-         break;
-      default:
-         break;
-   }
-
-   return {};
+    return role == Qt::DecorationRole ? data_->levels()[index.row()]->pixmap() : QVariant();
 }
 
-QModelIndex MvQZoomStackModel::index( int row, int column, const QModelIndex& /*parent */) const
+QModelIndex MvQZoomStackModel::index(int row, int column, const QModelIndex& /*parent */) const
 {
-   return createIndex(row,column);
+    return createIndex(row, column);
 }
 
-QModelIndex MvQZoomStackModel::parent( const QModelIndex & /*index*/ ) const
+QModelIndex MvQZoomStackModel::parent(const QModelIndex& /*index*/) const
 {
-   return QModelIndex();
+    return QModelIndex();
 }
 
 //=========================
@@ -333,7 +325,7 @@ MvQZoomStackWidget::MvQZoomStackWidget(MgQPlotScene* scene, QWidget* parent) :
     QWidget(parent)
 {
     setObjectName(QString::fromUtf8("zoomStackWidget"));
-    plotScene_   = scene;
+    plotScene_ = scene;
 
     auto vb = new QVBoxLayout(this);
     vb->setContentsMargins(margin_, margin_, margin_, margin_);
@@ -345,9 +337,9 @@ MvQZoomStackWidget::MvQZoomStackWidget(MgQPlotScene* scene, QWidget* parent) :
     view_->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     //view_->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     view_->setModel(model_);
-    vb->addWidget(view_,1);
+    vb->addWidget(view_, 1);
 
-    setFixedWidth(MvQZoomStackLevel::pixSize().width() + 2*margin_ + 10);
+    setFixedWidth(MvQZoomStackLevel::pixSize().width() + 2 * margin_ + 10);
 
     connect(view_, SIGNAL(clicked(QModelIndex)),
             this, SLOT(itemSelected(QModelIndex)));
@@ -392,7 +384,6 @@ void MvQZoomStackWidget::reset(MgQSceneItem* activeScene, bool changeActiveScene
 
     if (activeScene_) {
         if (MgQLayoutItem* zoomLayout = activeScene_->firstProjectorItem()) {
-
             int levelNum = zoomLayout->layout().zoomLevels();
             int actLevel = zoomLayout->layout().zoomCurrentLevel();
             QString id   = QString::fromStdString(zoomLayout->layout().id());
@@ -406,7 +397,8 @@ void MvQZoomStackWidget::reset(MgQSceneItem* activeScene, bool changeActiveScene
 
                     managePreviewLayout(page_[id], levelNum, actLevel);
                 }
-            } else {
+            }
+            else {
                 if (!page_.contains(id)) {
                     page_[id] = new MvQZoomStackData(id);
                     connect(page_[id], SIGNAL(actLevelChanged(QString, int)),
@@ -437,7 +429,7 @@ void MvQZoomStackWidget::managePreviewLayout(MvQZoomStackData* page, int levelNu
             plotScene_->removeItem(previewLayout);
 
             //Create a new scene and add the previewLayout to it!
-            QGraphicsScene* previewScene = new QGraphicsScene;
+            auto* previewScene = new QGraphicsScene;
             previewScene->addItem(previewLayout);
             previewLayout->setVisible(true);
             page->update(levelNum, actLevel, previewLayout);
@@ -448,17 +440,17 @@ void MvQZoomStackWidget::managePreviewLayout(MvQZoomStackData* page, int levelNu
 
 void MvQZoomStackWidget::adjustViewSize()
 {
-    auto px = MvQZoomStackLevel::pixSize();
-    int row = model_->rowCount();
-    int maxRow = 5;
-    int viewH = px.height()*row + 2*row*view_->spacing();
-    int maxViewH =  px.height()*maxRow+ 2*maxRow*view_->spacing();
+    auto px      = MvQZoomStackLevel::pixSize();
+    int row      = model_->rowCount();
+    int maxRow   = 5;
+    int viewH    = px.height() * row + 2 * row * view_->spacing();
+    int maxViewH = px.height() * maxRow + 2 * maxRow * view_->spacing();
 
     if (viewH > maxViewH) {
         viewH = maxViewH;
     }
 
-    setFixedHeight(viewH + 2*margin_ + 10);
+    setFixedHeight(viewH + 2 * margin_ + 10);
 }
 
 MvQZoomStackData* MvQZoomStackWidget::pageData(MgQSceneItem* item)
@@ -532,7 +524,7 @@ int MvQZoomStackWidget::currentLevel()
     return currentPage_->selectedLevel();
 }
 
-void MvQZoomStackWidget::itemSelected(const QModelIndex &current)
+void MvQZoomStackWidget::itemSelected(const QModelIndex& current)
 {
     if (current.isValid()) {
         slotStepTo(current.row());
