@@ -114,7 +114,7 @@ void ObjectInfo::ConvertRequestToMacro(MvRequest& inRequest,
             // Try to std::find out if this is a file reference.
             // We need to get the full path
             std::string tmpName = value;
-            if (IsParameterSet(inRequest, "_NAME"))
+            if (metview::IsParameterSet(inRequest, "_NAME"))
                 tmpName = std::string(mdirname(inRequest("_NAME"))) + "/" + value;
 
             std::string refName = MakeUserPath(tmpName);
@@ -126,7 +126,7 @@ void ObjectInfo::ConvertRequestToMacro(MvRequest& inRequest,
                 else
                     subRequest.setVerb("DATA");
 
-                if (!IsParameterSet(subRequest, "_NAME"))
+                if (!metview::IsParameterSet(subRequest, "_NAME"))
                     subRequest("_NAME") = tmpName.c_str();
 
                 Cached returnName = Convert(subRequest);
