@@ -938,7 +938,7 @@ bool ObjectList::IsDefaultValue(MvRequest& in, const char* param)
 
     MvRequest defReq = CreateDefaultRequest(in.getVerb());
 
-    if (IsParameterSet(in, param) && IsParameterSet(defReq, param)) {
+    if (metview::IsParameterSet(in, param) && metview::IsParameterSet(defReq, param)) {
         if (is_number(in(param)) && is_number(defReq(param)))
             retVal = ((double)in(param) == (double)defReq(param));
         else
