@@ -35,8 +35,7 @@
 // .DESCENDENT:
 //
 //
-#ifndef OutputFormatAction_H
-#define OutputFormatAction_H
+#pragma once
 
 #include "PlotModAction.h"
 
@@ -54,5 +53,3 @@ public:
     // Overriden from PlotModAction
     virtual void Execute(PmContext& context);
 };
-
-#endif
