@@ -675,7 +675,7 @@ void Page::SetProjection(const MvRequest& viewRequest)
 
 int Page::FirstPrintable()
 {
-    if (IsParameterSet(myRequest_, "FIRST_VISIBLE"))
+    if (metview::IsParameterSet(myRequest_, "FIRST_VISIBLE"))
         return myRequest_("FIRST_VISIBLE");
     else
         return 1;
