@@ -37,8 +37,10 @@
 // .ASCENDENT:
 //  Presentable
 //
-#ifndef Page_H
-#define Page_H
+
+#pragma once
+
+#include <memory>
 
 #include "Presentable.h"
 #include "PlotModView.h"
@@ -54,7 +56,7 @@ public:
     // Constructors
     Page(MvRequest& pageRequest);
     Page(const Page&);
-    virtual Presentable* Clone() const { return new Page(*this); }
+    Presentable* Clone() const override { return new Page(*this); }
 
     // Destructor
     ~Page();
@@ -63,36 +65,33 @@ public:
     // Overriden from Presentable class
 
     // Return my name
-    virtual string Name();
+    std::string Name() override;
 
-    virtual bool IsVisible()
-    {
-        return true;
-    }
+    bool IsVisible() override {return true;}
 
     // Draw me and all my children
-    virtual void Draw();
+    void Draw() override;
 
     //  draws the presentable
-    virtual void DrawProlog();
+    void DrawProlog() override;
 
     // Draw page header
-    virtual void DrawPageHeader();
+    void DrawPageHeader() override;
 
     // Register to draw trailer later
-    virtual void RegisterDrawTrailer();
+    void RegisterDrawTrailer() override;
 
     // Respond to a drop action
-    virtual void Drop(PmContext& context);
+    void Drop(PmContext& context) override;
 
     // Return the graphics engine (one per page)
-    virtual GraphicsEngine& GetGraphicsEngine() const
+    GraphicsEngine& GetGraphicsEngine() const override
     {
         return *engine_;
     }
 
     // Accept a visitor
-    virtual void Visit(Visitor& v);
+    void Visit(Visitor& v) override;
 
 #if 0
 	virtual void DrawBackground ( Canvas& canvas, bool emptyBack = false );
@@ -114,19 +113,19 @@ public:
     //virtual void ZoomRequest ( const Location& zoomCoord );
 
     // Zoom request given an index from the stack
-    virtual void ZoomRequest(int izoom);
+    void ZoomRequest(int izoom);
 
     // Zoom request given a string containing the zoom info
-    virtual void ZoomRequest(const string& zoomInfo);
+    void ZoomRequest(const std::string& zoomInfo);
 
     // Retrieve zoom information
-    virtual void ZoomInfo(int& zoomNumberOfLevels, int& zoomCurrentLevel);
+    void ZoomInfo(int& zoomNumberOfLevels, int& zoomCurrentLevel) override;
 
     // Replace the geographical area and plot the result
     //virtual void ReplaceArea ( const Location& zoomCoord, int zoom=-1 );
 
     // Generate a description of the page
-    virtual void DescribeYourself(ObjectInfo&);
+    void DescribeYourself(ObjectInfo&) override;
 
 #if 0
 	virtual void NeedsRedrawing(bool yesno);
@@ -142,30 +141,16 @@ public:
 	// Update Page's size
 #endif
 
-    virtual void ContentsDataUnit(int dataUnitId)
-    {
-        dataUnitId_ = dataUnitId;
-    }
+    void SetContentsDataUnit(int dataUnitId) override { dataUnitId_ = dataUnitId;}
+    int ContentsDataUnit() const override { return dataUnitId_; }
 
-    virtual int ContentsDataUnit()
-    {
-        return dataUnitId_;
-    }
-
-    virtual string MacroPlotIndexName(bool = true)
+    virtual std::string MacroPlotIndexName(bool = true) override
     {
         return myParent_->MacroPlotIndexName(true);
     }
 
-    virtual void DropShouldStay(bool drop)
-    {
-        dropShouldStay_ = drop;
-    }
-
-    virtual bool DropShouldStay()
-    {
-        return dropShouldStay_;
-    }
+    void SetDropShouldStay(bool drop) override { dropShouldStay_ = drop; }
+    bool DropShouldStay() const override { return dropShouldStay_; }
 
     // Local methods
     // Insert a new data unit (used in response to a drop action)
@@ -188,10 +173,10 @@ public:
     void InsertVisDefToPresentable(MvRequest&);
 
     // Remove icon from tree structure
-    virtual void RemoveIcon(MvIcon&);
+    void RemoveIcon(MvIcon&) override;
 
     // Remove all data icon from tree structure
-    virtual void RemoveAllData();
+    void RemoveAllData() override;
 
     // Create rows*columns subpages
     void CreateSubpages();
@@ -233,7 +218,7 @@ public:
     //U	void EraseForeDraw ();
 
     // Set/Get the projection associated to the canvas
-    virtual void SetProjection(const MvRequest& viewRequest);
+    void SetProjection(const MvRequest& viewRequest) override;
 
     PmProjection* GetProjection()
     {
@@ -247,26 +232,26 @@ public:
     }
 
     // Return TRUE if zooming is allowed for this projection
-    bool CanDoZoom();
+    bool CanDoZoom() override;
 
-    void SetDrawPriority(MvRequest& drawPriorRequest)
+    void SetDrawPriority(MvRequest& drawPriorRequest) override
     {
         drawingPriority_.SetPriority(drawPriorRequest);
     }
 
-    DrawingPriority& GetDrawPriority()
+    DrawingPriority& GetDrawPriority() override
     {
         return drawingPriority_;
     }
 
-    virtual PlotModView& GetView() const
+    PlotModView& GetView() const override
     {
         return *myView_;
     }
 
     int FirstPrintable();
 
-    virtual int PaperPageNumber(int);
+    int PaperPageNumber(int) override;
 
     // return list of canvas used by Page children
     //	virtual CanvasList GetCanvases();
@@ -304,20 +289,20 @@ public:
 	// Save View in the disk.
 #endif
 
-    bool CheckValidVisDef(MvIcon&, MvRequest&, MvIconList&);
+    bool CheckValidVisDefWithIcl(MvIcon&, MvRequest&, MvIconList&);
 
     // Dealing with Drop
-    virtual void DropSimulate(PmContext& context);
+    void DropSimulate(PmContext& context) override;
 
     // Dealing with Contents tools
-    virtual void contentsRequest(MvRequest&);
+    void contentsRequest(MvRequest&) override;
 
     // Update View structure
     virtual void UpdateView(const MvRequest&);
 
 protected:
     //Update certain data units for the new area
-    virtual void UpdateDataForZoom(const string& zoomInfo);
+    virtual void UpdateDataForZoom(const std::string& zoomInfo);
 
 private:
     // No copy allowed
@@ -338,5 +323,3 @@ private:
     std::unique_ptr<PmProjection> projection_;  // projection associated with page
     DrawingPriority drawingPriority_;
 };
-
-#endif
