@@ -35,8 +35,7 @@
 // .DESCENDENT:
 //
 //
-#ifndef PlotAction_H
-#define PlotAction_H
+#pragma once
 
 #include "PlotModAction.h"
 
@@ -54,5 +53,3 @@ public:
     // Overriden from PlotModAction
     virtual void Execute(PmContext& context);
 };
-
-#endif
