@@ -14,6 +14,7 @@
 #include "Page.h"
 #include "PlotMod.h"
 #include "Root.h"
+#include "MvLog.h"
 
 PlotModService::PlotModService(const char* serviceName,
                                PlotModView* view) :
@@ -33,9 +34,7 @@ PlotModService::PlotModService(const PlotModService& old) :
 {
 }
 
-PlotModService::~PlotModService()
-{
-}
+PlotModService::~PlotModService() = default;
 
 void PlotModService::endOfTask(MvTask* task)
 {
@@ -58,9 +57,7 @@ void PlotModService::endOfTask(MvTask* task)
         pageNode->DrawTask();  //Draw
     }
     else {
-        string title = "Error from ";
-        title += serviceName_.c_str();
-        PlotMod::Instance().UserWarningMessage(title);
+        MvLog().popup().warn() << "Error from " << serviceName_;
     }
 
     msg_.erase();
