@@ -248,8 +248,8 @@ PmCylindEquid::PmCylindEquid(const MvRequest& viewRequest) :
 //	GEODETIC TO EQUIDISTANT CYLINDRICAL COORDINATES
 Point PmCylindEquid ::LL2PC(Point& ptll)
 {
-    double ptllx = (double)ptll.X();
-    double ptlly = (double)ptll.Y();
+    auto ptllx = (double)ptll.X();
+    auto ptlly = (double)ptll.Y();
 
     ptllx = Prd * (ptllx - GPlon0) * cos(GPstlat1);
     ptlly = Prd * ptlly;
@@ -260,8 +260,8 @@ Point PmCylindEquid ::LL2PC(Point& ptll)
 //	EQUIDISTANT CYLINDRICAL TO GEODETIC COORDINATES
 Point PmCylindEquid ::PC2LL(Point& ptpc)
 {
-    double ptpcx = (double)ptpc.X();
-    double ptpcy = (double)ptpc.Y();
+    auto ptpcx = (double)ptpc.X();
+    auto ptpcy = (double)ptpc.Y();
 
     ptpcy = ptpcy / Prd;
     ptpcx = GPlon0 + ptpcx / (Prd * cos(GPstlat1));
@@ -419,7 +419,7 @@ Point PmPolarStereo ::PC2LL(Point& ptpc)
         e,      // Eccentricity
         pi,     // Ancillary variables
         lon0,   // auxilliary origin longitude
-        ro, t, xx, aux1, aux2, aux3, aux4, aux5, ptpcx=0., ptpcy, px, py;
+        ro, t, xx, aux1, aux2, aux3, aux4, aux5, ptpcx = 0., ptpcy, px, py;
 
     px = (double)ptpc.X();
     py = (double)ptpc.Y();
