@@ -43,8 +43,7 @@
 //// .COMMENTS:
 //  None
 
-#ifndef PM_GENERAL_PROJECTION_H
-#define PM_GENERAL_PROJECTION_H
+#pragma once
 
 #include "PmProjection.h"
 
@@ -740,5 +739,3 @@ public:
         return false;
     }
 };
-
-#endif
