@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef PM_projectionDEFINED
-#define PM_projectionDEFINED
+#pragma once
 
 #include <MvRequest.h>
 #include <Point.hpp>
@@ -540,5 +539,3 @@ public:
         return true;
     }
 };
-
-#endif
