@@ -39,8 +39,7 @@
 // .REFERENCES:
 //
 //
-#ifndef Preferences_H
-#define Preferences_H
+#pragma once
 
 #include "Presentable.h"
 
@@ -62,11 +61,8 @@ public:
     static MvRequest CoastRequest();
 
 
-
 private:
     Preferences& operator=(const Preferences&) { return *this; }
 
     Presentable* owner_;
 };
-
-#endif
