@@ -9,6 +9,8 @@
 
 #include "Presentable.h"
 
+#include <sstream>
+
 #include <Assertions.hpp>
 #include "MvDecoder.h"
 #include "DrawingPriority.h"
@@ -207,7 +209,7 @@ Presentable::~Presentable()
         myParent_->Remove(this);
 
     // Then, for all its children, delete them
-    MvChildIterator child = childList_.begin();
+    auto child = childList_.begin();
     while (child != childList_.end()) {
         // Before deletion, make the parent point to NULL
         // This is necessary because otherwise the top
@@ -226,10 +228,10 @@ Presentable::~Presentable()
     }
 }
 
-string
+std::string
 Presentable::Name()
 {
-    ostringstream ostr;
+    std::ostringstream ostr;
     ostr << "Presentable" << Id();
     return ostr.str();
 }
@@ -241,10 +243,10 @@ Presentable::Name()
 // -- INPUT  :  (none)
 //
 // -- OUTPUT :  A valid name for macro
-string
+std::string
 Presentable::MacroName()
 {
-    string str = (const char*)ObjectInfo::SpaceToUnderscore(this->Name().c_str());
+    std::string str = (const char*)ObjectInfo::SpaceToUnderscore(this->Name().c_str());
     return str;
 }
 
@@ -278,7 +280,7 @@ void Presentable::Remove(Presentable* p)
 
     // Test if child is at a lower depth than parent
     // Remove the child from the tree
-    MvChildIterator child = find(childList_.begin(), childList_.end(), p);
+    auto child = std::find(childList_.begin(), childList_.end(), p);
 
     ensure((*child) == p);
     childList_.erase(child);
@@ -306,7 +308,7 @@ struct DropFunctor
 
 void Presentable::Drop(PmContext& context)
 {
-    for_each(childList_.begin(), childList_.end(), DropFunctor(context));
+    std::for_each(childList_.begin(), childList_.end(), DropFunctor(context));
 }
 
 void Presentable::DropSimulate(PmContext& context)
@@ -314,8 +316,8 @@ void Presentable::DropSimulate(PmContext& context)
     if (!context.InRequest())
         return;
 
-    for (MvChildIterator ii = childList_.begin(); ii != childList_.end(); ii++)
-        (*ii)->Drop(context);
+    for (auto& ii : childList_)
+        ii->Drop(context);
 }
 
 #if 0
@@ -397,7 +399,7 @@ struct InitMatchingFunctor
 
 void Presentable::InitMatching()
 {
-    for_each(childList_.begin(), childList_.end(), InitMatchingFunctor());
+    std::for_each(childList_.begin(), childList_.end(), InitMatchingFunctor());
 }
 
 // --   METHOD  : DrawChildren
@@ -409,7 +411,7 @@ struct DrawFunctor
 
 void Presentable::DrawChildren()
 {
-    for_each(childList_.begin(), childList_.end(), DrawFunctor());
+    std::for_each(childList_.begin(), childList_.end(), DrawFunctor());
 }
 
 
@@ -422,7 +424,7 @@ struct RemoveAllDataFunctor
 
 void Presentable::RemoveAllDataChildren()
 {
-    for_each(childList_.begin(), childList_.end(), RemoveAllDataFunctor());
+    std::for_each(childList_.begin(), childList_.end(), RemoveAllDataFunctor());
 }
 
 void Presentable::RemoveMyData()
@@ -463,7 +465,7 @@ struct RemoveAllVisDefFunctor {
 void
 Presentable::RemoveAllVisDefChildren()
 {
-	for_each ( childList_.begin() ,childList_.end(), RemoveAllVisDefFunctor() );
+    std::for_each ( childList_.begin() ,childList_.end(), RemoveAllVisDefFunctor() );
 }
 
 void
@@ -522,7 +524,7 @@ struct RemoveAllPTextFunctor {
 void
 Presentable::RemoveAllPTextChildren()
 {
-	for_each ( childList_.begin() ,childList_.end(), RemoveAllPTextFunctor() );
+    std::for_each ( childList_.begin() ,childList_.end(), RemoveAllPTextFunctor() );
 }
 
 void
@@ -559,7 +561,7 @@ struct SaveFunctor {
 void
 Presentable::SaveChildren()
 {
-	for_each ( childList_.begin(), childList_.end(), SaveFunctor () );
+    std::for_each ( childList_.begin(), childList_.end(), SaveFunctor () );
 }
 #endif
 
@@ -589,8 +591,8 @@ Presentable::FindBranch(const int treeNodeId) const
 
 // --   METHOD  : FindBranchesByRequest
 // --   PURPOSE : Find branches of the tree which have an specific request
-// --   INPUT   : String requestName, vector<Presentable*>& presVec
-void Presentable::FindBranchesByRequest(string requestName, vector<Presentable*>& presVec)
+// --   INPUT   : String requestName, std::vector<Presentable*>& presVec
+void Presentable::FindBranchesByRequest(std::string requestName, std::vector<Presentable*>& presVec)
 {
     // Check for the current node
     const char* name = myRequest_.getVerb();
@@ -633,7 +635,7 @@ int Presentable::FindBranchIdByIconId(int iconId, int& dataId)
 // --   PURPOSE : Find a branch of the tree which has an specific View
 // --   INPUT   : String viewName
 Presentable*
-Presentable::FindBranch (string viewName)
+Presentable::FindBranch (std::string viewName)
 {
 	// Check for the current node
         if ( FindView(viewName) )
@@ -655,7 +657,7 @@ Presentable::FindBranch (string viewName)
 // --   PURPOSE : Find the superpage of the tree which has a node Id
 // --   INPUT   : Presentable Id ( unique )
 Presentable*
-Presentable::FindSuperPage() const
+Presentable::FindSuperPage(int /*index*/)
 {
     // Go up the tree, until a superpage is found
     // ( all superpages are children of the root )
@@ -1027,7 +1029,7 @@ struct VisitFunctor
 
 void Presentable::VisitChildren(Visitor& v)
 {
-    for_each(childList_.begin(), childList_.end(), VisitFunctor(v));
+    std::for_each(childList_.begin(), childList_.end(), VisitFunctor(v));
 }
 
 #if 0
@@ -1040,7 +1042,7 @@ struct ContentsFunctor {
 void
 Presentable::ChildrenContents( MvRequest& request )
 {
-	for_each ( childList_.begin(), childList_.end(), ContentsFunctor ( request ) );
+    std::for_each ( childList_.begin(), childList_.end(), ContentsFunctor ( request ) );
 }
 
 void
@@ -1138,7 +1140,7 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MacroVisDefMap& vdMap
 
     // Get an indexed name for the page. Need to be called even if
     // there are no drops, beacuse it updates the index.
-    string macroIndexName = this->MacroPlotIndexName();
+    std::string macroIndexName = this->MacroPlotIndexName();
 
     // 1) Describe Texts
     //    Find any texts associated with the presentable
@@ -1147,7 +1149,7 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MacroVisDefMap& vdMap
 
     // Loop over text icons
     bool first = true;
-    string ptextDrops;
+    std::string ptextDrops;
     MvListCursor lCursor;
     for (lCursor = iconList.begin(); lCursor != iconList.end(); ++lCursor) {
         MvIcon icon           = *lCursor;
@@ -1167,8 +1169,8 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MacroVisDefMap& vdMap
         }
 
         // Save icon name and its stacking order info
-        string sdesc = (const char*)myDescription.Convert(iconRequest);
-        ptextDrops   = ptextDrops + ", " + sdesc;
+        std::string sdesc = (const char*)myDescription.Convert(iconRequest);
+        ptextDrops        = ptextDrops + ", " + sdesc;
     }
 
     // 2) Describe Legends
@@ -1178,7 +1180,7 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MacroVisDefMap& vdMap
 
     // Loop over legend icons
     first = true;
-    string mlegDrops;
+    std::string mlegDrops;
     for (lCursor = iconList.begin(); lCursor != iconList.end(); ++lCursor) {
         MvIcon icon           = *lCursor;
         MvRequest iconRequest = icon.Request();
@@ -1197,8 +1199,8 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MacroVisDefMap& vdMap
         }
 
         // Save icon name and its stacking order info
-        string sdesc = (const char*)myDescription.Convert(iconRequest);
-        mlegDrops    = mlegDrops + ", " + sdesc;
+        std::string sdesc = (const char*)myDescription.Convert(iconRequest);
+        mlegDrops         = mlegDrops + ", " + sdesc;
     }
 
     // 3) Describe isolated Visdefs (not connected to the data)
@@ -1207,7 +1209,7 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MacroVisDefMap& vdMap
     dataBase.RetrieveIcon(PRES_VISDEF_REL, Id(), iconList);
 
     // Loop over visdefs
-    string listDrops;
+    std::string listDrops;
     MvIcon dummy;
     DescribeVisDefList(myDescription, iconList, dummy, listDrops, true, vdMap);
 
@@ -1217,7 +1219,7 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MacroVisDefMap& vdMap
     dataBase.RetrieveIcon(PRES_DATAUNIT_REL, Id(), iconList);
 
     // Loop over dataunits
-    MvListCursor du = iconList.begin();
+    auto du = iconList.begin();
     while (du != iconList.end()) {
         // If dataunit is not visible then process the next one
         MvIcon currentDataUnit = *du;
@@ -1229,14 +1231,14 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MacroVisDefMap& vdMap
 
         // Convert dataunit to macro code
         if (!(int)currentDataUnit.Request()("_SKIP_MACRO") && visible == 1) {
-            string dataUnitName = (const char*)myDescription.ConvertDataUnitToMacro(currentDataUnit);
+            std::string dataUnitName = (const char*)myDescription.ConvertDataUnitToMacro(currentDataUnit);
             if (dataUnitName.empty()) {
                 ++du;
                 continue;
             }
 
             // Save icon name and its stacking order info
-            listDrops = listDrops + string(", ") + dataUnitName;
+            listDrops = listDrops + std::string(", ") + dataUnitName;
 
             int use_mode = currentDataUnit.Request()("_USE_MODE");
             if (use_mode) {
@@ -1262,7 +1264,7 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MacroVisDefMap& vdMap
     {
         // Describe priority
         DrawingPriority& pageDrawPriority = this->GetDrawPriority();
-        string priorName                  = pageDrawPriority.DescribeYourself(myDescription, MacroName());
+        std::string priorName             = pageDrawPriority.DescribeYourself(myDescription, MacroName());
 
         if (!priorName.empty())
             listDrops = ptextDrops + mlegDrops + listDrops + "," + priorName;
@@ -1281,7 +1283,7 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MacroVisDefMap& vdMap
         myDescription.SetPlotAction();
         myDescription.PutNewLine("");
         myDescription.PutNewLine("# Plot command");
-        string str = "plot ( " + macroIndexName + ptextDrops + mlegDrops + listDrops + " )";
+        std::string str = "plot ( " + macroIndexName + ptextDrops + mlegDrops + listDrops + " )";
         myDescription.PutNewLine(str.c_str());
     }
 }
@@ -1293,11 +1295,11 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MvRequest& iconsReq)
 
     // Get an indexed name for the page. Need to be called even if
     // there are no drops, beacuse it updates the index.
-    string macroIndexName = this->MacroPlotIndexName();
+    std::string macroIndexName = this->MacroPlotIndexName();
 
     // Main loop: describe drops
     myDescription.PutNewLine("");
-    string listDrops;
+    std::string listDrops;
     while (iconsReq) {
         // Skip icon according to its status
         if ((const char*)iconsReq("_SKIP_MACRO") ||
@@ -1311,8 +1313,8 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MvRequest& iconsReq)
         // Convert icon to Macro code and save its name.
         // Certain type of icons needs a customised function.
         MvRequest req = iconsReq.justOneRequest();
-        string sdesc;
-        string iclass = (const char*)ObjectInfo::IconClass(req);
+        std::string sdesc;
+        std::string iclass = (const char*)ObjectInfo::IconClass(req);
         if (ObjectList::IsDataUnit(iclass.c_str())) {
             MvIcon ireq(req, true);
             sdesc = (const char*)myDescription.ConvertDataUnitToMacro(ireq);
@@ -1339,22 +1341,22 @@ void Presentable::DescribeDrops(ObjectInfo& myDescription, MvRequest& iconsReq)
         myDescription.SetPlotAction();
         myDescription.PutNewLine("");
         myDescription.PutNewLine("# Plot command");
-        string str = "plot ( " + macroIndexName + listDrops + " )";
+        std::string str = "plot ( " + macroIndexName + listDrops + " )";
         myDescription.PutNewLine(str.c_str());
     }
 }
 
 bool Presentable::DescribeVisDefList(ObjectInfo& myDescription,
                                      MvIconList& visdefList, MvIcon& dataUnit,
-                                     string& listDrops, bool addToDrops,
+                                     std::string& listDrops, bool addToDrops,
                                      MacroVisDefMap& vdMap)
 {
     // Retrieve the Icon Data Base
     MvIconDataBase& dataBase = this->IconDataBase();
 
     // Loop over visdefs
-    bool found      = false;
-    MvListCursor vd = visdefList.begin();
+    bool found = false;
+    auto vd    = visdefList.begin();
     while (vd != visdefList.end()) {
         // Skip visdef which is target not to be plotted
         MvIcon currentvd           = *vd;
@@ -1365,8 +1367,8 @@ bool Presentable::DescribeVisDefList(ObjectInfo& myDescription,
         }
 
         // Only generate the definition if it hasn't been done before
-        MacroVisDefMap::iterator ii = vdMap.find(currentvd.Id());
-        string visDefName;
+        auto ii = vdMap.find(currentvd.Id());
+        std::string visDefName;
         if (ii == vdMap.end()) {
             myDescription.PutNewLine("");
             visDefName            = myDescription.Convert(currentvdRequest);
@@ -1381,7 +1383,7 @@ bool Presentable::DescribeVisDefList(ObjectInfo& myDescription,
             addToDrops &&
             dataBase.IconVisibility(currentvd.Id())) {
             found     = true;
-            listDrops = listDrops + string(", ") + visDefName;
+            listDrops = listDrops + std::string(", ") + visDefName;
         }
         ++vd;
     }
@@ -1403,11 +1405,11 @@ int Presentable::PaperPageIndex() const
     return myParent_->PaperPageIndex();
 }
 
-void Presentable::PaperPageIndex(int paperPageIndex)
+void Presentable::PaperPageIndexV1(int paperPageIndex)
 {
     ensure(myParent_ != 0);
 
-    myParent_->PaperPageIndex(paperPageIndex);
+    myParent_->PaperPageIndexV1(paperPageIndex);
 }
 
 #if 0
@@ -1477,12 +1479,12 @@ void Presentable::DrawProlog()
         (*child)->DrawProlog();
 }
 
-void Presentable::DrawTrailer(MvRequest& fullReq)
+void Presentable::DrawTrailerWithReq(MvRequest& fullReq)
 {
     // Get children requests
     MvChildIterator child;
     for (child = childList_.begin(); child != childList_.end(); ++child)
-        (*child)->DrawTrailer(fullReq);
+        (*child)->DrawTrailerWithReq(fullReq);
 }
 
 void Presentable::DrawLayerInfo(const int iconRelId, const char* name)
@@ -1528,9 +1530,9 @@ bool Presentable::CheckDrawTask()
 
 void Presentable::NotifyObservers()
 {
-/*
-    set<PresentableObserver*> o = observers_;
-    for (set<PresentableObserver*>::iterator j = o.begin(); j != o.end(); ++j)
+    /*
+    std::set<PresentableObserver*> o = observers_;
+    for (std::set<PresentableObserver*>::iterator j = o.begin(); j != o.end(); ++j)
         (*j)->Notify(*this);
 */
 }
@@ -1542,7 +1544,7 @@ void Presentable::GetDataUnitInfo(MvRequest& out)
 
     // Get data unit list
     MvIconList* iconList = iconDataBase.IconList(DB_DATAUNIT);
-    MvListCursor lCursor = iconList->begin();
+    auto lCursor         = iconList->begin();
     if (lCursor == iconList->end()) {
         // No data unit available
         return;
@@ -1587,7 +1589,7 @@ void Presentable::ProcessCoastlines(MvRequest& coastRequest, bool calledFromMacr
 
     // Icon from a Macro
     if (calledFromMacro) {
-        string name;
+        std::string name;
         exclusive       = false;
         bool foreground = foundDU;
 
@@ -1597,10 +1599,11 @@ void Presentable::ProcessCoastlines(MvRequest& coastRequest, bool calledFromMacr
         if (layerMode &&
             (strcmp(layerMode, "FOREGROUND") == 0 ||
              strcmp(layerMode, "BACKGROUND") == 0)) {
-                exclusive = true;
-                this->SplitCoastlines(coastRequest, backReq, foreReq);
-        // split mode
-        } else {
+            exclusive = true;
+            this->SplitCoastlines(coastRequest, backReq, foreReq);
+            // split mode
+        }
+        else {
             if (foreground) {
                 foreReq = coastRequest;
                 foreReq.unsetParam("_APPL");  // remove tag stating that this came from Macro
@@ -1610,14 +1613,14 @@ void Presentable::ProcessCoastlines(MvRequest& coastRequest, bool calledFromMacr
                     name = "<Coastlines>";
 
                 // Set tags and update request names
-                string fname;
+                std::string fname;
                 fname                      = name + "(FG)";
                 foreReq("_NAME")           = fname.c_str();
                 foreReq("_PLOTTING_ORDER") = "FOREGROUND";
-            } else {
+            }
+            else {
                 exclusive = true;
                 this->SplitCoastlines(coastRequest, backReq, foreReq);
-
             }
         }
     }
@@ -1657,14 +1660,15 @@ void Presentable::CoastlinesBackground(MvRequest& req, MvRequest& backReq)
 
     const char* layerMode = (const char*)req("MAP_LAYER_MODE");
     // The whole coastlines icon is rendered into the foreground
-    if (layerMode  && strcmp(layerMode, "FOREGROUND") == 0) {
+    if (layerMode && strcmp(layerMode, "FOREGROUND") == 0) {
         return;
 
-    // The whole coastlines icon is rendered into the background
-    } else if (layerMode  && strcmp(layerMode, "BACKGROUND") == 0) {
-        backReq                   = req;
+        // The whole coastlines icon is rendered into the background
+    }
+    else if (layerMode && strcmp(layerMode, "BACKGROUND") == 0) {
+        backReq = req;
         // Set background tag and update icon name
-        string name;
+        std::string name;
         if ((const char*)backReq("_NAME"))
             name = (const char*)backReq("_NAME");
         name += "(BG)";
@@ -1672,11 +1676,12 @@ void Presentable::CoastlinesBackground(MvRequest& req, MvRequest& backReq)
         backReq("_PLOTTING_ORDER") = "BACKGROUND";
         return;
 
-    // Split mode
-    // Build a coastline background icon derived from a coastline icon
-    // By default, Coastline will only be plotted on the foreground, unless
-    // there is a sea/land shade to be drawn on the background.
-    } else {
+        // Split mode
+        // Build a coastline background icon derived from a coastline icon
+        // By default, Coastline will only be plotted on the foreground, unless
+        // there is a sea/land shade to be drawn on the background.
+    }
+    else {
         bool draw         = false;
         const char* onoff = (const char*)req("MAP_COASTLINE_LAND_SHADE");
         if (onoff && strcmp(onoff, "ON") == 0)
@@ -1699,7 +1704,7 @@ void Presentable::CoastlinesBackground(MvRequest& req, MvRequest& backReq)
             backReq("MAP_LABEL") = "OFF";
 
             // Set background tag and update icon name
-            string name;
+            std::string name;
             if ((const char*)backReq("_NAME"))
                 name = (const char*)backReq("_NAME");
             name += "(BG)";
@@ -1718,23 +1723,25 @@ void Presentable::CoastlinesForeground(MvRequest& req, MvRequest& foreReq)
     if (layerMode && strcmp(layerMode, "BACKGROUND") == 0) {
         return;
 
-    //The whole coastlines icon is rendered into the foreground
-    } else if (layerMode  && strcmp(layerMode, "FOREGROUND") == 0) {
+        //The whole coastlines icon is rendered into the foreground
+    }
+    else if (layerMode && strcmp(layerMode, "FOREGROUND") == 0) {
         foreReq = req;
-        string name;
-        if (const char *nch= (const char*)foreReq("_NAME")) {
+        std::string name;
+        if (const char* nch = (const char*)foreReq("_NAME")) {
             name = std::string(nch);
         }
         name += "(FG)";
-        foreReq("_NAME") = name.c_str();
+        foreReq("_NAME")           = name.c_str();
         foreReq("_PLOTTING_ORDER") = "FOREGROUND";
 
-    // Split mode!!!
-    // Build a coastline foreground icon derived from a coastline icon
-    // Account for land-sea shading. If they are setted to ON then
-    // they were previously drawn on the Background by default.
-    } else {
-        foreReq = req;
+        // Split mode!!!
+        // Build a coastline foreground icon derived from a coastline icon
+        // Account for land-sea shading. If they are setted to ON then
+        // they were previously drawn on the Background by default.
+    }
+    else {
+        foreReq           = req;
         const char* onoff = (const char*)req("MAP_COASTLINE_LAND_SHADE");
         if (onoff && strcmp(onoff, "ON") == 0)
             foreReq("MAP_COASTLINE_LAND_SHADE") = "OFF";
@@ -1744,7 +1751,7 @@ void Presentable::CoastlinesForeground(MvRequest& req, MvRequest& foreReq)
             foreReq("MAP_COASTLINE_SEA_SHADE") = "OFF";
 
         // Set foreground tag and update icon name
-        string name;
+        std::string name;
         if ((const char*)foreReq("_NAME"))
             name = (const char*)foreReq("_NAME");
         name += "(FG)";
@@ -1753,7 +1760,7 @@ void Presentable::CoastlinesForeground(MvRequest& req, MvRequest& foreReq)
     }
 }
 
-void Presentable::RemoveIcon(const int iconId)
+void Presentable::RemoveIconWithId(const int iconId)
 {
     // Get icon structure given an id.
     // This is needed because if icon is a Coastlines then its
@@ -1769,15 +1776,15 @@ void Presentable::RemoveIcon(const int iconId)
 
     // If icon is a coastline delete its companion
     MvRequest iconReq = icon.Request();
-    string verb       = (const char*)iconReq.getVerb();
+    std::string verb  = (const char*)iconReq.getVerb();
     if (ObjectList::IsVisDefCoastlines(verb.c_str())) {
         // Get icon name
-        string name = (const char*)iconReq("_NAME");
+        std::string name = (const char*)iconReq("_NAME");
         if (name.empty())
             return;
 
         // Get its companion name, if exists
-        string namec;
+        std::string namec;
         std::size_t found = name.find("(FG)");
         if (found != std::string::npos) {
             namec = name.substr(0, found);
@@ -1804,4 +1811,3 @@ void Presentable::RemoveIcon(const int iconId)
     this->HasDrawTask(true);
     this->DrawTask();
 }
-
