@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef ShareTargetManager_H
-#define ShareTargetManager_H
+#pragma once
 
 #include <string>
 #include <vector>
@@ -48,7 +47,7 @@ private:
 class ShareTargetManager : public std::vector<ShareTarget*>
 {
 public:
-    ShareTargetManager(){};
+    ShareTargetManager() {}
     ~ShareTargetManager();
 
     static ShareTargetManager* instance();
@@ -89,5 +88,3 @@ private:
 };
 
 //#endif
-
-#endif
