@@ -37,8 +37,7 @@
 //  ("Design Patterns", page. 107).
 //
 //
-#ifndef SimpleDecoder_H
-#define SimpleDecoder_H
+#pragma once
 
 #include "MvDecoder.h"
 
@@ -62,5 +61,3 @@ private:
     SimpleDecoder(const SimpleDecoder&);
     SimpleDecoder& operator=(const SimpleDecoder&) { return *this; }
 };
-
-#endif
