@@ -35,8 +35,7 @@
 // .REFERENCES:
 //
 
-#ifndef SkipAction_H
-#define SkipAction_H
+#pragma once
 #include "PlotModAction.h"
 
 class SkipAction : public PlotModAction
@@ -55,5 +54,3 @@ public:
     // Overriden from Base Class (PlotModAction)
     virtual void Execute(PmContext& context);
 };
-
-#endif
