@@ -7,8 +7,7 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef SPLINE_HPP
-#define SPLINE_HPP
+#pragma once
 
 #include <vector>
 
@@ -20,17 +19,17 @@ public:
     Spline(const std::vector<double>& x,
            const std::vector<double>& y);
     double eval(double x) const;
-    bool status() const {return status_;}
+    bool status() const { return status_; }
 
 private:
-    bool tdma( const std::vector<double> &a, const std::vector<double> &b,
-               const std::vector<double> &c, const std::vector<double> &d,
-               std::vector<double> &X );
+    bool tdma(const std::vector<double>& a, const std::vector<double>& b,
+              const std::vector<double>& c, const std::vector<double>& d,
+              std::vector<double>& X);
 
     std::vector<double> xp_;
     std::vector<double> yp_;
     // cubic polynomial coefficients
-    std::vector<double> coeffA_,coeffB_,coeffC_;
+    std::vector<double> coeffA_, coeffB_, coeffC_;
     bool status_{false};
 };
 
@@ -40,14 +39,13 @@ class SplineParam
 public:
     SplineParam() {}
     SplineParam(const std::vector<double>& x,
-           const std::vector<double>& y);
+                const std::vector<double>& y);
 
     void eval(double t, double& x, double& y) const;
-    bool status() const {return status_;}
+    bool status() const { return status_; }
+
 protected:
     Spline splineX_;
     Spline splineY_;
     bool status_{false};
 };
-
-#endif // SPLINE_HPP
