@@ -114,9 +114,9 @@ void SubPage::RemoveIcon(MvIcon& icon)
 
     Cached verb = icon.Request().getVerb();
     if (ObjectList::IsVisDef(verb)) {
-//        for (child = childList_.begin(); child != childList_.end(); ++child) {
-//            dataObj = (DataObject*)(*child);
-//        }
+        //        for (child = childList_.begin(); child != childList_.end(); ++child) {
+        //            dataObj = (DataObject*)(*child);
+        //        }
         // What else??
     }
     else if (ObjectList::IsDataUnit(verb)) {
@@ -171,7 +171,7 @@ bool SubPage::GetDrawPrior(DrawPriorMap* drawPriorMap)
     return true;
 }
 
-bool SubPage::GetDataObjects(list<DataObject*>& dolist)
+bool SubPage::GetDataObjects(std::list<DataObject*>& dolist)
 {
     if (childList_.empty())
         return false;
@@ -269,7 +269,7 @@ void SubPage::Draw()
     this->PendingDrawingsAdd();
 
     HasDrawTask(false);
-    VisitInBackground(false);
+    SetVisitInBackground(false);
 }
 
 #if 0
@@ -482,7 +482,7 @@ void SubPage::DrawTrailer()  //CHECK IF THIS IS STILL NEEDED
     this->PendingDrawingsAdd();
 }
 
-void SubPage::DrawTrailer(MvRequest& fullReq)
+void SubPage::DrawTrailerWithReq(MvRequest& fullReq)
 {
     // Retrieve the graphics engine
     GraphicsEngine& ge = this->GetGraphicsEngine();
@@ -617,7 +617,7 @@ long SubPage::PictureId(const char* typeName, bool generate)
     long id = 0;
     if (generate) {
         struct timeval t;
-        gettimeofday(&t, NULL);
+        gettimeofday(&t, nullptr);
         id                      = t.tv_sec + t.tv_usec;
         pictureIdMap_[typeName] = id;
     }
@@ -661,16 +661,16 @@ bool SubPage::NeedsRedrawing()
 }
 #endif
 
-bool SubPage::CheckValidVisDef(MvIcon& dataUnit, MvRequest& vdRequest, MvIconList& dataUnitList, int ndimFlag)
+bool SubPage::CheckValidVisDefWithIcl(MvIcon& dataUnit, MvRequest& vdRequest, MvIconList& dataUnitList, int ndimFlag)
 {
     if (childList_.size() == 0)
         return true;
 
     MvIconDataBase& dataBase = IconDataBase();
     bool found               = false;
-    for (MvChildIterator child = childList_.begin(); child != childList_.end(); ++child) {
+    for (auto& child : childList_) {
         // Get dataUnit object
-        DataObject* dataObj = (DataObject*)(*child);
+        auto* dataObj = (DataObject*)child;
 
         // Get corresponding dataunit icon from the DataBase
         MvIcon currentdu;
