@@ -19,6 +19,7 @@
 #include <Assertions.hpp>
 #include "MacroVisitor.h"
 #include "MvApplication.h"
+#include "MvLog.h"
 #include "MvScanFileType.h"
 #include "ObjectList.h"
 #include "Page.h"
@@ -65,7 +66,7 @@ SuperPage::SuperPage(const MvRequest& superpageRequest) :
         ensure(page != 0);
 
         // Insert the page in the superpage's child list
-        this->InsertOnePage(page);
+        this->InsertOnePageInner(page);
 
         // Goto the next page request
         pagesRequest.advance();
@@ -114,7 +115,7 @@ SuperPage::SuperPage(const SuperPage& old) :
     printIndex_(0)
 {
     // Make a new icon db from the old one
-    iconDataBase_ =  std::unique_ptr<MvIconDataBase>(new MvIconDataBase(old.IconDataBase()));
+    iconDataBase_ = std::unique_ptr<MvIconDataBase>(new MvIconDataBase(old.IconDataBase()));
 
     // Set new owner for preferences
     preferences_.Owner(*this);
@@ -195,9 +196,10 @@ struct DropFunctor
 
 void SuperPage::Drop(PmContext& context)
 {
+    MvLog().dbg() << "DROP";
     // Not dropped here, send to children
     if (!this->DroppedHere()) {
-        for_each(childList_.begin(), childList_.end(), DropFunctor(context));
+        std::for_each(childList_.begin(), childList_.end(), DropFunctor(context));
 
         return;
     }
@@ -211,17 +213,21 @@ void SuperPage::Drop(PmContext& context)
     while (dropRequest) {
         // Process Visdefs
         MvRequest request = dropRequest.justOneRequest();
-        Cached verb       = request.getVerb();
+        MvLog().dbg() << " ->req=";
+        request.print();
+
+        Cached verb = request.getVerb();
         if (ObjectList::IsVisDef(verb) == true) {
             this->InsertVisDef(request, vdReplace);
             vdReplace = false;
         }
-
-        // Process Coastlines
-        else if (ObjectList::IsVisDefCoastlines(verb))
+        else if (ObjectList::IsVisDefCoastlines(verb)) {
             ProcessCoastlines(request, PlotMod::Instance().CalledFromMacro());
-
-        // Process other icons
+        }
+        else if (ObjectList::IsWeatherSymbol(verb)) {
+            PlotMod::Instance().addWeatherSymbol(request);
+            // Process other icons
+        }
         else {
             if (!this->InsertCommonIcons(request))
                 remainingReq = remainingReq + request;
@@ -236,7 +242,7 @@ void SuperPage::Drop(PmContext& context)
         context.Update(remainingReq);
 
         // Send requests to Page
-        for_each(childList_.begin(), childList_.end(), DropFunctor(context));
+        std::for_each(childList_.begin(), childList_.end(), DropFunctor(context));
     }
     else
         context.AdvanceToEnd();
@@ -303,7 +309,7 @@ SuperPage::SaveInFile()
 // -- INPUT  :  (none)
 //
 // -- OUTPUT :  The name of the superpage
-string
+std::string
 SuperPage::Name()
 {
     return (const char*)ObjectInfo::ObjectName(myRequest_, "SuperPage", Id());
@@ -337,7 +343,7 @@ void SuperPage::DrawProlog()
         (*child)->DrawProlog();
 }
 
-void SuperPage::DrawTrailer(MvRequest& fullReq)
+void SuperPage::DrawTrailerWithReq(MvRequest& fullReq)
 {
     // Nothing to be drawn
     if (!this->HasDrawTask())
@@ -369,7 +375,7 @@ void SuperPage::GetAllRequests(MvRequest& fullReq, bool checkIconStatus)
     // Get all page requests
     MvChildIterator child;
     for (child = childList_.begin(); child != childList_.end(); ++child)
-        (*child)->DrawTrailer(fullReq);
+        (*child)->DrawTrailerWithReq(fullReq);
 
     // Take into consideration the icon status
     if (checkIconStatus) {
@@ -392,7 +398,7 @@ void SuperPage::SortRequest(MvRequest& in, MvRequest& out, bool save_layer)
     int index                = 0;
     float order              = -1.;
     float delta              = 0.001;
-    const string slayer("LAYER");
+    const std::string slayer("LAYER");
     in.rewind();
     while (in) {
         MvRequest req = in.justOneRequest();
@@ -422,7 +428,7 @@ void SuperPage::SortRequest(MvRequest& in, MvRequest& out, bool save_layer)
             continue;
         }
 
- #if 0
+#if 0
         // Skip icon if its visibility is off
         if (!dataBase.IconVisibility(req("_ID"))) {
             // Icon not to be drawn, skip it
@@ -432,7 +438,7 @@ void SuperPage::SortRequest(MvRequest& in, MvRequest& out, bool save_layer)
 
             // If icon is a dataunit then it is followed by a visdef,
             // which needs to be skipped too.
-            if (in && string(in.getVerb()) == "VISDEFS") {
+            if (in && std::string(in.getVerb()) == "VISDEFS") {
                 index++;
                 in.advance();
             }
@@ -455,7 +461,7 @@ void SuperPage::SortRequest(MvRequest& in, MvRequest& out, bool save_layer)
 
         // If the next icon is a visdef then it does not have the visibility
         // and stacking order tags. So, it needs to be added to the list now.
-        if (in && string(in.getVerb()) == "VISDEFS") {
+        if (in && std::string(in.getVerb()) == "VISDEFS") {
             order += delta;
             mymap[order] = index++;
 
@@ -619,8 +625,7 @@ void SuperPage::GenerateMacro()
     Presentable::Visit(*vis);
 
     // Post a message on the screen
-    string message = "Macro Generated in File " + macroFileName_;
-    PlotMod::Instance().UserInfoMessage(message);
+    MvLog().popup().info() << "Macro generated in file " << macroFileName_;
 }
 
 // -- METHOD :  Visit
@@ -664,7 +669,7 @@ SuperPage::GetMySize()
 //
 //               Has the side effect of updating member pageIndex_.
 //
-string
+std::string
 SuperPage::MacroPlotIndexName(bool useIndex)
 {
     int index;
@@ -673,7 +678,7 @@ SuperPage::MacroPlotIndexName(bool useIndex)
     else
         index = childList_.size() + 1;
 
-    ostringstream ostr;
+    std::ostringstream ostr;
     ostr << "dw[" << index << "]";
     return ostr.str();
 }
@@ -693,7 +698,7 @@ void SuperPage::DescribeDevice(ObjectInfo& myDescription)
 
     // Generate description for file
     MvRequest reqDev("PDFOUTPUT");
-    string filename = (const char*)ObjectInfo::ObjectPath(myRequest_);
+    std::string filename = (const char*)ObjectInfo::ObjectPath(myRequest_);
     filename += "/pdf";
     reqDev("OUTPUT_NAME") = filename.c_str();
     myDescription.ConvertRequestToMacro(reqDev, PUT_END, "File", "pdf_output");
@@ -720,22 +725,22 @@ void SuperPage::DescribeYourself(ObjectInfo& myDescription)
     myDescription.PutNewLine("");
     myDescription.PutNewLine("# SuperPage description");
 
-    set<Cached> skipSet;
+    std::set<Cached> skipSet;
     skipSet.insert("PAGES");
     myDescription.ConvertRequestToMacro(myRequest_, PUT_LAST_COMMA,
                                         MacroName().c_str(), "plot_superpage",
                                         skipSet);
 
     // Print the page list
-    int size        = myDescription.MaximumParameterNameLength(myRequest_);
-    string pageList = ListMyPages();
+    int size             = myDescription.MaximumParameterNameLength(myRequest_);
+    std::string pageList = ListMyPages();
     myDescription.FormatLine("PAGES", pageList.c_str(), "", size);
 
     // Close superpage request
     myDescription.PutNewLine(")");
     myDescription.PutNewLine("# plot_superpage returns a list of drop identifiers.");
     myDescription.PutNewLine("# Index 1 is for first page, and so on.\n");
-    string ret = "return " + MacroName();
+    std::string ret = "return " + MacroName();
     myDescription.PutNewLine(ret.c_str());
 }
 
@@ -747,14 +752,14 @@ void SuperPage::DescribeYourself(ObjectInfo& myDescription)
 //
 // --  OUTPUT  : list of page name ( enclosed in [..] )
 //
-string
+std::string
 SuperPage::ListMyPages()
 {
     // Put an enclosing brace
-    string pageNames = "[ ";
+    std::string pageNames = "[ ";
 
-    MvChildIterator child = childList_.begin();
-    int npages            = 1;
+    auto child = childList_.begin();
+    int npages = 1;
     while (child != childList_.end()) {
         // Put a comma separator
         if (npages > 1)
@@ -773,7 +778,7 @@ SuperPage::ListMyPages()
     return pageNames;
 }
 
-void SuperPage::PrintAll(bool printAll)
+void SuperPage::PrintAllV1(bool printAll)
 {
     if (printAll)
         myRequest_("_PRINT_OPTION") = "ALL";
@@ -909,7 +914,7 @@ int SuperPage::IncrementPrintIndex()
     return printIndex_;
 }
 
-void SuperPage::ZoomRequest(int treeNodeId, const string& zoomInfo)
+void SuperPage::ZoomRequestByDef(int treeNodeId, const std::string& zoomInfo)
 {
     // Find which child to send the information
     MvChildConstIterator child;
@@ -925,11 +930,10 @@ void SuperPage::ZoomRequest(int treeNodeId, const string& zoomInfo)
             return;
         }
     }
-
-    PlotMod::Instance().UserWarningMessage("Page to perform the zoom not found");
+    MvLog().popup().warn() << "Page to perform the zoom not found";
 }
 
-void SuperPage::ZoomRequest(int treeNodeId, int izoom)
+void SuperPage::ZoomRequestByLevel(int treeNodeId, int izoom)
 {
     // Find which child to send the information
     MvChildConstIterator child;
@@ -946,7 +950,7 @@ void SuperPage::ZoomRequest(int treeNodeId, int izoom)
         }
     }
 
-    PlotMod::Instance().UserWarningMessage("Page to perform the zoom not found");
+    MvLog().popup().warn() << "Page to perform the zoom not found";
 }
 
 bool SuperPage::UpdateLayerTransparency(int id, int value)
@@ -1012,7 +1016,7 @@ bool SuperPage::ExportPlot(MvRequest* req, bool sync)
     return true;
 }
 
-//typedef map<int, string> ecVisDefMap;
+//typedef std::map<int, std::string> ecVisDefMap;
 
 MvRequest
 SuperPage::ExportToEcCharts()
@@ -1055,9 +1059,9 @@ SuperPage::ExportToEcCharts()
         // Formula, Simple Formula, Grib Filter, ...
         else if (ObjectList::IsDataUnit(verb) ||
                  strcmp(verb, "PGRIB") == 0) {
-            ecReq           = ecReq + request;
-            string iclass   = (const char*)ObjectInfo::IconClass(request);
-            string fileName = ObjectInfo::FileName(request);
+            ecReq                = ecReq + request;
+            std::string iclass   = (const char*)ObjectInfo::IconClass(request);
+            std::string fileName = ObjectInfo::FileName(request);
             if (!IsBinaryOrMissingFile(fileName.c_str())) {
                 MvRequest fileReq;
                 fileReq.read(fileName.c_str(), true);
@@ -1086,7 +1090,7 @@ void SuperPage::PrintFile(MvRequest& req)
 {
     // Create output format request
     MvRequest driverReq("PDFOUTPUT");
-    string fileName = tempnam(getenv("METVIEW_TMPDIR"), "plot");
+    std::string fileName = tempnam(getenv("METVIEW_TMPDIR"), "plot");
     fileName += ".pdf";
     driverReq("OUTPUT_FULLNAME") = fileName.c_str();
     if ((const char*)req("_OUTPUT_FRAME_LIST")) {
@@ -1143,7 +1147,7 @@ Page* SuperPage::InsertOnePage(MvRequest& superpageRequest)
     ensure(page != 0);
 
     // Insert the page in the superpage's child list
-    this->InsertOnePage(page);
+    this->InsertOnePageInner(page);
 
     // Create and store the device information
     this->SetDeviceInfo();
@@ -1151,7 +1155,7 @@ Page* SuperPage::InsertOnePage(MvRequest& superpageRequest)
     return page;
 }
 
-void SuperPage::InsertOnePage(Page* page)
+void SuperPage::InsertOnePageInner(Page* page)
 {
     // Add page to the childlist
     this->Insert(page);
@@ -1179,7 +1183,7 @@ void SuperPage::contentsRequest(MvRequest& req)
         }
     }
 
-    PlotMod::Instance().UserWarningMessage("Page to perform the zoom not found");
+    MvLog().popup().warn() << "Page to perform the zoom not found";
 }
 
 #ifndef NOMETVIEW_QT
