@@ -37,8 +37,10 @@
 // .ASCENDENT:
 //  Presentable
 //
-#ifndef SuperPage_H
-#define SuperPage_H
+
+#pragma once
+
+#include <memory>
 
 #include "Device.h"
 #include "Preferences.h"
@@ -55,7 +57,7 @@ public:
     SuperPage(const MvRequest& inRequest);
     SuperPage(const SuperPage&);
 
-    virtual Presentable* Clone() const { return new SuperPage(*this); }
+    Presentable* Clone() const override { return new SuperPage(*this); }
 
     // Destructor
     ~SuperPage();
@@ -64,31 +66,25 @@ public:
     // Overriden from Presentable class
 
     // Create a reply request for creation
-    virtual void CreateReply(MvRequest& replyRequest);
+    void CreateReply(MvRequest& replyRequest) override;
 
     // Respond to a drop action
-    virtual void Drop(PmContext& context);
-
-    // Returns the preferences
-    virtual Preferences& GetPreferences()
-    {
-        return preferences_;
-    }
+    void Drop(PmContext& context) override;
 
     // Set print option: All subpages or visible ones only
-    virtual void PrintAll(bool);
-    virtual bool PrintAll();
+    void PrintAllV1(bool) override;
+    bool PrintAll() override;
 
     // Return my Name
-    virtual string Name();
+    virtual std::string Name() override;
 
     //	virtual Cached SuperPageName()
     //		{ return this->Name(); }
 
-    virtual string MacroPlotIndexName(bool useIndex = false);
+    std::string MacroPlotIndexName(bool useIndex = false) override;
 
     // Returns a pointer to the icon data base
-    virtual MvIconDataBase& IconDataBase() const
+    MvIconDataBase& IconDataBase() const override
     {
         return *(iconDataBase_.get());
     }
@@ -96,24 +92,21 @@ public:
     //	virtual void    Close();
     // Close all objects associated with the SuperPage
 
-    virtual void RemoveAllData()
+    void RemoveAllData() override
     {
         RemoveAllDataChildren();
     }
 
-    virtual void Draw();
+    void Draw() override;
     // Draws the superpage and all its children
 
-    virtual void DrawProlog();
-    virtual void DrawTrailer(MvRequest&);
+    void DrawProlog() override;
+    void DrawTrailerWithReq(MvRequest&) override;
 
-    virtual bool IsVisible()
-    {
-        return true;
-    }
+    bool IsVisible() override {return true;}
 
     // Implements the visitor pattern
-    virtual void Visit(Visitor& v);
+    void Visit(Visitor& v) override;
 
     // Returns the device associated to the superpage
     virtual Device& GetDevice() const
@@ -126,7 +119,7 @@ public:
     virtual void SetDeviceInfo();
 
     // Indicates the size of the superpage
-    virtual PaperSize GetMySize();
+    PaperSize GetMySize() override;
 
     // Retrieve all requests for the whole tree.
     // The requests have already been built and saved internally, but
@@ -134,7 +127,7 @@ public:
     // visibility/order/transparency are modified by the uPlot Sidebar.
     // Boolean checkIconStatus = false means use the saved requests;
     // otherwise, rebuild the requests by analysing the whole tree.
-    void GetAllRequests(MvRequest&, bool checkIconStatus = false);
+    void GetAllRequests(MvRequest&, bool checkIconStatus = false) override;
 
     // Rebuild the request by analisying the icon features: order,
     // visibility and transparency.
@@ -144,7 +137,7 @@ public:
     virtual void DescribeDevice(ObjectInfo& myDescription);
 
     // Generate a description of the superpage
-    virtual void DescribeYourself(ObjectInfo& myDescription);
+    void DescribeYourself(ObjectInfo& myDescription) override;
 
     // Insert Visdef in the database
     void InsertVisDef(MvRequest&, bool);
@@ -159,22 +152,22 @@ public:
     // If there is no Text Title here, search up the tree (i.e the Root).
     // If there is no Text Annotation, do not need to search up the tree,
     // because this type of icon is not mandatory to have.
-    virtual bool RetrieveTextTitle(MvIconList&);
-    void RetrieveTextAnnotation(MvIconList&);
+    bool RetrieveTextTitle(MvIconList&) override;
+    void RetrieveTextAnnotation(MvIconList&) override;
 
     // Retrieve the Legend
     // If failed, retrieves the root's Legend (default)
-    virtual bool RetrieveLegend(MvIcon&);
+    bool RetrieveLegend(MvIcon&) override;
 
     // Zoom methods
     //virtual void ZoomRequest ( int id, const Location& zoomCoord );
-    virtual void ZoomRequest(int id, const string&);
-    virtual void ZoomRequest(int id, int izoom);
+    void ZoomRequestByDef(int id, const std::string&) override;
+    void ZoomRequestByLevel(int id, int izoom) override;
 
     // Layer methods
-    virtual bool UpdateLayerTransparency(int, int);
-    virtual bool UpdateLayerVisibility(int, bool);
-    virtual bool UpdateLayerStackingOrder(int, int);
+    bool UpdateLayerTransparency(int, int) override;
+    bool UpdateLayerVisibility(int, bool) override;
+    bool UpdateLayerStackingOrder(int, int) override;
 
     // --  Internal methods
 
@@ -186,10 +179,10 @@ public:
     //		{ zoomPageId_ = id; }
 
     // Generate a new macro file based on the plot displayed on the screen
-    void GenerateMacro();
+    void GenerateMacro() override;
 
     // Provide a list of the names of the pages
-    string ListMyPages();
+    std::string ListMyPages();
 
     //	void PrintingFinished ( MvRequest& );
     // Complete the printing job - tell the user
@@ -197,12 +190,12 @@ public:
     //	void SaveInFile();
     // Save the contents of the superpage in a file
 
-    virtual void PendingDrawingsAdd()
+    void PendingDrawingsAdd() override
     {
         pendingDrawings_++;
     }
 
-    virtual void PendingDrawingsRemove()
+    void PendingDrawingsRemove() override
     {
         pendingDrawings_--;
     }
@@ -212,19 +205,19 @@ public:
     //			  (  hasNewpage_  == true  ); }
 
     // Returns the number of SuperPages for this SuperPage
-    virtual int PageIndex()
+    int PageIndex() override
     {
         return superPageIndex_;
     }
 
     // Returns the number of paper pages
-    virtual int PaperPageIndex()
+    int PaperPageIndex() const override
     {
         return paperPageIndex_;
     }
 
     // Sets the number of paper pages
-    virtual void PaperPageIndex(int paperPageIndex)
+    void PaperPageIndexV1(int paperPageIndex) override
     {
         paperPageIndex_ = paperPageIndex;
     }
@@ -239,7 +232,7 @@ public:
     //        virtual void RedrawIfWindow(int visdefId = 0);
     // Sets redrawing flags and does AddTask if needed.
 
-    virtual void RemoveIcon(MvIcon&);
+    void RemoveIcon(MvIcon&) override;
 
     //	virtual void SetInputPresentableId ( int );
 
@@ -253,22 +246,22 @@ public:
     // Dealing with Export plotting
     // Save a copy of the plotting. Set sync to true to make sure
     // that the file will be created before returning to the caller.
-    virtual bool ExportPlot(MvRequest*, bool sync = false);
+    bool ExportPlot(MvRequest*, bool sync = false) override;
 
     // Get the appropriate requests from the Display Window to
     // be used by ecCharts
-    virtual MvRequest ExportToEcCharts();
+    MvRequest ExportToEcCharts() override;
 
     // Dealing with Print plotting
     // Recreate the plotting and send it to a given printer
-    virtual void PrintFile(MvRequest&);
+    void PrintFile(MvRequest&) override;
 
     // Insert one Page
-    virtual Page* InsertOnePage(MvRequest&);
-    void InsertOnePage(Page*);
+    Page* InsertOnePage(MvRequest&) override;
+    void InsertOnePageV1(Page*);
 
     // Dealing with Contents tools
-    virtual void contentsRequest(MvRequest&);
+    void contentsRequest(MvRequest&) override;
 
 #ifndef NOMETVIEW_QT
     static void setPlotApplication(uPlotBase* pa)
@@ -286,12 +279,14 @@ private:
     // Copy Constructor and Operator=
     SuperPage& operator=(const SuperPage&);
 
+    void InsertOnePageInner(Page*);
+
     // Members
-    PaperSize size_;                         // size of superpage in paper coords (cms)
-    string macroFileName_;                   // name of the macro file which is produced
+    PaperSize size_;                                // size of superpage in paper coords (cms)
+    std::string macroFileName_;                     // name of the macro file which is produced
     std::unique_ptr<MvIconDataBase> iconDataBase_;  // icon data base (one per superpage)
     std::unique_ptr<Device> myDevice_;              // device (plot media)
-    Preferences preferences_;                // preferences associated to the superpage
+    Preferences preferences_;                       // preferences associated to the superpage
 
     int pageIndex_;  // number of pages used in Macro generation
 
@@ -308,5 +303,3 @@ private:
     static uPlotBase* plotApplication_;
 #endif
 };
-
-#endif
