@@ -336,12 +336,27 @@ bool ThermoView::ConsistencyCheckWithStr(MvRequest& req1, MvRequest& req2, std::
 
     if ((const char*)req1("COORDINATES"))
         vparam.push_back("COORDINATES");
+    if ((const char*)req1("THRESHOLD"))
+        vparam.push_back("THRESHOLD");
     if ((const char*)req1("AREA_AVERAGE"))
         vparam.push_back("AREA_AVERAGE");
     if ((const char*)req1("STATION"))
         vparam.push_back("STATION");
+    if ((const char*)req1("WMO_NAME"))
+        vparam.push_back("WMO_NAME");
+    if ((const char*)req1("WMO_IDENT"))
+        vparam.push_back("WMO_IDENT");
+    if ((const char*)req1("WIGOS_SERIES"))
+        vparam.push_back("WIGOS_SERIES");
+    if ((const char*)req1("WIGOS_ISSUER"))
+        vparam.push_back("WIGOS_ISSUER");
+    if ((const char*)req1("WIGOS_ISSUE_NUMBER"))
+        vparam.push_back("WIGOS_ISSUE_NUMBER");
+    if ((const char*)req1("WIGOS_LOCAL_NAME"))
+        vparam.push_back("WIGOS_LOCAL_NAME");
+    if ((const char*)req1("POINT_EXTRACTION"))
+        vparam.push_back("POINT_EXTRACTION");
 
-    vparam.push_back("POINT_EXTRACTION");
     vparam.push_back("DEW_POINT_FORMULATION");
     vparam.push_back("TEMPERATURE_PARAM");
     vparam.push_back("SPECIFIC_HUMIDITY_PARAM");
