@@ -75,8 +75,8 @@ VertProfViewM3Factory::Translate(const MvRequest& in)
     MvLog().warn() << "The Metview 3 VERTICAL PROFILE VIEW icon is deprecated. Parameter OVERLAY CONTROL will not be internally translated.";
 
     // Copy Page and Subpage parameters
-    CopySomeParameters(req, viewReq, "Subpage");
-    CopySomeParameters(req, viewReq, "Page");
+    metview::CopySomeParameters(req, viewReq, "Subpage");
+    metview::CopySomeParameters(req, viewReq, "Page");
 
     // Expand output request
     MvRequest out = ObjectList::ExpandRequest(viewReq, EXPAND_DEFAULTS);
@@ -246,8 +246,8 @@ bool VertProfView::UpdateView()
     cartView.setValue("VERTICAL_AXIS", viewRequest_.getSubrequest("LEVEL_AXIS"));
 
     // Copy PAGE and SUBPAGE definition
-    CopySomeParameters(viewRequest_, cartView, "PAGE");
-    CopySomeParameters(viewRequest_, cartView, "SUBPAGE");
+    metview::CopySomeParameters(viewRequest_, cartView, "PAGE");
+    metview::CopySomeParameters(viewRequest_, cartView, "SUBPAGE");
 
     // Save the original request
     cartView("_ORIGINAL_REQUEST") = viewRequest_;
