@@ -39,8 +39,7 @@
 // .REFERENCES:
 //  The relation between
 //
-#ifndef Visitor_H
-#define Visitor_H
+#pragma once
 
 class SuperPage;
 class Page;
@@ -71,5 +70,3 @@ private:
     Visitor(const Visitor&);
     Visitor& operator=(const Visitor&) { return *this; }
 };
-
-#endif
