@@ -41,8 +41,7 @@
 // .REFERENCES:
 //
 //
-#ifndef XDevice_H
-#define XDevice_H
+#pragma once
 
 #include "Device.h"
 
@@ -65,5 +64,3 @@ private:
     XDevice(const XDevice&);
     XDevice& operator=(const XDevice&) { return *this; }
 };
-
-#endif
