@@ -79,8 +79,8 @@ XSectViewM3Factory::Translate(const MvRequest& in)
     MvLog().warn() << "The Metview 3 CROSS SECTION VIEW icon is deprecated. Parameter OVERLAY CONTROL will not be internally translated.";
 
     // Copy Page and Subpage parameters
-    CopySomeParameters(req, viewReq, "Subpage");
-    CopySomeParameters(req, viewReq, "Page");
+    metview::CopySomeParameters(req, viewReq, "Subpage");
+    metview::CopySomeParameters(req, viewReq, "Page");
 
     // Expand output request
     MvRequest out = ObjectList::ExpandRequest(viewReq, EXPAND_DEFAULTS);
@@ -200,15 +200,15 @@ bool XSectView::UpdateView()
     cartView.setValue("VERTICAL_AXIS", viewRequest_.getSubrequest("VERTICAL_AXIS"));
 
     // Copy PAGE and SUBPAGE definition
-    CopySomeParameters(viewRequest_, cartView, "PAGE");
-    CopySomeParameters(viewRequest_, cartView, "SUBPAGE");
+    metview::CopySomeParameters(viewRequest_, cartView, "PAGE");
+    metview::CopySomeParameters(viewRequest_, cartView, "SUBPAGE");
 
     // Copy the original request without certain parameteres (to avoid duplication)
-    RemoveParameters(viewRequest_, "HORIZONTAL_AXIS");
-    RemoveParameters(viewRequest_, "VERTICAL_AXIS");
-    RemoveParameters(viewRequest_, "PAGE");
-    RemoveParameters(viewRequest_, "SUBPAGE");
-    RemoveParameters(viewRequest_, "_");
+    metview::RemoveParameters(viewRequest_, "HORIZONTAL_AXIS");
+    metview::RemoveParameters(viewRequest_, "VERTICAL_AXIS");
+    metview::RemoveParameters(viewRequest_, "PAGE");
+    metview::RemoveParameters(viewRequest_, "SUBPAGE");
+    metview::RemoveParameters(viewRequest_, "_");
     cartView("_ORIGINAL_REQUEST") = viewRequest_;
 
     // Update request
