@@ -15,10 +15,7 @@ ZoomStacks::ZoomStacks() :
     //empty constructor
 }
 
-ZoomStacks::~ZoomStacks()
-{
-    //empty destructor
-}
+ZoomStacks::~ZoomStacks() = default;
 
 void ZoomStacks::ClearAll()
 {
@@ -28,7 +25,7 @@ void ZoomStacks::ClearAll()
     zoomIndex_ = -1;
 }
 
-string
+std::string
 ZoomStacks::Get(int index)
 {
     // Check input index
@@ -42,7 +39,7 @@ ZoomStacks::Get(int index)
     }
 }
 
-void ZoomStacks::GeodeticPush(const string& zinfo)
+void ZoomStacks::GeodeticPush(const std::string& zinfo)
 {
     // If this zoom is not related to the stack top position then
     // remove elements from the stack
