@@ -42,7 +42,6 @@
 
 #include "MvQAbout.h"
 #include "MvQApplication.h"
-#include "MvQCursorDataWidget.h"
 #include "MvQDataWidget.h"
 #include "MvQKeyProfileTree.h"
 #include "MvQLayerModel.h"
@@ -84,7 +83,7 @@ uPlot::uPlot(QWidget* parent) :
     setWindowTitle("Metview - uPlot");
 
     //Initial size
-    setInitialSize(1200, 760);
+    setInitialSize(1100, 700);
 
 #ifdef METVIEW_WEATHER_ROOM
     //Check if weather room is enabled
@@ -140,38 +139,36 @@ uPlot::uPlot(QWidget* parent) :
     //-------------------
 
     dataWidget_ = new MvQDataWidget(plotScene_, plotView_);
-   
+
     //-------------------------------
     // Layer control widget
     // Contains both the layer contents and data
     //
     //-------------------------------
-    
+
     layerControlWidget_ = new LayerControlWidget(layerWidget_, dataWidget_, this);
-    
+
     //-------------------------------
     // Meteorological Symbol widget
-    //-------------------------------    
+    //-------------------------------
 
     symbolWidget_ = new MvQFeatureWidget(plotView_);
-    connect(symbolWidget_, SIGNAL(featureSelected(QString)),
-            plotView_, SLOT(enterFeatureAddMode(QString)));
-    
+
     //-----------------------------------
     // Control widget
     //-----------------------------------
 
-    controlWidget_             = new QWidget(this);
-    QVBoxLayout* controlLayout = new QVBoxLayout;
+    controlWidget_      = new QWidget(this);
+    auto* controlLayout = new QVBoxLayout;
     controlLayout->setContentsMargins(0, 0, 0, 0);
     controlWidget_->setLayout(controlLayout);
 
     // Scene selection
-    sceneWidget_  = new QWidget(this);
-    QLabel* label = new QLabel(tr("Active scene:"), this);
-    sceneCb_      = new MvQSceneComboBox(this);
+    sceneWidget_ = new QWidget(this);
+    auto* label  = new QLabel(tr("Active scene:"), this);
+    sceneCb_     = new MvQSceneComboBox(this);
 
-    QHBoxLayout* hb = new QHBoxLayout;
+    auto* hb = new QHBoxLayout;
     sceneWidget_->setLayout(hb);
     hb->addWidget(label);
     hb->addWidget(sceneCb_);
@@ -198,7 +195,7 @@ uPlot::uPlot(QWidget* parent) :
     //controlTab_->addTab(layerWidget_, tr("Layers"));
     //controlTab_->addTab(dataWidget_, tr("Data"));
 
-    controlTab_->addTab(symbolWidget_,tr("Symbols"));
+    controlTab_->addTab(symbolWidget_, tr("Symbols"));
 
     // feature undo/redo
     undoStack_ = new QUndoStack(this);
@@ -208,21 +205,21 @@ uPlot::uPlot(QWidget* parent) :
 #ifdef MVQ_FEATURE_DEV_MODE_
     // Feature edit
     //auto featureDevW = new QWidget(this);
-//    auto featureDevVb = new QVBoxLayout(featureDevW);
-//    featureDevVb->setContentsMargins(0,0,0,0);
+    //    auto featureDevVb = new QVBoxLayout(featureDevW);
+    //    featureDevVb->setContentsMargins(0,0,0,0);
 
-    auto featureInfoW= new QPlainTextEdit(this);
+    auto featureInfoW = new QPlainTextEdit(this);
     plotView_->setFeatureInfoWidget(featureInfoW);
     //featureDevVb->addWidget(featureInfoW);
 
     auto undoStackView = new QUndoView(undoStack_, this);
     //featureDevVb->addWidget(undoStackView);
 
-    QTabWidget *devTab = new QTabWidget(this);
+    auto* devTab = new QTabWidget(this);
     devTab->addTab(undoStackView, tr("History"));
     devTab->addTab(featureInfoW, tr("Info"));
 
-    controlTab_->addTab(devTab ,tr("Dev"));
+    controlTab_->addTab(devTab, tr("Dev"));
 #endif
 
     connect(controlTab_, SIGNAL(currentChanged(int)),
@@ -254,10 +251,10 @@ uPlot::uPlot(QWidget* parent) :
     mainSplitter_->setOpaqueResize(false);
 
     plotLayout_ = new QVBoxLayout();
-    plotLayout_->setContentsMargins(0,0,0,0);
+    plotLayout_->setContentsMargins(0, 0, 0, 0);
     plotLayout_->setSpacing(0);
 
-    QWidget* plotW = new QWidget(this);
+    auto* plotW = new QWidget(this);
     plotW->setLayout(plotLayout_);
     plotLayout_->addWidget(plotView_);
 
@@ -265,15 +262,6 @@ uPlot::uPlot(QWidget* parent) :
     mainSplitter_->addWidget(controlWidget_);
     mainSplitter_->setCollapsible(1, false);
 
-    //Set splitter initial size
-    int spWidth = mainSplitter_->size().width();
-    if (spWidth > 0) {
-        QList<int> spSize;
-        spSize << spWidth * 0.75;
-        spSize << spWidth - spSize[0];
-        mainSplitter_->setSizes(spSize);
-    }
-
     //Define the whole lot as central widget
     setCentralWidget(mainSplitter_);
 
@@ -290,7 +278,7 @@ uPlot::~uPlot()
 void uPlot::setupFileActions()
 {
     //Print
-    QAction* actionPrint = new QAction(this);
+    auto* actionPrint = new QAction(this);
     actionPrint->setObjectName(QString::fromUtf8("actionPrint"));
     QIcon icon;
     icon.addPixmap(QPixmap(QString::fromUtf8(":/uPlot/print.svg")), QIcon::Normal, QIcon::Off);
@@ -299,7 +287,7 @@ void uPlot::setupFileActions()
     actionPrint->setShortcut(tr("Ctrl+P"));
 
     //Export
-    QAction* actionExport = new QAction(this);
+    auto* actionExport = new QAction(this);
     actionExport->setObjectName(QString::fromUtf8("actionExport"));
     QIcon icon1;
     icon1.addPixmap(QPixmap(QString::fromUtf8(":/uPlot/export.svg")), QIcon::Normal, QIcon::Off);
@@ -308,7 +296,7 @@ void uPlot::setupFileActions()
     actionExport->setShortcut(tr("Ctrl+S"));
 
     //Generate Macro
-    QAction* actionMacro = new QAction(this);
+    auto* actionMacro = new QAction(this);
     actionMacro->setObjectName(QString::fromUtf8("actionMacro"));
     QIcon icon2;
     icon2.addPixmap(QPixmap(QString::fromUtf8(":/uPlot/generate_macro.svg")), QIcon::Normal, QIcon::Off);
@@ -405,7 +393,7 @@ void uPlot::setupShareActions()
     // Metview-ecCharts connection
     if (getenv("METVIEW_ECCHARTS")) {
         // Generate ecCharts layer
-        QAction* actionEcCharts = new QAction(this);
+        auto* actionEcCharts = new QAction(this);
         actionEcCharts->setObjectName(QString::fromUtf8("actionEcCharts"));
         QIcon icon3;
         icon3.addPixmap(QPixmap(QString::fromUtf8(":/uPlot/videowall.svg")), QIcon::Normal, QIcon::Off);
@@ -423,7 +411,7 @@ void uPlot::setupShareActions()
 void uPlot::setupToolsActions()
 {
     //Magnfier
-    QAction* actionMagnifier = new QAction(this);
+    auto* actionMagnifier = new QAction(this);
     actionMagnifier->setObjectName(QString::fromUtf8("actionMagnifier"));
     actionMagnifier->setCheckable(true);
     QIcon icon3;
@@ -432,7 +420,7 @@ void uPlot::setupToolsActions()
     actionMagnifier->setText(tr("&Magnifier"));
 
     //Cursor data
-    QAction* actionCursorData = new QAction(this);
+    auto* actionCursorData = new QAction(this);
     actionCursorData->setObjectName(QString::fromUtf8("actionCursorData"));
     actionCursorData->setCheckable(true);
     QIcon icon1;
@@ -507,7 +495,7 @@ void uPlot::setupViewActions()
     connect(actionHighlightScene_, SIGNAL(toggled(bool)),
             this, SLOT(slotHighlightActiveScene(bool)));
 
-    QAction* sep = new QAction(this);
+    auto* sep = new QAction(this);
     sep->setSeparator(true);
 
     MvQMainWindow::MenuType menuType = MvQMainWindow::ViewMenu;
@@ -601,8 +589,8 @@ void uPlot::setupAnimationActions()
 
     //Animation speed
     float fval[] = {0.5, 0.7, 1, 1.5, 2, 3, 4, 5, 10};
-    for (int i = 0; i < 9; i++) {
-        speed_.push_back(fval[i]);
+    for (float& i : fval) {
+        speed_.push_back(i);
     }
 
     actSpeedIndex_ = 2;
@@ -611,12 +599,12 @@ void uPlot::setupAnimationActions()
     timer_->setInterval(1000. / speed_[actSpeedIndex_]);
     connect(timer_, SIGNAL(timeout()), this, SLOT(slotToNext()));
 
-    QPushButton* speedPb = new QPushButton;
+    auto* speedPb = new QPushButton;
 
     speedPb->setText(tr("Speed"));
     speedPb->setObjectName("speedPb");
 
-    QMenu* menuSpeed = new QMenu("&Animation");
+    auto* menuSpeed = new QMenu("&Animation");
 
     speedPb->setMenu(menuSpeed);
 
@@ -639,7 +627,7 @@ void uPlot::setupAnimationActions()
     //vl->addWidget(speedSlider_);
     //vl->addWidget(speedLabel_);
 
-    QWidgetAction* wa = new QWidgetAction(menuSpeed);
+    auto* wa = new QWidgetAction(menuSpeed);
     wa->setDefaultWidget(speedSlider_);
     menuSpeed->addAction(wa);
 
@@ -652,7 +640,7 @@ void uPlot::setupAnimationActions()
 
 
     //Active scene highlight
-    QAction* action = new QAction(this);
+    auto* action = new QAction(this);
     action->setObjectName(QString::fromUtf8("actionAnimatedScenes"));
     QIcon icon4;
     icon4.addPixmap(QPixmap(QString::fromUtf8(":/uPlot/connectAnimations.svg")), QIcon::Normal, QIcon::Off);
@@ -1003,7 +991,7 @@ void uPlot::slotStepTo(int fr)
         dataWidget_->slotFrameChanged();
     }
 
-    if(!ignoreResetEnd_) {
+    if (!ignoreResetEnd_) {
         plotView_->resetEnd();
     }
 }
@@ -1185,7 +1173,7 @@ void uPlot::slotLayerUpdate()
     plotScene_->update();
 }
 
-void uPlot::progressMessage(const string& /*m*/)
+void uPlot::progressMessage(const std::string& /*m*/)
 {
 #ifdef METVIEW_EXPERIMENTAL
 
@@ -1243,9 +1231,9 @@ void uPlot::slotLayerVisibilityChanged(QString sid, bool onoff)
 
 void uPlot::slotLayerStackingOrderChanged(QList<QPair<QString, int> > lorder)
 {
-    for (int i = 0; i < lorder.size(); i++) {
-        int id    = lorder[i].first.toInt();
-        int value = lorder[i].second;
+    for (auto& i : lorder) {
+        int id    = i.first.toInt();
+        int value = i.second;
         owner_->UpdateLayerStackingOrder(id, value);
     }
 }
@@ -1255,7 +1243,7 @@ void uPlot::slotPlotScaleChanged()
     dataWidget_->slotPlotScaleChanged();
 }
 
-void uPlot::slotControlTabChanged(int index)
+void uPlot::slotControlTabChanged(int /*index*/)
 {
 #if 0
     if (index == 2) {
@@ -1264,7 +1252,7 @@ void uPlot::slotControlTabChanged(int index)
 #endif
 }
 
-void  uPlot::slotAddRibbonEditor(QWidget* w)
+void uPlot::slotAddRibbonEditor(QWidget* w)
 {
     plotLayout_->insertWidget(0, w);
 }
@@ -1305,7 +1293,26 @@ void uPlot::readSettings()
     settings.beginGroup("main");
     restoreGeometry(settings.value("geometry").toByteArray());
     restoreState(settings.value("state").toByteArray());
-    mainSplitter_->restoreState(settings.value("mainSplitter").toByteArray());
+
+    if (settings.contains("mainSplitter")) {
+        mainSplitter_->restoreState(settings.value("mainSplitter").toByteArray());
+    } else {
+        Q_ASSERT(mainSplitter_->count() == 2);
+        if (mainSplitter_->count() == 2) {
+            int w = size().width();
+            if (w > 0) {
+                auto sLst = mainSplitter_->sizes();
+                if (w > 800) {
+                    sLst[1] = 250;
+                    sLst[0] = w-250;
+                } else {
+                    sLst[1] = w/4;
+                    sLst[0] = w-w/4;
+                }
+                mainSplitter_->setSizes(sLst);
+            }
+        }
+    }
 
     stepWidget_->setCurrentKeyProfile(settings.value("stepKeyProfileName").toString());
     controlTab_->setCurrentIndex(settings.value("currentControlTabIndex").toInt());
