@@ -7,8 +7,10 @@
 
  ***************************** LICENSE END *************************************/
 
-#ifndef uPlot_H
-#define uPlot_H
+#pragma once
+
+#include <string>
+#include <vector>
 
 #include "uPlotBase.h"
 
@@ -32,7 +34,6 @@ class QWidgetAction;
 class ExportDialog;
 class MgQPlotScene;
 class MgQSceneItem;
-class MvQCursorDataWidget;
 class MvQDataWidget;
 class MvQStepModel;
 class MvQLayerWidget;
@@ -43,8 +44,6 @@ class MvQTreeView;
 class MvQZoomStackWidget;
 class LayerControlWidget;
 
-using namespace std;
-
 class MvQSceneComboBox : public QComboBox
 {
     Q_OBJECT
@@ -67,7 +66,7 @@ public:
 
     void newRequestForDriversBegin() override;
     void newRequestForDriversEnd() override;
-    void progressMessage(const string&) override;
+    void progressMessage(const std::string&) override;
 
 public slots:
     void slotShowControlPanel(bool);
@@ -97,7 +96,7 @@ public slots:
     void slotShareTarget();
 
 protected slots:
-    void  slotAddRibbonEditor(QWidget* w) override;
+    void slotAddRibbonEditor(QWidget* w) override;
 
 protected:
     void setupFileActions();
@@ -130,9 +129,8 @@ protected:
     MvQLayerWidget* layerWidget_;
     MvQDataWidget* dataWidget_;
     LayerControlWidget* layerControlWidget_;
-    MvQCursorDataWidget* cursorWidget_;
     MvQFeatureWidget* symbolWidget_;
-    
+
     QAction* actionAntialias_;
     QAction* actionControlPanel_;
 
@@ -145,7 +143,7 @@ protected:
     QAction* actionLast_;
     QSlider* speedSlider_;
     QTimer* timer_;
-    vector<float> speed_;
+    std::vector<float> speed_;
     int actSpeedIndex_;
     QLabel* speedLabel_;
 
@@ -159,13 +157,11 @@ protected:
     //	MvQProgressItem* progressItem_;
 
     // Progress Bar
-//    MvQProgressBarPanel* progressBar_;
-//    QWidgetAction* acltb_;
-//    QWidgetAction* acptb_;
+    //    MvQProgressBarPanel* progressBar_;
+    //    QWidgetAction* acltb_;
+    //    QWidgetAction* acptb_;
 
     QSplitter* mainSplitter_;
 
     bool weatherRoom_;
 };
-
-#endif
