@@ -11,6 +11,8 @@
 
 #include "uPlotApp.h"
 #include "PmContext.h"
+#include "PlotMod.h"
+#include "MvException.h"
 
 // TODO: set resources per geoTool and uPlot!
 uPlotApp::uPlotApp(int& ac, char** av, const char* name) :
@@ -23,16 +25,12 @@ uPlotApp::uPlotApp(int& ac, char** av, const char* name) :
     registerTMvServe(*this, 0, "_UPLOT_MANAGER_ID", true);
 }
 
-uPlotApp::~uPlotApp()
-{
-}
-
 // Serve Method
 // called by MvTransaction to process the request
 void uPlotApp::serve(MvProtocol& proto, MvRequest& inRequest)
 {
     // Create a new context, based on the input Request
-    PmContext* context = new PmContext(proto, inRequest);
+    auto* context = new PmContext(proto, inRequest);
 
     // Increment the reference counting
     context->Attach();
