@@ -17,11 +17,11 @@
 
 class uPlotBatchApp;
 
-class uPlotBatchTransaction:  public MvTransaction
+class uPlotBatchTransaction : public MvTransaction
 {
 public:
     uPlotBatchTransaction(uPlotBatchApp* app, const std::string& outReqPath) :
-        MvTransaction((const char*) nullptr),
+        MvTransaction((const char*)nullptr),
         app_(app),
         outReqPath_(outReqPath) {}
 
@@ -43,14 +43,13 @@ private:
 class uPlotBatchApp : public MvApplication
 {
 public:
-    uPlotBatchApp (int& ac, char** av, const char* name, const std::string&);
-    virtual ~uPlotBatchApp() {}
-    void serve(MvProtocol&, MvRequest&);
+    uPlotBatchApp(int& ac, char** av, const char* name, const std::string&);
+    virtual ~uPlotBatchApp() = default;
 
-private:
-    // No copy allowed
-    uPlotBatchApp (const uPlotBatchApp&);
-    uPlotBatchApp& operator=(const uPlotBatchApp&){return *this;}
+    uPlotBatchApp(const uPlotBatchApp&) = delete;
+    uPlotBatchApp& operator=(const uPlotBatchApp&) = delete;
+
+    void serve(MvProtocol&, MvRequest&);
 };
 
 
@@ -63,22 +62,22 @@ void uPlotBatchTransaction::callback(MvRequest& in)
         out.setVerb("ERROR");
 
         // Get icon name(s) involved on the operation
-//        if ((const char*)in("ICON_NAME")) {
-//            int cnt = in.iterInit("ICON_NAME");
-//            for (int i = 0; i < cnt; i++) {
-//                const char* iconChName;
-//                in.iterGetNextValue(iconChName);
-//                if (iconChName) {
-//                    if (i == 0)
-//                        out.setValue("ICON_NAME", iconChName);
-//                    else
-//                        out.addValue("ICON_NAME", iconChName);
-//                }
-//            }
-//        } else if ((const char*)in("PATH")) {
-//            const char* iconChName = mbasename((const char*)in("PATH"));
-//            out.setValue("ICON_NAME", iconChName);
-//        }
+        //        if ((const char*)in("ICON_NAME")) {
+        //            int cnt = in.iterInit("ICON_NAME");
+        //            for (int i = 0; i < cnt; i++) {
+        //                const char* iconChName;
+        //                in.iterGetNextValue(iconChName);
+        //                if (iconChName) {
+        //                    if (i == 0)
+        //                        out.setValue("ICON_NAME", iconChName);
+        //                    else
+        //                        out.addValue("ICON_NAME", iconChName);
+        //                }
+        //            }
+        //        } else if ((const char*)in("PATH")) {
+        //            const char* iconChName = mbasename((const char*)in("PATH"));
+        //            out.setValue("ICON_NAME", iconChName);
+        //        }
 
         // Get error message(s)
         const char* msg;
@@ -98,12 +97,12 @@ void uPlotBatchTransaction::callback(MvRequest& in)
     sendReply(out);
 
     // the batch task finished/failed, so we stop the mars event loop and exit normally!
-    app_->destroyService();    
+    app_->destroyService();
     exit(0);
 }
 
 uPlotBatchApp::uPlotBatchApp(int& ac, char** av, const char* name, const std::string& outReqPath) :
-           MvApplication(ac,av,name)
+    MvApplication(ac, av, name)
 {
     // Create the object for mars communication. It will handle incoming reuests and
     // call the serve method
@@ -111,27 +110,26 @@ uPlotBatchApp::uPlotBatchApp(int& ac, char** av, const char* name, const std::st
 
     Root::Create();
 
-    MagPlusBatchService* batch = new MagPlusBatchService();
+    auto* batch = new MagPlusBatchService();
     MagPlusService::Instance(batch);
 
-    PlotModBatch* pm = new PlotModBatch();
+    auto* pm = new PlotModBatch();
     PlotMod::Instance(pm);
 }
 
-void
-uPlotBatchApp::serve ( MvProtocol& proto, MvRequest& inRequest )
+void uPlotBatchApp::serve(MvProtocol& proto, MvRequest& inRequest)
 {
-   // Create a new context, based on the input Request
-   PmContext * context = new PmContext ( proto, inRequest );
+    // Create a new context, based on the input Request
+    auto* context = new PmContext(proto, inRequest);
 
-   // Increment the reference counting
-   context->Attach();
+    // Increment the reference counting
+    context->Attach();
 
-   // It is a new call, so it first needs to clean the previous structure
-   //Root::Instance().Clean();
+    // It is a new call, so it first needs to clean the previous structure
+    //Root::Instance().Clean();
 
-   // Execute the context
-   context->Execute();
+    // Execute the context
+    context->Execute();
 }
 
 int main(int argc, char** argv)
@@ -150,7 +148,8 @@ int main(int argc, char** argv)
     std::string outPath;
     if (const char* outPathCh = in("_OUT_REQ_FILE")) {
         outPath = std::string(outPathCh);
-    } else {
+    }
+    else {
         marslog(LOG_EROR, "No output request specified via _OUT_REQ_FILE!");
         exit(1);
     }
@@ -162,8 +161,8 @@ int main(int argc, char** argv)
         exit(1);
     }
 
-//    marslog(LOG_INFO,"Request:");
-//    in.print();
+    //    marslog(LOG_INFO,"Request:");
+    //    in.print();
 
     // skip UPLOT_MANAGER request
     if (strcmp(in.getVerb(), "UPLOT_MANAGER") == 0) {
@@ -184,7 +183,4 @@ int main(int argc, char** argv)
     MvApplication::callService(appName.c_str(), in, 0);
 
     app.run();
-
 }
-
-
