@@ -7,14 +7,18 @@
 
  ***************************** LICENSE END *************************************/
 
-#include <inc_iostream.h>
+#include "uPlotService.hpp"
+
 #include <sys/stat.h>
 
+#include <iostream>
+#include <sstream>
+#include <string>
+
 #include "Assertions.hpp"
 #include "MvPath.hpp"
 #include "MvTmpFile.h"
 #include "MvServiceTask.h"
-#include "uPlotService.hpp"
 
 // Methods for the uPlot Service class
 //
@@ -31,14 +35,9 @@ uPlotService::Instance()
     return uPlotServiceInstance_;
 }
 
-uPlotService::uPlotService()
-{
-    // Empty
-}
+uPlotService::uPlotService() = default;
 
-uPlotService::~uPlotService()
-{
-}
+uPlotService::~uPlotService() = default;
 
 // --- METHOD:  CalluPlot
 //
@@ -56,7 +55,7 @@ void uPlotService::CalluPlot(MvRequest& uPlotRequest, MvRequest& out)
     // Set filename to be used by uPlot to store the output request
     std::ostringstream appName;
     appName << "uPlotManager" << (long int)getpid();
-    string name                       = MakeTmpPath(appName.str().c_str());
+    std::string name                  = MakeTmpPath(appName.str().c_str());
     uPlotRequest("_UPLOT_MANAGER_ID") = (const char*)name.c_str();
 
     // Save request to be processed by uPlot
@@ -75,20 +74,20 @@ void uPlotService::CalluPlot(MvRequest& uPlotRequest, MvRequest& out)
         out("MESSAGE") = "uPlotService-> MV_DESKTOP_NAME is not defined!";
         return;
     }
-    string desktopName(desktop);
+    std::string desktopName(desktop);
     out("TARGET") = desktopName.c_str();
 
-    string GRIB_DEFINITION_PATH_ENV;
+    std::string GRIB_DEFINITION_PATH_ENV;
     const char* grb_def_path = getenv("GRIB_DEFINITION_PATH");
     if (grb_def_path) {
-        GRIB_DEFINITION_PATH_ENV = string(grb_def_path);
+        GRIB_DEFINITION_PATH_ENV = std::string(grb_def_path);
     }
 
     // Does this request contain a directive to change the working directory?
-    string cmd;
+    std::string cmd;
     const char* cwd = uPlotRequest("_CWD");
     if (cwd) {
-        cmd += "cd " + string(cwd) + ";";
+        cmd += "cd " + std::string(cwd) + ";";
         uPlotRequest.unsetParam("_CWD");
     }
 
@@ -96,8 +95,8 @@ void uPlotService::CalluPlot(MvRequest& uPlotRequest, MvRequest& out)
     if (!GRIB_DEFINITION_PATH_ENV.empty()) {
         cmd += "export GRIB_DEFINITION_PATH=" + GRIB_DEFINITION_PATH_ENV + ";";
     }
-    //cmd+="xterm -iconic -e /usr/local/apps/totalview/tv8.14.0-16/bin/tv8 $METVIEW_BIN/uPlot -a " + string(ftemp) + " $METVIEW_QT_APPLICATION_FLAGS &";
-    cmd += "$metview_command $METVIEW_BIN/uPlot " + string(ftemp) + " $METVIEW_QT_APPLICATION_FLAGS &";
+    //cmd+="xterm -iconic -e /usr/local/apps/totalview/tv8.14.0-16/bin/tv8 $METVIEW_BIN/uPlot -a " + std::string(ftemp) + " $METVIEW_QT_APPLICATION_FLAGS &";
+    cmd += "$metview_command $METVIEW_BIN/uPlot " + std::string(ftemp) + " $METVIEW_QT_APPLICATION_FLAGS &";
 
     system(cmd.c_str());
 
@@ -148,11 +147,11 @@ void uPlotService::endOfTask(MvTask* task)
         //const char* msg = 0;
         //while ( msg = task->getMessage (i++ ) )
 
-        //COUT << "uPlot endOfTask-> Failed to run uPlotService" << endl;
+        //COUT << "uPlot endOfTask-> Failed to run uPlotService" << std::endl;
     }
 
     // Retrieve the reply request
-    MvServiceTask* serviceTask = (MvServiceTask*)task;
+    auto* serviceTask = (MvServiceTask*)task;
 
     MvRequest replyRequest = serviceTask->getReply();
 
@@ -162,22 +161,22 @@ void uPlotService::endOfTask(MvTask* task)
 }
 
 // Use system command to start MetZoom. MetZoom will fork, register itself and
-// read the initial request to be processed. This request is stored in a 
+// read the initial request to be processed. This request is stored in a
 // temporary file whose filename is passed to MetZoom in the command line argument.
-void uPlotService::CallMetZoom(MvRequest& in,MvRequest& out)
+void uPlotService::CallMetZoom(MvRequest& in, MvRequest& out)
 {
-    cout << "MetZoomService::serve in" << endl;
+    std::cout << "MetZoomService::serve in" << std::endl;
     in.print();
 
     // Set filename to be used by MetZoom to store the output request
-	MvRequest req = in;
+    MvRequest req = in;
     // std::string appName = "uPlotManager" + std::to_string(getpid());
     // std::string name = MakeTmpPath(appName.c_str());
     // req("_UPLOT_MANAGER_ID") = (const char*)name.c_str();
 
-/*
+    /*
 	// Plotting procedure relies on parameter _CLASS being defined
-	string verb;
+	std::string verb;
 	if ( (const char*)req("_CLASS") )
 	   verb = (const char*)req("_CLASS");
 	else
@@ -187,58 +186,60 @@ void uPlotService::CallMetZoom(MvRequest& in,MvRequest& out)
 		return;
 	}
 */
-	// Input request: update verb and save it in the METVIEW_TMP directory
-	// If in the future we change the verb to MetZoom then we need
-	// to uncomment the line below
-	// req.setVerb(verb.c_str());
+    // Input request: update verb and save it in the METVIEW_TMP directory
+    // If in the future we change the verb to MetZoom then we need
+    // to uncomment the line below
+    // req.setVerb(verb.c_str());
 
     MvTmpFile reqFile(false);
-	// std::string temp = MakeTmpPath("MetZoom.req");
-	req.save(reqFile.path().c_str());
+    // std::string temp = MakeTmpPath("MetZoom.req");
+    req.save(reqFile.path().c_str());
 
     // Tell the caller that the request was done
     // The problem here is that the icon will be green even if uPlot
     // can not process the request.
     // WE NEED TO FIND A BETTER SOLUTION!!!!!!!
 
-    if ( const char *ch = getenv("MV_DESKTOP_NAME") ) {
+    if (const char* ch = getenv("MV_DESKTOP_NAME")) {
         out.setVerb("REPLY");
         out("TARGET") = ch;
-    } else { 
+    }
+    else {
         out.setVerb("ERROR");
         out("MESSAGE") = "MetZoom-> MV_DESKTOP_NAME is not defined!";
         return;
     }
 
-	// Call MetZoom script
+    // Call MetZoom script
     std::string mzStartPath;
-    if ( const char* ch = getenv("MV_METZOOM_START_CMD") ) {
+    if (const char* ch = getenv("MV_METZOOM_START_CMD")) {
         mzStartPath = std::string(ch);
     }
     // } else {
-	// 	out.setVerb("ERROR");
-	// 	out("MESSAGE") = "MetZoom error: environmental variable MV_METZOOM_START_CMD not defined";
-	// 	return;
-	// }
+    // 	out.setVerb("ERROR");
+    // 	out("MESSAGE") = "MetZoom error: environmental variable MV_METZOOM_START_CMD not defined";
+    // 	return;
+    // }
 
     std::string cmd = "python3 ";
     if (mzStartPath.empty()) {
         cmd = "metzoom_run";
-    } else {
+    }
+    else {
         cmd = mzStartPath;
     }
-    cmd +=  " --console-log --log=DEBUG --request=" + reqFile.path();
-	cout << "Calling: " << cmd << endl;
+    cmd += " --console-log --log=DEBUG --request=" + reqFile.path();
+    std::cout << "Calling: " << cmd << std::endl;
 
-	int istatus = system(cmd.c_str());
-	if (istatus) {
-		char *errmsg = strerror(errno);
-		std::ostringstream oss;
-		oss << "Error trying to start MetZoom. Error: " << errmsg << ". System command: " << cmd;
-		out.setVerb("ERROR");
-		out("MESSAGE") = oss.str().c_str();
-		return;
-	}
+    int istatus = system(cmd.c_str());
+    if (istatus) {
+        char* errmsg = strerror(errno);
+        std::ostringstream oss;
+        oss << "Error trying to start MetZoom. Error: " << errmsg << ". System command: " << cmd;
+        out.setVerb("ERROR");
+        out("MESSAGE") = oss.str().c_str();
+        return;
+    }
 
     // FAMI20181119
     // This is a optional code. It can be removed if there is no need to
@@ -263,7 +264,7 @@ void uPlotService::CallMetZoom(MvRequest& in,MvRequest& out)
     }
     */
 
-    cout << "MetZoomService::serve out" << endl;
+    std::cout << "MetZoomService::serve out" << std::endl;
     out.print();
 
     return;
