@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_action_interpolate_Gridded2RegularLL_h
-#define mir_action_interpolate_Gridded2RegularLL_h
+#pragma once
 
 #include "mir/action/interpolate/Gridded2UnrotatedGrid.h"
 #include "mir/util/BoundingBox.h"
@@ -34,7 +33,7 @@ public:
 
     // -- Destructor
 
-    virtual ~Gridded2RegularLL();
+    ~Gridded2RegularLL() override;
 
     // -- Convertors
     // None
@@ -64,8 +63,8 @@ protected:
     // -- Overridden methods
 
     // From Gridded2GriddedInterpolation
-    virtual bool sameAs(const Action&) const;
-    virtual void print(std::ostream&) const;
+    bool sameAs(const Action&) const override;
+    void print(std::ostream&) const override;
 
     // -- Class members
     // None
@@ -86,10 +85,10 @@ private:
     // -- Overridden methods
 
     // From Action
-    virtual const char* name() const;
+    const char* name() const override;
 
     // From Gridded2GriddedInterpolation
-    virtual const repres::Representation* outputRepresentation() const;
+    const repres::Representation* outputRepresentation() const override;
 
     // -- Class members
     // None
@@ -105,6 +104,3 @@ private:
 }  // namespace interpolate
 }  // namespace action
 }  // namespace mir
-
-
-#endif
