@@ -73,7 +73,8 @@ AreaCropper::AreaCropper(const param::MIRParametrisation& parametrisation, const
 }
 
 
-void AreaCropper::crop(const repres::Representation& repres, util::BoundingBox& bbox, std::vector<size_t>& mapping) {
+void AreaCropper::crop(const repres::Representation& repres, util::BoundingBox& bbox,
+                       util::AreaCropperMapping& mapping) {
     std::map<LL, size_t> m;
 
     Latitude n  = 0;
@@ -140,7 +141,7 @@ AreaCropper::~AreaCropper() = default;
 
 
 bool AreaCropper::sameAs(const Action& other) const {
-    auto o = dynamic_cast<const AreaCropper*>(&other);
+    const auto* o = dynamic_cast<const AreaCropper*>(&other);
     return (o != nullptr) && (bbox_ == o->bbox_);
 }
 
@@ -161,6 +162,12 @@ static void createCroppingCacheEntry(caching::CroppingCacheEntry& c, const repre
     Log::debug() << "Creating cropping cache entry for " << bbox << std::endl;
     c.bbox_ = bbox;
     c.mapping_.clear();
+
+    // Give a chance to representation-specialised cropping
+    if (representation->crop(c.bbox_, c.mapping_)) {
+        return;
+    }
+
     AreaCropper::crop(*representation, c.bbox_, c.mapping_);
 }
 
@@ -192,9 +199,12 @@ static const caching::CroppingCacheEntry& getMapping(const std::string& key,
         public:
             CroppingCacheCreator(const repres::Representation* representation, const util::BoundingBox& bbox) :
                 representation_(representation), bbox_(bbox) {}
+            ~CroppingCacheCreator() override = default;
 
             CroppingCacheCreator(const CroppingCacheCreator&) = delete;
+            CroppingCacheCreator(CroppingCacheCreator&&)      = delete;
             CroppingCacheCreator& operator=(const CroppingCacheCreator&) = delete;
+            CroppingCacheCreator& operator=(CroppingCacheCreator&&) = delete;
         };
 
         CroppingCacheCreator creator(representation, bbox);
@@ -241,7 +251,7 @@ void AreaCropper::execute(context::Context& ctx) const {
     auto& field = ctx.field();
     repres::RepresentationHandle representation(field.representation());
 
-    auto& c = getMapping(representation, bbox_, caching_);
+    const auto& c = getMapping(representation, bbox_, caching_);
     ASSERT_NONEMPTY_AREA_CROP("AreaCropper", !c.mapping_.empty());
 
     for (size_t i = 0; i < field.dimensions(); i++) {
@@ -298,7 +308,7 @@ bool AreaCropper::canCrop() const {
 }
 
 
-static ActionBuilder<AreaCropper> __action("crop.area");
+static const ActionBuilder<AreaCropper> __action("crop.area");
 
 
 }  // namespace action
