@@ -26,7 +26,7 @@ Noop::~Noop() = default;
 
 
 bool Noop::sameAs(const Action& other) const {
-    auto o = dynamic_cast<const Noop*>(&other);
+    const auto* o = dynamic_cast<const Noop*>(&other);
     return (o != nullptr);
 }
 
@@ -36,7 +36,7 @@ void Noop::print(std::ostream& out) const {
 }
 
 
-void Noop::execute(context::Context&) const {}
+void Noop::execute(context::Context& /*unused*/) const {}
 
 
 const char* Noop::name() const {
@@ -44,7 +44,7 @@ const char* Noop::name() const {
 }
 
 
-static ActionBuilder<Noop> __action("noop");
+static const ActionBuilder<Noop> __action("noop");
 
 
 }  // namespace action
