@@ -44,12 +44,12 @@ void Action::perform(context::Context& ctx) const {
 }
 
 
-bool Action::mergeWithNext(const Action&) {
+bool Action::mergeWithNext(const Action& /*unused*/) {
     return false;
 }
 
 
-bool Action::deleteWithNext(const Action&) {
+bool Action::deleteWithNext(const Action& /*unused*/) {
     return false;
 }
 
@@ -73,16 +73,16 @@ util::BoundingBox Action::outputBoundingBox() const {
     NOTIMP;
 }
 
-void Action::estimate(context::Context&, api::MIREstimation& /*estimation*/) const {
+void Action::estimate(context::Context& /*unused*/, api::MIREstimation& /*estimation*/) const {
     std::ostringstream oss;
     oss << "Action::estimate not implemented for " << *this;
     throw exception::SeriousBug(oss.str());
 }
 
 
-void Action::estimateNumberOfGridPoints(context::Context&, api::MIREstimation& estimation,
+void Action::estimateNumberOfGridPoints(context::Context& /*unused*/, api::MIREstimation& estimation,
                                         const repres::Representation& out) {
-    // trace::Timer timer("estimateNumberOfGridPoints", Log::error());
+    // trace::Timer timer("estimateNumberOfGridPoints");
     estimation.numberOfGridPoints(out.numberOfPoints());
 }
 
@@ -93,7 +93,7 @@ void Action::estimateMissingValues(context::Context& /*ctx*/, api::MIREstimation
     data::MIRField& field = ctx.field();
     ASSERT(field.dimensions() == 1);
     if (field.hasMissing()) {
-        trace::Timer timer("estimateMissingValues", Log::error());
+        trace::Timer timer("estimateMissingValues");
 
         param::DefaultParametrisation runtime;
         param::CombinedParametrisation combined(runtime, runtime, runtime);
