@@ -37,10 +37,10 @@ void SimpleExecutor::execute(context::Context& ctx, const ActionNode& node) cons
 }
 
 
-void SimpleExecutor::parametrisation(const param::MIRParametrisation&) {}
+void SimpleExecutor::parametrisation(const param::MIRParametrisation& /*unused*/) {}
 
 
-static SimpleExecutor executor("simple");
+static const SimpleExecutor executor("simple");
 
 
 }  // namespace action
