@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_action_transform_ShToRegularLL_h
-#define mir_action_transform_ShToRegularLL_h
+#pragma once
 
 #include "mir/action/transform/ShToGridded.h"
 #include "mir/util/BoundingBox.h"
@@ -35,7 +34,7 @@ public:
 
     // -- Destructor
 
-    ~ShToRegularLL();  // Change to virtual if base class
+    ~ShToRegularLL() override;
 
     // -- Convertors
     // None
@@ -66,11 +65,11 @@ private:
 
     // -- Overridden methods
 
-    bool sameAs(const Action&) const;
-    const char* name() const;
-    const repres::Representation* outputRepresentation() const;
-    void print(std::ostream&) const;
-    void sh2grid(data::MIRField& field, const atlas_trans_t& trans, const param::MIRParametrisation&) const;
+    bool sameAs(const Action&) const override;
+    const char* name() const override;
+    const repres::Representation* outputRepresentation() const override;
+    void print(std::ostream&) const override;
+    void sh2grid(data::MIRField& field, const atlas_trans_t& trans, const param::MIRParametrisation&) const override;
 
     // -- Class members
     // None
@@ -86,6 +85,3 @@ private:
 }  // namespace transform
 }  // namespace action
 }  // namespace mir
-
-
-#endif
