@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_action_transform_ShToRotatedRegularGG_h
-#define mir_action_transform_ShToRotatedRegularGG_h
+#pragma once
 
 #include "mir/action/transform/ShToGridded.h"
 #include "mir/util/Rotation.h"
@@ -34,7 +33,7 @@ public:
 
     // -- Destructor
 
-    ~ShToRotatedRegularGG();  // Change to virtual if base class
+    ~ShToRotatedRegularGG() override;
 
     // -- Convertors
     // None
@@ -65,11 +64,11 @@ private:
 
     // -- Overridden methods
 
-    bool sameAs(const Action&) const;
-    const char* name() const;
-    const repres::Representation* outputRepresentation() const;
-    void print(std::ostream&) const;
-    void sh2grid(data::MIRField& field, const atlas_trans_t& trans, const param::MIRParametrisation&) const;
+    bool sameAs(const Action&) const override;
+    const char* name() const override;
+    const repres::Representation* outputRepresentation() const override;
+    void print(std::ostream&) const override;
+    void sh2grid(data::MIRField& field, const atlas_trans_t& trans, const param::MIRParametrisation&) const override;
 
     // -- Class members
     // None
@@ -85,6 +84,3 @@ private:
 }  // namespace transform
 }  // namespace action
 }  // namespace mir
-
-
-#endif
