@@ -33,7 +33,7 @@ CroppingCache::CroppingCache() :
 
 void CroppingCacheEntry::print(std::ostream& out) const {
     out << "CroppingCacheEntry[size=" << mapping_.size() << ",bbox=" << bbox_
-        << ",size=" << Log::Bytes(sizeof(size_t) * mapping_.size()) << "]";
+        << ",size=" << Log::Bytes(sizeof(util::AreaCropperMapping::value_type) * mapping_.size()) << "]";
 }
 
 
@@ -57,7 +57,7 @@ void CroppingCacheEntry::save(const eckit::PathName& path) const {
     f << bbox_.east();
 
     f << mapping_.size();
-    for (auto& i : mapping_) {
+    for (const auto& i : mapping_) {
         f << i;
     }
 }
@@ -87,7 +87,7 @@ void CroppingCacheEntry::load(const eckit::PathName& path) {
     mapping_.clear();
     mapping_.reserve(size);
     for (size_t i = 0; i < size; ++i) {
-        size_t j;
+        util::AreaCropperMapping::value_type j;
         f >> j;
         mapping_.push_back(j);
     }
@@ -109,12 +109,13 @@ const char* CroppingCacheTraits::extension() {
 }
 
 
-void CroppingCacheTraits::save(const eckit::CacheManagerBase&, const value_type& c, const eckit::PathName& path) {
+void CroppingCacheTraits::save(const eckit::CacheManagerBase& /*unused*/, const value_type& c,
+                               const eckit::PathName& path) {
     c.save(path);
 }
 
 
-void CroppingCacheTraits::load(const eckit::CacheManagerBase&, value_type& c, const eckit::PathName& path) {
+void CroppingCacheTraits::load(const eckit::CacheManagerBase& /*unused*/, value_type& c, const eckit::PathName& path) {
     c.load(path);
 }
 
