@@ -71,8 +71,8 @@ InMemoryCacheStatistics& InMemoryCacheStatistics::operator/=(size_t n) {
     evictions_ /= n;
     hits_ /= n;
     misses_ /= n;
-    youngest_ /= n;
-    oldest_ /= n;
+    youngest_ /= double(n);
+    oldest_ /= double(n);
     capacity_ /= n;
     footprint_ /= n;
     unique_ /= n;
