@@ -14,13 +14,10 @@
 
 #include <map>
 
-#include "eckit/exception/Exceptions.h"
-#include "eckit/log/Log.h"
-#include "eckit/thread/AutoLock.h"
-#include "eckit/thread/Mutex.h"
-
-#include "mir/config/LibMir.h"
 #include "mir/param/MIRParametrisation.h"
+#include "mir/util/Exceptions.h"
+#include "mir/util/Log.h"
+#include "mir/util/Mutex.h"
 
 
 namespace mir {
@@ -35,39 +32,26 @@ LegendreLoader::LegendreLoader(const param::MIRParametrisation& parametrisation,
 LegendreLoader::~LegendreLoader() = default;
 
 
-eckit::Channel& LegendreLoader::log() {
-    static auto& channel = eckit::Log::debug<LibMir>();
-    return channel;
+atlas::trans::LegendreCache LegendreLoader::transCache() {
+    return {address(), size()};
 }
 
 
-eckit::Channel& LegendreLoader::info() {
-    static auto& channel = eckit::Log::info();
-    return channel;
-}
-
-
-eckit::Channel& LegendreLoader::warn() {
-    static auto& channel = eckit::Log::warning();
-    return channel;
-}
-
-
-static pthread_once_t once                              = PTHREAD_ONCE_INIT;
-static eckit::Mutex* local_mutex                        = nullptr;
+static util::once_flag once;
+static util::recursive_mutex* local_mutex               = nullptr;
 static std::map<std::string, LegendreLoaderFactory*>* m = nullptr;
 static void init() {
-    local_mutex = new eckit::Mutex();
+    local_mutex = new util::recursive_mutex();
     m           = new std::map<std::string, LegendreLoaderFactory*>();
 }
 
 
 LegendreLoaderFactory::LegendreLoaderFactory(const std::string& name) : name_(name) {
-    pthread_once(&once, init);
-    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
+    util::call_once(once, init);
+    util::lock_guard<util::recursive_mutex> lock(*local_mutex);
 
     if (m->find(name) != m->end()) {
-        throw eckit::SeriousBug("LegendreLoaderFactory: duplicate '" + name + "'");
+        throw exception::SeriousBug("LegendreLoaderFactory: duplicate '" + name + "'");
     }
 
     ASSERT(m->find(name) == m->end());
@@ -76,25 +60,25 @@ LegendreLoaderFactory::LegendreLoaderFactory(const std::string& name) : name_(na
 
 
 LegendreLoaderFactory::~LegendreLoaderFactory() {
-    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
+    util::lock_guard<util::recursive_mutex> lock(*local_mutex);
 
     m->erase(name_);
 }
 
 
 LegendreLoader* LegendreLoaderFactory::build(const param::MIRParametrisation& params, const eckit::PathName& path) {
-    pthread_once(&once, init);
-    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
+    util::call_once(once, init);
+    util::lock_guard<util::recursive_mutex> guard(*local_mutex);
 
     std::string name = "mapped-memory";
     params.get("legendre-loader", name);
 
-    eckit::Log::debug<LibMir>() << "LegendreLoaderFactory: looking for '" << name << "'" << std::endl;
+    Log::debug() << "LegendreLoaderFactory: looking for '" << name << "'" << std::endl;
 
     auto j = m->find(name);
     if (j == m->end()) {
-        list(eckit::Log::error() << "LegendreLoaderFactory: unknown '" << name << "', choices are: ");
-        throw eckit::SeriousBug("LegendreLoaderFactory: unknown '" + name + "'");
+        list(Log::error() << "LegendreLoaderFactory: unknown '" << name << "', choices are: ");
+        throw exception::SeriousBug("LegendreLoaderFactory: unknown '" + name + "'");
     }
 
     return j->second->make(params, path);
@@ -102,18 +86,18 @@ LegendreLoader* LegendreLoaderFactory::build(const param::MIRParametrisation& pa
 
 
 bool LegendreLoaderFactory::inSharedMemory(const param::MIRParametrisation& params) {
-    pthread_once(&once, init);
-    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
+    util::call_once(once, init);
+    util::lock_guard<util::recursive_mutex> guard(*local_mutex);
 
     std::string name = "mapped-memory";
     params.get("legendre-loader", name);
 
-    eckit::Log::debug<LibMir>() << "LegendreLoaderFactory: looking for '" << name << "'" << std::endl;
+    Log::debug() << "LegendreLoaderFactory: looking for '" << name << "'" << std::endl;
 
     auto j = m->find(name);
     if (j == m->end()) {
-        list(eckit::Log::error() << "LegendreLoaderFactory: unknown '" << name << "', choices are: ");
-        throw eckit::SeriousBug("LegendreLoaderFactory: unknown '" + name + "'");
+        list(Log::error() << "LegendreLoaderFactory: unknown '" << name << "', choices are: ");
+        throw exception::SeriousBug("LegendreLoaderFactory: unknown '" + name + "'");
     }
 
     return j->second->shared();
@@ -121,8 +105,8 @@ bool LegendreLoaderFactory::inSharedMemory(const param::MIRParametrisation& para
 
 
 void LegendreLoaderFactory::list(std::ostream& out) {
-    pthread_once(&once, init);
-    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
+    util::call_once(once, init);
+    util::lock_guard<util::recursive_mutex> guard(*local_mutex);
 
     const char* sep = "";
     for (const auto& j : *m) {
