@@ -75,7 +75,9 @@ public:
     void add(const eckit::PathName& path) { paths_.push_back(path); }
 
     Unloader(const Unloader&) = delete;
+    Unloader(Unloader&&)      = delete;
     Unloader& operator=(const Unloader&) = delete;
+    Unloader& operator=(Unloader&&) = delete;
 
     ~Unloader() {
         for (auto& path : paths_) {
@@ -113,7 +115,7 @@ public:
 SharedMemoryLoader::SharedMemoryLoader(const param::MIRParametrisation& parametrisation, const eckit::PathName& path) :
     LegendreLoader(parametrisation, path), address_(nullptr), size_(size_t(path.size())), unload_(false) {
 
-    trace::Timer timer("SharedMemoryLoader: loading '" + path.asString() + "'", Log::debug());
+    trace::Timer timer("SharedMemoryLoader: loading '" + path.asString() + "'");
 
     std::string name;
     if (parametrisation.get("legendre-loader", name)) {
@@ -199,8 +201,8 @@ SharedMemoryLoader::SharedMemoryLoader(const param::MIRParametrisation& parametr
 
     try {
 
-        auto addr = reinterpret_cast<char*>(address_);
-        auto nfo  = reinterpret_cast<SHMInfo*>(addr + (((size_ + page_size - 1) / page_size) * page_size));
+        auto* addr = reinterpret_cast<char*>(address_);
+        auto* nfo  = reinterpret_cast<SHMInfo*>(addr + (((size_ + page_size - 1) / page_size) * page_size));
 
         // Check if the file has been loaded in memory
         if (nfo->ready != 0) {
@@ -217,7 +219,7 @@ SharedMemoryLoader::SharedMemoryLoader(const param::MIRParametrisation& parametr
             }
         }
         else {
-            trace::Timer("SharedMemoryLoader: loading into shared memory", Log::debug());
+            trace::Timer("SharedMemoryLoader: loading into shared memory");
 
             eckit::AutoStdFile file(real);
             ASSERT(std::fread(address_, 1, size_, file) == size_);
@@ -321,10 +323,10 @@ bool SharedMemoryLoader::shared() {
 }
 
 
-static LegendreLoaderBuilder<SharedMemoryLoader> loader1("shared-memory");
-static LegendreLoaderBuilder<SharedMemoryLoader> loader2("shmem");
-static LegendreLoaderBuilder<SharedMemoryLoader> loader3("tmp-shmem");
-static LegendreLoaderBuilder<SharedMemoryLoader> loader5("tmp-shared-memory");
+static const LegendreLoaderBuilder<SharedMemoryLoader> loader1("shared-memory");
+static const LegendreLoaderBuilder<SharedMemoryLoader> loader2("shmem");
+static const LegendreLoaderBuilder<SharedMemoryLoader> loader3("tmp-shmem");
+static const LegendreLoaderBuilder<SharedMemoryLoader> loader5("tmp-shared-memory");
 
 
 }  // namespace legendre
