@@ -27,7 +27,7 @@ namespace matrix {
 FileLoader::FileLoader(const std::string& name, const eckit::PathName& path) :
     MatrixLoader(name, path), buffer_(size_t(path.size())) {
 
-    Log::info() << "Loading matrix from " << path << std::endl;
+    Log::debug() << "Loading matrix from " << path << std::endl;
 
     // Note: buffer size is based on file.size() -- which is assumed to be bigger than the memory footprint
     method::WeightMatrix w(path);
@@ -53,7 +53,7 @@ bool FileLoader::inSharedMemory() const {
 }
 
 
-static MatrixLoaderBuilder<FileLoader> loader("file-io");
+static const MatrixLoaderBuilder<FileLoader> loader("file-io");
 
 
 }  // namespace matrix
