@@ -70,7 +70,7 @@ public:
     const repres::Representation* representation() const;
 
     /// @warning Takes ownership of the vector
-    void update(MIRValuesVector&, size_t which);
+    void update(MIRValuesVector&, size_t which, bool recomputeHasMissing = false);
 
     const MIRValuesVector& values(size_t which) const;
     MIRValuesVector& direct(size_t which);  // Non-const version for direct update (Filter)
