@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_input_ConstantInput_h
-#define mir_input_ConstantInput_h
+#pragma once
 
 #include "mir/input/ArtificialInput.h"
 
@@ -27,7 +26,7 @@ public:
 
     // -- Constructors
 
-    ConstantInput(const param::MIRParametrisation&);
+    ConstantInput(const param::MIRParametrisation& param) : ArtificialInput(param) {}
 
     // -- Destructor
     // None
@@ -68,20 +67,15 @@ protected:
 
 private:
     // -- Members
-
-    double constant_;
+    // None
 
     // -- Methods
     // None
 
     // -- Overridden methods
 
-    // From MIRInput
-    virtual bool sameAs(const MIRInput&) const;
-
     // From ArtificialInput
-    virtual void print(std::ostream&) const;
-    virtual data::MIRValuesVector fill(size_t) const;
+    MIRValuesVector fill(size_t) const override;
 
     // -- Class members
     // None
@@ -96,6 +90,3 @@ private:
 
 }  // namespace input
 }  // namespace mir
-
-
-#endif
