@@ -32,7 +32,7 @@ EmptyInput::~EmptyInput() = default;
 
 
 bool EmptyInput::sameAs(const MIRInput& other) const {
-    auto o = dynamic_cast<const EmptyInput*>(&other);
+    const auto* o = dynamic_cast<const EmptyInput*>(&other);
     return (o != nullptr);
 }
 
@@ -58,10 +58,10 @@ void EmptyInput::print(std::ostream& out) const {
 }
 
 
-void EmptyInput::latitudes(std::vector<double>&) const {}
+void EmptyInput::latitudes(std::vector<double>& /*unused*/) const {}
 
 
-void EmptyInput::longitudes(std::vector<double>&) const {}
+void EmptyInput::longitudes(std::vector<double>& /*unused*/) const {}
 
 
 }  // namespace input
