@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_input_GribAllFileInput_h
-#define mir_input_GribAllFileInput_h
+#pragma once
 
 
 #include <string>
@@ -35,7 +34,7 @@ public:
 
     // -- Destructor
 
-    virtual ~GribAllFileInput();  // Change to virtual if base class
+    ~GribAllFileInput() override;
 
     // -- Convertors
     // None
@@ -83,15 +82,15 @@ private:
 
     // -- Overridden methods
 
-    virtual const param::MIRParametrisation& parametrisation(size_t which) const;
-    virtual data::MIRField field() const;
-    virtual bool next();
+    const param::MIRParametrisation& parametrisation(size_t which) const override;
+    data::MIRField field() const override;
+    bool next() override;
 
-    virtual bool sameAs(const MIRInput& other) const;
-    virtual void print(std::ostream& out) const;
+    bool sameAs(const MIRInput&) const override;
+    void print(std::ostream&) const override;
 
-    virtual grib_handle* gribHandle(size_t which = 0) const;
-    virtual size_t dimensions() const;
+    grib_handle* gribHandle(size_t which = 0) const override;
+    size_t dimensions() const override;
 
     // -- Class members
     // None
@@ -106,6 +105,3 @@ private:
 
 }  // namespace input
 }  // namespace mir
-
-
-#endif
