@@ -41,13 +41,13 @@ const Grid* ClassicPattern::make(const std::string& name) const {
 }
 
 
-std::string ClassicPattern::canonical(const std::string& name, const param::MIRParametrisation&) const {
+std::string ClassicPattern::canonical(const std::string& name, const param::MIRParametrisation& /*unused*/) const {
     ASSERT(name.size() > 1);
     return "N" + name.substr(1);
 }
 
 
-static ClassicPattern __pattern("^[nN][1-9][0-9]*$");
+static const ClassicPattern __pattern("^[nN][1-9][0-9]*$");
 
 
 }  // namespace grid
