@@ -41,13 +41,13 @@ const Grid* RegularPattern::make(const std::string& name) const {
 }
 
 
-std::string RegularPattern::canonical(const std::string& name, const param::MIRParametrisation&) const {
+std::string RegularPattern::canonical(const std::string& name, const param::MIRParametrisation& /*unused*/) const {
     ASSERT(name.size() > 1);
     return "F" + name.substr(1);
 }
 
 
-static RegularPattern __pattern("^[fF][1-9][0-9]*$");
+static const RegularPattern __pattern("^[fF][1-9][0-9]*$");
 
 
 }  // namespace grid
