@@ -22,7 +22,7 @@ namespace key {
 namespace packing {
 
 
-static PackingBuilder<CCSDS> __packing("ccsds", false, true);
+static const PackingBuilder<CCSDS> __packing("ccsds", false, true);
 
 
 CCSDS::CCSDS(const std::string& name, const param::MIRParametrisation& param) : Packing(name, param) {
@@ -35,12 +35,12 @@ CCSDS::CCSDS(const std::string& name, const param::MIRParametrisation& param) :
 }
 
 
-void CCSDS::fill(const repres::Representation*, grib_info& info) const {
+void CCSDS::fill(const repres::Representation* /*unused*/, grib_info& info) const {
     Packing::fill(info, CODES_UTIL_PACKING_TYPE_CCSDS);
 }
 
 
-void CCSDS::set(const repres::Representation*, grib_handle* handle) const {
+void CCSDS::set(const repres::Representation* /*unused*/, grib_handle* handle) const {
     Packing::set(handle, "grid_ccsds");
 }
 
