@@ -20,7 +20,7 @@ namespace key {
 namespace packing {
 
 
-static PackingBuilder<Complex> __packing("complex", "co", true, true);
+static const PackingBuilder<Complex> __packing("complex", "co", true, true);
 
 
 Complex::Complex(const std::string& name, const param::MIRParametrisation& param) : Packing(name, param) {
@@ -30,12 +30,12 @@ Complex::Complex(const std::string& name, const param::MIRParametrisation& param
 }
 
 
-void Complex::fill(const repres::Representation*, grib_info& info) const {
+void Complex::fill(const repres::Representation* /*unused*/, grib_info& info) const {
     Packing::fill(info, gridded() ? CODES_UTIL_PACKING_TYPE_GRID_COMPLEX : CODES_UTIL_PACKING_TYPE_SPECTRAL_COMPLEX);
 }
 
 
-void Complex::set(const repres::Representation*, grib_handle* handle) const {
+void Complex::set(const repres::Representation* /*unused*/, grib_handle* handle) const {
     Packing::set(handle, gridded() ? "grid_complex" : "spectral_complex");
 }
 
