@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_key_style_CustomStyle_h
-#define mir_key_style_CustomStyle_h
+#pragma once
 
 #include "mir/key/style/MIRStyle.h"
 
@@ -32,7 +31,7 @@ public:
 
     // -- Destructor
 
-    virtual ~CustomStyle();
+    ~CustomStyle() override;
 
     // -- Convertors
     // None
@@ -61,7 +60,7 @@ protected:
 
     // -- Overridden methods
 
-    virtual void print(std::ostream&) const;
+    void print(std::ostream&) const override;
 
     // -- Class members
     // None
@@ -78,7 +77,7 @@ private:
 
     // -- Overridden methods
 
-    void prepare(action::ActionPlan&, input::MIRInput&, output::MIROutput&) const;
+    void prepare(action::ActionPlan&, output::MIROutput&) const override;
 
     // -- Class members
     // None
@@ -87,15 +86,10 @@ private:
     // None
 
     // -- Friends
-
-    // friend std::ostream& operator<<(std::ostream& s, const CustomStyle& p)
-    // { p.print(s); return s; }
+    // None
 };
 
 
 }  // namespace style
 }  // namespace key
 }  // namespace mir
-
-
-#endif
