@@ -18,14 +18,14 @@ namespace key {
 namespace truncation {
 
 
-static TruncationBuilder<None> __truncation1("none");
-static TruncationBuilder<None> __truncation2("NONE");
+static const TruncationBuilder<None> __truncation1("none");
+static const TruncationBuilder<None> __truncation2("NONE");
 
 
-None::None(const param::MIRParametrisation& parametrisation, long) : Truncation(parametrisation) {}
+None::None(const param::MIRParametrisation& parametrisation, long /*unused*/) : Truncation(parametrisation) {}
 
 
-bool None::truncation(long&, long) const {
+bool None::truncation(long& /*unused*/, long /*inputTrucation*/) const {
     return false;
 }
 
