@@ -22,7 +22,7 @@ namespace mir {
 namespace lsm {
 
 
-static NoneLSM __lsm_selection("none");
+static const NoneLSM __lsm_selection("none");
 
 
 NoneLSM::NoneLSM(const std::string& name) : LSMSelection(name) {}
@@ -39,13 +39,14 @@ void NoneLSM::print(std::ostream& out) const {
 }
 
 
-Mask* NoneLSM::create(const param::MIRParametrisation&, const repres::Representation&, const std::string&) const {
+Mask* NoneLSM::create(const param::MIRParametrisation& /*unused*/, const repres::Representation& /*unused*/,
+                      const std::string& /*which*/) const {
     return new NoMask();
 }
 
 
-std::string NoneLSM::cacheKey(const param::MIRParametrisation&, const repres::Representation&,
-                              const std::string&) const {
+std::string NoneLSM::cacheKey(const param::MIRParametrisation& /*unused*/, const repres::Representation& /*unused*/,
+                              const std::string& /*which*/) const {
     return "none";
 }
 
