@@ -22,7 +22,7 @@
 #include "mir/util/Log.h"
 #include "mir/util/Mutex.h"
 
-#if defined(mir_HAVE_OMP)
+#if mir_HAVE_OMP
 extern "C" {
 void omp_set_num_threads(int);
 }
@@ -34,7 +34,7 @@ namespace method {
 
 
 Method::Method(const param::MIRParametrisation& params) : parametrisation_(params) {
-#if defined(mir_HAVE_OMP)
+#if mir_HAVE_OMP
     int num_threads = 1;
     if (params.get("parallel-omp-num-threads", num_threads)) {
         omp_set_num_threads(num_threads);
