@@ -75,8 +75,8 @@ MethodWeighted::~MethodWeighted() = default;
 
 void MethodWeighted::print(std::ostream& out) const {
     out << "nonLinear[";
-    auto sep = "";
-    for (auto& n : nonLinear_) {
+    const auto* sep = "";
+    for (const auto& n : nonLinear_) {
         out << sep << (*n);
         sep = ",";
     }
@@ -101,7 +101,7 @@ bool MethodWeighted::sameAs(const Method& other) const {
         return true;
     };
 
-    auto o = dynamic_cast<const MethodWeighted*>(&other);
+    const auto* o = dynamic_cast<const MethodWeighted*>(&other);
     return (o != nullptr) && (lsmWeightAdjustment_ == o->lsmWeightAdjustment_) && (pruneEpsilon_ == o->pruneEpsilon_) &&
            (sameNonLinearities(nonLinear_, o->nonLinear_)) && solver().sameAs(o->solver()) &&
            lsm::LandSeaMasks::sameLandSeaMasks(parametrisation_, o->parametrisation_) && cropping_.sameAs(o->cropping_);
@@ -112,7 +112,7 @@ bool MethodWeighted::sameAs(const Method& other) const {
 void MethodWeighted::createMatrix(context::Context& ctx, const repres::Representation& in,
                                   const repres::Representation& out, WeightMatrix& W, const lsm::LandSeaMasks& masks,
                                   const Cropping& /*cropping*/) const {
-    trace::ResourceUsage usage(std::string("MethodWeighted::createMatrix [") + name() + "]", Log::debug());
+    trace::ResourceUsage usage(std::string("MethodWeighted::createMatrix [") + name() + "]");
 
     computeMatrixWeights(ctx, in, out, W, validateMatrixWeights());
 
@@ -132,7 +132,7 @@ const WeightMatrix& MethodWeighted::getMatrix(context::Context& ctx, const repre
     auto& log = Log::debug();
 
     log << "MethodWeighted::getMatrix " << *this << std::endl;
-    trace::Timer timer("MethodWeighted::getMatrix", Log::debug());
+    trace::Timer timer("MethodWeighted::getMatrix");
 
     double here                   = timer.elapsed();
     const lsm::LandSeaMasks masks = getMasks(in, out);
@@ -305,7 +305,7 @@ void MethodWeighted::execute(context::Context& ctx, const repres::Representation
 
     static bool check_stats = eckit::Resource<bool>("mirCheckStats", false);
 
-    trace::Timer timer("MethodWeighted::execute", Log::debug());
+    trace::Timer timer("MethodWeighted::execute");
     auto& log = Log::debug();
     log << "MethodWeighted::execute" << std::endl;
 
@@ -349,7 +349,7 @@ void MethodWeighted::execute(context::Context& ctx, const repres::Representation
 
         std::ostringstream os;
         os << "Interpolating field (" << Log::Pretty(npts_inp) << " -> " << Log::Pretty(npts_out) << ")";
-        trace::Timer trace(os.str(), Log::debug());
+        trace::Timer trace(os.str());
 
         // compute some statistics on the result
         // This is expensive so we might want to skip it in production code
@@ -375,7 +375,7 @@ void MethodWeighted::execute(context::Context& ctx, const repres::Representation
             auto timing(ctx.statistics().matrixTimer());
             WeightMatrix M(W);  // modifiable matrix copy
 
-            for (auto& n : nonLinear_) {
+            for (const auto& n : nonLinear_) {
                 std::ostringstream str;
                 str << *n;
                 trace::Timer t(str.str());
@@ -497,7 +497,7 @@ void MethodWeighted::hash(eckit::MD5& md5) const {
     md5.add(name());
     md5 << pruneEpsilon_;
     md5 << lsmWeightAdjustment_;
-    for (auto& n : nonLinear_) {
+    for (const auto& n : nonLinear_) {
         n->hash(md5);
     }
 
