@@ -41,7 +41,7 @@ KNearestNeighbours::~KNearestNeighbours() = default;
 
 
 bool KNearestNeighbours::sameAs(const Method& other) const {
-    auto o = dynamic_cast<const KNearestNeighbours*>(&other);
+    const auto* o = dynamic_cast<const KNearestNeighbours*>(&other);
     return (o != nullptr) && pick().sameAs(o->pick()) && distanceWeighting().sameAs(o->distanceWeighting());
 }
 
@@ -59,7 +59,7 @@ void KNearestNeighbours::assemble(util::MIRStatistics& stats, WeightMatrix& W, c
 }
 
 
-void KNearestNeighbours::assemble(util::MIRStatistics&, WeightMatrix& W, const repres::Representation& in,
+void KNearestNeighbours::assemble(util::MIRStatistics& /*unused*/, WeightMatrix& W, const repres::Representation& in,
                                   const repres::Representation& out, const pick::Pick& pick,
                                   const distance::DistanceWeighting& distanceWeighting) const {
     auto& log = Log::debug();
@@ -82,7 +82,7 @@ void KNearestNeighbours::assemble(util::MIRStatistics&, WeightMatrix& W, const r
     std::vector<WeightMatrix::Triplet> triplets;
 
     {
-        trace::ProgressTimer progress("Locating", nbOutputPoints, {"point"}, log);
+        trace::ProgressTimer progress("Locating", nbOutputPoints, {"point"});
         double search = 0;
         double insert = 0;
 
