@@ -22,7 +22,8 @@ namespace distance {
 
 
 struct InverseDistanceWeighting : DistanceWeighting {
-    InverseDistanceWeighting(const param::MIRParametrisation&);
+protected:
+    InverseDistanceWeighting(const param::MIRParametrisation&, double power);
     void operator()(size_t ip, const Point3& point, const std::vector<search::PointSearch::PointValueType>& neighbours,
                     std::vector<WeightMatrix::Triplet>& triplets) const override;
 
