@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_method_knn_pick_DistanceAndNClosest_h
-#define mir_method_knn_pick_DistanceAndNClosest_h
+#pragma once
 
 #include "mir/method/knn/pick/NClosestOrNearest.h"
 #include "mir/method/knn/pick/Pick.h"
@@ -25,13 +24,13 @@ namespace pick {
 
 struct DistanceAndNClosest : Pick {
     DistanceAndNClosest(const param::MIRParametrisation&);
-    void pick(const search::PointSearch&, const Point3&, neighbours_t&) const;
-    size_t n() const;
-    bool sameAs(const Pick&) const;
+    void pick(const search::PointSearch&, const Point3&, neighbours_t&) const override;
+    size_t n() const override;
+    bool sameAs(const Pick&) const override;
 
 private:
-    void print(std::ostream&) const;
-    void hash(eckit::MD5&) const;
+    void print(std::ostream&) const override;
+    void hash(eckit::MD5&) const override;
     NClosestOrNearest nClosest_;
     double distance_;
 };
@@ -41,6 +40,3 @@ private:
 }  // namespace knn
 }  // namespace method
 }  // namespace mir
-
-
-#endif
