@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_method_knn_pick_NClosestOrNearest_h
-#define mir_method_knn_pick_NClosestOrNearest_h
+#pragma once
 
 #include "mir/method/knn/pick/Pick.h"
 
@@ -23,14 +22,15 @@ namespace pick {
 
 
 struct NClosestOrNearest : Pick {
+    NClosestOrNearest(size_t nClosest, double distanceTolerance = 1.);
     NClosestOrNearest(const param::MIRParametrisation&);
-    void pick(const search::PointSearch&, const Point3&, neighbours_t&) const;
-    size_t n() const;
-    bool sameAs(const Pick&) const;
-    void hash(eckit::MD5&) const;
+    void pick(const search::PointSearch&, const Point3&, neighbours_t&) const override;
+    size_t n() const override;
+    bool sameAs(const Pick&) const override;
+    void hash(eckit::MD5&) const override;
 
 private:
-    void print(std::ostream&) const;
+    void print(std::ostream&) const override;
     size_t nClosest_;
     double distanceTolerance_;
     double distanceTolerance2_;
@@ -41,6 +41,3 @@ private:
 }  // namespace knn
 }  // namespace method
 }  // namespace mir
-
-
-#endif
