@@ -21,6 +21,12 @@ namespace eckit {
 class MD5;
 }
 
+namespace mir {
+namespace repres {
+class Representation;
+}
+}  // namespace mir
+
 
 namespace mir {
 namespace method {
@@ -43,6 +49,8 @@ public:
     virtual bool sameAs(const Pick&) const                                            = 0;
     virtual void hash(eckit::MD5&) const                                              = 0;
 
+    virtual void distance(const repres::Representation&) const;
+
 private:
     virtual void print(std::ostream&) const = 0;
 
