@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_netcdf_eckityperCube_h
-#define mir_netcdf_eckityperCube_h
+#pragma once
 
 #include <functional>
 #include <numeric>
@@ -110,11 +109,8 @@ inline  // For speed
 }
 
 
-std::ostream& operator<<(std::ostream& out, const HyperCube& cube);
+std::ostream& operator<<(std::ostream&, const HyperCube&);
 
 
 }  // namespace netcdf
 }  // namespace mir
-
-
-#endif
