@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_netcdf_Step_h
-#define mir_netcdf_Step_h
+#pragma once
 
 #include <iosfwd>
 
@@ -34,12 +33,12 @@ public:
     Step()          = default;
     virtual ~Step() = default;
 
-    virtual int rank() const              = 0;
-    virtual void execute(MergePlan& plan) = 0;
-    virtual bool merge(Step* other);
+    virtual int rank() const         = 0;
+    virtual void execute(MergePlan&) = 0;
+    virtual bool merge(Step*);
 
 private:
-    virtual void print(std::ostream& s) const = 0;
+    virtual void print(std::ostream&) const = 0;
     friend std::ostream& operator<<(std::ostream& s, const Step& v) {
         v.print(s);
         return s;
@@ -54,6 +53,3 @@ struct CompareSteps {
 
 }  // namespace netcdf
 }  // namespace mir
-
-
-#endif
