@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_netcdf_Type_h
-#define mir_netcdf_Type_h
+#pragma once
 
 #include <string>
 
@@ -36,18 +35,18 @@ public:
 
     int code() const { return code_; }
 
-    bool operator==(const Type& other) const;
-    bool operator!=(const Type& other) const;
+    bool operator==(const Type&) const;
+    bool operator!=(const Type&) const;
 
     virtual Value* attributeValue(int nc, int id, const char* name, size_t len, const std::string& path) = 0;
     virtual void save(const Matrix&, int nc, int varid, const std::string& path) const                   = 0;
 
-    virtual bool coordinateOutputVariableMerge(Variable& a, const Variable& b, MergePlan& plan) = 0;
-    virtual bool cellMethodOutputVariableMerge(Variable& a, const Variable& b, MergePlan& plan) = 0;
+    virtual bool coordinateOutputVariableMerge(Variable& a, const Variable& b, MergePlan&) = 0;
+    virtual bool cellMethodOutputVariableMerge(Variable& a, const Variable& b, MergePlan&) = 0;
 
-    virtual void dump(std::ostream& out) const;
-    virtual void dump(std::ostream& out, const Matrix&) const        = 0;
-    virtual void printValues(std::ostream& out, const Matrix&) const = 0;
+    virtual void dump(std::ostream&) const;
+    virtual void dump(std::ostream&, const Matrix&) const        = 0;
+    virtual void printValues(std::ostream&, const Matrix&) const = 0;
 
 
     // -- Class methods
@@ -72,7 +71,7 @@ private:
     Type& operator=(const Type&);
 
     // -- Methods
-    virtual void print(std::ostream& s) const = 0;
+    virtual void print(std::ostream&) const = 0;
 
     // -- Friends
     friend std::ostream& operator<<(std::ostream& s, const Type& v) {
@@ -84,6 +83,3 @@ private:
 
 }  // namespace netcdf
 }  // namespace mir
-
-
-#endif
