@@ -10,8 +10,7 @@
  */
 
 
-#ifndef mir_output_GeoPointsOutput_h
-#define mir_output_GeoPointsOutput_h
+#pragma once
 
 #include "mir/output/MIROutput.h"
 
@@ -36,7 +35,7 @@ public:
 
     // -- Destructor
 
-    virtual ~GeoPointsOutput();
+    ~GeoPointsOutput() override;
 
     // -- Convertors
     // None
@@ -69,8 +68,8 @@ protected:
     // -- Overridden methods
 
     // From MIROutput
-    virtual bool sameParametrisation(const param::MIRParametrisation&, const param::MIRParametrisation&) const;
-    virtual bool printParametrisation(std::ostream&, const param::MIRParametrisation&) const;
+    bool sameParametrisation(const param::MIRParametrisation&, const param::MIRParametrisation&) const override;
+    bool printParametrisation(std::ostream&, const param::MIRParametrisation&) const override;
 
     // -- Class members
     // None
@@ -96,14 +95,9 @@ private:
     // None
 
     // -- Friends
-
-    // friend ostream& operator<<(ostream& s,const GeoPointsOutput& p)
-    // { p.print(s); return s; }
+    // None
 };
 
 
 }  // namespace output
 }  // namespace mir
-
-
-#endif
