@@ -10,8 +10,7 @@
  */
 
 
-#ifndef GribStreamOutput_H
-#define GribStreamOutput_H
+#pragma once
 
 #include "mir/output/GribOutput.h"
 
@@ -36,7 +35,7 @@ public:
 
     // -- Destructor
 
-    ~GribStreamOutput();  // Change to virtual if base class
+    ~GribStreamOutput() override;
 
     // -- Convertors
     // None
@@ -82,7 +81,7 @@ private:
     // -- Overridden methods
     // From MIROutput
 
-    void out(const void* message, size_t length, bool interpolated);
+    void out(const void* message, size_t length, bool interpolated) override;
 
     // -- Class members
     // None
@@ -91,12 +90,9 @@ private:
     // None
 
     // -- Friends
-
-    // friend ostream& operator<<(ostream& s,const GribStreamOutput& p)
-    //	{ p.print(s); return s; }
+    // None
 };
 
 
 }  // namespace output
 }  // namespace mir
-#endif
