@@ -79,12 +79,17 @@ struct OutputFromExtension : public MIROutputFactory {
 
     OutputFromExtension() : MIROutputFactory("extension") {}
 
+    OutputFromExtension(const OutputFromExtension&) = delete;
+    OutputFromExtension(OutputFromExtension&&)      = delete;
+    OutputFromExtension& operator=(const OutputFromExtension&) = delete;
+    OutputFromExtension& operator=(OutputFromExtension&&) = delete;
+
     ~OutputFromExtension() override {
         util::lock_guard<util::recursive_mutex> lock(*ext_mutex);
         m_extensions->clear();
     }
 
-} static _extension;
+} static const _extension;
 
 
 MIROutputFactory::MIROutputFactory(const std::string& name, const std::vector<std::string>& extensions) : name_(name) {
@@ -98,7 +103,7 @@ MIROutputFactory::MIROutputFactory(const std::string& name, const std::vector<st
     ASSERT(m_formats->find(name) == m_formats->end());
     (*m_formats)[name] = this;
 
-    for (auto& ext : extensions) {
+    for (const auto& ext : extensions) {
         ASSERT(!ext.empty());
         if (m_extensions->find(ext) != m_extensions->end()) {
             throw exception::SeriousBug("MIROutputFactory: duplicate extension '" + ext + "'");
@@ -172,7 +177,8 @@ void MIROutput::prepare(const param::MIRParametrisation& param, action::ActionPl
 }
 
 
-void MIROutput::estimate(const param::MIRParametrisation&, api::MIREstimation&, context::Context&) const {
+void MIROutput::estimate(const param::MIRParametrisation& /*unused*/, api::MIREstimation& /*unused*/,
+                         context::Context& /*unused*/) const {
     std::ostringstream oss;
     oss << "MIROutput::estimate not implemented for " << *this;
     throw exception::SeriousBug(oss.str());
