@@ -33,7 +33,8 @@ bool RawOutput::sameAs(const MIROutput& other) const {
 }
 
 
-bool RawOutput::sameParametrisation(const param::MIRParametrisation&, const param::MIRParametrisation&) const {
+bool RawOutput::sameParametrisation(const param::MIRParametrisation& /*unused*/,
+                                    const param::MIRParametrisation& /*unused*/) const {
     NOTIMP;
 }
 
@@ -58,7 +59,7 @@ size_t RawOutput::save(const param::MIRParametrisation& /*param*/, context::Cont
 
     size_ = values.size();
     ASSERT(size_ <= count_);
-    ::memcpy(values_, &values[0], size_ * sizeof(double));
+    std::memcpy(values_, &values[0], size_ * sizeof(double));
 
     return size_ * sizeof(double);
 }
