@@ -12,8 +12,9 @@
 
 #include "mir/param/SameParametrisation.h"
 
-#include <iostream>
-#include "eckit/exception/Exceptions.h"
+#include <ostream>
+
+#include "mir/util/Exceptions.h"
 
 
 namespace mir {
