@@ -52,16 +52,16 @@ Iterator* RotatedClassic::iterator() const {
 }
 
 
-void RotatedClassic::fill(grib_info& info) const {
-    Classic::fill(info);
-    rotation_.fill(info);
+void RotatedClassic::fillGrib(grib_info& info) const {
+    Classic::fillGrib(info);
+    rotation_.fillGrib(info);
     info.grid.grid_type = CODES_UTIL_GRID_SPEC_REDUCED_ROTATED_GG;
 }
 
 
-void RotatedClassic::fill(api::MIRJob& job) const {
-    Classic::fill(job);
-    rotation_.fill(job);
+void RotatedClassic::fillJob(api::MIRJob& job) const {
+    Classic::fillJob(job);
+    rotation_.fillJob(job);
 }
 
 
