@@ -31,6 +31,7 @@
 #include "mir/key/grid/Grid.h"
 #include "mir/param/MIRParametrisation.h"
 #include "mir/repres/Iterator.h"
+#include "mir/util/CheckDuplicatePoints.h"
 #include "mir/util/Domain.h"
 #include "mir/util/Exceptions.h"
 #include "mir/util/Grib.h"
@@ -38,7 +39,7 @@
 #include "mir/util/MeshGeneratorParameters.h"
 #include "mir/util/Types.h"
 
-#if defined(mir_HAVE_ATLAS)
+#if mir_HAVE_ATLAS
 #include "mir/key/grid/ORCAPattern.h"
 #include "mir/repres/other/ORCA.h"
 #endif
@@ -58,7 +59,7 @@ UnstructuredGrid::UnstructuredGrid(const param::MIRParametrisation& parametrisat
     }
     ASSERT(latitudes_.size() == longitudes_.size());
 
-    check("UnstructuredGrid from MIRParametrisation", latitudes_, longitudes_);
+    util::check_duplicate_points("UnstructuredGrid from MIRParametrisation", latitudes_, longitudes_, parametrisation);
 }
 
 
@@ -98,7 +99,7 @@ UnstructuredGrid::UnstructuredGrid(const eckit::PathName& path) {
         }
     }
 
-    check("UnstructuredGrid from " + path.asString(), latitudes_, longitudes_);
+    util::check_duplicate_points("UnstructuredGrid from " + path.asString(), latitudes_, longitudes_);
 }
 
 
@@ -106,7 +107,7 @@ void UnstructuredGrid::save(const eckit::PathName& path, const std::vector<doubl
                             const std::vector<double>& longitudes, bool binary) {
     Log::info() << "UnstructuredGrid::save " << path << std::endl;
 
-    check("UnstructuredGrid save to " + path.asString(), latitudes, longitudes);
+    util::check_duplicate_points("UnstructuredGrid::save to " + path.asString(), latitudes, longitudes);
 
     ASSERT(latitudes.size() == longitudes.size());
     if (binary) {
@@ -133,6 +134,7 @@ UnstructuredGrid::UnstructuredGrid(const std::vector<double>& latitudes, const s
                                    const util::BoundingBox& bbox) :
     Gridded(bbox), latitudes_(latitudes), longitudes_(longitudes) {
     ASSERT(latitudes_.size() == longitudes_.size());
+    util::check_duplicate_points("UnstructuredGrid from arguments", latitudes_, longitudes_);
 }
 
 
@@ -165,19 +167,19 @@ bool UnstructuredGrid::sameAs(const Representation& other) const {
 }
 
 
-void UnstructuredGrid::fill(grib_info& info) const {
+void UnstructuredGrid::fillGrib(grib_info& info) const {
     info.grid.grid_type        = CODES_UTIL_GRID_SPEC_UNSTRUCTURED;
     info.packing.editionNumber = 2;
 }
 
 
-void UnstructuredGrid::fill(api::MIRJob& job) const {
+void UnstructuredGrid::fillJob(api::MIRJob& job) const {
     job.set("latitudes", latitudes_);
     job.set("longitudes", longitudes_);
 }
 
 
-void UnstructuredGrid::fill(util::MeshGeneratorParameters& params) const {
+void UnstructuredGrid::fillMeshGen(util::MeshGeneratorParameters& params) const {
     if (params.meshGenerator_.empty()) {
         params.meshGenerator_ = "delaunay";
     }
@@ -263,30 +265,6 @@ bool UnstructuredGrid::includesSouthPole() const {
 }
 
 
-void UnstructuredGrid::check(const std::string& title, const std::vector<double>& latitudes,
-                             const std::vector<double>& longitudes) {
-    static bool checkDuplicatePoints = eckit::Resource<bool>("$MIR_CHECK_DUPLICATE_POINTS", true);
-    if (!checkDuplicatePoints) {
-        return;
-    }
-
-    ASSERT(latitudes.size() == longitudes.size());
-    ASSERT(!longitudes.empty());
-
-    std::set<std::pair<double, double>> seen;
-    size_t count = latitudes.size();
-
-    for (size_t i = 0; i < count; ++i) {
-        std::pair<double, double> p(latitudes[i], longitudes[i]);
-        if (!seen.insert(p).second) {
-            std::ostringstream oss;
-            oss << title << ": duplicate point lat=" << latitudes[i] << ", lon=" << longitudes[i];
-            throw exception::UserError(oss.str());
-        }
-    }
-}
-
-
 bool UnstructuredGrid::extendBoundingBoxOnIntersect() const {
     return false;
 }
@@ -301,7 +279,7 @@ static const RepresentationBuilder<UnstructuredGrid> unstructured_grid("unstruct
 
 template <>
 Representation* RepresentationBuilder<other::UnstructuredGrid>::make(const param::MIRParametrisation& param) {
-#if defined(mir_HAVE_ATLAS)
+#if mir_HAVE_ATLAS
     // specially-named unstructured grids
     std::string grid;
     if (param.get("grid", grid)) {
