@@ -34,11 +34,14 @@ public:
 
     // -- Constructors
 
-    UnstructuredGrid(const eckit::PathName&);
-    UnstructuredGrid(const param::MIRParametrisation&);
+    explicit UnstructuredGrid(const eckit::PathName&);
+    explicit UnstructuredGrid(const param::MIRParametrisation&);
     UnstructuredGrid(const std::vector<double>& latitudes, const std::vector<double>& longitudes,
                      const util::BoundingBox& = util::BoundingBox());
 
+    UnstructuredGrid(const UnstructuredGrid&) = delete;
+    UnstructuredGrid(UnstructuredGrid&&)      = delete;
+
     // -- Destructor
 
     ~UnstructuredGrid() override;
@@ -47,16 +50,15 @@ public:
     // None
 
     // -- Operators
-    // None
+
+    void operator=(const UnstructuredGrid&)  = delete;
+    void operator=(const UnstructuredGrid&&) = delete;
 
     // -- Methods
 
     static void save(const eckit::PathName&, const std::vector<double>& latitudes,
                      const std::vector<double>& longitudes, bool binary);
 
-    static void check(const std::string& title, const std::vector<double>& latitudes,
-                      const std::vector<double>& longitudes);
-
     // -- Overridden methods
 
 
@@ -96,9 +98,9 @@ private:
 
     // -- Overridden methods
 
-    void fill(grib_info&) const override;
-    void fill(api::MIRJob&) const override;
-    void fill(util::MeshGeneratorParameters&) const override;
+    void fillGrib(grib_info&) const override;
+    void fillJob(api::MIRJob&) const override;
+    void fillMeshGen(util::MeshGeneratorParameters&) const override;
 
     atlas::Grid atlasGrid() const override;
     void validate(const MIRValuesVector&) const override;
