@@ -64,7 +64,7 @@ private:
 
     // -- Overridden methods
 
-    void fill(grib_info&) const override;
+    void fillGrib(grib_info&) const override;
     const Representation* croppedRepresentation(const util::BoundingBox&) const override;
 
     // -- Class members
