@@ -69,7 +69,7 @@ bool SphericalHarmonics::includesSouthPole() const {
 }
 
 
-void SphericalHarmonics::fill(grib_info& info) const {
+void SphericalHarmonics::fillGrib(grib_info& info) const {
     // See copy_spec_from_ksec.c in libemos for info
 
     info.grid.grid_type  = CODES_UTIL_GRID_SPEC_SH;
@@ -83,7 +83,7 @@ void SphericalHarmonics::fill(grib_info& info) const {
 }
 
 
-void SphericalHarmonics::fill(api::MIRJob& job) const {
+void SphericalHarmonics::fillJob(api::MIRJob& job) const {
     job.set("resol", truncation_);
 }
 
