@@ -89,8 +89,8 @@ private:
 
     // -- Overridden methods
 
-    void fill(grib_info&) const override;
-    void fill(api::MIRJob&) const override;
+    void fillGrib(grib_info&) const override;
+    void fillJob(api::MIRJob&) const override;
     void estimate(api::MIREstimation&) const override;
     std::string factory() const override;
 
