@@ -15,23 +15,20 @@
 #include <map>
 #include <ostream>
 
-#include "eckit/exception/Exceptions.h"
-#include "eckit/log/Log.h"
-#include "eckit/thread/AutoLock.h"
-#include "eckit/thread/Mutex.h"
-
-#include "mir/config/LibMir.h"
+#include "mir/util/Exceptions.h"
+#include "mir/util/Log.h"
+#include "mir/util/Mutex.h"
 
 
 namespace mir {
 namespace stats {
 
 
-static eckit::Mutex* local_mutex                    = nullptr;
+static util::recursive_mutex* local_mutex           = nullptr;
 static std::map<std::string, ComparatorFactory*>* m = nullptr;
-static pthread_once_t once                          = PTHREAD_ONCE_INIT;
+static util::once_flag once;
 static void init() {
-    local_mutex = new eckit::Mutex();
+    local_mutex = new util::recursive_mutex();
     m           = new std::map<std::string, ComparatorFactory*>();
 }
 
@@ -44,12 +41,11 @@ Comparator::~Comparator() = default;
 
 
 ComparatorFactory::ComparatorFactory(const std::string& name) : name_(name) {
-    pthread_once(&once, init);
-
-    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
+    util::call_once(once, init);
+    util::lock_guard<util::recursive_mutex> lock(*local_mutex);
 
     if (m->find(name) != m->end()) {
-        throw eckit::SeriousBug("ComparatorFactory: duplicate '" + name + "'");
+        throw exception::SeriousBug("ComparatorFactory: duplicate '" + name + "'");
     }
 
     ASSERT(m->find(name) == m->end());
@@ -58,14 +54,15 @@ ComparatorFactory::ComparatorFactory(const std::string& name) : name_(name) {
 
 
 ComparatorFactory::~ComparatorFactory() {
-    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
+    util::lock_guard<util::recursive_mutex> lock(*local_mutex);
+
     m->erase(name_);
 }
 
 
 void ComparatorFactory::list(std::ostream& out) {
-    pthread_once(&once, init);
-    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
+    util::call_once(once, init);
+    util::lock_guard<util::recursive_mutex> lock(*local_mutex);
 
     const char* sep = "";
     for (auto& j : *m) {
@@ -78,15 +75,15 @@ void ComparatorFactory::list(std::ostream& out) {
 
 Comparator* ComparatorFactory::build(const std::string& name, const param::MIRParametrisation& param1,
                                      const param::MIRParametrisation& param2) {
-    pthread_once(&once, init);
-    eckit::AutoLock<eckit::Mutex> lock(local_mutex);
+    util::call_once(once, init);
+    util::lock_guard<util::recursive_mutex> lock(*local_mutex);
 
-    eckit::Log::debug<LibMir>() << "ComparatorFactory: looking for '" << name << "'" << std::endl;
+    Log::debug() << "ComparatorFactory: looking for '" << name << "'" << std::endl;
 
     auto j = m->find(name);
     if (j == m->end()) {
-        list(eckit::Log::error() << "No ComparatorFactory '" << name << "', choices are:");
-        throw eckit::SeriousBug("No ComparatorFactory '" + name + "'");
+        list(Log::error() << "ComparatorFactory: unknown '" << name << "', choices are: ");
+        throw exception::SeriousBug("ComparatorFactory: unknown '" + name + "'");
     }
 
     return j->second->make(param1, param2);
