@@ -13,6 +13,8 @@
 #include "mir/util/MIRStatistics.h"
 
 #include <sstream>
+#include <utility>
+#include <vector>
 
 #include "eckit/log/JSON.h"
 #include "eckit/serialisation/Stream.h"
@@ -22,63 +24,59 @@ namespace mir {
 namespace util {
 
 
-static const char* all_caches[] = {"mirBitmap", "mirArea", "mirCoefficient", "mirMatrix", "mirMesh", nullptr};
+static const std::vector<std::string> all_caches{"mirBitmap", "mirArea", "mirCoefficient", "mirMatrix", "mirMesh"};
 
 
-static const char* all_timings[] = {"crop",          "Time in area-crop",
-                                    "frame",         "Time in extracting frames",
-                                    "globalise",     "Time in extending to globe",
-                                    "bitmap",        "Time applying bitmaps",
-                                    "coefficient",   "Time loading/building coeff.",
-                                    "sh2grid",       "Time in SH to grid transform",
-                                    "grid2grid",     "Time in grid to grid interp.",
-                                    "vod2uv",        "Time in VO/D to U/V",
-                                    "computeMatrix", "Time compute matrices",
-                                    "matrix",        "Time matrix multiply",
-                                    "loadCoeff",     "Time loading coefficients",
-                                    "createCoeff",   "Time creating coefficients",
-                                    "calc",          "Time in basic computations",
-                                    "nabla",         "Time in nabla calculations",
-                                    "save",          "Time saving",
-                                    "gribEncoding",  "Time in GRIB encoding",
-                                    "gribDecoding",  "Time in GRIB decoding",
-                                    nullptr};
+static const std::vector<std::pair<std::string, std::string>> all_timings{
+    {"crop", "Time in area-crop"},
+    {"frame", "Time in extracting frames"},
+    {"globalise", "Time in extending to globe"},
+    {"bitmap", "Time applying bitmaps"},
+    {"coefficient", "Time loading/building coeff."},
+    {"sh2grid", "Time in SH to grid transform"},
+    {"grid2grid", "Time in grid to grid interp."},
+    {"vod2uv", "Time in VO/D to U/V"},
+    {"computeMatrix", "Time compute matrices"},
+    {"matrix", "Time matrix multiply"},
+    {"loadCoeff", "Time loading coefficients"},
+    {"createCoeff", "Time creating coefficients"},
+    {"calc", "Time in basic computations"},
+    {"nabla", "Time in nabla calculations"},
+    {"save", "Time saving"},
+    {"gribEncoding", "Time in GRIB encoding"},
+    {"gribDecoding", "Time in GRIB decoding"}};
 
 
 MIRStatistics::MIRStatistics() {
-    for (size_t i = 0; all_caches[i] != nullptr;) {
-        caches_.insert({all_caches[i++], {}});
+    for (const auto& c : all_caches) {
+        caches_.insert({c, {}});
     }
 
-    for (size_t i = 0; all_timings[i] != nullptr;) {
-        std::string key  = all_timings[i++];
-        std::string desc = all_timings[i++];
-        timings_.insert({key, {}});
-        descriptions_[key] = desc;
+    for (const auto& td : all_timings) {
+        timings_.insert({td.first, {}});
+        descriptions_[td.first] = td.second;
     }
 }
 
 
 MIRStatistics::MIRStatistics(eckit::Stream& s) {
-    for (size_t i = 0; all_caches[i] != nullptr;) {
-        caches_.insert({all_caches[i++], s});
+    for (const auto& c : all_caches) {
+        caches_.insert({c, s});
     }
 
-    for (size_t i = 0; all_timings[i] != nullptr;) {
-        std::string key  = all_timings[i++];
-        std::string desc = all_timings[i++];
-        s >> timings_[key];
-        descriptions_[key] = desc;
+    for (const auto& td : all_timings) {
+        s >> timings_[td.first];
+        descriptions_[td.first] = td.second;
     }
 }
 
 
 void MIRStatistics::encode(eckit::Stream& s) const {
-    for (auto& cache : caches_) {
+    for (const auto& cache : caches_) {
         s << cache.second;
     }
 
-    for (auto& tim : timings_) {
+    for (const auto& tim : timings_) {
         s << tim.second;
     }
 }
@@ -87,13 +85,13 @@ void MIRStatistics::encode(eckit::Stream& s) const {
 void MIRStatistics::json(eckit::JSON& j) const {
     j.startObject();
 
-    for (auto& cache : caches_) {
+    for (const auto& cache : caches_) {
         std::ostringstream s;
         s << cache.second.footprint_;
         j << cache.first << s.str();
     }
 
-    for (auto& tim : timings_) {
+    for (const auto& tim : timings_) {
         j << tim.first << tim.second.elapsed_;
     }
 
@@ -128,11 +126,11 @@ MIRStatistics& MIRStatistics::operator/=(size_t n) {
 
 
 void MIRStatistics::report(std::ostream& out, const char* indent) const {
-    for (auto& cache : caches_) {
+    for (const auto& cache : caches_) {
         cache.second.report(cache.first.c_str(), out, indent);
     }
 
-    for (auto& tim : timings_) {
+    for (const auto& tim : timings_) {
         auto description = descriptions_.at(tim.first);
         reportTime(out, description.c_str(), tim.second, indent);
     }
@@ -140,8 +138,8 @@ void MIRStatistics::report(std::ostream& out, const char* indent) const {
 
 
 void MIRStatistics::csvHeader(std::ostream& out) const {
-    auto sep = "";
-    for (auto& tim : timings_) {
+    const auto* sep = "";
+    for (const auto& tim : timings_) {
         out << sep << tim.first;
         sep = ",";
     }
@@ -149,8 +147,8 @@ void MIRStatistics::csvHeader(std::ostream& out) const {
 
 
 void MIRStatistics::csvRow(std::ostream& out) const {
-    auto sep = "";
-    for (auto& tim : timings_) {
+    const auto* sep = "";
+    for (const auto& tim : timings_) {
         out << sep << tim.second;
         sep = ", ";
     }
