@@ -20,10 +20,11 @@
 #include "mir/util/Log.h"
 
 
-using namespace mir;
+namespace mir {
+namespace tools {
 
 
-struct MIRFormula : tools::MIRTool {
+struct MIRFormula : MIRTool {
     using MIRTool::MIRTool;
 
     void usage(const std::string& tool) const override {
@@ -32,11 +33,11 @@ struct MIRFormula : tools::MIRTool {
                     << tool << std::endl;
     }
 
-    void execute(const eckit::option::CmdArgs&) override;
+    void execute(const eckit::option::CmdArgs& args) override;
 };
 
 
-void MIRFormula::execute(const eckit::option::CmdArgs&) {
+void MIRFormula::execute(const eckit::option::CmdArgs& /*args*/) {
     // std::istringstream in("sqrt(-(-2 + 3 - 4   - 5*10/2))");
     std::istringstream in("2 ^ 10");
     util::FormulaParser p(in);
@@ -53,7 +54,11 @@ void MIRFormula::execute(const eckit::option::CmdArgs&) {
 }
 
 
+}  // namespace tools
+}  // namespace mir
+
+
 int main(int argc, char** argv) {
-    MIRFormula tool(argc, argv);
+    mir::tools::MIRFormula tool(argc, argv);
     return tool.start();
 }
