@@ -108,7 +108,7 @@ CASE("ECMWFStyle") {
         const action::FormulaAction CORRECT_ACTION(p4);
 
 
-#if defined(mir_HAVE_ATLAS)
+#if mir_HAVE_ATLAS
         for (bool input_gridded : _yes_no) {
 #else
         for (bool input_gridded : {true}) {
